(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3106458,      47533]*)
(*NotebookOutlinePosition[   3107975,      47580]*)
(*  CellTagsIndexPosition[   3107931,      47576]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Blind Restoration of Astronomical Images", "Title",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Luca Caucci\n",
  StyleBox["email: caucci@cs.unibo.it", "Address"],
  "\n\nGiulia Spaletta\n",
  StyleBox["email: spaletta@dm.unibo.it\n", "Address"],
  "\n",
  StyleBox["Department of Mathematics,\nUniversity of Bologna,\nPiazza di \
Porta S. Donato, 5,\nI\[Dash]40127 Bologna, ITALY.", "Address"]
}], "Author",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Image restoration is of considerable interest in numerous scientific \
applications. When the image formation system is space invariant and linear, \
the blurred noise\[Dash]free image can be expressed as the convolution of the \
original image with a blurring function: if the latter is known, then the \
Fast Fourier Transform can be used to efficiently compute convolutions. The \
algorithm presented here tries to remove the blur, using ",
  StyleBox["a priori", "TBI"],
  " constraints, without the knowledge of the blurring function. This \
approach is often referred to as ",
  StyleBox["Blind Deconvolution and finds useful applications, in particular, \
in ", "TBI"],
  "astronomical imaging",
  StyleBox[", in which the ", "TBI"],
  "atmosphere of the Earth and the instruments of observation constitute \
sources of distortion and aberration that cannot be quantified in advance."
}], "Abstract",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["Introduction", "SectionFirst"],

Cell[TextData[{
  "We briefly describe the image restoration problem from a mathematical \
point of view considering, for simplicity, monodimensional (1D) images; for a \
more detailed description refer for example to [1, 2].\nLet ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{" ", 
              StyleBox[" ",
                FontWeight->"Bold"]}]], 
          RowBox[{
            StyleBox["f",
              "TB",
              FontWeight->"Bold"], "(", "x", ")"}]}], TraditionalForm]]],
  " be the image to be reconstructed. The observed continuous 1D image ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                RowBox[{"g", 
                  StyleBox[" ",
                    "TB"]}], "~"],
              FontWeight->"Bold"], \((x)\)}]}], TraditionalForm]]],
  " can be written as:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            OverscriptBox[
              RowBox[{"g", 
                StyleBox[" ",
                  "TB"]}], "~"],
            FontWeight->"Bold"], \((x)\)}], "  ", "=", 
        " \[NegativeThinSpace]\[NegativeThinSpace] ", 
        RowBox[{
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["h",
                  "TB",
                  FontWeight->"Bold"], " ", "\[Star]", 
                StyleBox[
                  RowBox[{" ", 
                    StyleBox[" ",
                      FontWeight->"Bold"]}]], 
                StyleBox["f",
                  "TB",
                  FontWeight->"Bold"]}], ")"}], \((x)\)}], " ", "+", " ", 
          RowBox[{
            StyleBox["\[Delta]",
              FontWeight->"Bold"], \((x)\)}]}]}], 
      TextForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"=", 
        RowBox[{
          RowBox[{
            StyleBox["g",
              FontWeight->"Bold"], \((x)\)}], " ", "+", " ", 
          RowBox[{
            StyleBox["\[Delta]",
              FontWeight->"Bold"], \((x)\)}]}]}], 
      TextForm]}], "NumberedEquation"],

Cell[TextData[{
  "in which \[Star] denotes the convolution operator, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["h",
            "TB",
            FontWeight->"Bold"], "(", "x", ")"}], TraditionalForm]]],
  " is a linear and space invariant blurring function, also known as ",
  StyleBox["point spread function",
    FontSlant->"Italic"],
  " (PSF), ",
  StyleBox["\[Delta]",
    FontWeight->"Bold"],
  "(x) represents randomly distributed noise and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["g",
            FontWeight->"Bold"], "(", "x", ")"}], TraditionalForm]]],
  " is the observed blurred noise\[Dash]free image. In a computer system \
images are discretized and stored as real vectors ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox["f",
            "TB"]}], TraditionalForm]],
    FontWeight->"Bold"],
  StyleBox[", ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            RowBox[{"g", 
              StyleBox[" ",
                "TB"]}], "~"],
          FontWeight->"Bold"], TraditionalForm]],
    FontWeight->"Bold"],
  StyleBox[", ",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB",
          FontWeight->"Bold"], TraditionalForm]],
    FontWeight->"Bold"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Delta]",
          "TB"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["g",
          "TB"], TraditionalForm]]],
  ", all of length ",
  Cell[BoxData[
      \(TraditionalForm\`2  m\  + \ n\)]],
  ". \nZero-padding of vectors is needed, in a convolution, in order to avoid \
overlapping; ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["f",
            "TB",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB",
          FontWeight->"Bold"], TraditionalForm]],
    FontWeight->"Bold"],
  " are obtained as ",
  StyleBox["extended forms",
    FontSlant->"Italic"],
  " of real vectors ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicF]",
          "TB",
          FontWeight->"Bold"], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            "TB"], 
          StyleBox["\[GothicH]",
            "TB",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2\ m\  + \ 1\)]],
  " respectively:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox["f",
              "TB"], " ", "=", " ", 
            RowBox[{
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {\(0\_\(m\ \[Times]\ n\)\)},
                    {\(I\_n\)},
                    {\(0\_\(m\ \[Times]\ n\)\)}
                    }], "\[NegativeThinSpace]", ")"}], " ", 
              StyleBox["\[GothicF]",
                FontWeight->"Bold"]}]}], 
          StyleBox[",",
            FontWeight->"Bold"], "        ", 
          RowBox[{
            StyleBox["h",
              "TB",
              FontWeight->"Bold"], 
            StyleBox[" ",
              "TB"], "=", " ", 
            RowBox[{
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {\(0\_\(\((m\  + \ 1)\)\ \[Times]\ m\)\), \(I\_\(m\  + \ 
                            1\)\)},
                    {\(0\_\(\((n\  - \ 1)\)\ \[Times]\ 
                            m\)\), \(0\_\(\((n\  - \ 
                                1)\)\ \[Times]\ \((m\  + \ 1)\)\)\)},
                    {\(I\_m\), \(0\_\(m\ \[Times]\ \((m\  + \ 1)\)\)\)}
                    }], "\[NegativeThinSpace]", ")"}], 
              StyleBox[
                RowBox[{" ", 
                  StyleBox[" ",
                    "TB"]}]], 
              RowBox[{
                StyleBox["\[GothicH]",
                  FontWeight->"Bold"], "."}]}]}]}]}], 
      TextForm]], "DisplayFormula"],

Cell[TextData[{
  "The integers ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "  are called the ",
  StyleBox["support",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["f",
            "TB",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB",
          FontWeight->"Bold"], TraditionalForm]],
    FontWeight->"Bold"],
  ", respectively. "
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Given ",
  Cell[BoxData[
      FormBox[
        StyleBox["g",
          "TB"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB",
          FontWeight->"Bold"], TraditionalForm]]],
  " and using the fact that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["g",
            "TB"], " ", "=", 
          StyleBox[" ",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["f",
              "TB",
              FontWeight->"Bold"], " ", "\[Star]", " ", 
            StyleBox["h",
              "TB",
              FontWeight->"Bold"], " "}]}], TraditionalForm]]],
  ", it is possible to express the original image ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  "  as a discrete deconvolution that can be computed efficiently using the \
Fourier transforms:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["f",
          FontWeight->"Bold"], "=", " ", 
        RowBox[{\(1\/\@\(2\ m\  + \ n\)\), " ", "IFT", " ", 
          RowBox[{"(", 
            RowBox[{"FFT", 
              RowBox[{
                RowBox[{"(", 
                  StyleBox["g",
                    "TB"], ")"}], " ", 
                StyleBox["/",
                  "TB"], " ", "FT"}], 
              RowBox[{"(", 
                StyleBox[
                  FormBox[
                    StyleBox["h",
                      "TB",
                      FontWeight->"Bold"],
                    "TraditionalForm"],
                  FontWeight->"Bold"], ")"}]}], ")"}]}]}], 
      TextForm]], "NumberedEquation"],

Cell[TextData[{
  "in which ",
  Cell[BoxData[
      \(TraditionalForm\`FT\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`IFT\)]],
  " denote the direct and inverse discrete Fourier transforms, while the \
symbol ",
  StyleBox["/", "TB"],
  " denotes the componentwise division of two vectors."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "In a practical case the noise ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Delta]",
          "TB"], TraditionalForm]]],
  " is not known and we have to consider ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            RowBox[{"g", 
              StyleBox[" ",
                "TB"]}], "~"],
          FontWeight->"Bold"], TraditionalForm]]],
  ", instead of ",
  Cell[BoxData[
      FormBox[
        StyleBox["g",
          "TB"], TraditionalForm]]],
  ", in (2).  By the linearity property of the Fourier transform [1], we \
have"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          OverscriptBox[
            StyleBox[\(\(f\)\(\ \)\),
              "TB"], "~"], " ", "=", " ", 
          RowBox[{\(1\/\@\(2\ m\  + \ n\)\), "  ", "IFT", 
            RowBox[{"(", 
              RowBox[{"FT", 
                RowBox[{
                  RowBox[{"(", 
                    StyleBox[
                      OverscriptBox[
                        RowBox[{"g", 
                          StyleBox[" ",
                            "TB"]}], "~"],
                      FontWeight->"Bold"], ")"}], " ", 
                  StyleBox["/",
                    "TB"], " ", "FT"}], 
                RowBox[{"(", 
                  StyleBox[
                    FormBox[
                      StyleBox["h",
                        "TB",
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], ")"}]}], ")"}]}]}], 
        "\[IndentingNewLine]"}], TextForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"              ", 
        RowBox[{"=", " ", 
          RowBox[{\(1\/\@\(2\ m\  + \ n\)\), "  ", "IFT", 
            RowBox[{"(", 
              RowBox[{"FT", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["g",
                        "TB"], 
                      StyleBox["+",
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontTracking->"Plain",
                        FontVariations->{"Underline"->False,
                        "Outline"->False,
                        "Shadow"->False,
                        "StrikeThrough"->False,
                        "Masked"->False,
                        "CompatibilityType"->0,
                        "RotationAngle"->0}], 
                      StyleBox["\[Delta]",
                        "TB"]}], ")"}], " ", 
                  StyleBox["/",
                    "TB"], " ", "FT"}], 
                RowBox[{"(", 
                  StyleBox[
                    FormBox[
                      StyleBox["h",
                        "TB",
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], ")"}]}], ")"}]}]}], 
        "\[IndentingNewLine]"}], TextForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"               ", 
        RowBox[{"=", 
          RowBox[{
            FormBox[
              StyleBox["f",
                FontWeight->"Bold"],
              "TraditionalForm"], "+", " ", 
            RowBox[{\(1\/\@\(2\ m\  + \ n\)\), "   ", "IFT", " ", 
              RowBox[{"(", 
                RowBox[{"FT", 
                  RowBox[{
                    RowBox[{"(", 
                      StyleBox["\[Delta]",
                        "TB"], ")"}], " ", 
                    StyleBox["/",
                      "TB"], " ", "FT"}], 
                  RowBox[{"(", 
                    StyleBox[
                      FormBox[
                        StyleBox["h",
                          "TB",
                          FontWeight->"Bold"],
                        "TraditionalForm"],
                      FontWeight->"Bold"], ")"}]}], ")"}]}]}]}]}], 
      TextForm]}], "DisplayFormula"],

Cell[TextData[{
  "in which ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["f",
              FontWeight->"Bold"], "~"], " "}], TraditionalForm]]],
  " is a vector, real and of length ",
  StyleBox["2 m + n",
    FontSlant->"Italic"],
  " , storing the image restored from the observed blurred and noisy image ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            RowBox[{"g", 
              StyleBox[" ",
                "TB"]}], "~"],
          FontWeight->"Bold"], TraditionalForm]]],
  ".\nIf some of the components of FT(",
  StyleBox["h",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ")",
  StyleBox["  ", "DisplayFormula"],
  "are much smaller in magnitude than the corresponding components of FT(",
  StyleBox["\[Delta]",
    FontWeight->"Bold"],
  "), then some components of the error ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["f",
              "TB"], "~"], "-", 
          StyleBox["f",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " can be very large, leading to noise amplification in the restored image. \
Regularization methods [2] are often used to face this problem, by giving low \
weight or even ignoring those components of ",
  StyleBox["h",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "  from which noise amplification may stem."
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blind Deconvolution", "Section"],

Cell[TextData[{
  StyleBox["Blind deconvolution",
    FontSlant->"Italic"],
  " refers to the estimation of both the original image ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  " and the PSF  ",
  StyleBox["h",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "  from the observed image ",
  Cell[BoxData[
      FormBox[
        FormBox[
          StyleBox[
            OverscriptBox[
              RowBox[{"g", 
                StyleBox[" ",
                  "TB"]}], "~"],
            FontWeight->"Bold"],
          "TraditionalForm"], TraditionalForm]]],
  ". This is harder than the so called ",
  StyleBox["classical deconvolution",
    FontSlant->"Italic"],
  " in which  ",
  StyleBox["h",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  " is known.\nDue to the lack of information on the PSF, blind image \
restoration algorithms generally require the introduction of ",
  StyleBox["a priori", "TI"],
  " information. \nThe method presented here assumes the knowledge of the \
support ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " of ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  " (when the exact support is not known, it must be estimated from ",
  Cell[BoxData[
      FormBox[
        FormBox[
          StyleBox[
            OverscriptBox[
              RowBox[{"g", 
                StyleBox[" ",
                  "TB"]}], "~"],
            FontWeight->"Bold"],
          "TraditionalForm"], TraditionalForm]]],
  ") and  imposes constraints of"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
non\[Dash]negativity and support of the image;\
\>", "BulletedList",
  TextAlignment->Left,
  TextJustification->1],

Cell["noise amplification;", "BulletedList",
  TextAlignment->Left,
  TextJustification->1],

Cell["conservation of the image energy;", "BulletedList",
  TextAlignment->Left,
  TextJustification->1],

Cell["support of the PSF.", "BulletedList",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "By enforcing these constraints (suitably weighted), a real vector ",
  StyleBox["\[GothicS]",
    FontWeight->"Bold"],
  " is computed that has dimension ",
  Cell[BoxData[
      \(TraditionalForm\`2\ p\  + \ 1\  \[LessEqual] \ 2\ m\  + \ n\)]],
  ". Then a",
  StyleBox[" real vector",
    FontVariations->{"CompatibilityType"->0}],
  " ",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["s ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " of length",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[\(2\ m\  + \ n\),
          "DisplayFormula",
          FontSlant->"Italic"]}]]],
  " (the ",
  StyleBox["extended form of",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" ",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\[GothicS]", "DisplayFormula",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  ") is obtained via an ",
  StyleBox["extension matrix ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox["Z",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], TraditionalForm]]],
  " as follows:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["s",
          FontWeight->"Bold"], 
        StyleBox[" ",
          "TB"], "=", " ", 
        RowBox[{
          RowBox[{
            RowBox[{"(", " \[NegativeThinSpace]", GridBox[{
                  {\(0\_\(\((p\  + \ 1)\)\ \[Times]\ p\)\), \(I\_\(p\  + \ 
                          1\)\)},
                  {\(0\_\(\((q\  - \ 
                              1)\)\(\ \)\(\[Times]\)\(\ \)\(p\)\(\ \ \ \
\)\)\), \(0\_\(\((q\  - \ 1)\)\ \[Times]\ \((p\  + \ 1)\)\)\)},
                  {\(I\_p\), \(0\_\(p\ \[Times]\ \((p\  + \ 1)\)\)\)}
                  }], "\[NegativeThinSpace]", ")"}], " ", 
            StyleBox["\[GothicS]",
              "TB"]}], 
          StyleBox[" ",
            "TB"], "=", 
          RowBox[{
            StyleBox["Z",
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}], " ", 
            StyleBox[\(\(\[GothicS]\)\(.\)\),
              "TB"]}]}]}], TextForm]], "NumberedEquation"],

Cell[TextData[{
  "in which ",
  Cell[BoxData[
      \(TraditionalForm\`q\  = \ \((2\ m\  + \ n)\)\  - \ 2\ p\)]],
  ". The integer ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is called the ",
  StyleBox["support",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\(s\)\(\ \)\),
          FontWeight->"Bold"], TraditionalForm]]],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "The vector",
  StyleBox[" ",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\[GothicS]", "DisplayFormula",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " is referred to as ",
  StyleBox["inverse filter ",
    FontSlant->"Italic"],
  " because its ",
  StyleBox["extended form",
    FontVariations->{"CompatibilityType"->0}],
  " ",
  StyleBox["s",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " represents the inverse of the PSF with respect to the convolution \
operator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          FormBox[
            RowBox[{
              StyleBox["s",
                FontWeight->"Bold"], " "}],
            "TraditionalForm"],
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{\(1\/\(2\ m\  + \ n\)\), " ", "IFT", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox["e",
                  "TB"], " ", 
                StyleBox["/",
                  "TB"], " ", "FT"}], 
              RowBox[{"(", 
                FormBox[
                  StyleBox["h",
                    FontWeight->"Bold"],
                  "TraditionalForm"], ")"}]}], ")"}]}]}], 
      TextForm]], "NumberedEquation"],

Cell[TextData[{
  "in which ",
  Cell[BoxData[
      FormBox[
        StyleBox["e",
          "TB"], TraditionalForm]]],
  " is the unit vector of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\ m\  + \ n\)]],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "Given ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            RowBox[{"g", 
              StyleBox[" ",
                "TB"]}], "~"],
          FontWeight->"Bold"], TraditionalForm]]],
  " and computed ",
  StyleBox["s",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " (from ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicS]",
          "TB"], TraditionalForm]]],
  "), the restored image ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["f",
              "TB"], "~"], " "}], TraditionalForm]]],
  " can finally be expressed as a convolution [1] and efficiently computed \
as:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        OverscriptBox[
          StyleBox["f",
            "TB"], "~"], " ", "=", " ", 
        RowBox[{\(\@\(2\ m\  + \ n\)\), "  ", "IFT", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"FT", 
                RowBox[{"(", 
                  StyleBox[
                    FormBox[
                      StyleBox[
                        OverscriptBox[
                          RowBox[{"g", 
                            StyleBox[" ",
                              "TB"]}], "~"],
                        FontWeight->"Bold"],
                      "TraditionalForm"],
                    FontWeight->"Bold"], ")"}], " ", "\[Times]", " ", "FT", 
                RowBox[{"(", 
                  StyleBox[
                    FormBox[
                      RowBox[{
                        StyleBox["s",
                          FontWeight->"Bold"], " "}],
                      "TraditionalForm"],
                    FontWeight->"Bold"], ")"}]}], ")"}], "."}]}]}], 
      TextForm]], "NumberedEquation"],

Cell[TextData[{
  "The blind deconvolution solver outlined here is called ",
  StyleBox["Non\[Dash]negativity, Support and PSF Constrained Recursive \
Inverse Filter",
    FontSlant->"Italic"],
  "  (NSH\[Dash]RIF).  It represents a modification of two other methods, \
known in the literature: NAS\[Dash]RIF [3] and NSR\[Dash]RIF [4]."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["\<\
So far we have considered 1D images, which are encountered in \
practical cases, such as the light spectrum emitted by a source. Our main \
interest concerns 2D images. The algorithm can be easily adapted to the 2D \
case: zero padding extensions are performed along both reference axes, 2D \
convolutions are computed by means of 2D Fourier transforms, direct and \
inverse, and the supports define rectangular areas [1, 2, 6].\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cost Function", "Section"],

Cell[TextData[{
  "To take into account all constraints, a non\[Dash]negative cost function \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " is constructed whose value measures the goodness of the inverse filter ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicS]",
          "TB"], TraditionalForm]]],
  ". The smaller ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " the more the restored image ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["f",
            "TB"], "~"], TraditionalForm]]],
  " represents an acceptable approximation to the true image ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  ".\n",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " is the sum of four terms, corresponding to the four classes of \
constraints mentioned previously:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"J", 
          RowBox[{"(", 
            StyleBox["\[GothicS]",
              "TB"], ")"}]}], " ", "=", " ", 
        RowBox[{
          SuperscriptBox[
            SubscriptBox[
              RowBox[{"\[LeftDoubleBracketingBar]", " ", 
                SubscriptBox[
                  StyleBox["z",
                    "TB"], "supp"], " ", "\[RightDoubleBracketingBar]"}], 
              "2"], "2"], " ", "+", "  ", 
          RowBox[{\(\[Micro]\_2\), " ", 
            SuperscriptBox[
              SubscriptBox[
                RowBox[{"\[LeftDoubleBracketingBar]", " ", 
                  SubscriptBox[
                    StyleBox["z",
                      "TB"], "reg"], " ", "\[RightDoubleBracketingBar]"}], 
                "2"], "2"]}], " ", "+", 
          " ", \(\(\[Micro]\_3\) \((\[Sum]\+\(i\  = \ 1\)\%\(2\ p\  + \ 1\)\
\[GothicS]\_i\  - \ 1)\)\^2\), " ", "+", "  ", 
          RowBox[{\(\[Micro]\_4\), " ", 
            RowBox[{
              SuperscriptBox[
                SubscriptBox[
                  RowBox[{"\[LeftDoubleBracketingBar]", " ", 
                    SubscriptBox[
                      StyleBox["z",
                        "TB"], "PSF"], " ", "\[RightDoubleBracketingBar]"}], 
                  "2"], "2"], "."}]}]}]}], TextForm]], "NumberedEquation"],

Cell["\<\
Non\[Dash]negativity and image support \
\>", "Subsection"],

Cell[TextData[{
  "Given the estimated support ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", let ",
  Cell[BoxData[
      \(TraditionalForm\`\((2\ m\  + \ n)\)\)]],
  " be such that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is integer. Only the central ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " elements of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["f",
              "TB"], 
            StyleBox["~",
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              "RotationAngle"->0}]],
          "TB"], TraditionalForm]]],
  " may be non zero and should be positive, since they represent the \
intensity of the beams captured by the instruments. Define a square real \
matrix  ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`\((2\ m\  + \ n)\)\)]],
  " as"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{\(V\  = \ \((v\_\(i, j\))\)\), ",", "        ", 
        RowBox[{\(v\_\(i, j\)\), " ", "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False], GridBox[{
                  {
                    "0", \(if\ \ i\  = \ 
                      j\ \ and\ \ m\  < \ 
                        i\  \[LessEqual] \ \((m\  + \ 
                              n)\)\ \ and\ \ f\&~\_i\  > \ 0\)},
                  {"1", "otherwise"}
                  }]}],
            (#&)]}]}], TextForm]], "DisplayFormula"],

Cell[TextData[{
  "and define a vector of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\ m\  + \ n\)]],
  " as:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["z",
            "TB"], "supp"], " ", "=", " ", 
        RowBox[{"V", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["f",
                "TB"], "~"], "."}]}]}], TextForm]], "DisplayFormula"],

Cell[TextData[{
  "Recalling (3) and (5), we can see that the first term in (6) depends on ",
  StyleBox["\[GothicS]",
    FontWeight->"Bold"],
  " and is given by a  continuous and convex function, though not everywhere \
differentiable."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Noise amplification ", "Subsection"],

Cell[TextData[{
  "We saw in the in first section that the small magnitude components of \
FT(",
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB"], TraditionalForm]]],
  "), or equivalently large  elements of FT(",
  Cell[BoxData[
      FormBox[
        StyleBox["s",
          FontWeight->"Bold"], TraditionalForm]]],
  "), can lead to noise amplification. Define the matrix:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{\(W\  = \ \((w\_\(i, j\))\)\), ",", "        ", 
        RowBox[{\(w\_\(i, j\)\), " ", "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False], GridBox[{
                  {"0", 
                    RowBox[{\(if\ \ i\), " ", "=", " ", 
                      RowBox[{\(j\ \ and\), " ", "\[VerticalSeparator]", 
                        SubscriptBox[
                          RowBox[{"(", 
                            RowBox[{"FT", 
                              RowBox[{"(", 
                                StyleBox["s",
                                  FontWeight->"Bold"], ")"}]}], ")"}], "i"], 
                        "\[VerticalSeparator]", 
                        " ", \(\(<\)\(\ \)\(\[Micro]\_1\)\)}]}]},
                  {"1", "otherwise"}
                  }]}],
            (#&)]}]}], TextForm]], "DisplayFormula"],

Cell["and construct  the vector:", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[
          StyleBox["z",
            "TB"], "reg"], " ", "=", " ", 
        RowBox[{"W", "    ", "FT", 
          RowBox[{
            RowBox[{"(", 
              StyleBox["s",
                FontWeight->"Bold"], ")"}], "."}]}]}], 
      TextForm]], "DisplayFormula"],

Cell[TextData[{
  "The second term in (6) depends on ",
  StyleBox["\[GothicS]",
    FontWeight->"Bold"],
  " and on two regularization parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_2\)]],
  ", that must be estimated heuristically; it is a ",
  StyleBox["quasi\[Dash]convex", "TI"],
  " function [7] that has a number of discontinuities of the order of the \
size of ",
  StyleBox["s",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Energy conservation ", "Subsection"],

Cell[TextData[{
  "The energy of the restored image must be equal to the energy of the \
observed image. The third term in (6) depends on ",
  StyleBox["\[GothicS]",
    FontWeight->"Bold"],
  " and on a regularization parameter, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_3\)]],
  ", that must be estimated heuristically. It is a convex function, \
infinitely many times differentiable. \nBy adding this third term, the \
trivial solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[GothicS]",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Bold"], "=", " ", 
          SubscriptBox[
            StyleBox["0",
              "TB"], \(2\ p\  + \ 1\)]}], TraditionalForm]]],
  "is also avoided."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["PSF support ", "Subsection"],

Cell[TextData[{
  "Only the first ",
  Cell[BoxData[
      \(TraditionalForm\`m\  + \ 1\)]],
  " and the last ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " elements of ",
  Cell[BoxData[
      FormBox[
        StyleBox["h",
          "TB"], TraditionalForm]]],
  " may be non zero. By constructing"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{\(U\  = \ \((u\_\(i, j\))\)\), ",", "        ", 
        RowBox[{\(u\_\(i, j\)\), " ", "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False], GridBox[{
                  {
                    "1", \(if\ \ i\  = \ 
                      j\ \ and\ \((\ m\  + \ 1)\)\  < \ 
                        i\  < \ \((m\  + \ n)\)\)},
                  {"0", "otherwise"}
                  }]}],
            (#&)]}]}], TextForm]], "DisplayFormula"],

Cell["and", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["z",
              "TB"], "PSF"], " ", "=", " \[NegativeThinSpace] ", 
          RowBox[{"U", " ", 
            StyleBox["h",
              "TB"]}]}], ","}], TextForm]], "DisplayFormula"],

Cell[TextData[{
  "Recalling (3) and (4), we can see that the last term in (6) depends on ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicS]",
          "TB"], TraditionalForm]]],
  " and is given by a convex function, continuous but not everywhere \
differentiable. The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_4\)]],
  " is used to weigh the PSF support constraint and must be estimated \
heuristically."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Convexity  and minimization Issues", "Subsection"],

Cell[TextData[{
  "The noise amplification constraint (corresponding to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_1, \ \[Micro]\_2\  \[NotEqual] \ 0\)]],
  ") has an effect on the convexity of  the cost function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " , which might become  non convex  (not even quasi\[Dash]convex) and \
discontinuous. "
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "We are then faced with a choice of which minimization algorithm to employ. \
In this work, a conjugate gradient iterator is used, namely the Polak \[Dash] \
Ribi\[EGrave]re  iteration [8]. \nThe solution is not guaranteed to converge \
to a global minimum; to achieve further regularization, few iterations are \
performed and the current solution (one of the non unique local minima of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  ") is taken as the inverse filter providing the best approximation to ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          "TB"], TraditionalForm]]],
  ". \nThe numerical testing shows however that the solution found is always \
acceptable. In practice we have observed that the conjugate iterator is able \
to move rapidly towards the region of convexity, without getting too close to \
the points of discontinuity that might occur along a descent direction, \
taking a step that allows jumping over such discontinuities."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Total Variation Regularization", "Subsection"],

Cell["\<\
Total variation regularization can be used to sharpen an image, \
increase its contrast and reduce some artifacts in a restored image that may \
be due to noise [4]. It can be applied, as a final step, to improve the \
quality of the restored image computed by the NSH\[Dash]RIF algorithm [5]. \
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Available blind deconvolution methods", "Subsection"],

Cell[TextData[{
  "Varying the choice of the regularization parameters ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_4\)]],
  " it is possible to obtain the restoration via numerical methods other than \
the NSH-RIF. \nAs an example, setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_4\  = \ 0\)]],
  " is equivalent to considering the method NSR\[Dash]RIF described in [5], \
while choosing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_2\  = \ \(\[Micro]\_4\  = \ 0\)\)]],
  " yields the NAS\[Dash]RIF algorithm proposed in [4]. The conditions under \
which the NAS\[Dash]RIF and NSR\[Dash]RIF methods are globally convergent are \
related to the Hessian of the cost function being positive definite. "
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Guide Star", "Section"],

Cell[TextData[{
  "In between classical and blind deconvolutions, there also exists the \
so-called ",
  StyleBox["myopic deconvolution",
    FontSlant->"Italic"],
  ", in which an estimation of the PSF is available from a previous \
observation or from a ",
  StyleBox["guide star",
    FontSlant->"Italic"],
  ". \nA guide star ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["g",
              "TB"], "star"], " "}], TraditionalForm]]],
  "is a reference image (a bright isolated point source, natural or \
artificially created) observed under atmospheric circumstances similar to \
those under which ",
  Cell[BoxData[
      FormBox[
        StyleBox["g",
          FontWeight->"Bold"], TraditionalForm]]],
  " was observed. In our notation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["g",
              "TB"], "star"], " "}], TraditionalForm]]],
  ", when available, is stored as a real vector of length ",
  StyleBox["2 m+n.", "DisplayFormula",
    FontSlant->"Italic"],
  "\nThe true image ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["f",
            FontWeight->"Bold"], "star"], TraditionalForm]]],
  " of the guide star is a white small point in a black background and its \
total energy is assumed to be unitary. The effect of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["f",
            FontWeight->"Bold"], "star"], TraditionalForm]]],
  " in the convolution with the PSF can be assumed to be very close to that \
of the identity operator (with respect to the convolution operator), that is \
to say ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["g",
                FontWeight->"Bold"], "star"], 
            FormBox[
              RowBox[{" ", 
                RowBox[{"=", 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox[
                      SubscriptBox["f", 
                        StyleBox["star",
                          FontWeight->"Plain"]],
                      "TB",
                      FontWeight->"Bold"], " ", "\[Star]", " ", 
                    StyleBox["h",
                      "TB",
                      FontWeight->"Bold"], " "}]}]}],
              "TraditionalForm"]}], "\[TildeTilde]", 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox[
            FormBox["h",
              "TraditionalForm"],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". Therefore ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["g",
            FontWeight->"Bold"], "star"], TraditionalForm]]],
  " can be used as an estimate of the initial PSF.\nThe NSH\[Dash]RIF \
procedure can also be used as a myopic deconvolution algorithm, if a guide \
star is known. Otherwise, the NSH\[Dash]RIF solver may employ an initial \
guess for the inverse filter, created by means of the Dirac delta function."
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Section"],

Cell[TextData[{
  "Two packages have been developed. The ",
  StyleBox["BDRestoration", "MR"],
  " package collects the restoration routine NSH\[Dash]RIF together with some \
auxiliary routines. The ",
  StyleBox["FITS", "MR"],
  " package allows handling 2D images stored in the FITS format [9], commonly \
used for astronomical images (the ",
  StyleBox["Import",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Export",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " routines have recently been extended and now are able to handle ",
  StyleBox["FITS",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " files as well). \nMost of the code uses ",
  StyleBox["Compile", "MR"],
  " to obtain an implementation four times faster than the uncompiled \
functionally equivalent implementation. Images are stored as real matrices \
with values in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \ 1]\)\)]],
  ". The direct and inverse Fourier transform pair routines provided by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are used. \nWe do not exploit the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " multi\[Dash]variable minimization routine ",
  StyleBox["FindMinimum", "MR"],
  " as a ",
  StyleBox["black\[Dash]box; ",
    FontSlant->"Italic"],
  "the Polak\[Dash]Ribi\[EGrave]re conjugate gradient method is coded [8] and \
it makes use of ",
  StyleBox["FindMinimum", "MR"],
  " for the line minimization at each iteration. In this way we are able to \
monitor the algorithm at each iteration, using simulated data to analyze how \
the computing time and the final result depend on the choice of the four \
regularization parameters ",
  Cell[BoxData[
      \(TraditionalForm\`\[Micro]\_i\)]],
  ".\nThe code and the packages described are written and tested under \
version 4.1."
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Examples", "Section"],

Cell["Simulated Data", "Subsection"],

Cell["\<\
In this first experiment, the restoration algorithm is tested on a \
blurred image, obtained from a synthetic 2D image that is convoluted with a \
Gaussian PSF and to which Poissonian noise is added. The notation adopted are \
the same as for the 1D case, but here variables denote matrices instead of \
vectors.
As a first step, two standard packages and the blind deconvolution package \
are loaded.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(<< LinearAlgebra`MatrixManipulation`\), "\n", 
    \(<< Statistics`DiscreteDistributions`\), "\[IndentingNewLine]", 
    \(<< BDRestoration`\), "\[IndentingNewLine]", 
    \(\(Off[General::spell, \ General::spell1];\)\)}], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "The values of the discrete PSF are stored in the ",
  Cell[BoxData[
      \(TraditionalForm\`15\ \[Times]\ 15\)]],
  " matrix  ",
  StyleBox["\[GothicH]",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Courier",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({m\_y, \ m\_x}\  = \ {7, \ 7};\)\), "\[IndentingNewLine]", 
    \(\(h\  = \ 
        Table[N[Exp[\(-\((i^2\  + \ j^2)\)\)\ /\ 10]], \ {i, \ \(-m\_y\), \ 
            m\_y}, \ {j, \ \(-m\_x\), \ m\_x}];\)\), "\[IndentingNewLine]", 
    \(\(h\  /= \ Apply[Plus, \ h, \ {0, \ 1}];\)\), "\[IndentingNewLine]", 
    \(\(showImage[h];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0238095 0.0634921 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
15 string
15 15 8 [15 0 0 15 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000001010101010000000000
000000010204060606040201000000
00000104080E1315130E0804010000
0001040A15222E332E22150A040100
000208152A455E685E452A15080200
01040E2245739BAB9B7345220E0401
0106132E5E9BD1E7D19B5E2E130601
0106153368ABE7FFE7AB6833150601
0106132E5E9BD1E7D19B5E2E130601
01040E2245739BAB9B7345220E0401
000208152A455E685E452A15080200
0001040A15222E332E22150A040100
00000104080E1315130E0804010000
000000010204060606040201000000
000000000001010101010000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=
ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000
;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^
000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0
dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`06
1PH900@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH9
00@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@4
10T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T0
0P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P82
2P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P01
0@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P010@4K
000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P010@4K0000
00@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P010@4K000000@0
dLfY00030=7=ZA8000002@010@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P8
2P0410@900410A800000103AcJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E
5AD901<C4`T03Ph>2@0820P:00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:
00P820T03Ph>2@0C4a<901DE5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=
ZA8000002@010@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P82P0410@90041
0A800000103AcJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E5AD901<C4`T0
3Ph>2@0820P:00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:00P820T03Ph>
2@0C4a<901DE5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=ZA8000002@01
0@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P82P0410@900410A800000103A
cJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E5AD901<C4`T03Ph>2@0820P:
00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:00P820T03Ph>2@0C4a<901DE
5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=Z@T000002@010@4900@410T0
2PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0
dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R
2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E
5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY0003
0=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:
00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R
8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T0
00002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT0
10@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^
2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@01
0@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@01
0@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<9
02h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@020P8900P8
20T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P890000
00@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0
ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE
2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY
00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z
:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX9
04E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=
Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE
5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0
GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T00000
2@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P8
2@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1X
J6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T00@412@0410@9
00h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@9
00410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^K
V`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT0
8R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0
dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c
2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15
ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY0003
0=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:
028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=c
L`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T0
0@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT0
3Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K
2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@06
1PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@06
1PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL9
0=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C
4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH90041
0@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0
Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^
2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY
00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1N
GUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh9
09^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=
Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^
;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0
dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@41
2@061PH901DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE
2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3o
ool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH9
01DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH9
00410@@0dLfY00030=7=Z@T00@412@061PH901DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OW
i`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901DE5@T0
<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH900410@@0
dLfY00030=7=Z@T00@412@061PH901DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[
2@1XJ6P:03<c<`T05ADE2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901DE5@T0<c<c2P1X
J6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH900410@@0dLfY0003
0=7=Z@T00@412@061PH901DE5@T0<c<c2P1XJ6P90:^[Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:
03<c<`T05ADE2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901DE5@T0<c<c2P1XJ6P90:^[
Z`T0inOW2@3oool90>OWi`T0Zj^[2@1XJ6P:03<c<`T05ADE2@061PH900410@@0dLfY00030=7=Z@T0
0@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT0
4a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A
2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@06
1PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@06
1PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL9
0=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C
4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH90041
0@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0
Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^
2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY
00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh909^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1N
GUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=Z@T00@412@061PH901<C4`T0;Rh^2P1NGUh9
09^KV`T0dM7A2@3WinL90=7Ad@T0Vi^K2@1NGUh:02h^;PT04a<C2@061PH900410@@0dLfY00030=7=
Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R
8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0
Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@41
2@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>
2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[
Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@9
00h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@9
00410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^K
V`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT0
8R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0
dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c
2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY00030=7=Z@T00@412@0410@900h>3PT08R8R2P15
ADD907=cL`T0Vi^K2@2[Zj/909^KV`T0Lg=c2@15ADD:028R8PT03Ph>2@0410@900410@@0dLfY0003
0=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:
01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5
A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T0
00002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T0
20P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN
2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@02
0P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@02
0P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P9
05iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P8
20T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P890000
00@0dLfY00030=7=Z@T000002@020P8900P820T05ADE2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0
ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY00030=7=Z@T000002@020P8900P820T05ADE
2P0Z:RX904E5A@T0GUiN2@1XJ6P905iNGPT0ADE52@0Z:RX:01DE5@T020P82@020P89000000@0dLfY
00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E
5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9
028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=
Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:
2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0
;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T00000
2@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@4
2@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c
<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@49
00@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49
000000@0dLfY00030=7=Z@T000002@010@4900@410T02PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^
;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0dLfY00030=7=Z@T000002@010@4900@410T0
2PX:2P0E5AD9028R8PT0;Rh^2@0c<c<902h^;PT08R8R2@0E5AD:00X:2PT010@42@010@49000000@0
dLfY00030=7=ZA8000002@010@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P8
2P0410@900410A800000103AcJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E
5AD901<C4`T03Ph>2@0820P:00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:
00P820T03Ph>2@0C4a<901DE5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=
ZA8000002@010@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P82P0410@90041
0A800000103AcJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E5AD901<C4`T0
3Ph>2@0820P:00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:00P820T03Ph>
2@0C4a<901DE5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=ZA8000002@01
0@4900@410X020P82@0>3Ph901<C4`T05ADE2@0C4a<900h>3PT020P82P0410@900410A800000103A
cJT000<0dLfY4P00000900410@T010@42P0820P900h>3PT04a<C2@0E5AD901<C4`T03Ph>2@0820P:
00@410T00@414P0000040=7=Z@000`3AcJTB000000T00@412@0410@:00P820T03Ph>2@0C4a<901DE
5@T04a<C2@0>3Ph900P820X010@42@010@4B000000@0dLfY00030=7=ZA/000002@010@4:00820PT0
10@46`061PH900@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@4
6`061PH900@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`06
1PH900@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH9
00@410T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@4
10T00P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T0
0P822P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P82
2P010@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P01
0@4K000000@0dLfY00030=7=ZA/000002@010@4:00820PT010@46`061PH900@410T00P822P010@4K
000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0
dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY0003
0=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh0
0000;@010@4^000000@0dLfY00030=7=ZBh00000;@010@4^000000@0dLfY00030=7=ZBh00000;@01
0@4^000000@0dLfY002@0=7=Z@00T03AcJT00900dLfY002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {278.812, 135.812}} -> {-20.2004, 14.5834, \
0.110141, 0.110141}}]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["showImage", "MR"],
  ", which internally uses ",
  StyleBox["RasterArray",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is part of the ",
  StyleBox["BDRestoration", "MR"],
  " package, takes any matrix as input and visualizes it as a gray scale \
image. The blurred noisy test image ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["g",
            "TB"], "~"], TraditionalForm]]],
  " is created from an original monochromatic ",
  Cell[BoxData[
      \(TraditionalForm\`15\ \[Times]\ 45\)]],
  " image  ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicF]",
          "TB"], TraditionalForm]]],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(w\  = \ Table[1. , \ {3}, \ {3}];\)\), "\n", 
    \(\(b\  = \ 1\  - \ w;\)\), "\[IndentingNewLine]", 
    \(\(f\  = 
        BlockMatrix[{\[IndentingNewLine]{w, \ w, \ w, \ b, \ w, \ w, w, \ 
              b, \ w, \ w, \ w, \ b, \ w, \ w, \ w}, \[IndentingNewLine]{w, \ 
              b, \ w, \ b, \ b, \ w, \ b, \ b, \ w, \ b, \ b, \ b, \ b, \ 
              b, \ w}, \[IndentingNewLine]{w, \ b, \ w, \ b, \ b, \ w, \ b, \ 
              b, \ w, \ w, \ w, \ b, \ w, \ w, \ w}, \[IndentingNewLine]{w, \ 
              b, \ w, \ b, \ w, \ w, \ b, \ b, \ b, \ b, \ w, \ b, \ b, \ 
              b, \ w}, \[IndentingNewLine]{w, \ w, \ w, \ b, \ b, \ w, \ b, \ 
              b, \ w, \ w, \ w, \ b, \ w, \ w, \ 
              w}\[IndentingNewLine]}];\)\), "\[IndentingNewLine]", 
    \(\(g\  = \ Re[convolveMatrices[f, \ h]];\)\), "\[IndentingNewLine]", 
    \(\({len\_y, \ len\_x}\  = \ Dimensions[g];\)\), "\[IndentingNewLine]", 
    \(\({\[Beta], \ \[Gamma]}\  = \ {5, \ 1000};\)\), "\[IndentingNewLine]", 
    \(\(noise\  = \ 
        Table[Random[
              PoissonDistribution[\[Beta]]], \ {len\_y}, \ {len\_x}]\ /\ \
\[Gamma];\)\), "\n", 
    \(\(\[Rho]\  = \ 
        Apply[Plus, \ g, \ {0, \ 1}]\ /\ 
          Apply[Plus, \ g\  + \ noise, \ {0, \ 1}];\)\), "\n", 
    \(\(g\&~\  = \ \((g\  + \ 
              noise)\)\ *\ \[Rho];\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]\  = \ g\&~\  - \ g;\)\), "\[IndentingNewLine]", 
    \(\(f\&^\  = \ extendImageMatrix[f, \ m\_y, \ m\_x];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["The extensions of the matrices ", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicF]",
          "TB"], TraditionalForm]],
    FontWeight->"Bold"],
  " ",
  StyleBox["and ", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  Cell[BoxData[
      FormBox[
        StyleBox["\[GothicH]",
          "TB"], TraditionalForm]]],
  " ",
  StyleBox["are implicitly performed within the function ", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["convolveMatrices", "TB",
    FontFamily->"Courier"],
  StyleBox[". An explicit extension of ", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\[GothicF]",
    FontWeight->"Bold"],
  StyleBox[" is computed by ", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["extendImageMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  StyleBox["and is necessary for a better comparison during the visualization \
of the original image and the simulated", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  " ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["g",
            "TB"], "~"], TraditionalForm]]],
  StyleBox[".\n", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  "A common way to measure noise is by the ",
  StyleBox["signal to noise ratio",
    FontSlant->"Italic"],
  " (SNR) expressed in Decibels (dB):"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print["\<SNR: \>", \ 
        computeSNR[g, \ \[Delta]], \ "\< dB\>"];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("SNR: "\[InvisibleSpace]35.35248885110249`\
\[InvisibleSpace]" dB"\),
      SequenceForm[ "SNR: ", 35.352488851102493, " dB"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "As the noise increases, the SNR decreases. The constants ",
  StyleBox["\[Beta]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["\[Gamma]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allow to change the intensity of the noise that affects the test image. \
The extended original image and the blurred noisy image are shown below."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(showImage[f\&^];\)\), "\[IndentingNewLine]", 
    \(\(showImage[g\&~];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFF0000
00000000000000000000000000FFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFF0000
00000000000000000000000000FFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFF0000
00000000000000000000000000FFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000FFFFFFFFFFFF0000000000000000000000
00FFFFFF000000000000000000FFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000FFFFFFFFFFFF0000000000000000000000
00FFFFFF000000000000000000FFFFFF00000000000000
00000000000000FFFFFF000000FFFFFF000000FFFFFFFFFFFF0000000000000000000000
00FFFFFF000000000000000000FFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000FFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000D0?ooo`L00000
5@3oool7000001D0oooo1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3o
ool7000001D0oooo1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3oool7
000001D0oooo1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3oool70000
01D0oooo1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3oool7000001D0
oooo1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3oool7000001D0oooo
1`00000D0?oooa400000103AcJT000<0dLfY4@00000D0?ooo`L000005@3oool7000001D0oooo1`00
000D0?oooa400000103AcJT000<0dLfY4@0000060?ooo`L000001`3oool>000000L0oooo3P000007
0?ooob8000001`3ooolA000000@0dLfY00030=7=ZA4000001P3oool7000000L0oooo3P0000070?oo
o`h000001`3ooolR000000L0oooo4@0000040=7=Z@000`3AcJTA000000H0oooo1`0000070?ooo`h0
00001`3oool>000000L0oooo8P0000070?oooa400000103AcJT000<0dLfY4@0000060?ooo`L00000
1`3oool>000000L0oooo3P0000070?ooob8000001`3ooolA000000@0dLfY00030=7=ZA4000001P3o
ool7000000L0oooo3P0000070?ooo`h000001`3ooolR000000L0oooo4@0000040=7=Z@000`3AcJTA
000000H0oooo1`0000070?ooo`h000001`3oool>000000L0oooo8P0000070?oooa400000103AcJT0
00<0dLfY4@0000060?ooo`L000001`3oool>000000L0oooo3P0000070?ooob8000001`3ooolA0000
00@0dLfY00030=7=ZA4000001P3oool7000000L0oooo3P0000070?ooo`h000005@3oool7000001@0
oooo4@0000040=7=Z@000`3AcJTA000000H0oooo1`0000070?ooo`h000001`3oool>000001D0oooo
1`00000D0?oooa400000103AcJT000<0dLfY4@0000060?ooo`L000001`3oool>000000L0oooo3P00
000E0?ooo`L00000503ooolA000000@0dLfY00030=7=ZA4000001P3oool7000000L0oooo3P000007
0?ooo`h000005@3oool7000001@0oooo4@0000040=7=Z@000`3AcJTA000000H0oooo1`0000070?oo
o`h000001`3oool>000001D0oooo1`00000D0?oooa400000103AcJT000<0dLfY4@0000060?ooo`L0
00001`3oool>000000L0oooo3P00000E0?ooo`L00000503ooolA000000@0dLfY00030=7=ZA400000
1P3oool7000000L0oooo3P0000070?ooo`h000005@3oool7000001@0oooo4@0000040=7=Z@000`3A
cJTA000000H0oooo1`0000070?ooo`L000003P3ooolL000000L0oooo500000070?oooa400000103A
cJT000<0dLfY4@0000060?ooo`L000001`3oool7000000h0oooo700000070?oooa@000001`3ooolA
000000@0dLfY00030=7=ZA4000001P3oool7000000L0oooo1`00000>0?oooa`000001`3ooolD0000
00L0oooo4@0000040=7=Z@000`3AcJTA000000H0oooo1`0000070?ooo`L000003P3ooolL000000L0
oooo500000070?oooa400000103AcJT000<0dLfY4@0000060?ooo`L000001`3oool7000000h0oooo
700000070?oooa@000001`3ooolA000000@0dLfY00030=7=ZA4000001P3oool7000000L0oooo1`00
000>0?oooa`000001`3ooolD000000L0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P000007
0?ooo`h000005@3oool7000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?oo
o`h000005@3oool7000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?ooo`h0
00005@3oool7000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?ooo`h00000
5@3oool7000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?ooo`h000005@3o
ool7000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?ooo`h000005@3oool7
000001@0oooo4@0000040=7=Z@000`3AcJTA000001@0oooo3P0000070?ooo`h000005@3oool70000
01@0oooo4@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY002@0=7=Z@00T03A
cJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {182.062, 112.312}} -> {-80.2954, 48.3064, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
010201000103020202000102020102020101020101020202030301020204010302040101
0103020201020301030101030601010101010301020102
000101010201030202030404030303030404010303030404030503030403030304030504
0302040202020303040405040405030202020001030200
02010201020305070808090A080908060404060607080908090908070506050507080808
0808080705050406080709080A07080605030201010101
0003020303070A0D121215171513100E0C0C0D0F13131415161311100D0C0C0F13141615
1414120E0B0E0C0F111414151414120D0A070403020101
00010304080D161D24292C302F2B26201B181B21272A2E2E2F2A262019171C20242C2E2F
2C29241F1A191A1F25292E2D2D29241D150C0704020101
020204060D192636464F55565551473D322D313A454F5559564F453A312E323C484F5554
514C4238302B2F39424C53565350443728170D07020302
0203040A1429415A6F8087888780736152494C5A6C7C888B877D6C5A4D495160727D8484
7F7668574844495667768185847E6F583F28150B040302
0202050D1F38587D9CB0BBBCB9B09E866E63677991A8B9BDB9A8927967626F869DAEB4B3
AB9B877160585F72889AAAB2B4AE9B7D59361D0D060303
0204071225446E9BBFD4DFDEDCD4C2A58775758CA7C7DBE5DBC7AA8A767789A6C2D1D7CF
C2B1997F6C626B7F9BB1C2CFD6D2BD9B6F472512060502
010407152D507EADD2E6EDEBEBE5D5B9947D798CACCFE8F1E8D0AB8B787C96BAD7E5E4D8
C5B4987F6861687E99B1C6D7E4E6D4AE7F502C13070301
020508172E5585B6D7E4E6E3E5E6DABE977B7080A0C6E3EFE2C59D7E707998C1DFEDE5D3
BDA89077615B62768DA8BCD3E6EBDFBA87542E16090201
010409152F5688B6D4DBD8D3D6DCD6BD9673656D8BB4D6E2D3AF886A607196C1E1EBE4D0
BAA48D7360575F6F88A1B8D0E6EEE3BF8C592F170A0403
03040815305787B3CED0C8C1C7D2CFB8936D5C627FA8CAD4C4A0765752678FBEE0EBE8D8
C5B0977E696064768FA7C0D9ECF4E9C38F583016090601
03030915305788B2C9C8BDB6BECBCAB5916D5B6380A7C6D0BD94694B465D85B3D7E9EBE4
D9C8B2957B6C71859FB6CEE4F6FBEFC58F5A3016090301
030509162F5687B1C8C6BCB2BBC6CAB59574656F8CB1CFD3BA8F63433E5275A2C6DDE7EA
E7DECAAC8E7A788AA3BDD5E9FBFFEDC8915B3115090302
020309152E5688B0C9CABDB6BDC9CCB99A7D7382A1C6DCDEBF8F5F3F3744658BADC7D8E4
EBEBDBBD99807B879DB6CEE4F6FDEBC6905A3017080403
020608182F5688B3CDD0C7C2C8D0D1BE9E868292B3D6E8E2C28F5D3B2F39547494B0C4D8
E7EEE0C59E81768093A9C1D8EBF4E7C28F592F17090402
010309162F5688B6D4DBD7D3D6DCD7C0A0898597BADBECE3C18E5B3A2C344C6A89A4BBD1
E4ECE2C59F82737A8EA1B8CFE4EFE2BF8C582F15070402
020409152C5486B5D7E5E6E3E6E6DCC29C837D8FAECFE0D9B98757382D364D6E8DA6BED4
E5EDE1C49F81767E92A8BFD4E6ECDFBA87542E15080402
020409152B517EAED2E5EBECEBE6D6B690736C7896B2C5C2A77C52352D37547294B1C5D7
E5E6D7BA987E79859BB3C5D8E3E6D5AF7F502C13090402
0202071124456F9CBFD3DDDFDCD3C0A17D5F515D728EA0A18E6B47332B37527496ADC3CF
D6D4C0A6897577849DB1C3CED4D2BD9A6F452610070301
0204060D1D36587C9CAFBABCBAAF9C7F6048383E4F6577796D53372524304B69859CABB2
B6AF9E856F636574899CABB2B5AE9B7C58371E0E060303
0102060A14273F586F7F8589867E6F5A4430252732424E534A38261B1A26394F65748186
8480726050474D5969768184857D705A3F27170B060301
020204070D182737464F545755504637291C14151D262F332C24191112192734424B5255
544F483C322C3139444C5255544F453726170E07030303
03030203070D151D252A2E302C2B241D160F0A0B0E13181A17130E0A080D151C242A2D2E
2D2C261F1B181A20242A2C2D2F2A251E170D0804030201
0101020303060A0C111415161515100D0B08070506090B0C090A070607080A0E11151714
1513120F0D0B0E0E111515161512110F0A060301030101
00020101020503060708080A090906060503040204040504060503030204040606080A08
0808080506040607080908090A07080705030302010002
010001030002020202040404030403040201010103030203030302020202020303040404
0205020303030403040404050503020202030002020001
000101010103010203010202000101020203010103010203020201010102030102020101
0201000302020202030104020102020402020202040001
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=Z@<00@410P020P8200410@<000000P010@4200<30`L00P820P00000300410@@0
0P820`010@4400820PD00@410P020P8500410@L00P8210030`<300410@@00P820`0410@200410@80
0`<30`020P8200@410L00@410P030`<500820P800@410P020P8300<30`800@410P030`<500410@80
0`<30P061PH<00410@800`<30`010@4200820P800@410`020P840=7=Z@000`3AcJT300410@800P82
0P010@43000000800@410P030`<700820P8000000`010@4400820P<00@4110020P8500410@800P82
1@010@4700820P@00`<30`010@4400820P<010@40P010@4200<30`<00P820P0410@700410@800`<3
1@020P8200410@800P820`030`<200410@800`<31@010@4200<30`801PH630010@4200<30`<00@41
0P020P8200410@<00P82103AcJT000<0dLfY0`010@4200820P800@410`00000200410@800`<31`02
0P82000000<00@4110020P8300410@@00P821@010@4200820PD00@411`020P8400<30`<00@411002
0P8300@410800@410P030`<300820P8010@41`010@4200<30`D00P820P010@4200820P<00`<30P01
0@4200<30`D00@410P030`<200H61P`00@410P030`<300410@800P820P010@4300820P@0dLfY0003
0=7=Z@<000001`010@4200820P800@410`030`<400820P800`<31@0410@900<30`D010@40P010@47
00<30`D010@40P030`<200D51@D00`<30P0410@700<30`<010@40P030`<200D51@8010@40`030`<2
00820P8010@41`020P8500<30`D010@40P051@D400@410<01@D50P030`<700820P8000000`010@42
00<30`800P820`0000040=7=Z@000`3AcJT3000000L00@410P020P8200410@<00`<310020P8200<3
0`D010@42@030`<500@410800@411`030`<500@410800`<30P051@D500<30`8010@41`030`<300@4
10800`<30P051@D200@410<00`<30P020P8200@410L00P821@030`<500@410801@D5100410@300D5
1@800`<31`020P82000000<00@410P030`<200820P<00000103AcJT000<0dLfY0`020P8200410@80
0P820`010@4200820P800`<30`051@D200L71`@020P80`092@T200X:2P8020P80`092@T200P82080
1PH61@0410@500H61P801`L70P0820P200T92@<020P810092@T300P820801`L70P051@D300H61P@0
1@D50`071`L=00P820<01`L710051@D300@410801PH60P0820P300L71`802@T90P0820P200X:2P<0
1`L70P0820P200H61P<01@D50P030`<200820PX00@41103AcJT000<0dLfY0`020P8200410@800P82
0`010@4200820P800`<30`051@D200L71`@020P80`092@T200X:2P8020P80`092@T200P820801PH6
1@0410@500H61P801`L70P0820P200T92@<020P810092@T300P820801`L70P051@D300H61P@01@D5
0`071`L=00P820<01`L710051@D300@410801PH60P0820P300L71`802@T90P0820P200X:2P<01`L7
0P0820P200H61P<01@D50P030`<200820PX00@41103AcJT000<0dLfY0`00000200<30`800P821@03
0`<200L71`<02PX:0P0=3@d4018B4P<05ADE0P0G5aL201DE5@<04a<C0P0@410200h>3PD030`<0P0=
3@d300l?3`@04a<C0P0D51@301DE5@805QHF0P0C4a<3014A4@80410@0P0=3@d500`<30803`l?0`0C
4a<201@D50805QHF0P0E5AD501@D50804Q8B0`0>3Ph200/;2`803Ph>0`0<30`200l?3`804A4A1@0D
51@201DE5@D051@D0P0B4Q8200d=3@<02PX:0P071`L200@410<00`<30P020P8500410@@0dLfY0003
0=7=Z@<000000P030`<200820PD00`<30P071`L300X:2P803@d=100B4Q8301DE5@805aLG0P0E5AD3
01<C4`80410@0P0>3Ph500`<30803@d=0`0?3`l401<C4`8051@D0`0E5AD201HF5P804a<C0`0A4A42
010@40803@d=1@0<30`200l?3`<04a<C0P0D51@201HF5P805ADE1@0D51@2018B4P<03Ph>0P0;2`/2
00h>3P<030`<0P0?3`l2014A4@D051@D0P0E5AD501@D50804Q8B0P0=3@d300X:2P801`L70P0410@3
00<30`800P821@010@440=7=Z@000`3AcJT3000000800@410P030`<300@4108020P80P0=3@d301HF
5P807AdM0P0T92@202TY:@<0;2`/0P0`<30202l_;`<0:b/[0P0V9RH2020P80<06a/K0P0H61P201/K
6`<08B4Q0P0W9bL202XZ:PD0;Rh^0P0_;bl202XZ:P<09RHV0P0P820201TI6@<05aLG0P0L71`2020P
80<092@T0P0/;2`202h^;P80;bl_0`0/;2`202TY:@8092@T0`0O7al201XJ6P806ATI0`0J6QX201lO
7`809BDU0`0Y:BT202h^;P@0;Bd]0`0Y:BT202@T90807AdM0`0E5AD200`<30801`L70`0410@20082
0PD00@41103AcJT000<0dLfY0`00000200410@800`<30`0410@200P820803@d=0`0F5QH201dM7@80
92@T0P0Y:BT302`/;080<30`0P0_;bl302/[:`809RHV0P0P820301/K6`8061PH0P0K6a/3024Q8@80
9bLW0P0Z:RX502h^;P80;bl_0P0Z:RX302HV9P80820P0P0I6AT301LG5`8071`L0P0P820302@T9080
;2`/0P0^;Rh202l_;`<0;2`/0P0Y:BT202@T90<07alO0P0J6QX201TI6@<06QXJ0P0O7al202DU9@<0
:BTY0P0^;Rh402d];@<0:BTY0P0T92@201dM7@<05ADE0P0<30`200L71`<010@40P020P8500410@@0
dLfY00030=7=Z@<000000P010@4200<30`<010@40P0820P200d=3@<05QHF0P0M7Ad202@T9080:BTY
0`0/;2`2030`<080;bl_0`0[:b/202HV9P80820P0`0K6a/201PH60806a/K0`0Q8B4202LW9`80:RXZ
1@0^;Rh202l_;`80:RXZ0`0V9RH2020P80806ATI0`0G5aL201`L7080820P0`0T92@202`/;080;Rh^
0P0_;bl302`/;080:BTY0P0T92@301lO7`806QXJ0P0I6AT301XJ6P807alO0P0U9BD302TY:@80;Rh^
100];Bd302TY:@8092@T0P0M7Ad301DE5@8030`<0P071`L300@410800P821@010@440=7=Z@000`3A
cJT500820P8010@40`061PH200d=3@806ATI0`0V9RH203Hf=P80ATI60P1?Cdl305EEE@80EUIF0P1E
EED3055AD@80AdM70P0m?Cd3038b<P80;Bd]0P0a<C4303Xj>P80ADE50P1?Cdl205EEE@<0FEUI0P1F
EUH204m?C`<0ADE50P0j>SX2034a<@<0;Rh^0P0b<S8203`l?0<0B4Q80P1?Cdl205EEE@80E5AD0`1A
DE4204a<C080@T920`0h>3P2030`<080:b/[0`0_;bl203Ti>@80@T920`1<C4`205=CD`80EUIF0P1C
De<3051@D080A4A40P0g=cL302PX:0805aLG0P0=3@d300L71`800P820P030`<300820P@0dLfY0003
0=7=Z@D00P820P0410@300H61P803@d=0P0I6AT302HV9P80=SHf0P16ATH204m?C`<0EEEE0P1FEUH2
05EEE@<0DE5A0P17AdL203dm?@<0<S8b0P0];Bd2034a<@<0>SXj0P15ADD204m?C`80EEEE0`1IFET2
05IFEP80Cdm?0`15ADD203Xj>P80<C4a0`0^;Rh2038b<P80?3`l0`18B4P204m?C`80EEEE0P1DE5@3
055AD@80C4a<0P12@T8303Ph>080<30`0P0[:b/302l_;`80>CTi0P12@T8304a<C080De=C0P1FEUH2
05=CD`<0D51@0P14A4@203Lg=`<0:2PX0P0G5aL200d=3@<01`L70P020P8200<30`<00P82103AcJT0
00<0dLfY0`020P8200<30`8010@40`0:2PX201@D5080:BTY0`11@D4205YJFP80Kfm_0P20P80308N7
Q`80R8R80P27QhL30820P080Lg=c0P1QHF43059BDP80BDU90P1<C4`305YJFP80K6a/0P1lO7`208R8
R0<0Rh^;0P27QhL207emO@<0K6a/0P1JFUX204e=C@<0BDU90P1ADE42061PH0<0LW9b0P1mOGd408B4
Q0<0Ogmo0P1fMWH206QXJ0<0EeMG0P18B4P204A4A0<0BDU90P1FEUH206MWI`<0MWIf0P21PH4208F5
Q@80Q8B40`1nOWh206m_K`80F5QH0`0o?cl202PX:0805ADE0`0;2`/200@410800`<30`020P840=7=
Z@000`3AcJT300820P800`<30P0410@300X:2P8051@D0P0Y:BT30451@@80FUYJ0P1_Kfl20820P0<0
QhN70P28R8P208N7Q`<0P8200P1cLg<2065QH@<0DU9B0P19BDT204a<C0<0FUYJ0P1/K6`207alO080
R8R80`2;Rh/208N7Q`80OGem0`1/K6`205YJFP80CDe=0`19BDT2055AD@80H61P0`1bLW8207emO@@0
Q8B40`1oOgl207IfMP80J6QX0`1GEeL204Q8B080A4A40`19BDT205IFEP80IfMW0`1fMWH20861P@80
QHF50P24Q8@307inOP80Kfm_0P1HF5P303lo?`80:2PX0P0E5AD300/;2`8010@40P030`<300820P@0
dLfY00030=7=Z@D00P820P051@D300d=3@807alO0P0h>3P305QHF080OGem0P2LW9`20;2`/0<0^k^k
0P2l_;`20;Vi^@<0/;2`0P2NWYh208J6QP<0KVi^0P1SHf<206MWI`<0NGUi0P2ATI420:RXZ080^KVi
0`2m_Kd20;Vi^@80Z:RX0`2BTY8207UiN@80IfMW0`1RHV8206m_K`80QXJ60`2MWId20:j^[P80];Bd
0P2c/k<30:^[Z`80Vi^K0P27QhL3075aL@80H61P0P1HF5P305mOG`80LW9b0P28R8P309ZJVP80ZZZZ
0P2b/[820;Bd]0<0[Zj^0P2KVi/207emO@<0FEUI0P0f=SH201dM7@<03@d=0P061PH500<30`@0dLfY
00030=7=Z@D00P820P051@D300d=3@807alO0P0h>3P305QHF080OGem0P2LW9`20;2`/0<0^k^k0P2l
_;`20;Vi^@<0/;2`0P2NWYh208J6QP<0KVi^0P1SHf<206MWI`<0NGUi0P2ATI420:RXZ080^KVi0`2m
_Kd20;Vi^@80Z:RX0`2BTY8207UiN@80IfMW0`1RHV8206m_K`80QXJ60`2MWId20:j^[P80];Bd0P2c
/k<30:^[Z`80Vi^K0P27QhL3075aL@80H61P0P1HF5P305mOG`80LW9b0P28R8P309ZJVP80ZZZZ0P2b
/[820;Bd]0<0[Zj^0P2KVi/207emO@<0FEUI0P0f=SH201dM7@<03@d=0P061PH500<30`@0dLfY0003
0=7=Z@<00P820P0410@200L71`<04Q8B0P0U9BD204A4A0<0KVi^0P2KVi/20;no_`80e=CD0`3Ogml2
0=kNgP80g=cL0`3De=@20<;2`P80YJFU0`27QhL407EeM@<0S8b<0P2WYjL20<O7a`80fm_K0`3UiND2
0=_Kf`80alO70`2ZZZX208Z:RP80MWIf0`1gMgL208V9R@80YZJV0`32`/820=7Ad@80emOG0P3?cll3
0<;2`P80/K6a0P2IVIT307moO`80K6a/0P1RHV8306][J`80Ogmo0P2KVi/30;6a/@80`/;20P3?cll2
0=KFeP<0d];B0P2m_Kd209^KV`<0Kfm_0P17AdL202DU9@<04Q8B0P061PH200D51@<00P82103AcJT0
00<0dLfY0`020P8200@410801`L70`0B4Q8202DU9@80A4A40`1^KVh209^KV`80_kno0P3De=@30=oO
g`80g]kN0P3Lg=`30=CDe080`/;20P2UYJD308N7Q`@0MGEe0`2<S8`20:NWY`80alO70P3Kfm/30>GU
i@80fm_K0P37alL30:ZZZP80RXZ:0P1fMWH307MgM`80RHV90P2VYZH30<;2`P80dM7A0P3GemL20<o?
c`<0`/;20P2a/K4209VIV@<0Ogmo0P1/K6`2069RHP<0Jf][0P1oOgl209^KV`<0/K6a0P32`/820<o?
c`80e]KF0`3Bd]820;fm_@80Vi^K0`1_Kfl204M7A`809BDU0`0B4Q8200H61P801@D50`020P840=7=
Z@000`3AcJT300820P8010@40P071`L3018B4P809BDU0P14A4@306i^KP80Vi^K0P2o_kl20=CDe0<0
gmoO0P3Ng]h20=cLg0<0e=CD0P32`/820:FUY@<0QhN7101eMGD308b<S080YjNW0P37alL20=_Kf`<0
iNGU0P3Kfm/20<O7a`<0ZZZZ0P2:RXX207IfMP<0MgMg0P29RHT20:JVYP<0`/;20P3AdM420=OGe`80
clo?0`32`/820;6a/@80VIVI0`1oOgl206a/K080HV9R0`1[Jf/207moO`80Vi^K0`2a/K420<;2`P80
clo?0P3Fe]H30=;BdP80_Kfm0P2KVi/306m_K`80AdM70P0U9BD3018B4P801PH60P051@D300820P@0
dLfY00030=7=Z@<00@410P0410@200L71`<05ADE0P0];Bd2051@D0<0OWin0P2][Jd20=;BdP80i^KV
0`3]kNd40>_[j`<0iNGU0P3EeMD20;Vi^@<0U9BD0P1mOGd207UiN@<0S8b<0P2/[:`20<o?c`80j>SX
0`3alO420>SXj080d=3@0`2[Zj/208^;R`80N7Qh0`1lO7`209JFUP80^[Zj0`3GemL20>GUi@80i>CT
0P3Hf=P30<G5a@80];Bd0P2HV9P307moO`80J6QX0P1QHF4306QXJ080OWin0P2IVIT30;6a/@80a/K6
0P3GemL20>CTi0<0i^KV0P3De=@20:j^[P<0Ogmo0P1@D50202`/;0<04a<C0P071`L200<30`<00@41
103AcJT000<0dLfY0`010@4200@410801`L70`0E5AD202d];@80D51@0`1nOWh20:f][@80d];B0P3V
i^H30>g]k@@0jn_[0`3UiND20=GEe@80^KVi0`2DU9@207emO@80NGUi0`2<S8`20:b/[080clo?0P3X
j>P30?7al@80j>SX0P3@d=030:^[Z`80Rh^;0P1hN7P307alO080UYJF0P2j^[X30=OGe`80iNGU0P3T
i>@20=SHf0<0aLG50P2d];@209RHV0<0Ogmo0P1XJ6P2065QH@<0J6QX0P1nOWh209VIV@<0/K6a0P36
a/H20=OGe`80i>CT0`3Vi^H20=CDe080[Zj^0`1oOgl2051@D080;2`/0`0C4a<200L71`800`<30`01
0@440=7=Z@000`3AcJT300820P801@D50P0820P301LG5`80;Rh^0P1EEED308F5Q@80][Jf0P3GemL2
0>CTi0<0i^KV0P3Shn<20>GUi@<0i^KV0P3Jf]X20;jn_P<0UiNG0P1kNg/2071`L0<0P8200P2PX:02
0<K6aP80hn?S0`3_knl20>;RhP80aLG50`2MWId207inOP80L71`0`1iNGT209RHV080`L710`3Ogml2
0>g]k@80iNGU0P3Cdm<30;fm_@80Z:RX0P2@T90307MgM`80HF5Q0P1KFe/3069RHP80MWIf0P2=SHd3
0:RXZ080_;bl0P3Cdm<20>KViP<0jn_[0P3Ogml20;Zj^P<0QhN70P1DE5@202h^;P<05QHF0P092@T2
00820P<00@41103AcJT000<0dLfY0`020P8200D51@8020P80`0G5aL202h^;P80EEEE0`25QHD20;Jf
]P80emOG0P3Ti>@30>KViP80hn?S0P3UiND30>KViP80f][J0P2n_[h309NGU`80Ng]k0P1`L7030820
P080X:2P0P36a/H20>?Sh`<0kno_0P3Rh^820<G5a@<0WIfM0P1nOWh2071`L0<0NGUi0P2HV9P20<71
`@<0gmoO0P3]kNd20>GUi@80dm?C0`2m_Kd20:RXZ080T92@0`1gMgL2065QH@80Fe]K0`1RHV8207If
MP80SHf=0`2XZ:P20;bl_080dm?C0P3Vi^H30>_[j`80gmoO0P2j^[X308N7Q`80E5AD0P0^;Rh301HF
5P802@T90P020P8300410@@0dLfY00030=7=Z@<00@410P0410@200T92@<05ADE0P0_;bl205IFEP<0
R8R80P2f][H20=CDe080fm_K0`3Hf=P20=?Cd`80e]KF0`3Lg=`20=KFeP80_Kfm0`2FUYH207=cL`80
IFEU0`1]KFd208^;R`80];Bd0P3Fe]H30>;RhP80dm?C0P2_[jl308R8R080JVYZ0P1PH603075aL@80
UYJF0P31`L430>7Qh@80jn_[0P3Ti>@20=3@d0<0^[Zj0P2TY:@208f=S@<0Lg=c0P1PH60205MGE`<0
GemO0P1_Kfl208R8R0<0XJ6Q0P2h^;P20=3@d080i^KV0`3^k^h20>?Sh`80_kno0`2<S8`205UIF@80
;bl_0`0G5aL200X:2P8010@40`030`<40=7=Z@000`3AcJT300410@8010@40P092@T301DE5@80;bl_
0P1FEUH308R8R080][Jf0P3De=@20=_Kf`<0f=SH0P3Cdm<20=KFeP<0g=cL0P3Fe]H20;fm_@<0UYJF
0P1cLg<206EUI@<0KFe]0P2;Rh/20;Bd]080e]KF0`3Rh^820=?Cd`80[jn_0`28R8P206YZJP80H61P
0`1aLG4209JFUP80`L710`3QhN420>_[j`80i>CT0P3@d=030;Zj^P80Y:BT0P2=SHd307=cL`80H61P
0P1GEeL305mOG`80Kfm_0P28R8P30:6QX@80^;Rh0P3@d=020>KViP<0k^k^0P3Shn<20;no_`<0S8b<
0P1IFET202l_;`<05aLG0P0:2PX200@410<00`<3103AcJT000<0dLfY0`010@4200@410802@T90`0E
5AD202l_;`80EUIF0`28R8P20;Jf]P80e=CD0P3Kfm/30=SHf080dm?C0P3Fe]H30=cLg080e]KF0P2m
_Kd309JFUP80Lg=c0P1UIFD306e]K@80Rh^;0P2d];@20=KFeP<0h^;R0P3Cdm<20:n_[`<0R8R80P1Z
JVX2061PH0<0LG5a0P2FUYH20<71`@<0hN7Q0P3[jn/20>CTi080d=3@0`2j^[X20:BTY080SHf=0`1c
Lg<2061PH080EeMG0`1OGel206m_K`80R8R80`2QXJ420;Rh^080d=3@0P3Vi^H30>k^kP80hn?S0P2o
_kl308b<S080FEUI0P0_;bl301LG5`802PX:0P0410@300<30`@0dLfY00030=7=Z@<00`<30P0410@2
00P820<05ADE0P0`<30205MGE`<0QhN70P2c/k<20<k>cP80d=3@0`38b<P20<71`@80alO70`3Bd]82
0<o?c`80^;Rh0`2CTi<206e]K@80G5aL0`1RHV8207moO`80Z:RX0P3:b/X30=CDe080a<C40P2PX:03
07IfMP80EeMG0P1BDU8306MWI`80Shn?0P2n_[h30>3Ph080jn_[0P3Xj>P20=SHf0<0aLG50P2`/;02
09NGU`<0OWin0P1YJFT2061PH0<0I6AT0P1fMWH208n?S`<0YjNW0P30`<020=WIf@80k>c/0`3dm?@2
0>WYj@80`l?30`2?Shl205QHF080<30`0`0F5QH200T92@801PH60`010@440=7=Z@000`3AcJT300<3
0`8010@40P0820P301DE5@80<30`0P1GEeL308N7Q`80/k>c0P3>c/h20=3@d0<0b<S80P31`L420<O7
a`<0d];B0P3?cll20;Rh^0<0Ti>C0P1]KFd205aLG0<0HV9R0P1oOgl20:RXZ080b/[:0`3De=@20<C4
a080X:2P0`1fMWH205MGE`80DU9B0`1WIfL208n?S`80_[jn0`3Ph>020>_[j`80j>SX0P3Hf=P30<G5
a@80/;2`0P2GUiL307inOP80JFUY0P1PH60306ATI080MWIf0P2?Shl30:NWY`80`<300P3IfMT20>c/
k0<0m?Cd0P3YjNT20<?3``<0Shn?0P1HF5P2030`<0<05QHF0P092@T200H61P<00@41103AcJT000<0
dLfY1@030`<200T92@<05ADE0P0`<30205MGE`<0R8R80P2b/[820<W9b@80b<S80`2m_Kd20;Jf]P80
_[jn0`3;bl/20<[:bP80]KFe0`2ATI4206e]K@80Fe]K0`1SHf<20820P080YjNW0P36a/H30=3@d080
_Kfm0P2DU9@306UYJ@80Bd];0P16ATH305eMG@80QHF50P2c/k<30=OGe`80jNWY0P3[jn/20>CTi0<0
fMWI0P38b<P20;:b/P<0UIFE0P1kNg/206a/K0<0LG5a0P25QHD209nOW`<0][Jf0P3>c/h20>CTi080
m_Kf0`3kno/20>o_k`80aLG50`2?Shl205YJFP80<30`0`0F5QH200T92@800`<30`010@440=7=Z@00
0`3AcJT500<30`802@T90`0E5AD2030`<080EeMG0`28R8P20;:b/P80bLW90P38b<P30;fm_@80][Jf
0P2n_[h30<_;b`80b/[:0P2e]KD3096AT@80KFe]0P1KFe/306=SH`80P8200P2WYjL20<K6aP<0d=3@
0P2m_Kd209BDU0<0JFUY0P1;Bd/204I6AP<0GEeM0P25QHD20;>c/`<0emOG0P3YjNT20>_[j`80i>CT
0`3IfMT20<S8b080/[:b0`2EUID207]kN`80K6a/0`1aLG4208F5Q@80WinO0`2f][H20<k>cP80i>CT
0P3fm_H30?_kn`80kno_0P35aLD308n?S`80FUYJ0P0`<30301HF5P802@T90P030`<300410@@0dLfY
00030=7=Z@<00`<30P051@D200T92@<05QHF0P0_;bl205IFEP<0QhN70P2a/K420<S8b080a/K60`2l
_;`20;:b/P80^k^k0`36a/H20<[:bP80]KFe0`2EUID207AdM080IFEU0`1_Kfl208b<S080/K6a0P3?
cll30=?Cd`80^[Zj0P2?Shl306=SH`80@d=30P0n?Sh3059BDP80MGEe0P2RXZ830<K6aP80gMgM0P3W
inL20>[ZjP<0inOW0P3Ng]h20<[:bP<0[:b/0P2>SXh207YjNP<0N7Qh0P2:RXX20:>SX`<0_Kfm0P3E
eMD20>WYj@80no_k0`3oool20>g]k@80b<S80`2ATI4205]KF`80<C4a0`0E5AD200T92@800`<30`02
0P840=7=Z@000`3AcJT300<30`801@D50P092@T301HF5P80;bl_0P1FEUH308N7Q`80/K6a0P38b<P2
0<K6aP<0_;bl0P2b/[820;^k^`<0a/K60P3:b/X20;Fe]@<0UIFE0P1dM7@206EUI@<0Kfm_0P2<S8`2
0;6a/@80clo?0`3Cdm<20;Zj^P80Shn?0`1SHf<204=3@`80?Shn0`1BDU8207EeM@80XZ:R0`36a/H2
0=gMg@80inOW0P3Zj^X30>OWi`80g]kN0P3:b/X30:b/[080SXj>0P1jNWX307QhN080RXZ:0P2SXj<3
0;fm_@80eMGE0P3YjNT20?_kn`<0oooo0P3]kNd20<S8b0<0TI6A0P1KFe/2034a<@<05ADE0P092@T2
00<30`<00P82103AcJT000<0dLfY0`020P8200<30`802@T90`0E5AD202h^;P80EUIF0`28R8P20;2`
/080bLW90P3:b/X30;fm_@80][Jf0P2m_Kd30<W9b@80c<c<0P2i^KT309ZJVP80OGem0P1cLg<308:2
PP80XJ6Q0P36a/H20=cLg0<0g]kN0P2o_kl208n?S`<0GemO0P0o?cl203Lg=`<0A4A40P1UIFD208^;
R`<0[Jf]0P37alL20=SHf080i>CT1@3[jn/20=_Kf`<0_Kfm0P2IVIT20820P0<0Ng]k0P27QhL209fM
W@<0][Jf0P3>c/h20>CTi080m_Kf0`3moOd20>_[j`80a/K60`2@T90205YJFP80<30`0`0G5aL200P8
208010@40`030`<40=7=Z@000`3AcJT300820P800`<30P092@T301DE5@80;Rh^0P1FEUH308R8R080
/;2`0P39bLT20<[:bP<0_Kfm0P2f][H20;fm_@<0bLW90P3<c<`20;Vi^@<0VYZJ0P1mOGd207=cL`<0
PX:20P2QXJ420<K6aP80g=cL0`3Ng]h20;no_`80Shn?0`1OGel203lo?`80=cLg0`14A4@206EUI@80
Rh^;0`2][Jd20<O7a`80f=SH0P3Ti>@50>_[j`80fm_K0`2m_Kd209VIV@80P8200`1kNg/208N7Q`80
WIfM0`2f][H20<k>cP80i>CT0P3fm_H30?gmo@80jn_[0P36a/H3092@T080FUYJ0P0`<30301LG5`80
20P80P0410@300<30`@0dLfY00030=7=Z@<00P820P030`<200T92@<05ADE0P0^;Rh205IFEP<0R8R8
0P2`/;020<W9b@80b/[:0`2m_Kd20;Jf]P80_Kfm0`39bLT20<c<c080^KVi0`2JVYX207emO@80Lg=c
0`22PX820:6QX@80a/K60P3Lg=`30=kNgP80_kno0P2?Shl305mOG`80?clo0P0g=cL304A4A080IFEU
0P2;Rh/30:f][@80alO70P3Hf=P20>CTi0D0jn_[0P3Kfm/30;fm_@80VIVI0P20P80307]kN`80QhN7
0P2MWId30;Jf]P80c/k>0P3Ti>@20?KfmP<0oOgm0P3[jn/20<K6aP<0T92@0P1JFUX2030`<0<05aLG
0P0820P200@410<00`<3103AcJT000<0dLfY0`020P8200H61P8020P80`0H61P202l_;`80EUIF0`28
R8P20;>c/`80cLg=0P3@d=030<O7a`80`/;20P38b<P30=3@d080dM7A0P2n_[h309jNWP80QXJ60P22
PX8309:BTP80/k>c0P3Fe]H20>SXj0<0h^;R0P32`/8208n?S`<0GEeM0P0k>c/202l_;`<0>CTi0P1D
E5@207AdM0<0U9BD0P2`/;020<C4a080f=SH0`3WinL20>k^kP80h>3P0`35aLD209jNWP80PH610`1f
MWH20820P080Ti>C0`2YZJT20<71`@80f=SH0P3[jn/30?Cdm080inOW0P32`/8308n?S`80FEUI0P0_
;bl301LG5`802@T90P0410@300820P@0dLfY00030=7=Z@<00P820P061PH200P820<061PH0P0_;bl2
05IFEP<0R8R80P2c/k<20<g=c@80d=3@0`37alL20<;2`P80b<S80`3@d=020=7Ad@80_[jn0`2NWYh2
08J6QP80PX:20`2BTY820;>c/`80e]KF0P3Xj>P30>;RhP80`/;20P2?Shl305eMG@80>c/k0P0_;bl3
03Ti>@80E5AD0P1dM7@309BDU080/;2`0P34a<@20=SHf0<0inOW0P3^k^h20>3Ph0<0aLG50P2NWYh2
0861P@<0MWIf0P20P80209>CT`<0ZJVY0P31`L420=SHf080jn_[0`3dm?@20>OWi`80`/;20`2?Shl2
05UIF@80;bl_0`0G5aL200T92@8010@40`020P840=7=Z@000`3AcJT300410@800`<30P092@T301HF
5P80;bl_0P1FEUH308R8R080][Jf0P3De=@20=_Kf`<0emOG0P3Cdm<20=KFeP<0g=cL0P3GemL20<30
`0<0X:2P0P29RHT208F5Q@<0UiNG0P2j^[X20=_Kf`80k>c/0`3Shn<20<71`@80SXj>0`1KFe/203Xj
>P80;2`/0`0d=3@204a<C080JVYZ0`29RHT20:BTY080^k^k0P3AdM430>CTi080k>c/0P3Rh^830<G5
a@80WinO0P22PX8307=cL`80NWYj0P2>SXh30:6QX@80^;Rh0P3?cll20>CTi0<0kno_0P3Rh^820;no
_`<0S8b<0P1HF5P202l_;`<05ADE0P071`L200@410<00P82103AcJT000<0dLfY0`010@4200<30`80
2@T90`0F5QH202l_;`80EUIF0`28R8P20;Jf]P80e=CD0P3Kfm/30=OGe`80dm?C0P3Fe]H30=cLg080
emOG0P30`<030:2PX080RHV90P25QHD309NGU`80^[Zj0P3Kfm/20>c/k0<0hn?S0P31`L4208j>SP<0
Fe]K0P0j>SX202`/;0<0=3@d0P1<C4`206YZJP<0RHV90P2TY:@20;^k^`80dM7A0`3Ti>@20>c/k080
h^;R0`35aLD209nOW`80PX:20`1cLg<207YjNP80SXj>0`2QXJ420;Rh^080clo?0P3Ti>@30>o_k`80
h^;R0P2o_kl308b<S080F5QH0P0_;bl301DE5@801`L70P0410@300820P@0dLfY00030=7=Z@<00P82
0P0410@200T92@<05ADE0P0/;2`205ADE0<0QXJ60P2e]KD20=OGe`80iNGU0`3Vi^H20>?Sh`D0i^KV
0P3Lg=`20<;2`P<0W9bL0P23Ph<207emO@<0Shn?0P2^[Zh20<o?c`80h>3P0`3IfMT20;Vi^@80QhN7
0`1GEeL203Ph>080;Bd]0`0f=SH204e=C@80KVi^0`2=SHd20:JVYP80_[jn0P3De=@30>GUi@80kNg]
0P3QhN430<C4a080WinO0P21PH4307IfMP80OWin0P2BTY830:RXZ080_kno0P3De=@20>KViP<0k>c/
0P3Ogml20;Zj^P<0QhN70P1DE5@202h^;P<05ADE0P0820P200@410<00P82103AcJT000<0dLfY0`02
0P8200@410802@T90`0E5AD202`/;080E5AD0`26QXH20;Fe]@80emOG0P3UiND30>KViP80hn?S1@3V
i^H20=cLg080`/;20`2LW9`208>3P`80OGem0`2?Shl20:j^[P80clo?0P3Ph>030=WIf@80^KVi0P27
QhL305MGE`80>3Ph0P0];Bd303Hf=P80CDe=0P1^KVh308f=S@80YZJV0P2n_[h20=CDe0<0iNGU0P3]
kNd20>7Qh@<0a<C40P2OWil20861P@<0MWIf0P1nOWh209:BTP<0Z:RX0P2o_kl20=CDe080i^KV0`3/
k>`20=oOg`80^[Zj0`27QhL205ADE080;Rh^0`0E5AD200P8208010@40`020P840=7=Z@000`3AcJT3
00820P8010@40P092@T301DE5@80:b/[0P1ADE4307inOP80[Zj^0P3Bd]820>GUi@<0jn_[0P3/k>`2
0>_[j`<0i^KV0P3Fe]H20;Jf]P<0T92@0P1cLg<206a/K0<0N7Qh0P2FUYH20;:b/P80aLG50`32`/82
0:NWY`80O7al0`1BDU8203De=@80;Bd]0`0g=cL205ADE080LW9b0`2DU9@20;6a/@80aLG50P3GemL3
0>GUi@80i^KV0P3GemL30;Zj^P80V9RH0P1nOWh307UiN@80QHF50P2KVi/30;>c/`80aLG50P3Hf=P2
0>?Sh`<0i^KV0P3EeMD20:n_[`<0Ogmo0P1@D50202`/;0<04a<C0P092@T200@410<00P82103AcJT0
00<0dLfY0`020P8200@410802@T90`0E5AD202/[:`80DE5A0`1nOWh20:j^[P80d];B0P3UiND30>_[
j`80k>c/0P3[jn/30>KViP80e]KF0P2f][H3092@T080Lg=c0P1/K6`307QhN080UYJF0P2b/[820<G5
a@<0`/;20P2WYjL207alO0<0DU9B0P0e=CD202d];@<0=cLg0P1DE5@2079bLP<0U9BD0P2a/K420<G5
a@80emOG0`3UiND20>KViP80emOG0`2j^[X209RHV080OWin0`1iNGT208F5Q@80Vi^K0`2c/k<20<G5
a@80f=SH0P3Shn<30>KViP80eMGE0P2_[jl307moO`80D51@0P0/;2`301<C4`802@T90P0410@30082
0P@0dLfY00030=7=Z@<00P820P0410@200T92@<05ADE0P0[:b/2055AD@<0OWin0P2^[Zh20=;BdP80
iNGU0`3[jn/20>c/k080jn_[0`3Vi^H20=KFeP80][Jf0`2@T90207=cL`80K6a/0`1hN7P209JFUP80
/[:b0P35aLD30<;2`P80YjNW0P1lO7`3059BDP80=CDe0P0];Bd303Lg=`80E5AD0P1bLW8309BDU080
/K6a0P35aLD20=OGe`<0iNGU0P3Vi^H20=OGe`<0^[Zj0P2HV9P207inOP<0NGUi0P25QHD209^KV`<0
/k>c0P35aLD20=SHf080hn?S0`3Vi^H20=GEe@80[jn_0`1oOgl2051@D080;2`/0`0C4a<200T92@80
10@40`020P840=7=Z@000`3AcJT500820P801`L70`0A4A4202@T9080ADE50`1_Kfl209bLW080_kno
0P3Cdm<30=gMg@80gmoO0P3Lg=`30=?Cd`80`<300P2QXJ4307emO@80GemO0P1ADE4305eMG@80LW9b
0P2>SXh20:2PX0<0XJ6Q0P2>SXh206][J`<0AdM70P0c<c<202/[:`<0=cLg0P1BDU8207AdM0<0UYJF
0P2][Jd20<?3``80clo?0`3Fe]H20=CDe080`<300`2VYZH208V9R@80MGEe0`1gMgL208B4Q080WIfM
0`2a/K420<?3``80c/k>0P3De=@30=;BdP80_Kfm0P2JVYX306m_K`80ADE50P0V9RH3010@40801`L7
0P030`<300410@@0dLfY00030=7=Z@D00P820P071`L3014A4@8092@T0P15ADD306m_K`80W9bL0P2o
_kl20=?Cd`<0gMgM0P3Ogml20=cLg0<0dm?C0P30`<020:6QX@<0OGem0P1OGel2055AD@<0GEeM0P1b
LW8208j>SP80X:2P0`2QXJ4208j>SP80Jf][0`17AdL203<c<`80:b/[0`0g=cL2059BDP80M7Ad0`2F
UYH20:f][@80`l?30P3?cll30=KFeP80e=CD0P30`<030:JVYP80RHV90P1eMGD307MgM`80Q8B40P2M
WId30;6a/@80`l?30P3>c/h20=CDe0<0d];B0P2m_Kd209ZJVP<0Kfm_0P15ADD202HV9P<0410@0P07
1`L200<30`<00@41103AcJT000<0dLfY0`020P8200@410801PH60`0=3@d201dM7@80=SHf0`1HF5P2
07alO080W9bL0P2_[jl30;Zj^P80_;bl0P2j^[X30:n_[`80W9bL0P1oOgl3061PH080B4Q80P0h>3P3
03hn?P80Cdm?0P1UIFD207MgM`<0NGUi0P1]KFd205=CD`<0=cLg0P0U9BD202@T90<0<30`0P1;Bd/2
06UYJ@<0QHF50P2LW9`20:^[Z`80/[:b0`2f][H20:n_[`80WYjN0`25QHD206m_K`80Hf=S0`1UIFD2
07AdM080RHV90`2LW9`20:^[Z`80/[:b0P2e]KD30:j^[P80Vi^K0P1lO7`305QHF080=cLg0P0N7Qh3
00h>3P801PH61@030`<40=7=Z@000`3AcJT300820P8010@40P061PH300d=3@807AdM0P0f=SH305QH
F080O7al0P2LW9`20:n_[`<0^[Zj0P2l_;`20;Zj^P<0[jn_0P2LW9`207moO`<0H61P0P18B4P203Ph
>0<0?Shn0P1?Cdl206EUI@80MgMg0`1iNGT206e]K@80De=C0`0g=cL202DU9@8092@T0`0`<30204];
B`80JFUY0`25QHD209bLW080Zj^[0P2b/[830;Jf]P80[jn_0P2NWYh308F5Q@80Kfm_0P1SHf<306EU
I@80M7Ad0P29RHT309bLW080Zj^[0P2b/[820;Fe]@<0[Zj^0P2KVi/207alO0<0F5QH0P0g=cL201hN
7P<03Ph>0P061PH500<30`@0dLfY00030=7=Z@<00@410P020P8200H61P<02PX:0P0D51@202LW9`<0
?clo0P1HF5P206m_K`80Ogmo0`25QHD208V9R@80QXJ60`1nOWh206m_K`80FUYJ0`14A4@2030`<080
9BDU0`0W9bL2038b<P80@T920P1>CTh305=CD`80BTY:0P0h>3P302HV9P806a/K0P0J6QX302HV9P80
>CTi0P1?Cdl306EUI@80M7Ad0P21PH4208J6QP<0Q8B40P20P802079bLP<0H61P0P1@D50204M7A`<0
CDe=0P1IFET206UYJ@<0MWIf0P21PH4208B4Q080QHF50`1mOGd2071`L080FUYJ0`0o?cl202LW9`80
5aLG0`0;2`/200H61P800`<30`010@440=7=Z@000`3AcJT300410@800P820P061PH300X:2P8051@D
0P0W9bL303lo?`80F5QH0P1_Kfl207moO`<0QHF50P29RHT208J6QP<0OWin0P1_Kfl205YJFP<0A4A4
0P0`<30202DU9@<09bLW0P0b<S820492@P80CTi>0`1CDe<204Y:BP80>3Ph0`0V9RH201/K6`806QXJ
0`0V9RH203Ti>@80Cdm?0`1UIFD207AdM080PH610P26QXH308B4Q080P8200P1bLW83061PH080D51@
0P17AdL304e=C@80FEUI0P1YJFT307IfMP80PH610P24Q8@208F5Q@<0OGem0P1`L70205YJFP<0?clo
0P0W9bL201LG5`<02`/;0P061PH200<30`<00@41103AcJT000<0dLfY1@020P8200@410<01`L70P0=
3@d201PH60<09bLW0P0g=cL204I6AP80Cdm?0`1DE5@205MGE`80EEEE0`1@D50204I6AP80=cLg0`0Y
:BT201`L708051@D0`0E5AD201dM7@809RHV0P0_;bl303<c<`80;2`/0P0T92@301TI6@804A4A0P0B
4Q8301TI6@809bLW0P0d=3@30492@P80Bd];0P1BDU8205EEE@<0E5AD0P1?Cdl204Q8B0<0?3`l0P0b
<S8202`/;0<0<C4a0P0i>CT204A4A0<0C4a<0P1BDU8205EEE@80E5AD0`1?Cdl204E5A@80=cLg0`0V
9RH201LG5`803Ph>0`071`L700<30`@0dLfY00030=7=Z@D00P820P0410@300L71`803@d=0P0H61P3
02LW9`80=cLg0P16ATH204m?C`<0E5AD0P1GEeL205EEE@<0D51@0P16ATH203Lg=`<0:BTY0P0L71`2
01@D50<05ADE0P0M7Ad202HV9P80;bl_0`0c<c<202`/;08092@T0`0I6AT2014A4@804Q8B0`0I6AT2
02LW9`80=3@d0`12@T8204];B`80DU9B0P1EEED305ADE080Cdm?0P18B4P303`l?080<S8b0P0/;2`3
034a<@80>CTi0P14A4@304a<C080DU9B0P1EEED205ADE0<0Cdm?0P15ADD203Lg=`<09RHV0P0G5aL2
00h>3P<01`L71`030`<40=7=Z@000`3AcJT500820P8010@40`071`L200d=3@8061PH0`0W9bL203Lg
=`80ATI60P1?Cdl305ADE080EeMG0P1EEED3051@D080ATI60P0g=cL302TY:@8071`L0P0D51@301DE
5@807AdM0P0V9RH202l_;`<0<c<c0P0/;2`202@T90<06ATI0P0A4A42018B4P<06ATI0P0W9bL203@d
=0<0@T920P1;Bd/2059BDP80EEEE0`1DE5@204m?C`80B4Q80`0l?3`2038b<P80;2`/0`0a<C4203Ti
>@80A4A40`1<C4`2059BDP80EEEE0P1DE5@304m?C`80ADE50P0g=cL302HV9P805aLG0P0>3Ph300L7
1`L00`<3103AcJT000<0dLfY1@030`<200820P<00`<30P071`L200d=3@<05ADE0P0M7Ad202DU9@80
:RXZ0`0^;Rh2030`<080;2`/0`0[:b/202@T90807AdM0`0F5QH200l?3`802PX:0`0;2`/200h>3P80
4a<C0P0H61P301XJ6P805aLG0P0C4a<300h>3P802PX:0P0820P300d=3@805ADE0P0L71`302@T9080
:RXZ0P0];Bd202h^;P<0;Bd]0P0/;2`202HV9P<07alO0P0K6a/201PH60<06QXJ0P0P820202@T90<0
:RXZ0P0/;2`202d];@80;bl_0`0Z:RX202DU9@807QhN0`0G5aL200d=3@8020P80`0410@200<30`80
0P820`010@440=7=Z@000`3AcJT500<30`800P820`030`<200L71`803@d=0`0E5AD201dM7@809BDU
0P0Z:RX302h^;P80<30`0P0/;2`302/[:`8092@T0P0M7Ad301HF5P803`l?0P0:2PX300/;2`803Ph>
0P0C4a<201PH60<06QXJ0P0G5aL201<C4`<03Ph>0P0:2PX200P820<03@d=0P0E5AD201`L70<092@T
0P0Z:RX202d];@80;Rh^0`0];Bd202`/;0809RHV0`0O7al201/K6`8061PH0`0J6QX2020P808092@T
0`0Z:RX202`/;080;Bd]0P0_;bl302XZ:P809BDU0P0N7Qh301LG5`803@d=0P0820P300@410800`<3
0P020P8300410@@0dLfY00030=7=Z@D00@410P020P8500<30`801PH60`0:2PX200`<30804A4A0P0D
51@301DE5@805QHF1@0E5AD2010@40803@d=0`0;2`/200P820801`L70`051@D200H61P802@T90P0;
2`/300`<30802@T90P0:2PX300L71`801PH60P071`L300P820802PX:0P0>3Ph3014A4@805ADE0P0G
5aL201@D50<05ADE0P0C4a<2018B4P<03`l?0P0=3@d200/;2`D03Ph>0P0A4A4501DE5@805QHF0P0E
5AD3018B4P804A4A0P0?3`l300X:2P801PH60P030`<300410@800`<31@010@440=7=Z@000`3AcJT5
00410@800P821@030`<200H61P<02PX:0P0<30`2014A4@8051@D0`0E5AD201HF5PD05ADE0P0@4102
00d=3@<02`/;0P0820P200L71`<01@D50P061PH200T92@802`/;0`0<30`200T92@802PX:0`071`L2
00H61P801`L70`0820P200X:2P803Ph>0`0A4A4201DE5@805aLG0P0D51@301DE5@804a<C0P0B4Q83
00l?3`803@d=0P0;2`/500h>3P804A4A1@0E5AD201HF5P805ADE0`0B4Q82014A4@803`l?0`0:2PX2
00H61P800`<30`010@4200<30`D00@41103AcJT000<0dLfY0`00000200820PD00@410P020P8200D5
1@<00`<30P061PH200L71`D020P80P0:2PX500T92@@01PH60`051@D200<30`8010@40`020P8400@4
10801@D50`0410@200H61P801@D51@030`<200820PD010@41@061PH200P820802PX:2@0820P300D5
1@801PH60P0410@300H61P801`L70P0820P300T92@8020P80P092@T200X:2P<01`L70P0820P200L7
1`<01@D510030`<300820P800@410P00000300820P@0dLfY00030=7=Z@<000000P020P8500410@80
0P820P051@D300<30`801PH60P071`L500P820802PX:1@092@T400H61P<01@D50P030`<200@410<0
0P82100410@200D51@<010@40P061PH200D51@D00`<30P020P8500@410D01PH60P0820P200X:2PT0
20P80`051@D200H61P8010@40`061PH200L71`8020P80`092@T200P820802@T90P0:2PX300L71`80
20P80P071`L300D51@@00`<30`020P8200410@8000000`020P840=7=Z@000`3AcJT300410@800000
0P010@4300<30`8000002@020P8700@410800`<30`0410@200<30`8010@40`020P8700410@@00`<3
0P020P8700<30``00P821@030`<600@410<00P820P051@D200820PL00`<30`0410@200<30`L010@4
10051@D300<30`L00P820P030`<2000000D00P820P00000300410@@0dLfY00030=7=Z@<00@410P00
000200410@<00`<30P00000900820PL010@40P030`<300@410800`<30P0410@300820PL00@411003
0`<200820PL00`<330020P8500<30`H010@40`020P8200D51@800P821`030`<300@410800`<31`04
10@400D51@<00`<31`020P8200<30`8000001@020P82000000<00@41103AcJT000<0dLfY0`010@42
000000800@410`030`<2000000T00P821`0410@200<30`<010@40P030`<200@410<00P821`010@44
00<30`800P821`030`<<00820PD00`<31P0410@300820P801@D50P020P8700<30`<010@40P030`<7
00@410@01@D50`030`<700820P800`<30P00000500820P8000000`010@440=7=Z@000`3AcJT30000
00T00@410P030`<300410@800P820P030`<200410@D00P820P00000500410@D00P820P030`<50041
0@800`<30P010@4200820P<00`<310020P8700410@<00P820P030`<200410@D00P8210010@430082
0P800@410P00000300<30`T00P820P030`<300410@8010@40P020P8200410@D00P820P0410@:0082
0P8010@40P00000300410@@0dLfY00030=7=Z@<000002@010@4200<30`<00@410P020P8200<30`80
0@411@020P82000000D00@411@020P8200<30`D00@410P030`<200410@800P820`030`<400820PL0
0@410`020P8200<30`800@411@020P8400410@<00P820P010@42000000<00`<32@020P8200<30`<0
0@410P0410@200820P800@411@020P8200@410X00P820P0410@2000000<00@41103AcJT00900dLfY
002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {270.812, 201.062}} -> {-80.2954, 87.0512, \
0.436562, 0.436562}}]
}, Open  ]],

Cell[TextData[{
  "The situation simulated here is that of a blind deconvolution problem, \
that is to say there is no information on the PSF. The matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["s",
          "TB"], TraditionalForm]]],
  " stores the values of an initial guess for the inverse filter, created by \
means of the Dirac delta function. Having defined this, we apply the \
restoration algorithm on the observed image ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["g",
            "TB"], "~"], TraditionalForm]]],
  "; the time required by the restoration is also shown."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({p\_y, \ p\_x}\  = \ {10, \ 10};\)\), "\[IndentingNewLine]", 
    \(\(s\  = \ 
        Table[DiscreteDelta[i, \ j], \ {i, \ \(-p\_y\), \ 
            p\_y}, \ {j, \ \(-p\_x\), \ p\_x}];\)\), "\[IndentingNewLine]", 
    \(\(\[Mu]\  = \ {0, 0, 1\ /\ 10, 1\ /\ 10};\)\), "\[IndentingNewLine]", 
    \(\({n\_y, \ n\_x}\  = \ Dimensions[f];\)\ \ \  (*\ 
      exact\ support\ *) \), "\[IndentingNewLine]", 
    \(\(Timing[\({res, \ value, \ variation, \ error}\  = \ 
            NSHRIF[g\&~, \ s, \ \[Mu], \ n\_y, \ n\_x, \ 
              NSHRIFMaxIterations\  \[Rule] \ 50, \ 
              NSHRIFTrueF\  \[Rule] \ f, \ 
              NSHRIFRestoredList\  \[Rule] \ True];\)]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \(63.57`\ Second\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "When the option ",
  StyleBox["NSHRIFRestoredList", "TB",
    FontFamily->"Courier"],
  " is set to ",
  StyleBox["True", "TB",
    FontFamily->"Courier"],
  ", the restoration algorithm returns the list ",
  StyleBox["res", "TB",
    FontFamily->"Courier"],
  " of the images restored at each iteration. ",
  StyleBox["value", "TB",
    FontFamily->"Courier"],
  " stores the cost function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " at each iteration, ",
  StyleBox["variation", "TB",
    FontFamily->"Courier"],
  " contains the relative variation between the values of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " at two consecutive iterations and the ",
  StyleBox["error", "TB",
    FontFamily->"Courier"],
  " vector measures the relative differences between the restored images and \
the true image, if available. The stopping criterion is based on a maximum \
number of iterations and on a default tolerance on both the value of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"J", "(", 
          StyleBox["\[GothicS]",
            "TB"], ")"}], TraditionalForm]]],
  " and its relative variation; the options ",
  StyleBox["NSHRIFEpsilon", "TB",
    FontFamily->"Courier"],
  " and ",
  StyleBox["NSHRIFStopEpsilon", "TB",
    FontFamily->"Courier"],
  " can be used to specify a tolerance for such quantities",
  StyleBox[".", "TB",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  "\nThe final result is given by the restored image obtained at the last \
iteration. It is possible to display the log information in order to analyze \
the behavior of the algorithm through the iterations."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(restored\  = \ Last[res];\)\), "\[IndentingNewLine]", 
    \(\(showImage[restored];\)\), "\[IndentingNewLine]", 
    \(\(Show[
        GraphicsArray[{{ListPlot[value, \ PlotJoined\  \[Rule] \ True, \ 
                PlotRange\  \[Rule] \ {0, \ Max[value]}, \ 
                PlotLabel\  \[Rule] \ "\<Cost function\>", \ 
                DisplayFunction\  \[Rule] Identity], \ 
              ListPlot[variation, \ PlotJoined\  \[Rule] \ True, \ 
                PlotRange\  \[Rule] \ {0, \ Max[variation]}, \ 
                PlotLabel\  \[Rule] \ "\<Relative variation\>", \ 
                DisplayFunction\  \[Rule] Identity]}, \ {ListPlot[error, \ 
                PlotJoined\  \[Rule] \ True, \ 
                PlotRange\  \[Rule] \ {0, \ Max[error]}, \ 
                PlotLabel\  \[Rule] \ "\<Relative error\>", \ 
                DisplayFunction\  \[Rule] Identity]}}], \ 
        ImageSize\  \[Rule] \ 72\ *\ 4];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000005697B4C1ABA3A17E4304083579A0A49B71888C936F3100023466919DAE
CDD3BF8E471219588B9AA3959093885A00000000000000
0000000000000084D2EFF7C8CCD4B96E2005248EB5E3D1DBC4D3BD6C220A2562A5B9D2C7
DAFFF0AD7129386EBCC7B3AEBBCFB88400000000000000
0000000000000095E6F5E5A9BCD6CD992807175F9FCFD7D0CBD096540C00237EB9BAA088
88CAB79C48211C528383736897CACE9100000000000000
00000000000000A8D6BD875874B8D8A8380500275F8FB4C6B7A15F2D00001F82AEAC561B
0D375D5319070926252500004A85BF9600000000000000
00000000000000A3D4A4581D3D9EE2C262030000004484AB9C5F330600003D94B9883900
00001911000000000B0000001A6EAB8B00000000000000
00000000000000A7DCA041002DA2E4CF7F0E0000001564867F62280000185DC2EBB16A22
0717211F08000D32563C1F1E3B83BC8A00000000000000
00000000000000BAE6A73F0032B3E6D07A1E000000164D7C8153301A184785CFF9E9AB83
7F8693622C0F429ED9BF9A818DAFD68900000000000000
00000000000000B6E5A84E002E86E8C27F34010705285C7968483B31446079B8D7DCBAB1
BCDBD1994F2539A4ECF7D4A3B1C8B79A00000000000000
0000000000000096C89416000063BAA2612A214056736C8D653E2E3E4C49596A7073666E
99E1EEB543031E629DAA8A6776A7A28600000000000000
000000000000007FA46C0000003784793A274F7099A48E715023112129201B0100000001
4EAFBFA82800001037280700105D8B6C00000000000000
0000000000000075A1691200003C725120183F77B1C5B1794D12000E0F01000000000000
1D85B78F2100000000000000004B7A7300000000000000
0000000000000072AF8F4E1334659179180320618FAAA78B5A0A00000004001718000001
3FABCC9F4600000024130000246FA18100000000000000
000000000000007CBCC09F7F89A3AF701A00061D5D6886895E1F0000000034416B795B62
96C0CF9F47001A568A9A61616BAEBF8800000000000000
0000000000000082C5C9C1B2A8AEAA773200000212445E767138010600002D6EB7AFB9A4
B5D4AB85451A588DDDD2C29797B6A47300000000000000
0000000000000048929BAB91978C7A51260B00000008384E5C2D000000002C6A9BB9A885
8D88783D1A173B80B5B8A9828084754800000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000205IFEP80UiNG
0P2d];@30<71`@80Zj^[0P2SXj<30:6QX@80OWin0P13@d<300@4108020P80P0e=CD307UiN@80X:2P
0P2TY:@209^KV`<0LG5a0P28R8P208b<S0<0Ti>C0P1_Kfl2034a<@<000000P020P8203@d=0<0IVIV
0P2ATI4209fMW@80[Zj^0`3=cLd20=?Cd`80_kno0`2>SXh204M7A`804Q8B0`0I6AT205QHF080Rh^;
0`2JVYX20:>SX`80UIFE0P2@T90309>CT`80R8R80P1JFUXA000000@0dLfY00030=7=ZA4000000P1F
EUH209NGU`80];Bd0`31`L420:^[Z`80Xj>S0`2QXJ4207inOP80@d=30`0410@200P82080=CDe0`1i
NGT20:2PX080Y:BT0P2KVi/3075aL@80R8R80P2<S8`309>CT`80Kfm_0P0a<C43000000800P820P0d
=3@306IVIP80TI6A0P2MWId20:j^[P<0cLg=0P3Cdm<20;no_`<0SXj>0P17AdL2018B4P<06ATI0P1H
F5P208^;R`<0VYZJ0P2SXj<209FEU@80T92@0`2CTi<208R8R080FUYJ4@0000040=7=Z@000`3AcJTA
00000080Q8B40P3Bd]820>o_k`<0moOg0P38b<P20<c<c0<0e=CD0P2i^KT206i^KP<0820P0P051@D2
02@T90<0SXj>0P2e]KD20>?Sh`80dM7A0`3Kfm/20<C4a080dm?C0`2m_Kd206a/K0808R8R0`0:2PX2
02DU9@80HV9R0`2UYJD20;Vi^@80d];B0P37alL30=[JfP80oooo0P3`l?030:f][@80LG5a0P0Y:BT3
03Ph>080KVi^0P2l_;`30<O7a`80/k>c0P2^[Zh20;^k^`<0clo?0P2h^;P208B4Q1400000103AcJT0
00<0dLfY4@00000208B4Q080d];B0P3_knl30?Ogm`80b<S80P3<c<`30=CDe080^KVi0P1^KVh3020P
80801@D50P0T92@308j>SP80]KFe0P3Shn<20=7Ad@<0fm_K0P34a<@20=?Cd`<0_Kfm0P1/K6`2028R
8P<02PX:0P0U9BD2069RHP<0YJFU0P2i^KT20=;BdP80alO70`3Jf]X20?ooo`80l?3`0`2][Jd2075a
L@80:BTY0`0h>3P206i^KP80_;bl0`37alL20;>c/`80[Zj^0P2k^k/30<o?c`80^;Rh0P24Q8@A0000
00@0dLfY00030=7=ZA4000000P24Q8@20=;BdP80kno_0`3gmoL20<S8b080c<c<0`3De=@20;Vi^@80
KVi^0`0P820200D51@8092@T0`2>SXh20;Fe]@80hn?S0P3AdM430=_Kf`80a<C40P3Cdm<30;fm_@80
K6a/0P0R8R8300X:2P809BDU0P1RHV830:FUY@80^KVi0P3Bd]820<O7a`<0f][J0P3oool20?3`l0<0
[Jf]0P1aLG4202TY:@<0>3Ph0P1^KVh20;bl_0<0alO70P2c/k<20:j^[P80^k^k0`3?cll20;Rh^080
Q8B44@0000040=7=Z@000`3AcJTA00000080UIFE0P3Vi^H20?Gem@<0iNGU0P2YZJT20;bl_0<0e]KF
0P3=cLd209VIV@<0:2PX0P071`L201LG5`<0GemO0P2OWil20<o?c`80emOG0`3@d=020<_;b`80d=3@
0`2FUYH205ADE08030`<0`00000202<S8`80OWin0`2i^KT20;Zj^P80X:2P1@28R8P20<[:bP80]kNg
0`2LW9`204Q8B0808B4Q0`0L71`2059BDPD0Ph>30P1cLg<206QXJ080UiNG0`3:b/X20<k>cP80TI6A
4@0000040=7=Z@000`3AcJTA00000080UIFE0P3Vi^H20?Gem@<0iNGU0P2YZJT20;bl_0<0e]KF0P3=
cLd209VIV@<0:2PX0P071`L201LG5`<0GemO0P2OWil20<o?c`80emOG0`3@d=020<_;b`80d=3@0`2F
UYH205ADE08030`<0`00000202<S8`80OWin0`2i^KT20;Zj^P80X:2P1@28R8P20<[:bP80]kNg0`2L
W9`204Q8B0808B4Q0`0L71`2059BDPD0Ph>30P1cLg<206QXJ080UiNG0`3:b/X20<k>cP80TI6A4@00
00040=7=Z@000`3AcJTA00000080Z:RX0P3Fe]H20;fm_@<0QhN70P1HF5P207AdM0<0^;Rh0P3Hf=P2
0:RXZ0<0>3Ph0P051@D2000000<09bLW0P1OGel208n?S`80];Bd0`36a/H20;Ng]`80XJ6Q0`1OGel2
02d];@D000000P0O7al208:2PP<0[Zj^0P2/[:`205IFEP806a/K0`0=3@d203Lg=`80GEeM0`1CDe<2
01TI6@801`L70`092@T202HV9PD09BDU1000000204Y:BP<0QHF50P2o_kl209JFUQ400000103AcJT0
00<0dLfY4@0000020:RXZ080e]KF0P2m_Kd308N7Q`80F5QH0P1dM7@30;Rh^080f=SH0P2XZ:P303Ph
>0801@D50P00000302LW9`80GemO0P2?Shl20;Bd]0<0a/K60P2g]kL20:6QX@<0GemO0P0];Bd50000
00807alO0P22PX830:j^[P80[:b/0P1FEUH201/K6`<03@d=0P0g=cL205eMG@<0De=C0P0I6AT200L7
1`<02@T90P0V9RH502DU9@@000000P1:BTX308F5Q@80_kno0P2FUYHA000000@0dLfY00030=7=ZA40
00000P2SXj<20=CDe080Y:BT0`1HF5P201dM7@80?Cdm0`2NWYh20>;RhP80`/;20`1RHV8200<30`L0
00000P14A4@208B4Q0<0Zj^[0P2LW9`205mOG`<0<c<c0P061PH500000080?Cdm0P2DU9@30;Vi^@80
R8R80P0i>CT7000000806ATI0`0A4A49000000802`/;1`00000201XJ6P<0KVi^0P2[Zj/208^;Ra40
0000103AcJT000<0dLfY4@0000020:>SX`80e=CD0P2TY:@305QHF0807AdM0P0m?Cd309jNWP80h^;R
0P32`/83069RHP800`<31`00000204A4A080Q8B40`2[Zj/209bLW080GemO0`0c<c<200H61PD00000
0P0m?Cd209BDU0<0^KVi0P28R8P203Ti>@L000000P0I6AT3014A4@T000000P0;2`/7000000806QXJ
0`1^KVh20:^[Z`80Rh^;4@0000040=7=Z@000`3AcJTA00000080Xj>S0P3De=@20:BTY0<0F5QH0P0M
7Ad203dm?@<0WYjN0P3Rh^820<;2`P<0HV9R0P030`<700000080A4A40P24Q8@30:^[Z`80W9bL0P1O
Gel303<c<`801PH61@00000203dm?@80U9BD0`2i^KT208R8R080>CTi1`00000201TI6@<04A4A2@00
000200/;2`L000000P0J6QX306i^KP80Zj^[0P2;Rh/A000000@0dLfY00030=7=ZA4000000P2WYjL2
0=cLg080X:2P0`11@D4200000080;Bd]0`2RXZ820>CTi080clo?0`1oOgl200h>3PL000000P0E5AD2
06ATI0<0QXJ60P1oOgl2069RHP<0:2PX1000000301PH6080GEeM0P32`/830>_[j`80/K6a0P1ZJVX2
028R8P<01`L70P0G5aL2024Q8@<07alO0P0820P2000000<03@d=0P0b<S8205IFEP<0?3`l0P0O7al2
01hN7P80>c/k0`23Ph<20;bl_080RXZ:4@0000040=7=Z@000`3AcJTA00000080YjNW0P3Lg=`20:2P
X0<0@D510P00000202d];@<0XZ:R0P3Ti>@20<o?c`<0Ogmo0P0>3Ph7000000805ADE0P1TI6@308J6
QP80Ogmo0P1RHV8302PX:0@000000`0H61P205eMG@80`/;20`3[jn/20;6a/@80JVYZ0P0R8R8300L7
1`805aLG0P0Q8B4301lO7`8020P80P00000300d=3@80<S8b0P1FEUH303`l?0807alO0P0N7Qh203/k
>`<0Ph>30P2l_;`208Z:RQ400000103AcJT000<0dLfY4@0000020;Zj^P80i^KV0P2WYjL303lo?`80
00000P0b<S830;>c/`80i^KV0P3@d=0307YjNP807QhN1`00000201HF5P80CDe=0`1lO7`20861P@80
De=C0`0`<30201XJ6P8061PH0`17AdL208F5Q@80clo?0`3inOT20>WYj@80Zj^[0P23Ph<307moO`80
QXJ60P2CTi<3069RHP80;2`/0P0?3`l30492@P80WYjN0P3IfMT30;no_`80VYZJ0P21PH4208f=S@<0
[jn_0P3Fe]H208V9RA400000103AcJT000<0dLfY4@0000020;Zj^P80i^KV0P2WYjL303lo?`800000
0P0b<S830;>c/`80i^KV0P3@d=0307YjNP807QhN1`00000201HF5P80CDe=0`1lO7`20861P@80De=C
0`0`<30201XJ6P8061PH0`17AdL208F5Q@80clo?0`3inOT20>WYj@80Zj^[0P23Ph<307moO`80QXJ6
0P2CTi<3069RHP80;2`/0P0?3`l30492@P80WYjN0P3IfMT30;no_`80VYZJ0P21PH4208f=S@<0[jn_
0P3Fe]H208V9RA400000103AcJT000<0dLfY4@0000020;Jf]P80iNGU0P2XZ:P304i>CP8000000P0^
;Rh308J6QP80j>SX0P32`/8307moO`80=3@d0P010@4300L71`801@D50P0X:2P205aLG0<0NGUi0P1X
J6P204Q8B0<0>c/k0P0a<C4204A4A0<0H61P0P1iNGT20;Rh^0<0emOG0P3Lg=`20;Zj^P80/K6a0`2l
_;`20=_Kf`80dM7A0`2IVIT204m?C`809BDU0`0i>CT20:BTY080k>c/0`3gmoL20=CDe080Xj>S0P2a
/K430<S8b080]kNg0P2JVYXA000000@0dLfY00030=7=ZA4000000P2f][H20>GUi@80Z:RX0`1>CTh2
00000080;Rh^0`26QXH20>SXj080`/;20`1oOgl203@d=0800@410`071`L200D51@80:2PX0P1LG5`3
07UiN@80J6QX0P18B4P303/k>`80<C4a0P14A4@3061PH080NGUi0P2h^;P30=OGe`80g=cL0P2j^[X2
0;6a/@<0_;bl0P3Kfm/20=7Ad@<0VIVI0P1?Cdl202DU9@<0>CTi0P2TY:@20>c/k0<0moOg0P3De=@2
0:>SX`80/K6a0`38b<P20;Ng]`80VYZJ4@0000040=7=Z@000`3AcJTA00000080UYJF0P38b<P209BD
U0<05QHF1000000306=SH`80^[Zj0P2RXZ83065QH@80:RXZ0P0Q8B430410@080EUIF0P1cLg<206a/
K0<0SHf=0P1UIFD203hn?P<0;Rh^0P0n?Sh204a<C0<0BDU90P1IFET206YZJP<0L71`0P1cLg<206IV
IP80KVi^0`2IVIT20>7Qh@80k^k^0`2e]KD204=3@`800`<30`0N7Qh2069RHP80WIfM0`2ZZZX208Z:
RP80IfMW0P1fMWH30:NWY`80XZ:R0P26QXHA000000@0dLfY00030=7=ZA4000000P2FUYH20<S8b080
U9BD0`0F5QH4000000<0Hf=S0P2j^[X20::RXP<0HF5Q0P0Z:RX2024Q8@<0@4100P1FEUH207=cL`80
K6a/0`2=SHd206EUI@80?Shn0`0^;Rh203hn?P80C4a<0`19BDT205UIF@80JVYZ0`1`L70207=cL`80
IVIV0P1^KVh309VIV@80hN7Q0P3^k^h30;Fe]@80@d=30P030`<301hN7P80HV9R0P2MWId30:ZZZP80
RXZ:0P1WIfL207IfMP<0YjNW0P2RXZ8208J6QQ400000103AcJT000<0dLfY4@00000209JFUP80b<S8
0P2DU9@301HF5P@000000`1SHf<20;Zj^P80XZ:R0`1QHF4202XZ:P808B4Q0`10@40205IFEP80Lg=c
0P1/K6`308f=S@80IFEU0P0n?Sh302h^;P80?Shn0P1<C4`304U9B@80FEUI0P1ZJVX3071`L080Lg=c
0P1VIVH206i^KP<0VIVI0P3QhN420>k^kP<0]KFe0P13@d<200<30`<07QhN0P1RHV8209fMW@<0ZZZZ
0P2:RXX206MWI`80MWIf0`2WYjL20::RXP80QXJ64@0000040=7=Z@000`3AcJTA00000080Ogmo0P2T
Y:@206a/K0L000000`0g=cL208B4Q080NGUi0`0j>SX202LW9`80Cdm?0`1`L70209VIV@80Y:BT0P2>
SXh3075aL@80D51@0P0S8b<3014A4@808B4Q0P0Y:BT3020P80806a/K0P010@47000000800@410`1>
CTh20:n_[`80_kno0`2XZ:P202PX:0D000000P0@410203Lg=`<0:2PX0P071`L200000080410@0`1M
GEd208^;R`80K6a/4@0000040=7=Z@000`3AcJTA00000080Ogmo0P2TY:@206a/K0L000000`0g=cL2
08B4Q080NGUi0`0j>SX202LW9`80Cdm?0`1`L70209VIV@80Y:BT0P2>SXh3075aL@80D51@0P0S8b<3
014A4@808B4Q0P0Y:BT3020P80806a/K0P010@47000000800@410`1>CTh20:n_[`80_kno0`2XZ:P2
02PX:0D000000P0@410203Lg=`<0:2PX0P071`L200000080410@0`1MGEd208^;R`80K6a/4@000004
0=7=Z@000`3AcJTA00000080MGEe0P2QXJ4206UYJ@<04Q8B1000000303`l?080LW9b0P1ADE43020P
808061PH0P0o?cl307MgM`80/K6a0P35aLD20;6a/@<0NGUi0P1=CDd2018B4P<000000P0>3Ph200l?
3`<00@413@00000301dM7@80QHF50P2g]kL308n?S`808B4Q4P00000304];B`80NWYj0P1cLg<A0000
00@0dLfY00030=7=ZA4000000P1eMGD20:6QX@80JFUY0`0B4Q84000000<0?3`l0P1bLW82055AD@<0
820P0P0H61P203lo?`<0MgMg0P2a/K420<G5a@80/K6a0`1iNGT204e=C@804Q8B0`00000200h>3P80
3`l?0`010@4=000000<07AdM0P25QHD20;Ng]`<0Shn?0P0Q8B4B000000<0Bd];0P1jNWX207=cLa40
0000103AcJT000<0dLfY4@000002079bLP80[jn_0P2?Shl304i>CP804a<C0P0d=3@306EUI@80TI6A
0P1iNGT301PH60800`<30P0P8203065QH@80Shn?0P2ZZZX20:NWY`<0Rh^;0P1JFUX200X:2PL00000
0`0410@2000000805aLG0`0H61P4000000800@410`0o?cl20:^[Z`80c<c<0`2OWil204I6APL00000
0P0T92@301<C4`@000000P0T92@306m_K`80XJ6Q0P21PH4A000000@0dLfY00030=7=ZA4000000P1b
LW820:n_[`80Shn?0`1>CTh201<C4`80=3@d0`1UIFD2096AT@80NGUi0`0H61P200<30`80820P0`1Q
HF4208n?S`80ZZZZ0P2WYjL308^;R`80FUYJ0P0:2PX7000000<010@40P00000201LG5`<061PH1000
000200410@<0?clo0P2[Zj/20<c<c0<0WinO0P16ATH70000008092@T0`0C4a<40000008092@T0`1_
Kfl20:6QX@80PH614@0000040=7=Z@000`3AcJTA00000080O7al0P2l_;`20<30`0<0WinO0P1oOgl2
08V9R@<0Xj>S0P2_[jl2071`L0<06QXJ0P00000200H61P<07AdM0P1MGEd206QXJ080QXJ60`29RHT2
05iNGP807alO2P00000203@d=080@D510`1[Jf/207UiN@80Fe]K0P1RHV8309JFUP80`<300P3?cll3
09nOW`80AdM70P00000301XJ6P80EUIF0P2:RXX309ZJVP@0HF5Q0P1[Jf/30:j^[P80_kno0P28R8PA
000000@0dLfY00030=7=ZA4000000P1lO7`20;bl_080`<300`2OWil207moO`80RHV90`2SXj<20:n_
[`80L71`0`0J6QX2000000801PH60`0M7Ad205eMG@80J6QX0P26QXH308V9R@80GUiN0P0O7al:0000
0080=3@d0P11@D4306][J`80NGUi0P1KFe/2069RHP<0UYJF0P30`<020<o?c`<0WinO0P17AdL20000
00<06QXJ0P1FEUH208Z:RP<0VYZJ101QHF4206][J`<0[Zj^0P2o_kl208R8R1400000103AcJT000<0
dLfY4@00000207alO080_;bl0P30`<0309nOW`80Ogmo0P29RHT30:>SX`80[jn_0P1`L70301XJ6P80
00000P061PH301dM7@80GEeM0P1XJ6P208J6QP<0RHV90P1NGUh201lO7`X000000P0d=3@20451@@<0
Jf][0P1iNGT205]KF`80HV9R0`2FUYH20<30`080clo?0`2OWil204M7A`8000000`0J6QX205IFEP80
RXZ:0`2JVYX4065QH@80Jf][0`2^[Zh20;no_`80R8R84@0000040=7=Z@000`3AcJTA00000080PX:2
0P35aLD20<W9b@<0`L710P2b/[820:RXZ0<0[Zj^0P2ZZZX207MgM`<0<S8b1000000300820P804Q8B
0P14A4@205iNGP<0MWIf0P1aLG4203Ph>0<00@410P061PH500000080;Bd]0P1^KVh30;Ng]`80[jn_
0P2i^KT20:BTY0<0]KFe0P3De=@20:^[Z`<0QHF50P15ADD201XJ6P<0F5QH0P2=SHd20=gMg@<0d];B
0P32`/8409NGU`<0][Jf0P2TY:@207=cLa400000103AcJT000<0dLfY4@00000208:2PP80aLG50P39
bLT30<71`@80/[:b0P2XZ:P30:j^[P80ZZZZ0P1gMgL3038b<P@000000`020P82018B4P80A4A40P1N
GUh307IfMP80LG5a0P0h>3P300410@801PH61@00000202d];@80KVi^0`2g]kL20:n_[`80^KVi0P2T
Y:@30;Fe]@80e=CD0P2[Zj/308F5Q@80ADE50P0J6QX305QHF080SHf=0P3MgMd30=;BdP80`/;2102G
UiL30;Jf]P80Y:BT0P1cLg<A000000@0dLfY00030=7=ZA4000000P18B4P209:BTP80Vi^K0`2[Zj/2
096AT@80UiNG0`2<S8`207YjNP80DE5A0`0V9RH200/;2`L000000P0820P203Ph>0<0CTi>0P1LG5`2
02d];@X000000P0/;2`206YZJP<0Vi^K0P2i^KT20:RXZ080QHF50`2=SHd208R8R080N7Qh0`0m?Cd2
01XJ6P805aLG0`0k>c/20820P080]KFe0`2h^;P20:VYZ@80PX:20P20P80308B4Q080MGEe0P18B4PA
000000@0dLfY00030=7=ZA4000000P18B4P209:BTP80Vi^K0`2[Zj/2096AT@80UiNG0`2<S8`207Yj
NP80DE5A0`0V9RH200/;2`L000000P0820P203Ph>0<0CTi>0P1LG5`202d];@X000000P0/;2`206YZ
JP<0Vi^K0P2i^KT20:RXZ080QHF50`2=SHd208R8R080N7Qh0`0m?Cd201XJ6P805aLG0`0k>c/20820
P080]KFe0`2h^;P20:VYZ@80PX:20P20P80308B4Q080MGEe0P18B4PA000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT00900dLfY002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {269.938, 200.188}} -> {-80.2954, 86.6692, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 288 177.994 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 1.28749e-17 1.93528 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .09676 -24 -4.5 ]
[.01131 .09676 0 4.5 ]
[.01131 .19353 -18 -4.5 ]
[.01131 .19353 0 4.5 ]
[.01131 .29029 -24 -4.5 ]
[.01131 .29029 0 4.5 ]
[.01131 .38706 -18 -4.5 ]
[.01131 .38706 0 4.5 ]
[.01131 .48382 -24 -4.5 ]
[.01131 .48382 0 4.5 ]
[.01131 .58058 -18 -4.5 ]
[.01131 .58058 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 10.125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(10)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(30)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(40)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(50)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .09676 m
.03006 .09676 L
s
[(0.05)] .01131 .09676 1 0 Mshowa
.02381 .19353 m
.03006 .19353 L
s
[(0.1)] .01131 .19353 1 0 Mshowa
.02381 .29029 m
.03006 .29029 L
s
[(0.15)] .01131 .29029 1 0 Mshowa
.02381 .38706 m
.03006 .38706 L
s
[(0.2)] .01131 .38706 1 0 Mshowa
.02381 .48382 m
.03006 .48382 L
s
[(0.25)] .01131 .48382 1 0 Mshowa
.02381 .58058 m
.03006 .58058 L
s
[(0.3)] .01131 .58058 1 0 Mshowa
.125 Mabswid
.02381 .01935 m
.02756 .01935 L
s
.02381 .03871 m
.02756 .03871 L
s
.02381 .05806 m
.02756 .05806 L
s
.02381 .07741 m
.02756 .07741 L
s
.02381 .11612 m
.02756 .11612 L
s
.02381 .13547 m
.02756 .13547 L
s
.02381 .15482 m
.02756 .15482 L
s
.02381 .17418 m
.02756 .17418 L
s
.02381 .21288 m
.02756 .21288 L
s
.02381 .23223 m
.02756 .23223 L
s
.02381 .25159 m
.02756 .25159 L
s
.02381 .27094 m
.02756 .27094 L
s
.02381 .30965 m
.02756 .30965 L
s
.02381 .329 m
.02756 .329 L
s
.02381 .34835 m
.02756 .34835 L
s
.02381 .3677 m
.02756 .3677 L
s
.02381 .40641 m
.02756 .40641 L
s
.02381 .42576 m
.02756 .42576 L
s
.02381 .44512 m
.02756 .44512 L
s
.02381 .46447 m
.02756 .46447 L
s
.02381 .50317 m
.02756 .50317 L
s
.02381 .52253 m
.02756 .52253 L
s
.02381 .54188 m
.02756 .54188 L
s
.02381 .56123 m
.02756 .56123 L
s
.02381 .59994 m
.02756 .59994 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Relative) show
117.000 11.562 moveto
(error) show
147.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04286 .61803 m
.0619 .54137 L
.08095 .46665 L
.1 .44887 L
.11905 .41581 L
.1381 .41273 L
.15714 .39761 L
.17619 .36982 L
.19524 .33459 L
.21429 .33198 L
.23333 .32217 L
.25238 .30267 L
.27143 .30876 L
.29048 .3085 L
.30952 .31822 L
.32857 .31322 L
.34762 .31738 L
.36667 .32617 L
.38571 .33111 L
.40476 .31899 L
.42381 .30682 L
.44286 .28937 L
.4619 .2876 L
.48095 .27794 L
.5 .26255 L
.51905 .26571 L
.5381 .27112 L
.55714 .26899 L
.57619 .27128 L
.59524 .27107 L
.61429 .27557 L
.63333 .27747 L
.65238 .26567 L
.67143 .26214 L
.69048 .25408 L
.70952 .25506 L
.72857 .2405 L
.74762 .23877 L
.76667 .23398 L
.78571 .23163 L
.80476 .22548 L
.82381 .22668 L
.84286 .23133 L
.8619 .23268 L
.88095 .22762 L
.9 .24121 L
.91905 .23845 L
.9381 .23841 L
.95714 .24091 L
.97619 .24439 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 2.33103e-17 0.0383801 [
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .09595 -18 -4.5 ]
[.01131 .09595 0 4.5 ]
[.01131 .1919 -6 -4.5 ]
[.01131 .1919 0 4.5 ]
[.01131 .28785 -18 -4.5 ]
[.01131 .28785 0 4.5 ]
[.01131 .3838 -12 -4.5 ]
[.01131 .3838 0 4.5 ]
[.01131 .47975 -24 -4.5 ]
[.01131 .47975 0 4.5 ]
[.01131 .5757 -12 -4.5 ]
[.01131 .5757 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 10.125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(10)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(20)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(30)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(40)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(50)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .09595 m
.03006 .09595 L
s
[(2.5)] .01131 .09595 1 0 Mshowa
.02381 .1919 m
.03006 .1919 L
s
[(5)] .01131 .1919 1 0 Mshowa
.02381 .28785 m
.03006 .28785 L
s
[(7.5)] .01131 .28785 1 0 Mshowa
.02381 .3838 m
.03006 .3838 L
s
[(10)] .01131 .3838 1 0 Mshowa
.02381 .47975 m
.03006 .47975 L
s
[(12.5)] .01131 .47975 1 0 Mshowa
.02381 .5757 m
.03006 .5757 L
s
[(15)] .01131 .5757 1 0 Mshowa
.125 Mabswid
.02381 .01919 m
.02756 .01919 L
s
.02381 .03838 m
.02756 .03838 L
s
.02381 .05757 m
.02756 .05757 L
s
.02381 .07676 m
.02756 .07676 L
s
.02381 .11514 m
.02756 .11514 L
s
.02381 .13433 m
.02756 .13433 L
s
.02381 .15352 m
.02756 .15352 L
s
.02381 .17271 m
.02756 .17271 L
s
.02381 .21109 m
.02756 .21109 L
s
.02381 .23028 m
.02756 .23028 L
s
.02381 .24947 m
.02756 .24947 L
s
.02381 .26866 m
.02756 .26866 L
s
.02381 .30704 m
.02756 .30704 L
s
.02381 .32623 m
.02756 .32623 L
s
.02381 .34542 m
.02756 .34542 L
s
.02381 .36461 m
.02756 .36461 L
s
.02381 .40299 m
.02756 .40299 L
s
.02381 .42218 m
.02756 .42218 L
s
.02381 .44137 m
.02756 .44137 L
s
.02381 .46056 m
.02756 .46056 L
s
.02381 .49894 m
.02756 .49894 L
s
.02381 .51813 m
.02756 .51813 L
s
.02381 .53732 m
.02756 .53732 L
s
.02381 .55651 m
.02756 .55651 L
s
.02381 .59489 m
.02756 .59489 L
s
.02381 .61408 m
.02756 .61408 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Cost) show
93.000 11.562 moveto
(function) show
141.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04286 .61803 m
.0619 .32331 L
.08095 .13857 L
.1 .12237 L
.11905 .08604 L
.1381 .07279 L
.15714 .06175 L
.17619 .04279 L
.19524 .03012 L
.21429 .02926 L
.23333 .02716 L
.25238 .02535 L
.27143 .02267 L
.29048 .02025 L
.30952 .01752 L
.32857 .0167 L
.34762 .01632 L
.36667 .01426 L
.38571 .01292 L
.40476 .01226 L
.42381 .01173 L
.44286 .01089 L
.4619 .01044 L
.48095 .01009 L
.5 .00934 L
.51905 .00923 L
.5381 .00889 L
.55714 .0085 L
.57619 .00837 L
.59524 .00824 L
.61429 .00803 L
.63333 .00793 L
.65238 .00761 L
.67143 .00746 L
.69048 .00712 L
.70952 .00706 L
.72857 .00691 L
.74762 .00685 L
.76667 .00679 L
.78571 .00671 L
.80476 .00661 L
.82381 .00659 L
.84286 .00639 L
.8619 .00635 L
.88095 .00627 L
.9 .00601 L
.91905 .00592 L
.9381 .00584 L
.95714 .00568 L
.97619 .00566 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0194363 -2.72135e-17 1.08163 [
[.21817 -0.0125 -6 -9 ]
[.21817 -0.0125 6 0 ]
[.41254 -0.0125 -6 -9 ]
[.41254 -0.0125 6 0 ]
[.6069 -0.0125 -6 -9 ]
[.6069 -0.0125 6 0 ]
[.80126 -0.0125 -6 -9 ]
[.80126 -0.0125 6 0 ]
[.99563 -0.0125 -6 -9 ]
[.99563 -0.0125 6 0 ]
[.01131 .10816 -18 -4.5 ]
[.01131 .10816 0 4.5 ]
[.01131 .21633 -18 -4.5 ]
[.01131 .21633 0 4.5 ]
[.01131 .32449 -18 -4.5 ]
[.01131 .32449 0 4.5 ]
[.01131 .43265 -18 -4.5 ]
[.01131 .43265 0 4.5 ]
[.01131 .54082 -18 -4.5 ]
[.01131 .54082 0 4.5 ]
[.5 .63053 -56 0 ]
[.5 .63053 56 10.125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21817 0 m
.21817 .00625 L
s
[(10)] .21817 -0.0125 0 1 Mshowa
.41254 0 m
.41254 .00625 L
s
[(20)] .41254 -0.0125 0 1 Mshowa
.6069 0 m
.6069 .00625 L
s
[(30)] .6069 -0.0125 0 1 Mshowa
.80126 0 m
.80126 .00625 L
s
[(40)] .80126 -0.0125 0 1 Mshowa
.99563 0 m
.99563 .00625 L
s
[(50)] .99563 -0.0125 0 1 Mshowa
.125 Mabswid
.06268 0 m
.06268 .00375 L
s
.10155 0 m
.10155 .00375 L
s
.14043 0 m
.14043 .00375 L
s
.1793 0 m
.1793 .00375 L
s
.25705 0 m
.25705 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.33479 0 m
.33479 .00375 L
s
.37366 0 m
.37366 .00375 L
s
.45141 0 m
.45141 .00375 L
s
.49028 0 m
.49028 .00375 L
s
.52915 0 m
.52915 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.64577 0 m
.64577 .00375 L
s
.68465 0 m
.68465 .00375 L
s
.72352 0 m
.72352 .00375 L
s
.76239 0 m
.76239 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.87901 0 m
.87901 .00375 L
s
.91788 0 m
.91788 .00375 L
s
.95675 0 m
.95675 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .10816 m
.03006 .10816 L
s
[(0.1)] .01131 .10816 1 0 Mshowa
.02381 .21633 m
.03006 .21633 L
s
[(0.2)] .01131 .21633 1 0 Mshowa
.02381 .32449 m
.03006 .32449 L
s
[(0.3)] .01131 .32449 1 0 Mshowa
.02381 .43265 m
.03006 .43265 L
s
[(0.4)] .01131 .43265 1 0 Mshowa
.02381 .54082 m
.03006 .54082 L
s
[(0.5)] .01131 .54082 1 0 Mshowa
.125 Mabswid
.02381 .02163 m
.02756 .02163 L
s
.02381 .04327 m
.02756 .04327 L
s
.02381 .0649 m
.02756 .0649 L
s
.02381 .08653 m
.02756 .08653 L
s
.02381 .1298 m
.02756 .1298 L
s
.02381 .15143 m
.02756 .15143 L
s
.02381 .17306 m
.02756 .17306 L
s
.02381 .19469 m
.02756 .19469 L
s
.02381 .23796 m
.02756 .23796 L
s
.02381 .25959 m
.02756 .25959 L
s
.02381 .28122 m
.02756 .28122 L
s
.02381 .30286 m
.02756 .30286 L
s
.02381 .34612 m
.02756 .34612 L
s
.02381 .36775 m
.02756 .36775 L
s
.02381 .38939 m
.02756 .38939 L
s
.02381 .41102 m
.02756 .41102 L
s
.02381 .45428 m
.02756 .45428 L
s
.02381 .47592 m
.02756 .47592 L
s
.02381 .49755 m
.02756 .49755 L
s
.02381 .51918 m
.02756 .51918 L
s
.02381 .56245 m
.02756 .56245 L
s
.02381 .58408 m
.02756 .58408 L
s
.02381 .60571 m
.02756 .60571 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Relative) show
117.000 11.562 moveto
(variation) show
171.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04325 .51581 m
.06268 .61803 L
.08212 .12646 L
.10155 .32109 L
.12099 .16667 L
.14043 .164 L
.15986 .33214 L
.1793 .32015 L
.19874 .03082 L
.21817 .07793 L
.23761 .072 L
.25705 .11442 L
.27648 .11556 L
.29592 .14542 L
.31535 .05087 L
.33479 .02467 L
.35423 .13642 L
.37366 .10146 L
.3931 .05543 L
.41254 .04648 L
.43197 .07786 L
.45141 .0441 L
.47085 .03656 L
.49028 .08107 L
.50972 .01254 L
.52915 .03947 L
.54859 .04796 L
.56803 .01584 L
.58746 .01708 L
.6069 .02737 L
.62634 .01428 L
.64577 .04285 L
.66521 .02178 L
.68465 .04891 L
.70408 .00991 L
.72352 .02194 L
.74295 .00984 L
.76239 .00904 L
.78183 .01318 L
.80126 .0157 L
.8207 .00351 L
.84014 .03298 L
.85957 .00634 L
.87901 .01398 L
.89845 .04556 L
.91788 .0154 L
.93732 .01495 L
.95675 .02908 L
.97619 .00464 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3AcJTQ
0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ0=7=Z@00o`3AcJTQ
0=7=Z@00<@3AcJT4000000<0dLfY0P0000090=7=Z@@000000`3AcJT2000000X0dLfY0P0000040=7=
Z@8000002`3AcJT00`000000dLfY0=7=Z@020=7=Z@8000002@3AcJT3000000@0dLfY0P00002N0=7=
Z@00<`3AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00<000000=7=Z@3AcJT01P3AcJT00`00
0000dLfY0=7=Z@030=7=Z@040000003AcJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000000P3A
cJT010000000dLfY0=7=Z@00000:0=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT00`000000
dLfY0=7=Z@090=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT0V`3AcJT003<0
dLfY00D000000=7=Z@3AcJT0dLfY000000020=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=
Z@3AcJT00P3AcJT010000000dLfY0=7=Z@00000;0=7=Z@040000003AcJT0dLfY00000080dLfY00<0
00000=7=Z@3AcJT01@3AcJT500000080dLfY00@000000=7=Z@3AcJT000002`3AcJT010000000dLfY
0=7=Z@0000020=7=Z@030000003AcJT0dLfY09/0dLfY000c0=7=Z@050000003AcJT0dLfY0=7=Z@00
00000P3AcJT00`000000dLfY0=7=Z@080=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT00`00
0000dLfY0=7=Z@070=7=Z@8000000`3AcJT010000000dLfY0=7=Z@0000070=7=Z@040000003AcJT0
dLfY000000<0dLfY00@000000=7=Z@3AcJT00000203AcJT3000000<0dLfY00@000000=7=Z@3AcJT0
0000W@3AcJT003<0dLfY00D000000=7=Z@3AcJT0dLfY000000020=7=Z@030000003AcJT0dLfY00T0
dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@090=7=Z@040000003AcJT0dLfY
00000080dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY000000030=7=Z@040000003AcJT0
dLfY000000P0dLfY00<000000=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@00002M0=7=Z@00<@3A
cJT3000000<0dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY0=7=Z@0000020=7=Z@04
0000003AcJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000000P3AcJT010000000dLfY0=7=Z@00
00090=7=Z@8000000`3AcJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY00<0dLfY
00@000000=7=Z@3AcJT00000W@3AcJT003<0dLfY00<000000=7=Z@3AcJT00P3AcJT2000000X0dLfY
0P0000040=7=Z@8000002P3AcJT2000000@0dLfY0P00000;0=7=Z@030000003AcJT0dLfY0080dLfY
0P0000090=7=Z@@000000`3AcJT2000009h0dLfY003o0=7=ZB40dLfY000R0=7=ZF000000WP3AcJT0
02@0dLfY00<000000=7=Z@3AcJT03`3AcJT00`000000dLfY0=7=Z@0?0=7=Z@030000003AcJT0dLfY
00l0dLfY00<000000=7=Z@3AcJT03`3AcJT00`000000dLfY0=7=Z@0?0=7=Z@030000003AcJT0dLfY
09l0dLfY000T0=7=Z@030000003AcJT0dLfY0?T0dLfY000T0=7=Z@030000003AcJT0dLfY0?T0dLfY
000T0=7=Z@030000003AcJT0dLfY0?T0dLfY000T0=7=Z@030000003AcJT0dLfY0?T0dLfY000T0=7=
Z@030000003AcJT0dLfY0?T0dLfY000=0=7=Z@800000103AcJT00`000000dLfY0=7=Z@030=7=Z@80
00000`3AcJT3000000<0dLfY00<000000=7=Z@3AcJT0n@3AcJT000`0dLfY00@000000=7=Z@3AcJT0
0000203AcJT010000000dLfY0=7=Z@0000050=7=Z@040000003AcJT0dLfY00000?/0dLfY000<0=7=
Z@040000003AcJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000001@3AcJT010000000dLfY0=7=
Z@00003k0=7=Z@00303AcJT010000000dLfY0=7=Z@0000080=7=Z@040000003AcJT0dLfY00000080
dLfY0`0000030=7=Z@030000003AcJT0dLfY0?T0dLfY000<0=7=Z@040000003AcJT0dLfY000000P0
dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY
0?T0dLfY000<0=7=Z@040000003AcJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000000P3AcJT0
0`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY0?T0dLfY000=0=7=Z@8000002P3AcJT20000
00<0dLfY100000020=7=Z@030000003AcJT0dLfY0?T0dLfY000T0=7=Z@030000003AcJT0dLfY0?T0
dLfY000T0=7=Z@030000003AcJT0dLfY0?T0dLfY000C0=7=Z@800000103AcJT00`000000dLfY0=7=
Z@020=7=Z@@000000P3AcJT00`000000dLfY0=7=Z@3i0=7=Z@004P3AcJT010000000dLfY0=7=Z@00
000:0=7=Z@050000003AcJT0dLfY0=7=Z@000000n`3AcJT00180dLfY00@000000=7=Z@3AcJT00000
2P3AcJT01@000000dLfY0=7=Z@3AcJT000000?/0dLfY000B0=7=Z@040000003AcJT0dLfY000000X0
dLfY00D000000=7=Z@3AcJT0dLfY0000003k0=7=Z@004P3AcJT010000000dLfY0=7=Z@00000:0=7=
Z@050000003AcJT0dLfY0=7=Z@000000n`3AcJT00180dLfY00@000000=7=Z@3AcJT00000203AcJT3
000000<0dLfY00<000000=7=Z@3AcJT0AP3AcJT200000;40dLfY000C0=7=Z@8000002`3AcJT01@00
0000dLfY0=7=Z@3AcJT0000004D0dLfY0`0000020=7=Z@L00000ZP3AcJT002@0dLfY00<000000=7=
Z@3AcJT0?`3AcJT4000000`0dLfY2@00002Q0=7=Z@00903AcJT00`000000dLfY0=7=Z@0k0=7=Z@@0
0000^P3AcJT002@0dLfY00<000000=7=Z@3AcJT0:@3AcJT4000000/0dLfY0`00002n0=7=Z@003@3A
cJT2000000@0dLfY00<000000=7=Z@3AcJT00P3AcJT400000080dLfY0`0000030=7=Z@030000003A
cJT0dLfY02P0dLfY00<000000=7=Z@3AcJT00P3AcJT;00000<40dLfY000<0=7=Z@040000003AcJT0
dLfY000000X0dLfY00<000000=7=Z@3AcJT0103AcJT010000000dLfY0=7=Z@00000X0=7=Z@800000
d@3AcJT000`0dLfY00@000000=7=Z@3AcJT000002P3AcJT00`000000dLfY0=7=Z@040=7=Z@040000
003AcJT0dLfY000002H0dLfY0P00003C0=7=Z@00303AcJT010000000dLfY0=7=Z@00000:0=7=Z@04
0000003AcJT0dLfY0=7=Z@<000000`3AcJT00`000000dLfY0=7=Z@0C0=7=Z@@000002`3AcJT20000
0=D0dLfY000<0=7=Z@040000003AcJT0dLfY000000X0dLfY00D000000=7=Z@3AcJT0dLfY00000005
0=7=Z@030000003AcJT0dLfY0180dLfY00<000000=7=Z@3AcJT00P3AcJT6000000<0dLfY0P00003G
0=7=Z@00303AcJT010000000dLfY0=7=Z@0000080=7=Z@<000000`3AcJT00`000000dLfY0=7=Z@03
0=7=Z@030000003AcJT0dLfY0100dLfY0P00000;0=7=Z@<00000f@3AcJT000d0dLfY0P00000;0=7=
Z@040000003AcJT0dLfY0=7=Z@@000000P3AcJT00`000000dLfY0=7=Z@0=0=7=Z@<00000j@3AcJT0
02@0dLfY00<000000=7=Z@3AcJT0303AcJT00`000000dLfY0=7=Z@3Z0=7=Z@00903AcJT00`000000
dLfY0=7=Z@0<0=7=Z@030000003AcJT0dLfY0>X0dLfY000C0=7=Z@800000103AcJT00`000000dLfY
0=7=Z@020=7=Z@@000000P3AcJT00`000000dLfY0=7=Z@0;0=7=Z@030000003AcJT0dLfY0>/0dLfY
000B0=7=Z@040000003AcJT0dLfY000000P0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY
0=7=Z@0;0=7=Z@030000003AcJT0dLfY0>/0dLfY000B0=7=Z@040000003AcJT0dLfY000000T0dLfY
00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT0dLfY0>`0dLfY
000B0=7=Z@040000003AcJT0dLfY000000X0dLfY00D000000=7=Z@3AcJT0dLfY0000000;0=7=Z@80
0000kP3AcJT00180dLfY00@000000=7=Z@3AcJT000002`3AcJT010000000dLfY0=7=Z@0000090=7=
Z@800000l03AcJT00180dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY0=7=Z@000002
0=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT0l03AcJT001<0dLfY0P00000:0=7=
Z@8000000`3AcJT00`000000dLfY0=7=Z@050=7=Z@030000003AcJT0dLfY0?40dLfY000T0=7=Z@03
0000003AcJT0dLfY00D0dLfY00<000000=7=Z@3AcJT0l@3AcJT002@0dLfY00<000000=7=Z@3AcJT0
0`3AcJT200000?@0dLfY000=0=7=Z@800000103AcJT00`000000dLfY0=7=Z@020=7=Z@@000000P3A
cJT3000000<0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@3d0=7=Z@00303AcJT0
10000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY00H0dLfY00@000000=7=Z@3AcJT00000
103AcJT00`000000dLfY0=7=Z@3d0=7=Z@00303AcJT010000000dLfY0=7=Z@0000090=7=Z@030000
003AcJT0dLfY00D0dLfY00@000000=7=Z@3AcJT00000103AcJT00`000000dLfY0=7=Z@3d0=7=Z@00
303AcJT010000000dLfY0=7=Z@00000:0=7=Z@040000003AcJT0dLfY0=7=Z@<000000`3AcJT00`00
0000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY0?@0dLfY000<0=7=Z@040000003AcJT0dLfY0000
00/0dLfY00@000000=7=Z@3AcJT000001@3AcJT01@000000dLfY0=7=Z@3AcJT000000?L0dLfY000<
0=7=Z@040000003AcJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY
0=7=Z@030=7=Z@050000003AcJT0dLfY0=7=Z@000000m`3AcJT000d0dLfY0P00000:0=7=Z@800000
0`3AcJT400000080dLfY00D000000=7=Z@3AcJT0dLfY0000003g0=7=Z@00903AcJT01@000000dLfY
0=7=Z@3AcJT000000?L0dLfY000T0=7=Z@050000003AcJT0dLfY0=7=Z@000000m`3AcJT001<0dLfY
0P0000040=7=Z@030000003AcJT0dLfY00<0dLfY0P0000030=7=Z@050000003AcJT0dLfY0=7=Z@00
0000m`3AcJT00180dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY0=7=Z@0000020=7=
Z@040000003AcJT0dLfY00000?P0dLfY000B0=7=Z@040000003AcJT0dLfY000000/0dLfY00@00000
0=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@3f0=7=Z@004P3AcJT010000000dLfY0=7=Z@00
00090=7=Z@8000000`3AcJT010000000dLfY0=7=Z@00003h0=7=Z@004P3AcJT010000000dLfY0=7=
Z@00000;0=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT0mP3AcJT00180dLfY
00@000000=7=Z@3AcJT00000203AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT00000
0?T0dLfY000C0=7=Z@8000002P3AcJT2000000<0dLfY00<000000=7=Z@000000n@3AcJT00?l0dLfY
8@3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT002L0dLfY0`0000020=7=Z@030000003AcJT0dLfY
00<000000P3AcJT500000080dLfY0P0000000`3AcJT000000=7=Z@020=7=Z@8000000P3AcJT50000
00<0dLfY00<000000=7=Z@3AcJT00P3AcJT3000000T0dLfY0`0000020=7=Z@@000000P3AcJT40000
00<0dLfY0P0000030=7=Z@@00000YP3AcJT002P0dLfY00@000000=7=Z@3AcJT000000P3AcJT00`00
0000dLfY0=7=Z@050=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT01@000000dLfY0=7=Z@3A
cJT000000080dLfY00D000000=7=Z@3AcJT0dLfY000000040=7=Z@030000003AcJT000000080dLfY
00<000000=7=Z@3AcJT02@3AcJT00`000000dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY00<0dLfY
00<000000=7=Z@3AcJT00P3AcJT010000000dLfY0=7=Z@0000030=7=Z@030000003AcJT0dLfY0:H0
dLfY000X0=7=Z@<000000`3AcJT3000000D0dLfY00<000000=7=Z@3AcJT00P3AcJT3000000<0dLfY
00<000000=7=Z@3AcJT0103AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT000000080dLfY
0`0000090=7=Z@<00000103AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY0080dLfY
00@000000=7=Z@3AcJT000000`3AcJT00`000000dLfY0=7=Z@2V0=7=Z@00:03AcJT010000000dLfY
0=7=Z@0000020=7=Z@040000003AcJT0dLfY000000@0dLfY00<000000=7=Z@3AcJT0103AcJT01@00
0000dLfY0=7=Z@3AcJT0000000H0dLfY00D000000=7=Z@3AcJT0dLfY000000030=7=Z@030000003A
cJT000000080dLfY00<000000=7=Z@3AcJT01P3AcJT010000000dLfY0=7=Z@0000030=7=Z@030000
003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT00P3AcJT010000000dLfY0=7=Z@0000030=7=Z@03
0000003AcJT0dLfY0:H0dLfY000X0=7=Z@040000003AcJT0dLfY000000<0dLfY0P0000050=7=Z@03
0000003AcJT0dLfY0080dLfY0P0000030=7=Z@@000000`3AcJT200000080dLfY0P0000020=7=Z@80
00000P3AcJT2000000X0dLfY0P0000030=7=Z@030000003AcJT000000080000000<0dLfY0000003A
cJT00`0000020=7=Z@8000000`3AcJT00`000000dLfY0000000200000:D0dLfY000W0=7=Z@@00000
2`3AcJT00`000000dLfY0=7=Z@080=7=Z@030000003AcJT0dLfY0=`0dLfY000e0=7=Z@8000002P3A
cJT00`000000dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY0=D0dLfY003o0=7=ZB40dLfY003o0=7=
ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=
ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY000a0=7=Z@@000000`3AcJT2
000000T0dLfY100000030=7=Z@8000002P3AcJT2000000@0dLfY0P00000;0=7=Z@030000003AcJT0
dLfY0080dLfY0P0000090=7=Z@<00000103AcJT2000003T0dLfY100000030=7=Z@8000002@3AcJT4
000000<0dLfY0P00000;0=7=Z@800000103AcJT2000000/0dLfY00<000000=7=Z@3AcJT00P3AcJT2
000000X0dLfY0`0000040=7=Z@8000004P3AcJT003<0dLfY00D000000=7=Z@3AcJT0dLfY00000002
0=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@00
00080=7=Z@040000003AcJT0dLfY00000080dLfY00@000000=7=Z@3AcJT000002P3AcJT01@000000
dLfY0=7=Z@3AcJT000000080dLfY00<000000=7=Z@3AcJT02@3AcJT010000000dLfY0=7=Z@000002
0=7=Z@030000003AcJT0dLfY03P0dLfY00D000000=7=Z@3AcJT0dLfY000000020=7=Z@030000003A
cJT0dLfY00H0dLfY00<000000=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@0000090=7=Z@040000
003AcJT0dLfY00000080dLfY00@000000=7=Z@3AcJT000002P3AcJT01@000000dLfY0=7=Z@3AcJT0
00000080dLfY00<000000=7=Z@3AcJT02P3AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003A
cJT0dLfY00l0dLfY000c0=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT00`000000dLfY0=7=
Z@070=7=Z@030000003AcJT0dLfY0080dLfY00@000000=7=Z@3AcJT000002`3AcJT010000000dLfY
0=7=Z@0000020=7=Z@030000003AcJT0dLfY00D0dLfY1@0000020=7=Z@040000003AcJT0dLfY0000
00/0dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@0h0=7=Z@050000003AcJT0
dLfY0=7=Z@0000000P3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY0080dLfY00@0
00000=7=Z@3AcJT00000303AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0dLfY00D0
dLfY1@0000020=7=Z@040000003AcJT0dLfY000000`0dLfY00@000000=7=Z@3AcJT000000P3AcJT0
0`000000dLfY0=7=Z@0?0=7=Z@00<`3AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00<00000
0=7=Z@3AcJT0203AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00<000000=7=Z@3AcJT01`3A
cJT2000000<0dLfY00@000000=7=Z@3AcJT000001`3AcJT010000000dLfY0=7=Z@0000030=7=Z@04
0000003AcJT0dLfY000000P0dLfY0`0000030=7=Z@040000003AcJT0dLfY000003X0dLfY00D00000
0=7=Z@3AcJT0dLfY000000020=7=Z@030000003AcJT0dLfY00P0dLfY00D000000=7=Z@3AcJT0dLfY
000000020=7=Z@030000003AcJT0dLfY00P0dLfY0P0000030=7=Z@040000003AcJT0dLfY000000L0
dLfY00@000000=7=Z@3AcJT000000`3AcJT010000000dLfY0=7=Z@0000090=7=Z@<000000`3AcJT0
10000000dLfY0=7=Z@00000A0=7=Z@00<`3AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00<0
00000=7=Z@3AcJT02@3AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0dLfY00T0dLfY
00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@060=7=Z@030000003AcJT0000000<0
dLfY00@000000=7=Z@3AcJT00000203AcJT00`000000dLfY0=7=Z@030=7=Z@040000003AcJT0dLfY
000003X0dLfY00D000000=7=Z@3AcJT0dLfY000000020=7=Z@030000003AcJT0dLfY00T0dLfY00@0
00000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@0:0=7=Z@040000003AcJT0dLfY00000080
dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY000000030=7=Z@040000003AcJT0dLfY0000
00T0dLfY00<000000=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@00000A0=7=Z@00<@3AcJT30000
00<0dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY0=7=Z@0000020=7=Z@040000003A
cJT0dLfY000000P0dLfY00@000000=7=Z@3AcJT000000P3AcJT010000000dLfY0=7=Z@0000090=7=
Z@8000000`3AcJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY00<0dLfY00@00000
0=7=Z@3AcJT00000>03AcJT3000000<0dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY
0=7=Z@0000020=7=Z@040000003AcJT0dLfY000000T0dLfY00@000000=7=Z@3AcJT000000P3AcJT0
10000000dLfY0=7=Z@0000090=7=Z@8000000`3AcJT010000000dLfY0=7=Z@0000090=7=Z@030000
003AcJT0dLfY00<0dLfY00@000000=7=Z@3AcJT000004@3AcJT003<0dLfY00<000000=7=Z@3AcJT0
0P3AcJT2000000X0dLfY0P0000040=7=Z@8000002P3AcJT2000000@0dLfY0P00000;0=7=Z@030000
003AcJT0dLfY0080dLfY0P0000090=7=Z@@000000`3AcJT2000003/0dLfY00<000000=7=Z@3AcJT0
0P3AcJT2000000X0dLfY0P0000040=7=Z@8000002`3AcJT2000000@0dLfY0P00000;0=7=Z@030000
003AcJT0dLfY0080dLfY0P00000:0=7=Z@@000000`3AcJT200000180dLfY003o0=7=ZB40dLfY000R
0=7=ZF000000:@3AcJUP000001D0dLfY000T0=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT0
1@000000dLfY0=7=Z@3AcJT000000080dLfY00D000000=7=Z@3AcJT0dLfY000000030=7=Z@040000
003AcJT0dLfY000000<0dLfY00<000000=7=Z@3AcJT0>`00000^0=7=Z@050000003AcJT0dLfY0=7=
Z@0000000`3AcJT010000000dLfY0=7=Z@0000030=7=Z@050000003AcJT0dLfY0=7=Z@0000000`3A
cJT010000000dLfY0=7=Z@0000030=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT01@000000
dLfY0=7=Z@3AcJT0000000<0dLfY00@000000=7=Z@00000000000`3AcJT01@000000dLfY0=7=Z@3A
cJT000000080dLfY00P000000=7=Z@3AcJT0dLfY0000003AcJT000000=7=Z@D000000P3AcJT30000
00060=7=Z@000000dLfY0000003AcJT000000P3AcJT02@000000dLfY0=7=Z@3AcJT000000=7=Z@00
0000dLfY0000000E0=7=Z@00903AcJT00`000000dLfY0=7=Z@0D0=7=Z@X00000J03AcJT2000002d0
dLfY00<000000=7=Z@3AcJT00P3AcJT300000080dLfY0P0000020=7=Z@040000003AcJT0dLfY0=7=
Z@<00000103AcJT300000080dLfY00@000000=7=Z@000000dLfY0P0000020=7=Z@<000000P3AcJT0
0`000000dLfY0=7=Z@0F0=7=Z@00903AcJT00`000000dLfY0=7=Z@0<0=7=Z@P00000LP3AcJT00`00
0000dLfY0=7=Z@0>0=7=Z@030000003AcJT0dLfY00X0dLfY00<000000=7=Z@3AcJT03@3AcJT00`00
0000dLfY000000020=7=Z@040000003AcJT0dLfY0=7=Z@80000000P0dLfY0000003AcJT000000=7=
Z@000000dLfY000000d0dLfY00L000000=7=Z@3AcJT0dLfY0000003AcJT0000000<0dLfY0P00000I
0=7=Z@00903AcJT00`000000dLfY0=7=Z@0;0=7=Z@030000003AcJT0dLfY07P0dLfY0P00000?0=7=
Z@030000003AcJT0dLfY00T0dLfY0P00000:0=7=Z@<000000P3AcJT00`000000dLfY000000020=7=
Z@030000003AcJT0dLfY00D0dLfY00H000000=7=Z@3AcJT000000=7=Z@00000B0=7=Z@8000007P3A
cJT002@0dLfY00<000000=7=Z@3AcJT02`3AcJT00`000000dLfY0=7=Z@1h0=7=Z@030000003AcJT0
dLfY00h0dLfY0P0000090=7=Z@030000003AcJT0000000D0dLfY0P0000030=7=Z@030000003AcJT0
00000080dLfY00<000000=7=Z@3AcJT00P00000<0=7=Z@030000003AcJT0dLfY0140dLfY00<00000
0=7=Z@3AcJT07@3AcJT002@0dLfY00<000000=7=Z@3AcJT02@3AcJT2000007/0dLfY0P00000?0=7=
Z@8000002@3AcJT010000000dLfY0=7=Z@0000030=7=Z@060000003AcJT0dLfY0000003AcJT00000
0`3AcJT00`000000dLfY000000140=7=Z@004P3AcJT4000000<0dLfY00<000000=7=Z@3AcJT00P3A
cJT3000000<0dLfY00<000000=7=Z@3AcJT01`3AcJT2000007d0dLfY00<000000=7=Z@3AcJT03P3A
cJT00`000000dLfY00000002000000H0dLfY00@000000=7=Z@3AcJT000000`3AcJT01P000000dLfY
0=7=Z@000000dLfY000000<0dLfY0P0000150=7=Z@004P3AcJT00`000000dLfY0=7=Z@0<0=7=Z@04
0000003AcJT0dLfY000000P0dLfY00<000000=7=Z@3AcJT0O@3AcJT2000000l0dLfY00D000000=7=
Z@000000dLfY000000050=7=Z@050000003AcJT0dLfY0=7=Z@0000000`3AcJT01@000000dLfY0=7=
Z@3AcJT0000000D0dLfY00<000000=7=Z@3AcJT0@`3AcJT001<0dLfY00<000000=7=Z@3AcJT02`3A
cJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY06`0dLfY0P0000040=7=Z@030000
003AcJT0dLfY0080dLfY100000020=7=Z@030000003AcJT0dLfY00h0dLfY00<000000=7=Z@3AcJT0
0P3AcJT00`000000dLfY0=7=Z@020=7=Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT00`000000
dLfY0=7=Z@1>0=7=Z@00503AcJT00`000000dLfY0=7=Z@070=7=Z@<000000`3AcJT00`000000dLfY
0=7=Z@050=7=Z@030000003AcJT0dLfY06`0dLfY00@000000=7=Z@3AcJT000002P3AcJT01@000000
dLfY0=7=Z@3AcJT000000100dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@020=7=
Z@050000003AcJT0dLfY0=7=Z@0000000P3AcJT00`000000dLfY0=7=Z@1>0=7=Z@005@3AcJT00`00
0000dLfY0=7=Z@060=7=Z@030000003AcJT0dLfY00<0dLfY00<000000=7=Z@3AcJT01@3AcJT00`00
0000dLfY0=7=Z@1/0=7=Z@040000003AcJT0dLfY000000X0dLfY00@000000=7=Z@3AcJT0dLfY0P00
000>0=7=Z@030000003AcJT0dLfY00@0dLfY0P0000020=7=Z@030000003AcJT0dLfY0080dLfY0P00
001A0=7=Z@004P3AcJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY00<0dLfY00<0
00000=7=Z@3AcJT00`3AcJT2000006l0dLfY00@000000=7=Z@3AcJT000002P3AcJT01@000000dLfY
0=7=Z@3AcJT0000000D0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@060=7=Z@80
00001@3AcJT200000540dLfY000C0=7=Z@8000002@3AcJT400000080dLfY00<000000=7=Z@3AcJT0
0P3AcJT00`000000dLfY0=7=Z@1_0=7=Z@040000003AcJT0dLfY000000X0dLfY00@000000=7=Z@3A
cJT0dLfY0P0000040=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=Z@3AcJT01P3AcJT20000
00D0dLfY00<000000=7=Z@3AcJT0D03AcJT002@0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000
dLfY0=7=Z@1_0=7=Z@040000003AcJT0dLfY000000P0dLfY0`0000030=7=Z@030000003AcJT0dLfY
00<0dLfY00<000000=7=Z@3AcJT01`3AcJT00`000000dLfY0=7=Z@070=7=Z@030000003AcJT0dLfY
05H0dLfY000T0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT0L03AcJT2000000/0
dLfY00@000000=7=Z@3AcJT0dLfY0P0000040=7=Z@030000003AcJT0dLfY00L0dLfY00<000000=7=
Z@3AcJT0H03AcJT001h0dLfY0`0000030=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3A
cJT0P@3AcJT00`000000dLfY0=7=Z@030=7=Z@040000003AcJT0dLfY0=7=Z@800000103AcJT00`00
0000dLfY0=7=Z@1P0=7=Z@008@3AcJT010000000dLfY0=7=Z@0000040=7=Z@030000003AcJT0dLfY
0840dLfY0P0000040=7=Z@8000000P3AcJT2000000@0dLfY00<000000=7=Z@3AcJT0H03AcJT00240
dLfY00@000000=7=Z@3AcJT00000103AcJT00`000000dLfY0=7=Z@210=7=Z@030000003AcJT0dLfY
00<0dLfY0P0000020=7=Z@800000103AcJT00`000000dLfY0=7=Z@1P0=7=Z@007P3AcJT3000000<0
dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@1`0=7=Z@800000103AcJT00`000000
dLfY0=7=Z@020=7=Z@@000000P3AcJT2000000@0dLfY0P0000020=7=Z@800000103AcJT00`000000
dLfY0=7=Z@1P0=7=Z@007P3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY0080dLfY
00<000000=7=Z@3AcJT0K`3AcJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY00<0
dLfY00<000000=7=Z@3AcJT00`3AcJT2000000040=7=Z@000000dLfY000000@0dLfY00<000000=7=
Z@3AcJT0H03AcJT001h0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY0=7=Z@020=7=Z@03
0000003AcJT0dLfY06l0dLfY00@000000=7=Z@3AcJT000002@3AcJT00`000000dLfY0=7=Z@020=7=
Z@800000103AcJT2000000050=7=Z@000000dLfY0=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@1P
0=7=Z@007P3AcJT400000080dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=Z@1_0=7=
Z@040000003AcJT0dLfY000000X0dLfY00D000000=7=Z@3AcJT0dLfY000000050=7=Z@80000000D0
dLfY0000003AcJT0dLfY000000030=7=Z@030000003AcJT0dLfY0600dLfY000T0=7=Z@050000003A
cJT0dLfY0=7=Z@000000LP3AcJT010000000dLfY0=7=Z@00000;0=7=Z@030000003AcJT0dLfY0080
0000103AcJT2000000050=7=Z@000000dLfY0=7=Z@0000000`3AcJT00`000000dLfY0=7=Z@1P0=7=
Z@00903AcJT01@000000dLfY0=7=Z@3AcJT000000780dLfY00@000000=7=Z@3AcJT00000203AcJT0
10000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0dLfY0080dLfY00D000000=7=Z@000000dLfY
000000020=7=Z@050000003AcJT0dLfY0=7=Z@000000HP3AcJT002@0dLfY00D000000=7=Z@3AcJT0
dLfY0000001c0=7=Z@8000002P3AcJT2000000<0dLfY0P0000030=7=Z@050000003AcJT000000=7=
Z@0000000P3AcJT010000000dLfY0=7=Z@00001S0=7=Z@004`3AcJT00`000000dLfY0=7=Z@030=7=
Z@030000003AcJT0dLfY0080dLfY0`0000030=7=Z@050000003AcJT0dLfY0=7=Z@000000Q03AcJT0
0`000000dLfY0=7=Z@020=7=Z@050000003AcJT000000=7=Z@0000000P3AcJT010000000dLfY0=7=
Z@00001S0=7=Z@004`3AcJT00`000000dLfY0=7=Z@0;0=7=Z@040000003AcJT0dLfY000000<0dLfY
00<000000=7=Z@3AcJT0PP3AcJT2000000<0dLfY00<000000=7=Z@3AcJT00P0000020=7=Z@040000
003AcJT0dLfY000006<0dLfY000D0=7=Z@030000003AcJT0dLfY00X0dLfY00@000000=7=Z@3AcJT0
00000`3AcJT00`000000dLfY0=7=Z@220=7=Z@030000003AcJT0dLfY0080dLfY00@000000=7=Z@3A
cJT000000`3AcJT010000000dLfY0=7=Z@00001S0=7=Z@00503AcJT00`000000dLfY0=7=Z@070=7=
Z@<000000`3AcJT01@000000dLfY0=7=Z@3AcJT0000007<0dLfY0P0000040=7=Z@030000003AcJT0
dLfY00<0dLfY0P0000030=7=Z@8000000`3AcJT010000000dLfY0=7=Z@0000040=7=Z@030000003A
cJT0000006<0dLfY000E0=7=Z@030000003AcJT0dLfY00H0dLfY00<000000=7=Z@3AcJT00`3AcJT0
1@000000dLfY0=7=Z@3AcJT000000780dLfY00@000000=7=Z@3AcJT00000203AcJT010000000dLfY
0=7=Z@0000020=7=Z@030000003AcJT0dLfY0080dLfY00@000000=7=Z@3AcJT00000103AcJT00`00
0000dLfY0000001S0=7=Z@004P3AcJT010000000dLfY0=7=Z@0000080=7=Z@030000003AcJT0dLfY
00<0dLfY00D000000=7=Z@3AcJT0dLfY0000001b0=7=Z@040000003AcJT0dLfY000000/0dLfY00<0
00000=7=Z@3AcJT00P0000030=7=Z@040000003AcJT0dLfY000000@0dLfY0`00001S0=7=Z@004P3A
cJT4000000P0dLfY100000020=7=Z@050000003AcJT0dLfY0=7=Z@000000LP3AcJT010000000dLfY
0=7=Z@0000090=7=Z@8000000`3AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY00D0
dLfY00<000000=7=Z@3AcJT0H`3AcJT002@0dLfY00D000000=7=Z@3AcJT0dLfY0000001b0=7=Z@04
0000003AcJT0dLfY000000/0dLfY00<000000=7=Z@3AcJT00P0000030=7=Z@030000003AcJT0dLfY
06/0dLfY000T0=7=Z@050000003AcJT0dLfY0=7=Z@000000LP3AcJT010000000dLfY0=7=Z@000008
0=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=
Z@1[0=7=Z@00603AcJT4000000<0dLfY0P0000030=7=Z@050000003AcJT0dLfY0=7=Z@000000L`3A
cJT2000000X0dLfY0P0000030=7=Z@8000000`3AcJT00`000000dLfY0=7=Z@1[0=7=Z@006P3AcJT0
1@000000dLfY0=7=Z@3AcJT000000080dLfY00@000000=7=Z@3AcJT000000`3AcJT00`000000dLfY
0=7=Z@220=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT0J`3AcJT001X0dLfY00D0
00000=7=Z@3AcJT0dLfY000000020=7=Z@040000003AcJT0dLfY000000<0dLfY00<000000=7=Z@3A
cJT0PP3AcJT2000000<0dLfY00<000000=7=Z@3AcJT0J`3AcJT001X0dLfY00D000000=7=Z@3AcJT0
dLfY000000020=7=Z@040000003AcJT0dLfY000000<0dLfY00<000000=7=Z@3AcJT0PP3AcJT00`00
0000dLfY0=7=Z@020=7=Z@030000003AcJT0dLfY06/0dLfY000J0=7=Z@050000003AcJT0dLfY0=7=
Z@0000000P3AcJT010000000dLfY0=7=Z@0000020=7=Z@030000003AcJT0dLfY0780dLfY0P000004
0=7=Z@030000003AcJT0dLfY00@0dLfY00@000000=7=Z@3AcJT0dLfY0P0000030=7=Z@030000003A
cJT0dLfY06/0dLfY000H0=7=Z@<000000`3AcJT010000000dLfY0=7=Z@0000020=7=Z@040000003A
cJT0dLfY000007<0dLfY00@000000=7=Z@3AcJT000002P3AcJT01@000000dLfY0=7=Z@3AcJT00000
00@0dLfY00<000000=7=Z@3AcJT0J`3AcJT001X0dLfY00<000000=7=Z@3AcJT00P3AcJT2000000<0
dLfY00@000000=7=Z@3AcJT00000L`3AcJT010000000dLfY0=7=Z@0000070=7=Z@D000000P3AcJT2
000000<0dLfY00<000000=7=Z@3AcJT0J`3AcJT002@0dLfY00@000000=7=Z@3AcJT00000L`3AcJT0
10000000dLfY0=7=Z@0000070=7=Z@040000003AcJT0dLfY000000<0dLfY00<000000=7=Z@3AcJT0
0P3AcJT00`000000dLfY0=7=Z@1[0=7=Z@00903AcJT010000000dLfY0=7=Z@00001c0=7=Z@040000
003AcJT0dLfY000000P0dLfY00<000000=7=Z@0000000`3AcJT2000000<0dLfY00<000000=7=Z@3A
cJT0J`3AcJT000`0dLfY100000020=7=Z@@000000`3AcJT00`000000dLfY0=7=Z@020=7=Z@<00000
0`3AcJT010000000dLfY0=7=Z@00001c0=7=Z@040000003AcJT0dLfY000000T0dLfY0P0000030=7=
Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT0J`3AcJT000h0dLfY00D000000=7=Z@3A
cJT0dLfY0000000>0=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT0LP3AcJT2
000000/0dLfY00@000000=7=Z@3AcJT0dLfY0P0000030=7=Z@030000003AcJT0dLfY06/0dLfY000>
0=7=Z@030000003AcJT0dLfY0080dLfY00<000000=7=Z@3AcJT02`3AcJT010000000dLfY0=7=Z@00
00020=7=Z@030000003AcJT0dLfY08<0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=
Z@1[0=7=Z@003P3AcJT00`000000dLfY0=7=Z@030=7=Z@030000003AcJT0dLfY00L0dLfY0`000003
0=7=Z@040000003AcJT0dLfY000008D0dLfY00<000000=7=Z@3AcJT00P3AcJT00`000000dLfY0=7=
Z@1[0=7=Z@003P3AcJT00`000000dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY00H0dLfY00<00000
0=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@0000250=7=Z@8000000P3AcJT00`000000dLfY0=7=
Z@1/0=7=Z@00303AcJT3000000<0dLfY00@000000=7=Z@3AcJT00000203AcJT00`000000dLfY0=7=
Z@030=7=Z@040000003AcJT0dLfY000008D0dLfY00D000000=7=Z@000000dLfY0000001^0=7=Z@00
3P3AcJT00`000000dLfY0=7=Z@020=7=Z@8000002@3AcJT400000080dLfY00@000000=7=Z@3AcJT0
0000M03AcJT2000000@0dLfY00<000000=7=Z@3AcJT00P3AcJT3000000<0dLfY0`0000000`3AcJT0
00000=7=Z@1]0=7=Z@00903AcJT010000000dLfY0=7=Z@00001c0=7=Z@040000003AcJT0dLfY0000
00/0dLfY00P000000=7=Z@3AcJT000000=7=Z@000000dLfY000006h0dLfY000T0=7=Z@040000003A
cJT0dLfY000007<0dLfY00@000000=7=Z@3AcJT000002`3AcJT00`000000dLfY0=7=Z@0200000003
0=7=Z@000000000006h0dLfY000H0=7=Z@@000000P3AcJT3000000<0dLfY00<000000=7=Z@000000
M03AcJT010000000dLfY0=7=Z@0000080=7=Z@<000000`3AcJT00`000000dLfY0=7=Z@02000006h0
dLfY000J0=7=Z@030000003AcJT0dLfY00@0dLfY00H000000=7=Z@3AcJT000000=7=Z@00001d0=7=
Z@040000003AcJT0dLfY000000P0dLfY00<000000=7=Z@3AcJT00`3AcJT2000000030=7=Z@000000
000006h0dLfY000J0=7=Z@030000003AcJT0dLfY00@0dLfY00H000000=7=Z@3AcJT000000=7=Z@00
001d0=7=Z@040000003AcJT0dLfY000000P0dLfY00<000000=7=Z@3AcJT00`3AcJT00`000000dLfY
0=7=Z@02000006h0dLfY000J0=7=Z@040000003AcJT0dLfY0=7=Z@<000000`3AcJT00`000000dLfY
0000001e0=7=Z@8000002@3AcJT400000080dLfY0P0000000`3AcJT000000000001^0=7=Z@006P3A
cJT01@000000dLfY0=7=Z@3AcJT0000000D0dLfY00<000000=7=Z@000000QP3AcJT01@000000dLfY
0=7=Z@3AcJT0000006h0dLfY000H0=7=Z@<000000`3AcJT00`000000dLfY0=7=Z@030=7=Z@030000
003AcJT0000008H0dLfY0P0000020=7=Z@030000003AcJT0dLfY06`0dLfY000J0=7=Z@040000003A
cJT0dLfY0=7=Z@@000000P3AcJT00`000000dLfY000000260=7=Z@050000003AcJT0dLfY0=7=Z@00
0000KP3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT00?l0dLfY8@3AcJT002`0
dLfY0P0000040=7=Z@8000000`3AcJT3000000D0dLfY0P0000080=7=Z@@000000`3AcJT200000003
0=7=Z@00000000000080000000<0dLfY0000000000000P3AcJT2000000D0dLfY0P0000020=7=Z@D0
00000P3AcJT200000080dLfY0`0000000`3AcJT000000000000]0=7=Z@<000000P3AcJT00`000000
dLfY0=7=Z@0300000080dLfY1@0000020=7=Z@80000000<0dLfY0000003AcJT00P3AcJT200000080
dLfY1@0000030=7=Z@030000003AcJT0dLfY0080dLfY0`00000:0=7=Z@030000003AcJT0dLfY0080
dLfY0P0000000`3AcJT000000=7=Z@0400000080dLfY1@0000020=7=Z@80000000<0dLfY0000003A
cJT00P3AcJT200000080dLfY1@0000020=7=Z@8000000P3AcJT3000000030=7=Z@000000000000l0
dLfY000[0=7=Z@040000003AcJT0dLfY00000080dLfY00@000000=7=Z@3AcJT000001@3AcJT01@00
0000dLfY0=7=Z@3AcJT000000080dLfY00<000000=7=Z@3AcJT01P3AcJT00`000000dLfY0=7=Z@02
0=7=Z@040000003AcJT0dLfY00000080dLfY00@000000=7=Z@3AcJT000000P3AcJT010000000dLfY
0=7=Z@0000030=7=Z@040000003AcJT0dLfY000000<0dLfY00D000000=7=Z@3AcJT0dLfY00000002
0=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT0;@3AcJT010000000dLfY0=7=
Z@0000020=7=Z@030000003AcJT0dLfY00D0dLfY00D000000=7=Z@3AcJT0dLfY000000020=7=Z@05
0000003AcJT0dLfY0=7=Z@0000000P3AcJT01@000000dLfY0=7=Z@3AcJT0000000@0dLfY00<00000
0=7=Z@0000000P3AcJT00`000000dLfY0=7=Z@0:0=7=Z@030000003AcJT000000080dLfY00@00000
0=7=Z@3AcJT000000`3AcJT00`000000dLfY0=7=Z@040=7=Z@050000003AcJT0dLfY0=7=Z@000000
0P3AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00D000000=7=Z@3AcJT0dLfY000000030=7=
Z@040000003AcJT0dLfY00000080dLfY00@000000=7=Z@3AcJT00000403AcJT002/0dLfY00<00000
0=7=Z@3AcJT00`3AcJT010000000dLfY0=7=Z@0000030=7=Z@800000103AcJT00`000000dLfY0=7=
Z@090=7=Z@030000003AcJT0dLfY0080dLfY00@000000=7=Z@3AcJT000000P3AcJT010000000dLfY
0=7=Z@0000020=7=Z@030000003AcJT0dLfY00@0dLfY00<000000=7=Z@3AcJT0103AcJT01@000000
dLfY0=7=Z@3AcJT000000080dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@0]
0=7=Z@<000000`3AcJT3000000D0dLfY00<000000=7=Z@3AcJT00P3AcJT3000000<0dLfY00<00000
0=7=Z@3AcJT0103AcJT00`000000dLfY0=7=Z@020=7=Z@030000003AcJT000000080dLfY0`00000:
0=7=Z@030000003AcJT0000000<0dLfY0`0000030=7=Z@030000003AcJT0dLfY00@0dLfY00<00000
0=7=Z@3AcJT00P3AcJT3000000<0dLfY00<000000=7=Z@3AcJT0103AcJT01@000000dLfY0=7=Z@3A
cJT000000080dLfY00@000000=7=Z@3AcJT000000P3AcJT00`000000dLfY0=7=Z@0>0=7=Z@00:`3A
cJT00`000000dLfY0=7=Z@030=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT0
103AcJT00`000000dLfY0=7=Z@090=7=Z@030000003AcJT0dLfY0080dLfY00@000000=7=Z@3AcJT0
00000P3AcJT010000000dLfY0=7=Z@0000020=7=Z@040000003AcJT0dLfY000000<0dLfY00<00000
0=7=Z@3AcJT0103AcJT01@000000dLfY0=7=Z@3AcJT000000080dLfY00@000000=7=Z@3AcJT00000
0P3AcJT00`000000dLfY0=7=Z@0]0=7=Z@040000003AcJT0dLfY00000080dLfY00@000000=7=Z@3A
cJT00000103AcJT00`000000dLfY0=7=Z@040=7=Z@050000003AcJT0dLfY0=7=Z@0000001P3AcJT0
1@000000dLfY0=7=Z@3AcJT0000000<0dLfY00<000000=7=Z@0000000P3AcJT00`000000dLfY0=7=
Z@060=7=Z@050000003AcJT0dLfY0=7=Z@000000103AcJT01@000000dLfY0=7=Z@3AcJT0000000H0
dLfY00<000000=7=Z@3AcJT0103AcJT01@000000dLfY0=7=Z@3AcJT0000000H0dLfY00D000000=7=
Z@3AcJT0dLfY000000020=7=Z@040000003AcJT0dLfY00000080dLfY00<000000=7=Z@3AcJT03P3A
cJT002/0dLfY00@000000=7=Z@3AcJT000000`3AcJT2000000@0dLfY0`0000020=7=Z@@00000203A
cJT4000000040=7=Z@00000000000=7=Z@80000000<0dLfY0000003AcJT00P0000040=7=Z@800000
0`3AcJT4000000<0dLfY0P0000040=7=Z@8000000P3AcJT010000000dLfY00000000000`0=7=Z@04
0000003AcJT0dLfY000000<0dLfY0P0000050=7=Z@030000003AcJT0dLfY0080dLfY0P0000030=7=
Z@@000000`3AcJT200000080dLfY0P0000020=7=Z@8000000P3AcJT2000000P0dLfY0P0000020=7=
Z@8000000P3AcJT2000000<0dLfY00<000000=7=Z@0000000P0000020=7=Z@800000103AcJT20000
00<0dLfY100000030=7=Z@800000103AcJT200000080dLfY00@000000=7=Z@00000000004@3AcJT0
02`0dLfY0P00000@0=7=Z@030000003AcJT0dLfY00T0dLfY00<000000=7=Z@3AcJT05@3AcJT00`00
0000dLfY0=7=Z@100=7=Z@@000002`3AcJT00`000000dLfY0=7=Z@080=7=Z@030000003AcJT0dLfY
03T0dLfY00<000000=7=Z@3AcJT08P3AcJT003h0dLfY00<000000=7=Z@3AcJT02P3AcJT2000001D0
dLfY00<000000=7=Z@3AcJT0103AcJT00`000000dLfY0=7=Z@170=7=Z@8000002P3AcJT00`000000
dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY02L0dLfY00<000000=7=Z@3AcJT0203AcJT00`000000
dLfY0=7=Z@040=7=Z@030000003AcJT0dLfY01/0dLfY003o0=7=ZB40dLfY003o0=7=ZB40dLfY003o
0=7=ZB40dLfY003o0=7=ZB40dLfY0000\
\>"],
  ImageRangeCache->{{{180, 467}, {465.875, 288.938}} -> {-1.37295, 2.08851, \
0.00733523, 0.00733523}, {{187.125, 317}, {461.625, 381.375}} -> {-119.513, \
1.49215, 0.552302, 0.00543592}, {{187.125, 317}, {373.375, 293.125}} -> \
{-119.513, 51.051, 0.552302, 0.274101}, {{329.938, 459.812}, {373.375, \
293.125}} -> {-191.516, 1.81147, 0.541256, 0.00972608}}]
}, Open  ]],

Cell[TextData[{
  "Using the vector ",
  StyleBox["res", "TB",
    FontFamily->"Courier"],
  ", it is possible to judge the visual quality of the images obtained at \
different iterations. In the case under examination, for example, by \
displaying the image restored after each ten iterations it is possible to \
judge when to stop the procedure."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[showImage[res[\([i]\)]], \ {i, \ 10, \ 50, \ 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
0000000000000043697C837E7D7A643D1203113761839A97967E5D2F050000264E6E7C85
8B85725638262F4D667177757675684700000000000000
000000000000006997A9AEA1A7AA97672F0D0F4173ADCBDDCBAF7B390B052355859BA69C
96927C583D2836547985878E99A1916B00000000000000
000000000000007BA7B0A999A8B7AE853B0B002360A2D0E0D2AD692B03053576A3AC9D84
6E6C5139170E18395763697390A6A17800000000000000
00000000000000809A8D74687FA5B18B3B0000002D74AFC8B5853E0900023E86ACAC7F51
2F22180600000013212E2C426C8A997800000000000000
000000000000007584643C2B4A84A5893D000000003C81A18C4D0E0000034B92B39E6B2F
0A00000000000000080C0D214E788B6E00000000000000
000000000000006A6E3E08001C6692813C000000001A64806A3200000004529FBEA3723D
1C100600000000091C1C1E3151788B6900000000000000
00000000000000675F2500000054847B380000000020627F6725000000095496B4A67D5D
504D4C341A0B19374B46454F6985926800000000000000
00000000000000655B1E0000003D81784000000000448497722C000000053F78908C756D
7688876D482B2742565B5A5D78918C6F00000000000000
00000000000000645E270000003D7C77440600013C86B3C38F4000000000204452514C59
7AA4AE92592C222D3C43464F6C8C8B6D00000000000000
000000000000006C6C3C00000C4B7E794517103075BCE3DCA65003000000000D13141737
6DA4AF98521A010A161A2131557E8B6A00000000000000
000000000000007A896639233B71917B471D1A4491DAFFEFB55C0D00000000000100092C
679EAF8C460E00000405112955848F7400000000000000
0000000000000087A7997D6B819FAE904819133F86CDF5EDB65F16000000061D25202C4E
7DAFB288460700001A2C3E547C9EA58000000000000000
000000000000008DB7C0B5AEB8C5BE8B420B021D629DCBCFA35E1F00000B32465C676A80
A3B7AD7E3E0C0C2950717A90A3BBB48700000000000000
0000000000000082B1C0C3C3C4C3B17E3B0000012D6A919E875321120B224A6E8D909BA0
AFB695693615294C819AABAEB5BCA67B00000000000000
00000000000000578596A3A0A49D865A24000000052F56635B381706132B54768C98958E
92886F411E1327527E98A39E9E97825B00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000204=3@`80JFUY
0P1lO7`308>3P`80OWin0P1mOGd307YjNP80I6AT0P0m?Cd3018B4P800`<30P0A4A4303Lg=`80HF5Q
0P23Ph<209ZJVP<0UiNG0P2FUYH207inOP<0GEeM0P0_;bl200D51@D000000P0V9RH304i>CP80KVi^
0P1lO7`208F5Q@<0Rh^;0P25QHD2079bLP<0EUIF0P0h>3P202HV9P<0;bl_0P1=CDd206IVIP<0LG5a
0P1gMgL207EeM@80MWIf0`1eMGD206QXJ080AdM74@0000040=7=Z@000`3AcJTA00000080@d=30P1Y
JFT207alO0<0Ph>30P1nOWh207emO@<0NWYj0P1TI6@203dm?@<04Q8B0P030`<2014A4@<0=cLg0P1Q
HF4208>3P`80VYZJ0`2GUiL209JFUP80OWin0`1MGEd202l_;`801@D51@00000202HV9P<0CTi>0P1^
KVh207alO080QHF50`2;Rh/208F5Q@80LW9b0`1FEUH203Ph>0809RHV0`0_;bl204e=C@80IVIV0`1a
LG4207MgM`80MGEe0P1fMWH307EeM@80J6QX0P17AdLA000000@0dLfY00030=7=ZA4000000P1YJFT2
09NGU`80ZJVY0`2^[Zh20:6QX@80YjNW0`2ZZZX209NGU`80IfMW0`0_;bl200d=3@803`l?0`11@D42
07=cL`80[Jf]0P3;bl/30=gMg@80bl_;0P2_[jl307]kN`80>CTi0P0;2`/300D51@808b<S0P1EEED3
08F5Q@80Vi^K0P2VYZH209bLW0<0UYJF0P2BTY8207alO0<0F5QH0P0m?Cd202PX:0<0=SHf0P1DE5@2
07UiN@<0QHF50P27QhL208j>SP80VIVI0`2QXJ42096AT@80Jf][4@0000040=7=Z@000`3AcJTA0000
0080JFUY0P2GUiL20:VYZ@<0[Zj^0P2QXJ420:NWY`<0ZZZZ0P2GUiL206MWI`<0;bl_0P0=3@d200l?
3`<0@D510P1cLg<20:f][@80bl_;0`3MgMd20<_;b`80[jn_0`1kNg/203Ti>@802`/;0`051@D202<S
8`80EEEE0`25QHD209^KV`80YZJV0P2LW9`309JFUP80TY:B0P1lO7`305QHF080?Cdm0P0X:2P303Hf
=P80E5AD0P1iNGT308F5Q@80QhN70P2>SXh209VIV@<0XJ6Q0P2ATI4206][Ja400000103AcJT000<0
dLfY4@00000206UYJ@80UiNG0P2YZJT30:j^[P80XJ6Q0P2WYjL30:ZZZP80UiNG0P1WIfL302l_;`80
3@d=0P0?3`l30451@@80Lg=c0P2][Jd20<_;b`<0gMgM0P3;bl/20:n_[`<0Ng]k0P0i>CT200/;2`<0
1@D50P0S8b<205EEE@<0QHF50P2KVi/20:JVYP80W9bL0`2FUYH209:BTP80O7al0`1HF5P203dm?@80
:2PX0`0f=SH205ADE080NGUi0`25QHD208N7Q`80SXj>0P2IVIT30:6QX@80TI6A0P1[Jf/A000000@0
dLfY00030=7=ZA4000000P1kNg/20:NWY`80/;2`0`2YZJT209VIV@80Z:RX0`2g]kL20:j^[P80QHF5
0`0k>c/200/;2`8000000`0S8b<2061PH080XZ:R0P3@d=030>3Ph080d];B0P2][Jd306UYJ@80:b/[
0P030`<300D51@80=CDe0P1fMWH30:>SX`80[:b/0P2MWId208B4Q0<0KVi^0P1/K6`2055AD@<0>CTi
0P0G5aL200h>3P<061PH0P0i>CT205MGE`<0Hf=S0P1YJFT207=cL`80T92@0`2VYZH20:6QX@80N7Qh
4@0000040=7=Z@000`3AcJTA00000080Ng]k0P2WYjL20;2`/0<0ZJVY0P2IVIT20:RXZ0<0]kNg0P2^
[Zh208F5Q@<0>c/k0P0;2`/2000000<08b<S0P1PH6020::RXP80d=3@0`3Ph>020=;BdP80[Jf]0`1Y
JFT202/[:`800`<30`051@D203De=@80MWIf0`2SXj<20:b/[080WIfM0P24Q8@306i^KP80K6a/0P1A
DE4303Ti>@805aLG0P0>3Ph301PH6080>CTi0P1GEeL306=SH`80JFUY0P1cLg<2092@T0<0YZJV0P2Q
XJ4207QhN1400000103AcJT000<0dLfY4@0000020820P080VYZJ0P2=SHd307AdM080J6QX0P1oOgl3
0:FUY@80/K6a0P2;Rh/303/k>`L000000P0];Bd207AdM080[jn_0`38b<P20;Fe]@80QHF50`0n?Sh2
00T92@8000000`020P8203hn?P80QXJ61@2/[:`207moO`80DE5A0`0_;bl2028R8P8061PH0`061PH7
000000804a<C0P0Q8B4302h^;P80;2`/0P12@T8206a/K0<0RXZ:0P2IVIT207QhN1400000103AcJT0
00<0dLfY4@0000020820P080VYZJ0P2=SHd307AdM080J6QX0P1oOgl30:FUY@80/K6a0P2;Rh/303/k
>`L000000P0];Bd207AdM080[jn_0`38b<P20;Fe]@80QHF50`0n?Sh200T92@8000000`020P8203hn
?P80QXJ61@2/[:`207moO`80DE5A0`0_;bl2028R8P8061PH0`061PH7000000804a<C0P0Q8B4302h^
;P80;2`/0P12@T8206a/K0<0RXZ:0P2IVIT207QhN1400000103AcJT000<0dLfY4@00000207EeM@80
Q8B40P1TI6@303`l?080:b/[0P1:BTX308B4Q080YJFU0P29RHT303dm?@T000000P0l?3`20861P@<0
XJ6Q0P2<S8`204e=C@<03Ph>1000000300<30`80Bd];0P2BTY830;>c/`80WYjN0P1[Jf/202l_;`<0
2PX:4000000200P820<030`<0P0=3@d2024Q8@80CTi>0`1hN7P208^;R`80KVi^4@0000040=7=Z@00
0`3AcJTA00000080MGEe0P24Q8@206ATI0<0?3`l0P0[:b/204Y:BP<0Q8B40P2UYJD208V9R@<0?Cdm
2@00000203`l?080PH610`2QXJ4208b<S080CDe=0`0>3Ph4000000<00`<30P1;Bd/209:BTP<0/k>c
0P2NWYh206][J`80;bl_0`0:2PX@0000008020P80`0<30`200d=3@808B4Q0P1>CTh307QhN080Rh^;
0P1^KVhA000000@0dLfY00030=7=ZA4000000P1eMGD208B4Q080I6AT0`0l?3`202/[:`80BTY:0`24
Q8@20:FUY@80RHV90`0m?Cd900000080?3`l0P21PH430:6QX@80S8b<0P1=CDd300h>3P@000000`03
0`<204];B`80TY:B0`2c/k<209jNWP80Jf][0P0_;bl300X:2Q0000000P0820P300`<30803@d=0P0Q
8B4204i>CP<0N7Qh0P2;Rh/206i^KQ400000103AcJT000<0dLfY4@00000206YZJP80KVi^0P0n?Sh3
00P8208000000P0L71`306IVIP80TY:B0P21PH4303`l?0T000000P0J6QX206ATI0<0P8200P1ZJVX2
038b<PL000000`0410@2059BDP80WinO0`2n_[h20:>SX`80LW9b0P0m?Cd301`L7080410@0P061PH:
000000802@T91@0L71`201hN7P80<C4a0P1ADE4307QhN080Rh^;0P1YJFTA000000@0dLfY00030=7=
ZA4000000P1ZJVX206i^KP80?Shn0`0820P20000008071`L0`1VIVH209:BTP80PH610`0l?3`90000
00806QXJ0P1TI6@30820P080JVYZ0P0b<S87000000<010@40P1BDU8209nOW`<0_[jn0P2SXj<2079b
LP80?Cdm0`0L71`2010@40801PH62P00000200T92@D071`L0P0N7Qh2034a<@80DE5A0`1hN7P208^;
R`80JFUY4@0000040=7=Z@000`3AcJTA00000080IfMW0P1OGel202DU9@L000000`1DE5@208B4Q080
Ng]k0`0h>3P900000080820P0P1RHV8307moO`80IfMW0P0U9BD7000000<02@T90P1DE5@209JFUP<0
];Bd0P2VYZH207emO@80GEeM0`1@D50204e=C@80C4a<0`0d=3@201XJ6P802`/;0`0I6AT203Lg=`80
Bd];0`16ATH204E5A@80Cdm?0P1YJFT308F5Q@80TY:B0P1XJ6PA000000@0dLfY00030=7=ZA400000
0P1WIfL205mOG`809BDU1`00000305ADE080Q8B40P1kNg/303Ph>0T000000P0P8202069RHP<0Ogmo
0P1WIfL202DU9@L000000`092@T205ADE080UYJF0`2d];@20:JVYP80OGem0P1MGEd3051@D080CDe=
0P1<C4`303@d=0806QXJ0P0;2`/301TI6@80=cLg0P1;Bd/304I6AP80ADE50P1?Cdl206UYJ@<0QHF5
0P2BTY8206QXJ1400000103AcJT000<0dLfY4@00000206EUI@80Fe]K0P0N7Qh7000000<0?Cdm0P21
PH4207QhN0<0@4102@00000204A4A080Q8B40`2GUiL2079bLP80;2`/1`00000300D51@80?clo0P1h
N7P3092@T080S8b<0P1eMGD206e]K@<0MWIf0P28R8P208N7Q`<0KFe]0P18B4P202/[:`<09bLW0P12
@T8205IFEP<0Fe]K0P1JFUX205eMG@80N7Qh0`2ATI4208b<S080Kfm_4@0000040=7=Z@000`3AcJTA
00000080IFEU0P1KFe/201hN7PL000000`0m?Cd20861P@80N7Qh0`10@40900000080A4A40P24Q8@3
09NGU`80LW9b0P0/;2`7000000<01@D50P0o?cl207QhN0<0T92@0P2<S8`207EeM@80KFe]0`1fMWH2
08R8R080QhN70`1]KFd204Q8B080:b/[0`0W9bL20492@P80EUIF0`1KFe/205YJFP80GEeM0P1hN7P3
096AT@80S8b<0P1_KflA000000@0dLfY00030=7=ZA4000000P1TI6@205iNGP809bLW1`00000303dm
?@80O7al0P1gMgL304A4A0801PH60P00000300410@80?3`l0P26QXH20;>c/`<0`l?30P2?Shl20410
@0X000000P0P820204A4A0<0DU9B0P1ADE4204a<C080FEUI0`1jNWX20:BTY080[Zj^0`2BTY8205UI
F@80;2`/0`0R8R8202d];@80?3`l0`13@d<204I6AP80Cdm?0P1/K6`308b<S080Rh^;0P1]KFdA0000
00@0dLfY00030=7=ZA4000000P1TI6@205iNGP809bLW1`00000303dm?@80O7al0P1gMgL304A4A080
1PH60P00000300410@80?3`l0P26QXH20;>c/`<0`l?30P2?Shl20410@0X000000P0P820204A4A0<0
DU9B0P1ADE4204a<C080FEUI0`1jNWX20:BTY080[Zj^0`2BTY8205UIF@80;2`/0`0R8R8202d];@80
?3`l0`13@d<204I6AP80Cdm?0P1/K6`308b<S080Rh^;0P1]KFdA000000@0dLfY00030=7=ZA400000
0P1TI6@205iNGP809bLW1`00000303dm?@80O7al0P1gMgL304A4A0801PH60P00000300410@80?3`l
0P26QXH20;>c/`<0`l?30P2?Shl20410@0X000000P0P820204A4A0<0DU9B0P1ADE4204a<C080FEUI
0`1jNWX20:BTY080[Zj^0`2BTY8205UIF@80;2`/0`0R8R8202d];@80?3`l0`13@d<204I6AP80Cdm?
0P1/K6`308b<S080Rh^;0P1]KFdA000000@0dLfY00030=7=ZA400000101/K6`203`l?0D000000P0<
30`304];B`80OWin0P1iNGT304E5A@805aLG0P0@4103030`<080MGEe0P2l_;`20>?Sh`<0g=cL0P2V
YZH2051@D0<00`<32@00000200d=3@<04a<C0P0D51@201LG5`80=cLg0`1]KFd20:BTY080[jn_0`2H
V9P2059BDP806QXJ0`010@4200X:2P805QHF0`0J6QX2024Q8@80<C4a0P1EEED307inOP80Rh^;0P1Z
JVXA000000@0dLfY00030=7=ZA400000101/K6`203`l?0D000000P0<30`304];B`80OWin0P1iNGT3
04E5A@805aLG0P0@4103030`<080MGEe0P2l_;`20>?Sh`<0g=cL0P2VYZH2051@D0<00`<32@000002
00d=3@<04a<C0P0D51@201LG5`80=cLg0`1]KFd20:BTY080[jn_0`2HV9P2059BDP806QXJ0`010@42
00X:2P805QHF0`0J6QX2024Q8@80<C4a0P1EEED307inOP80Rh^;0P1ZJVXA000000@0dLfY00030=7=
ZA4000000P1jNWX208V9R@80IVIV0`0i>CT202<S8`80>c/k0`1aLG42096AT@80Ng]k0`17AdL201dM
7@806QXJ0`14A4@2096AT@80f][J0P3oool30>o_k`80]KFe0P1LG5`300d=3@/000000`010@420000
00802@T90P0/;2`306MWI`80WYjN0P2_[jl308b<S080ATI60P0>3Ph50000008010@40`051@D2014A
4@80:BTY0P1EEED308B4Q080Shn?0P1dM7@A000000@0dLfY00030=7=ZA4000000P1jNWX208V9R@80
IVIV0`0i>CT202<S8`80>c/k0`1aLG42096AT@80Ng]k0`17AdL201dM7@806QXJ0`14A4@2096AT@80
f][J0P3oool30>o_k`80]KFe0P1LG5`300d=3@/000000`010@42000000802@T90P0/;2`306MWI`80
WYjN0P2_[jl308b<S080ATI60P0>3Ph50000008010@40`051@D2014A4@80:BTY0P1EEED308B4Q080
Shn?0P1dM7@A000000@0dLfY00030=7=ZA4000000P27QhL20:NWY`80VIVI0`1mOGd206][J`80PH61
0`2OWil20:j^[P80T92@0`18B4P201TI6@804a<C0`0o?cl208J6QP80cLg=0P3emOD30>g]k@80][Jf
0P1OGel301HF5PL000000P061PH201dM7@<09BDU0P0P820202`/;080CTi>0`1mOGd20:n_[`80/[:b
0`28R8P204I6AP801`L71@00000201XJ6P<0;2`/0P0n?Sh205ADE080O7al0`2NWYh20:FUY@80P820
4@0000040=7=Z@000`3AcJTA00000080QhN70P2WYjL209VIV@<0OGem0P1[Jf/20861P@<0WinO0P2^
[Zh2092@T0<0B4Q80P0I6AT201<C4`<0?clo0P26QXH20<g=c@80mOGe0`3]kNd20;Jf]P80GemO0`0F
5QH7000000801PH60P0M7Ad302DU9@80820P0P0/;2`204i>CP<0OGem0P2_[jl20;:b/P<0R8R80P16
ATH200L71`D000000P0J6QX302`/;080?Shn0P1DE5@207alO0<0WYjN0P2UYJD20820P1400000103A
cJT000<0dLfY4@00000208f=S@80]kNg0P30`<030;Fe]@80[Zj^0P2h^;P30<G5a@80_[jn0P2;Rh/3
0492@P802`/;0P020P8301dM7@80HV9R0P2MWId20<_;b`<0clo?0P2SXj<205iNGP<07alO10000003
00/;2`80<S8b0P16ATH305aLG080IfMW0P1ZJVX20820P0<0Xj>S0P2g]kL20:f][@<0OWin0P0n?Sh5
00`<3080:BTY0P1@D503075aL@80NWYj0P2@T9020:>SX`<0^k^k0P2d];@208N7Qa400000103AcJT0
00<0dLfY4@00000208f=S@80]kNg0P30`<030;Fe]@80[Zj^0P2h^;P30<G5a@80_[jn0P2;Rh/30492
@P802`/;0P020P8301dM7@80HV9R0P2MWId20<_;b`<0clo?0P2SXj<205iNGP<07alO1000000300/;
2`80<S8b0P16ATH305aLG080IfMW0P1ZJVX20820P0<0Xj>S0P2g]kL20:f][@<0OWin0P0n?Sh500`<
3080:BTY0P1@D503075aL@80NWYj0P2@T9020:>SX`<0^k^k0P2d];@208N7Qa400000103AcJT000<0
dLfY4@00000208f=S@80]kNg0P30`<030;Fe]@80[Zj^0P2h^;P30<G5a@80_[jn0P2;Rh/30492@P80
2`/;0P020P8301dM7@80HV9R0P2MWId20<_;b`<0clo?0P2SXj<205iNGP<07alO1000000300/;2`80
<S8b0P16ATH305aLG080IfMW0P1ZJVX20820P0<0Xj>S0P2g]kL20:f][@<0OWin0P0n?Sh500`<3080
:BTY0P1@D503075aL@80NWYj0P2@T9020:>SX`<0^k^k0P2d];@208N7Qa400000103AcJT000<0dLfY
4@00000208:2PP80/K6a0P30`<050<?3``80a<C40`33`l<20;6a/@80OWin0`0k>c/4000000<00@41
0P0];Bd206YZJP80TI6A0`2NWYh208N7Q`80De=C0`0Q8B42018B4P802`/;0`0R8R8204Y:BP80KVi^
0`2=SHd2092@T080Vi^K0P2PX:030:n_[`80][Jf0P2EUID306UYJ@80=SHf0P0E5AD302TY:@80C4a<
0P21PH4309ZJVP80Zj^[0P2^[Zh20;Fe]@<0_;bl0P2VYZH207]kNa400000103AcJT000<0dLfY4@00
000208:2PP80/K6a0P30`<050<?3``80a<C40`33`l<20;6a/@80OWin0`0k>c/4000000<00@410P0]
;Bd206YZJP80TI6A0`2NWYh208N7Q`80De=C0`0Q8B42018B4P802`/;0`0R8R8204Y:BP80KVi^0`2=
SHd2092@T080Vi^K0P2PX:030:n_[`80][Jf0P2EUID306UYJ@80=SHf0P0E5AD302TY:@80C4a<0P21
PH4309ZJVP80Zj^[0P2^[Zh20;Fe]@<0_;bl0P2VYZH207]kNa400000103AcJT000<0dLfY4@000002
05MGE`80QHF50P2FUYH30:>SX`80X:2P0P2TY:@309fMW@80QXJ60P1JFUX302@T90L000000P051@D2
02l_;`80EUIF0`1SHf<205]KF`80>3Ph0`0G5aL200H61P804a<C0`0[:b/205ADE080MWIf0`2<S8`2
09RHV080UIFE0P2>SXh309:BTP80R8R80P1_Kfl30451@@807QhN0P0C4a<302LW9`80DU9B0P1nOWh3
09RHV080Xj>S102NWYh309NGU`80PX:20P1KFe/A000000@0dLfY00030=7=ZA4000000P1GEeL208F5
Q@80UYJF0`2SXj<20:2PX080Y:BT0`2MWId208J6QP80FUYJ0`0T92@7000000801@D50P0_;bl205IF
EP<0Hf=S0P1KFe/203Ph>0<05aLG0P061PH201<C4`<0:b/[0P1DE5@207IfMP<0S8b<0P2HV9P209FE
U@80SXj>0`2BTY8208R8R080Kfm_0`11@D4201hN7P804a<C0`0W9bL2059BDP80OWin0`2HV9P20:>S
X`@0WYjN0`2GUiL208:2PP80Fe]K4@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {169.75, 100}} -> {-80.2954, 42.9312, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
0000000000000049788D9488827C5B2700000236637D8A7D887D693C060000113A5D6A78
8B8E7F5D30121B476A767E777676663D00000000000000
000000000000006FA8BCBFA4A7A98E4D050000366AA6B8CCBDB1873D02000E427688968B
909E8D5F3813244F84928D91A0AC986A00000000000000
000000000000007FB8BFB190A1B5AA761500000F5396BCCAC2AE6E2F000027709D9D8365
556C553D0B0005335B6463688DB1AF7D00000000000000
000000000000008BAA936A5271A9C0932E00000021669EB8AA85431300014192B3A65F22
03080F01000000111D2510235B87A78200000000000000
000000000000008BA0713518439AD3B75A0000000033789B8A4F1C0000216DB8D0A15401
0000000000000000100700003874987B00000000000000
00000000000000919E5D10002999DFD3820F0000001D678371450D00053D90E2F8C0752F
0D0C0D080000112F46352328477EA27D00000000000000
00000000000000A3A2570000209EE7E2932C000000336D8B793F10001257A4E5F8D79971
6B737D61402F4D809C856B617699B48100000000000000
00000000000000A7A65905001883E7DF9D4302021F5C95A580441906205386BBC6B79691
A7CCD1B07D5A5C8DAAA389748CAAA88E00000000000000
000000000000009B9F590000056FC8C4843A182F61A1BDCC944C140511284C615F57506A
A3EAFFDA884C475C6F6B574E6A999E8400000000000000
000000000000008E96580000095CA39C5A2625478DCAE0CE964505000000010000000025
7CD5EBD06D2000121C1103053071927600000000000000
00000000000000879F6F2D09246C95743203073B8FD6F1D2953C00000000000000000002
5FB9D9AD4B000000000000001C6A8B7A00000000000000
0000000000000081AF9B71526E93A67C1800001867B0D6CA90330000000000000000002B
73C4D19C42000000000002144B87A68400000000000000
000000000000007FB8C3B5A9B5C4B9700D000000316EA3AC7E3600000000142440505372
A7C7C0842E000015415F556B84B3BA8900000000000000
0000000000000075B2C6CDCECFCDB46F16000000003B6A81713A040000012F5D8C8FA0A5
B8C59A64220019468899A39BA6BAA87900000000000000
00000000000000438199B0AEB7AD90561300000000073A50532D0500000E406D8EA3A092
9688692E0400164F849AA09293927F5400000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000204U9B@80N7Qh
0P2=SHd309BDU080R8R80P22PX8307alO080Fe]K0P0W9bL5000000800P820`0f=SH206=SH`80OGem
0P2:RXX307emO@80R8R80P1mOGd306UYJ@80?3`l0P061PH5000000804A4A0`0j>SX205eMG@80JVYZ
0P1hN7P308^;R`80SXj>0P1oOgl305eMG@80<30`0P0B4Q8301/K6`80AdM70P1ZJVX307IfMP80OWin
0P1gMgL507IfMP80IVIV0P0m?CdA000000@0dLfY00030=7=ZA4000000P19BDT207QhN080SHf=0`2D
U9@208R8R080PX:20`1lO7`205]KF`809bLW1@00000200820P<0=SHf0P1SHf<207emO@80RXZ:0`1m
OGd208R8R080OGem0`1YJFT203`l?0801PH61@000002014A4@<0>SXj0P1MGEd206YZJP80N7Qh0`2;
Rh/208j>SP80Ogmo0`1MGEd2030`<0804Q8B0`0K6a/204M7A`80JVYZ0`1fMWH207inOP80MgMg1@1f
MWH206IVIP80?Cdm4@0000040=7=Z@000`3AcJTA00000080Kfm_0P2XZ:P20;bl_0<0_kno0P2TY:@2
0:NWY`<0ZJVY0P2>SXh204e=C@<01@D51000000303Hf=P80JVYZ0P2VYZH20;Rh^0<0c<c<0P2m_Kd2
0;6a/@<0QhN70P0m?Cd200820P<000000P0>3Ph20492@P<0MWIf0P28R8P209JFUP80Rh^;0`2@T902
09jNWP80SHf=0`1OGel203Ph>0804a<C0`0T92@204m?C`80Q8B40`2BTY8208f=S@80TI6A0P2PX:03
0:b/[080V9RH0P1ZJVXA000000@0dLfY00030=7=ZA4000000P1_Kfl20:RXZ080_;bl0`2o_kl20:BT
Y080YjNW0`2YZJT208j>SP80CDe=0`051@D4000000<0=SHf0P1ZJVX20:JVYP80^;Rh0`3<c<`20;fm
_@80/K6a0`27QhL203dm?@800P820`00000200h>3P80@T920`1fMWH208R8R080UYJF0P2;Rh/3092@
T080WYjN0P2=SHd305mOG`80>3Ph0P0C4a<302@T9080Cdm?0P24Q8@309:BTP80SHf=0P2ATI420:2P
X0<0[:b/0P2HV9P206YZJQ400000103AcJT000<0dLfY4@00000206m_K`80Z:RX0P2l_;`30;no_`80
Y:BT0P2WYjL30:VYZ@80SXj>0P1=CDd300D51@@000000`0f=SH206YZJP80YZJV0P2h^;P30<c<c080
_Kfm0P2a/K4308N7Q`80?Cdm0P020P83000000803Ph>0P12@T8307IfMP80R8R80P2FUYH208^;R`<0
T92@0P2NWYh208f=S@<0GemO0P0h>3P201<C4`<092@T0P1?Cdl208B4Q0<0TY:B0P2=SHd2096AT@80
X:2P0`2/[:`209RHV080JVYZ4@0000040=7=Z@000`3AcJTA00000080Ogmo0P2h^;P20;no_`<0/K6a
0P2@T9020:6QX@<0]KFe0P2ZZZX207IfMP<05ADE1000000300l?3`80De=C0P2FUYH20;bl_0<0b/[:
0P32`/820:j^[P<0KVi^0P0_;bl5000000809bLW0P1`L70509fMW@80Ph>30P1UIFD305EEE@80K6a/
0P1EEED303dm?@802`/;0P00000300D51@80<c<c0P1KFe/306ATI080Hf=S0P1XJ6P208f=S@<0/K6a
0P2_[jl207emOA400000103AcJT000<0dLfY4@00000207moO`80^;Rh0P2o_kl30;6a/@80T92@0P2Q
XJ430;Fe]@80ZZZZ0P1fMWH301DE5@@000000`0?3`l205=CD`80UYJF0P2l_;`30<[:bP80`/;20P2^
[Zh306i^KP80;bl_1@00000202LW9`80L71`1@2MWId208>3P`80IFEU0`1EEED206a/K080EEEE0`0m
?Cd200/;2`8000000`051@D203<c<`80Fe]K0`1TI6@206=SH`80J6QX0P2=SHd30;6a/@80[jn_0P1m
OGdA000000@0dLfY00030=7=ZA4000000P2;Rh/20:ZZZP80Ti>C0`1ZJVX2059BDP80LG5a0`2YZJT2
0<30`080Ti>C0`0^;Rh7000000808B4Q0P1VIVH209jNWP<0^;Rh0P2ZZZX208F5Q@<0@d=30P0C4a<2
000000<00@410P11@D4209:BTP<0/k>c0P2VYZH205mOG`808R8R0`030`<200P820803`l?0`010@47
000000804A4A0P0M7Ad302DU9@80410@0P0S8b<205]KF`<0QhN70P2WYjL208:2PQ400000103AcJT0
00<0dLfY4@00000208^;R`80ZZZZ0P2CTi<306YZJP80DU9B0P1aLG430:VYZ@80`<300P2CTi<302h^
;PL000000P0Q8B4206IVIP80WYjN0`2h^;P20:ZZZP80QHF50`13@d<201<C4`8000000`010@420451
@@80TY:B0`2c/k<20:JVYP80GemO0P0R8R8300<30`8020P80P0?3`l300410@L000000P0A4A4201dM
7@<09BDU0P0@410202<S8`80Fe]K0`27QhL20:NWY`80PX:24@0000040=7=Z@000`3AcJTA00000080
Rh^;0P2PX:02075aL@<0=CDe0P0H61P204=3@`<0VYZJ0P3Cdm<20;Ng]`<0FUYJ2@00000203<c<`80
N7Qh0`2KVi/208Z:RP80Cdm?0`0L71`4000000<08B4Q0P1]KFd20;Rh^0<0d=3@0P2QXJ4205ADE080
0@414`000002010@40<01`L71000000203Ph>0<0M7Ad0P2HV9P207]kNa400000103AcJT000<0dLfY
4@00000208^;R`80X:2P0P1aLG4303De=@8061PH0P13@d<309ZJVP80dm?C0P2g]kL305YJFPT00000
0P0c<c<207QhN0<0Vi^K0P2:RXX204m?C`<071`L10000003024Q8@80KFe]0P2h^;P30=3@d080XJ6Q
0P1DE5@200410A<000000P0@410300L71`@000000P0h>3P307AdM080V9RH0P1kNg/A000000@0dLfY
00030=7=ZA4000000P2;Rh/20:2PX080LG5a0`0e=CD201PH6080@d=30`2JVYX20=?Cd`80]kNg0`1J
FUX900000080<c<c0P1hN7P309^KV`80RXZ:0P1?Cdl301`L70@000000`0Q8B4206e]K@80^;Rh0`3@
d=020:6QX@80E5AD0P010@4C00000080410@0`071`L400000080>3Ph0`1dM7@209RHV080Ng]k4@00
00040=7=Z@000`3AcJTA00000080TI6A0P2NWYh205eMG@<0410@0P00000202TY:@<0VIVI0P3Ogml2
0=?Cd`<0PX:20P0?3`l7000000807AdM0P1WIfL308>3P`80LG5a0P15ADD300d=3@8000000P051@D3
03dm?@80T92@0P3Rh^830?Shn080`<300P1eMGD202l_;`<03@d=0P0<30`200d=3@<020P810000003
014A4@80;bl_0P16ATH303De=@808b<S0P0X:2P204M7A`<0OWin0P2RXZ8207emOA400000103AcJT0
00<0dLfY4@000002096AT@80WYjN0P1MGEd3010@408000000P0Y:BT309VIV@80gmoO0P3Cdm<308:2
PP803`l?1`00000201dM7@80IfMW0`23Ph<2075aL@80ADE50`0=3@d2000000801@D50`0m?Cd2092@
T080h^;R0`3hn?P20<30`080MGEe0P0_;bl300d=3@8030`<0P0=3@d300P820@000000`0A4A4202l_
;`80ATI60`0e=CD202<S8`80:2PX0P17AdL307inOP80XZ:R0P1mOGdA000000@0dLfY00030=7=ZA40
00000P2SXj<20::RXP80EeMG1@000002020P80<0WYjN0P3WinL20>;RhP<0Ti>C0P0/;2`700000080
<c<c0P1]KFd308^;R`80NGUi0P0o?cl3010@408000000P0B4Q8305MGE`80Y:BT0P3UiND30?Shn080
emOG0P2IVIT2075aL@<0Jf][0P1cLg<207emO@<0HF5Q0P10@40202l_;`<0CDe=0P20P80209bLW0<0
QHF50P1[Jf/2065QH@80MWIf0`2IVIT20;Bd]080PH614@0000040=7=Z@000`3AcJTA00000080Xj>S
0P2RXZ8205MGE`D000000P0P820309jNWP80inOW0P3Rh^8309>CT`80;2`/1`00000203<c<`80KFe]
0`2;Rh/207UiN@80?clo0`0@4102000000804Q8B0`1GEeL20:BTY080iNGU0`3hn?P20=OGe`80VIVI
0P1aLG4306][J`80Lg=c0P1mOGd3065QH@80@4100P0_;bl304e=C@80P8200P2LW9`308F5Q@80Jf][
0P1QHF4207IfMP<0VIVI0P2d];@20861PA400000103AcJT000<0dLfY4@0000020:NWY`80YZJV0P1I
FET300D51@8000000P0H61P308>3P`80inOW0P3Ogml309fMW@80@d=31@020P8201lO7`80G5aL0P2E
UID30:FUY@80P8200P14A4@301TI6@801PH60P0P820305=CD`80QXJ60P2k^k/30<K6aP80]kNg0P2F
UYH2096AT@<0YjNW0P3<c<`20=7Ad@<0/;2`0P1mOGd205YJFP<0G5aL0P2=SHd20:ZZZP<0Xj>S0P29
RHT207AdM080S8b<0`2ZZZX20:RXZ080SXj>4@0000040=7=Z@000`3AcJTA00000080YjNW0P2VYZH2
05UIF@<01@D50P00000201PH60<0Ph>30P3WinL20=oOg`<0WIfM0P13@d<500820P807alO0P1LG5`2
09FEU@<0YJFU0P20P80204A4A0<06ATI0P061PH2020P80<0De=C0P26QXH20;^k^`<0a/K60P2g]kL2
09JFUP80TI6A0`2WYjL20<c<c080dM7A0`2`/;0207emO@80FUYJ0`1LG5`208f=S@80ZZZZ0`2SXj<2
08V9R@80M7Ad0P2<S8`30:ZZZP80Z:RX0P2>SXhA000000@0dLfY00030=7=ZA4000000P2KVi/209nO
W`80FEUI1@00000200D51@<0Kfm_0P38b<P20<C4a0<0Q8B40P0j>SX201PH60<0;bl_0P1QHF420:6Q
X@80_Kfm0`3<c<`209BDU080C4a<0`0D51@200D51@804A4A0`0X:2P204a<C080HF5Q0`1OGel205MG
E`80D51@0P1ZJVX30:>SX`80j^[Z0P3oool30=[JfP80R8R80P1<C4`304M7A`80G5aL0P1_Kfl306][
J`80EeMG0P1>CTh206YZJP<0VIVI0P2NWYh208B4Q1400000103AcJT000<0dLfY4@00000209^KV`80
WinO0P1IFET5000000801@D50`1_Kfl20<S8b080a<C40`24Q8@203Xj>P8061PH0`0_;bl2065QH@80
XJ6Q0P2m_Kd30<c<c080U9BD0P1<C4`301@D50801@D50P0A4A4302PX:080C4a<0P1QHF4305mOG`80
EeMG0P1@D50206YZJP<0Xj>S0P3Zj^X20?ooo`<0f][J0P28R8P204a<C0<0AdM70P1LG5`206m_K`<0
Jf][0P1GEeL204i>CP80JVYZ0`2IVIT209jNWP80Q8B44@0000040=7=Z@000`3AcJTA00000080Vi^K
0P2OWil205UIF@D000000P051@D306m_K`80b<S80P34a<@308B4Q080>SXj0P0H61P302l_;`80HF5Q
0P2QXJ420;fm_@<0c<c<0P2DU9@204a<C0<051@D0P051@D2014A4@<0:2PX0P1<C4`2065QH@<0GemO
0P1GEeL2051@D080JVYZ0`2SXj<20>[ZjP80oooo0`3Jf]X208R8R080C4a<0`17AdL205aLG080Kfm_
0`1[Jf/205MGE`80CTi>0P1ZJVX309VIV@80WYjN0P24Q8@A000000@0dLfY00030=7=ZA4000000P2>
SXh209JFUP80F5QH1@00000200T92@<0G5aL0P2SXj<209bLW0<0FUYJ0P0V9RH202DU9@<0AdM70P2=
SHd20<[:bP80h>3P0`3>c/h209JFUP80ADE50`051@D7000000800@412@00000202DU9@<0O7al0P3E
eMD20>_[j`<0d=3@0P1]KFd2020P80<000000P0B4Q8201`L70<04A4A0P030`<200D51@80<30`0`1a
LG4209:BTP80MWIf4@0000040=7=Z@000`3AcJTA00000080SXj>0P2FUYH205QHF0D000000P092@T3
05aLG080Xj>S0P2LW9`305YJFP809RHV0P0U9BD304M7A`80SHf=0P3:b/X20>3Ph0<0c/k>0P2FUYH2
04E5A@<01@D51`00000200410@T000000P0U9BD307alO080eMGE0P3[jn/30=3@d080KFe]0P0P8203
000000804Q8B0P0L71`3014A4@800`<30P051@D2030`<0<0LG5a0P2BTY8207IfMQ400000103AcJT0
00<0dLfY4@00000208N7Q`80WinO0P1_Kfl302d];@802@T90P0T92@306a/K080UIFE0P1dM7@3038b
<P800`<30P071`L303/k>`80Shn?0P3Fe]H20?7al@<0d];B0P2EUID203`l?1D000000P020P8305mO
G`80^KVi0P3IfMT30:f][@80Bd];4000000201`L70<0JVYZ0P2;Rh/207YjNQ400000103AcJT000<0
dLfY4@00000208N7Q`80WinO0P1_Kfl302d];@802@T90P0T92@306a/K080UIFE0P1dM7@3038b<P80
0`<30P071`L303/k>`80Shn?0P3Fe]H20?7al@<0d];B0P2EUID203`l?1D000000P020P8305mOG`80
^KVi0P3IfMT30:f][@80Bd];4000000201`L70<0JVYZ0P2;Rh/207YjNQ400000103AcJT000<0dLfY
4@0000020861P@80[jn_0P2KVi/3075aL@80DU9B0P1^KVh309>CT`80YZJV0P1lO7`301PH60@00000
0`0H61P206MWI`80/;2`0P3Fe]H30<[:bP80T92@0P0c<c<E00000080:b/[0`1cLg<20<C4a080dM7A
0`2LW9`20492@P`000000P020P8201@D5080Bd];0`27QhL20:JVYP80Q8B44@0000040=7=Z@000`3A
cJTA00000080PH610P2_[jl209^KV`<0LG5a0P1BDU8206i^KP<0Ti>C0P2VYZH207alO0<061PH1000
000301PH6080IfMW0P2`/;020=KFeP<0b/[:0P2@T90203<c<aD000000P0[:b/307=cL`80a<C40P3A
dM4309bLW080@T923000000200820P8051@D0P1;Bd/308N7Q`80YZJV0P24Q8@A000000@0dLfY0003
0=7=ZA4000000P1oOgl20;Rh^080`l?30`2e]KD20:VYZ@80]KFe0`34a<@20;Vi^@80L71`0`0=3@d7
00000080<C4a0P1^KVh20:>SX`<0[:b/0P1nOWh203Hf=PX000000P0D51@202@T90<0@4100P1@D502
05=CD`80LW9b0`2WYjL20<O7a`80`<300`24Q8@202h^;PD000000P0E5AD20451@@<0GemO0P1EEED2
06][J`80Q8B40`2c/k<20;Zj^P80RHV94@0000040=7=Z@000`3AcJTA00000080Ogmo0P2h^;P20<?3
``<0]KFe0P2YZJT20;Fe]@<0a<C40P2i^KT2071`L0<03@d=1`000002034a<@80KVi^0P2SXj<30:b/
[080OWin0P0f=SH:0000008051@D0P0T92@30410@080D51@0P1CDe<2079bLP<0YjNW0P37alL20<30
`0<0Q8B40P0^;Rh5000000805ADE0P11@D4305mOG`80EEEE0P1[Jf/208B4Q0<0/k>c0P2j^[X208V9
RA400000103AcJT000<0dLfY4@00000207moO`80^;Rh0P33`l<30;Fe]@80ZJVY0P2e]KD30<C4a080
^KVi0P1`L70300d=3@L000000P0a<C4206i^KP80Xj>S0`2/[:`207inOP80=SHf2P00000201@D5080
92@T0`10@402051@D080De=C0P1bLW830:NWY`80alO70P30`<0308B4Q080;Rh^1@00000201DE5@80
@D510`1OGel205EEE@80Jf][0P24Q8@30;>c/`80^[Zj0P29RHTA000000@0dLfY00030=7=ZA400000
0P1eMGD20;:b/P80a/K60`3=cLd20<k>cP80clo?0`3=cLd20;Bd]080Kfm_0`0F5QH900000080>c/k
0P1ZJVX30861P@80LG5a0P0j>SX300@410@000000`010@4202l_;`80GEeM0`2<S8`208n?S`80X:2P
0P2UYJD30;Rh^080aLG50P2JVYX306ATI0808R8R0P00000301TI6@80ATI60P28R8P309VIV@80Xj>S
0P2KVi/20:JVYP<0^[Zj0P2XZ:P207UiNA400000103AcJT000<0dLfY4@00000207EeM@80/[:b0P36
a/H30<g=c@80c/k>0P3?cll30<g=c@80];Bd0P1_Kfl301HF5PT000000P0k>c/206YZJP<0PH610P1a
LG4203Xj>P<010@41000000300410@80;bl_0P1MGEd308b<S080Shn?0P2PX:020:FUY@<0^;Rh0P35
aLD209ZJVP<0I6AT0P0R8R82000000<06ATI0P16ATH208R8R0<0VIVI0P2SXj<209^KV`80YZJV0`2j
^[X20:RXZ080NGUi4@0000040=7=Z@000`3AcJTA00000080@d=30P21PH4209VIV@<0/;2`0P2^[Zh2
0;Ng]`<0[Jf]0P2@T90205IFEP<04a<C2@00000200L71`80>SXj0`1@D50205=CD`80;Bd]0`051@D4
000000<03Ph>0P10@40206e]K@<0SXj>0P2SXj<20:2PX080TY:B0`2FUYH208R8R080JFUY0`0^;Rh2
00@4108000000`0F5QH204m?C`80Q8B40`2JVYX20:2PX080TY:B0P2CTi<309:BTP80Ogmo0P1DE5@A
000000@0dLfY00030=7=ZA4000000P13@d<20861P@80VIVI0`2`/;020:j^[P80]kNg0`2][Jd2092@
T080EUIF0`0C4a<9000000801`L70P0j>SX3051@D080De=C0P0];Bd300D51@@000000`0>3Ph20410
@080KFe]0`2>SXh20:>SX`80X:2P0P2BTY8309JFUP80R8R80P1YJFT302h^;P8010@40P00000301HF
5P80Cdm?0P24Q8@309ZJVP80X:2P0P2BTY8209>CT`<0TY:B0P1oOgl205ADE1400000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00T03AcJT00900dLfY0000\
\>"],
  ImageRangeCache->{{{180, 323}, {258.5, 188.75}} -> {-80.2954, 81.676, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
0000000000000068A0B9C1AEA49A753E090A316B8F969175888C8C6B36090E345A7B8491
A8AE9E77411E2B638F9CA1948D8B7A4C00000000000000
0000000000000095D8EEF0CACACBAF6C250A2277A1CECAD5C5CBB16D301F386B9FABB6A8
B1C8BA865B2E4377B7C2B4B0BAC7B07D00000000000000
00000000000000A5E7EDD8A9B8CFC797350D134D8ABED0D1CBC5905722184A96C3BB9876
698F7D672E1C285E8A8D80799EC6C68F00000000000000
00000000000000AED0B17B5472B2D3AC490D00184E83AABAAB8F552D121658AECCB8601B
0010261F000012373F3F16205A8CB59000000000000000
00000000000000A6C18639093294DCC8700E0000003C748F7D451C00002B79C8DDA04400
000000000000081A2A1400002A6E9D8100000000000000
00000000000000A8BC700E00108BDEDA8E1D000000125063512D0000053F94ECFFB8600F
0000000300052149654928213A76A37B00000000000000
00000000000000B9C26D00000992E1E2953200000018435A4A1700000F5AAAEBFCD18556
515F7256362A59A3CAAB82687595B57A00000000000000
00000000000000BDC8740E000774E4DB9D480907123A616741120000265F8FC3C9B0847A
92BDC6A36E5062AEDBD5AD8592ACA48900000000000000
00000000000000AFC07600000063C5C28642273D5F88888D53180007253F606C5F4C3A4F
8CDDF9D1773F4D799C99785C6D9A9B7F00000000000000
00000000000000A4B57306000054A3A0613946669CBEB690581500000A17200900000006
63CAE5CD6116042D443519092B6C917200000000000000
000000000000009FBF893B09206D9D7E43223267AFDBD7A2631700000002030000000000
4BB2DCB24B0200001200000013678A7B00000000000000
000000000000009AD0B8845A759EB8943207114D8EBEC8AB6E1900000010131E12000023
6DCBE0AC5200000A2C291C1B4C88AB8800000000000000
0000000000000099D7E2CDBAC4D4CF8829000011597C9D996827000002194B546B72667C
B2D5D49A4403164C8099797F8ABAC18C00000000000000
000000000000008DCDDEE1DDD9D7C48433000000134B67756633070F06235587BAB4BEB8
C8D7AA773713467FCAD2CCAFADBDA77600000000000000
000000000000004D8FA4B9B0B6AA8F5C26000000000F364449240200041C5487ACC1B69D
9E8E71351111387DB6C4BB9B928C774B00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000206QXJ080X:2P
0P2i^KT30<71`@80[Zj^0P2TY:@309ZJVP80MGEe0P0n?Sh300T92@802PX:0P0a<C4306][J`80Shn?
0P2FUYH2096AT@<0MGEe0P28R8P508b<S080Jf][0P0f=SH300T92@803Ph>0P0d=3@305YJFP80Ng]k
0P24Q8@2096AT@<0Z:RX0P2^[Zh209jNWP<0MgMg0P11@D4201hN7P<0:b/[0P1SHf<208n?S`<0W9bL
0P2QXJ4209BDU080SHf=0`2;Rh/207YjNP80C4a<4@0000040=7=Z@000`3AcJTA00000080J6QX0P2P
X:020;Vi^@<0`L710P2^[Zh20:BTY0<0VYZJ0P1eMGD203hn?P<02@T90P0:2PX2034a<@<0Jf][0P2?
Shl209JFUP80TI6A0`1eMGD208R8R0D0S8b<0P1[Jf/203Hf=P<02@T90P0>3Ph203@d=0<0FUYJ0P1k
Ng/208B4Q080TI6A0`2XZ:P20:j^[P80WYjN0`1gMgL20451@@807QhN0`0[:b/206=SH`80Shn?0`2L
W9`20:6QX@80U9BD0P2=SHd308^;R`80NWYj0P1<C4`A000000@0dLfY00030=7=ZA4000000P2EUID2
0=SHf080k^k^0`3`l?040<[:bP<0bl_;0P2_[jl206a/K0<09BDU0P0:2PX2028R8P<0MgMg0P2QXJ42
0<k>cP80b/[:0`3EeMD20<G5a@80bl_;0`2a/K4206e]K@80<30`0`0O7al203Ph>080Jf][0`2OWil2
0:^[Z`80][Jf0P2XZ:P30;6a/@80b<S80P2j^[X308J6QP80Fe]K0P0^;Rh304=3@`80MgMg0P2g]kL3
0<;2`P80];Bd0P2`/;020;Zj^P<0alO70P2`/;0207emOA400000103AcJT000<0dLfY4@00000209FE
U@80f=SH0P3^k^h30?3`l0@0b/[:0`3;bl/20:n_[`80K6a/0`0U9BD200X:2P808R8R0`1gMgL20:6Q
X@80c/k>0P3:b/X30=GEe@80aLG50P3;bl/30;6a/@80KFe]0P0`<30301lO7`80>3Ph0P1[Jf/309nO
W`80Zj^[0P2f][H20:RXZ0<0/K6a0P38b<P20;Zj^P<0QXJ60P1KFe/202h^;P<0@d=30P1gMgL20;Ng
]`<0`/;20P2d];@20;2`/080^[Zj0`37alL20;2`/080OGem4@0000040=7=Z@000`3AcJTA00000080
UIFE0P3Hf=P20>k^kP<0l?3`103:b/X30<_;b`80[jn_0P1/K6`302DU9@802PX:0P0R8R8307MgM`80
XJ6Q0P3>c/h20<[:bP<0eMGE0P35aLD20<_;b`<0/K6a0P1]KFd2030`<0<07alO0P0h>3P206][J`<0
WinO0P2[Zj/20;Jf]P80Z:RX0`2a/K420<S8b080^[Zj0`26QXH205]KF`80;Rh^0`13@d<207MgM`80
]kNg0`32`/820;Bd]080/;2`0P2j^[X30<O7a`80/;2`0P1mOGdA000000@0dLfY00030=7=ZA400000
0P2UYJD20>OWi`80kNg]0`3Hf=P20:VYZ@80^;Rh0`3?cll20<O7a`80UiNG0`0e=CD200d=3@804a<C
0`1=CDd208Z:RP80_[jn0P3@d=030=7Ad@80bl_;0P35aLD3092@T080EeMG0P0R8R8301PH6080BTY:
0P2FUYH30<?3``80^k^k0P2HV9P207IfMP<0JFUY0P2?Shl207emO@<0IfMW0P0^;Rh201`L70<0:2PX
0P1NGUh208Z:RP<0SHf=0P20P80207UiN@80WYjN1@36a/H208n?Sa400000103AcJT000<0dLfY4@00
00020:FUY@80inOW0P3]kNd30=SHf080ZJVY0P2h^;P30<o?c`80alO70P2GUiL303De=@803@d=0P0C
4a<304e=C@80RXZ:0P2n_[h20=3@d0<0dM7A0P3;bl/20<G5a@<0T92@0P1GEeL2028R8P<061PH0P1:
BTX209JFUP<0`l?30P2k^k/209RHV080MWIf0`1YJFT208n?S`80OGem0`1WIfL202h^;P8071`L0`0X
:2P205iNGP80RXZ:0`2=SHd20820P080NGUi0P2NWYh50<K6aP80Shn?4@0000040=7=Z@000`3AcJTA
00000080[Zj^0P3@d=020;6a/@<0Ng]k0P1DE5@2079bLP<0/[:b0P3Cdm<20:b/[0<0BDU90P0=3@d2
000000<061PH0P1>CTh208>3P`80ZZZZ0`2j^[X20:^[Z`80Shn?0`1EEED202d];@804Q8B0`0F5QH2
05QHF080[Zj^0`3<c<`20;Rh^080H61P0P0K6a/300000080410@0P0V9RH301lO7`@000000`0B4Q82
03Lg=`D0?clo0P0F5QH2020P8080FUYJ0`2<S8`20;Fe]@80T92@4@0000040=7=Z@000`3AcJTA0000
0080[Zj^0P3@d=020;6a/@<0Ng]k0P1DE5@2079bLP<0/[:b0P3Cdm<20:b/[0<0BDU90P0=3@d20000
00<061PH0P1>CTh208>3P`80ZZZZ0`2j^[X20:^[Z`80Shn?0`1EEED202d];@804Q8B0`0F5QH205QH
F080[Zj^0`3<c<`20;Rh^080H61P0P0K6a/300000080410@0P0V9RH301lO7`@000000`0B4Q8203Lg
=`D0?clo0P0F5QH2020P8080FUYJ0`2<S8`20;Fe]@80T92@4@0000040=7=Z@000`3AcJTA00000080
YZJV0P31`L4208J6QP<0>CTi0P092@T2038b<P<0U9BD0P3Lg=`20<S8b0<0L71`0P0>3Ph700000080
?3`l0P1dM7@308n?S`80OGem0P15ADD301`L70@000000`0[:b/207UiN@80b<S80`3MgMd20:2PX080
A4A44000000300P820806QXJ0P0Z:RX301@D50@000000P0Z:RX306i^KP80WIfM0P21PH4A000000@0
dLfY00030=7=ZA4000000P2VYZH20<71`@80QXJ60`0i>CT200T92@80<S8b0`2DU9@20=cLg080b<S8
0`1`L70200h>3PL000000P0l?3`207AdM0<0Shn?0P1mOGd204E5A@<071`L1000000302/[:`80NGUi
0P38b<P30=gMg@80X:2P0P14A4@@000000<020P80P0J6QX202XZ:P<051@D1000000202XZ:P<0KVi^
0P2MWId20861PA400000103AcJT000<0dLfY4@0000020:JVYP80`L710P26QXH303Ti>@802@T90P0b
<S8309BDU080g=cL0P38b<P3071`L0803Ph>1`00000203`l?080M7Ad0`2?Shl207emO@80ADE50`0L
71`4000000<0:b/[0P1iNGT20<S8b0<0gMgM0P2PX:0204A4A10000000`0820P201XJ6P80:RXZ0`0D
51@400000080:RXZ0`1^KVh209fMW@80PH614@0000040=7=Z@000`3AcJTA00000080Z:RX0P2l_;`2
071`L0<03Ph>0P000002010@40<0Rh^;0P3Ng]h20=[JfP<0SXj>0P0M7Ad7000000804Q8B0P1@D503
06=SH`80DE5A0P0];Bd5000000801@D50`0o?cl209BDU080k>c/0`3oool20;Rh^080H61P0P0?3`l7
000000<00`<30P00000200D51@<08B4Q0P19BDT206EUI@<0BDU90P0X:2P2024Q8@80>SXj0`1fMWH2
0:>SX`80Ng]k4@0000040=7=Z@000`3AcJTA00000080Z:RX0P2l_;`2071`L0<03Ph>0P000002010@
40<0Rh^;0P3Ng]h20=[JfP<0SXj>0P0M7Ad7000000804Q8B0P1@D50306=SH`80DE5A0P0];Bd50000
00801@D50`0o?cl209BDU080k>c/0`3oool20;Rh^080H61P0P0?3`l7000000<00`<30P00000200D5
1@<08B4Q0P19BDT206EUI@<0BDU90P0X:2P2024Q8@80>SXj0`1fMWH20:>SX`80Ng]k4@0000040=7=
Z@000`3AcJTA00000080^KVi0P32`/8206e]K@D000000P092@T309:BTP80hN7Q0P3Rh^8309FEU@80
<S8b1`00000201PH6080@d=30`1JFUX204Y:BP805aLG1@00000200l?3`<0FUYJ0P2ZZZX20>_[j`<0
o?cl0P3AdM4208F5Q@80EUIF0`1ADE4205mOG`80LW9b0`1FEUH203Hf=P80:RXZ0`1IFET20:>SX`80
b/[:0`2[Zj/208:2PP80J6QX0P1eMGD309FEU@80]KFe0P1jNWXA000000@0dLfY00030=7=ZA400000
0P2i^KT20<;2`P80KFe]1@00000200T92@<0TY:B0P3QhN420>;RhP<0UIFE0P0b<S870000008061PH
0P13@d<305YJFP80BTY:0P0G5aL5000000803`l?0`1JFUX20:ZZZP80jn_[0`3lo?`20=7Ad@80QHF5
0P1FEUH3055AD@80GemO0P1bLW8305IFEP80=SHf0P0Z:RX305UIF@80Xj>S0P3:b/X30:^[Z`80PX:2
0P1XJ6P207EeM@<0UIFE0P2e]KD207YjNQ400000103AcJT000<0dLfY4@0000020;fm_@80b<S80P1d
M7@300h>3P8000000P071`L307AdM080i>CT0P3Kfm/309fMW@80B4Q80P092@T300L71`804Q8B0P0j
>SX2065QH@<0IfMW0P11@D42018B4PD000000P0V9RH305mOG`80Shn?0P33`l<30<W9b@80/;2`0P24
Q8@207YjNP<0TY:B0P2m_Kd20<K6aP<0Xj>S0P1^KVh2051@D0<0HV9R0P2^[Zh20=_Kf`<0eMGE0P2]
[Jd208F5Q@80TY:B0`2/[:`20:BTY080RHV94@0000040=7=Z@000`3AcJTA00000080_Kfm0P38b<P2
07AdM0<03Ph>0P00000200L71`<0M7Ad0P3Ti>@20=_Kf`<0WIfM0P18B4P200T92@<01`L70P0B4Q82
03Xj>P80HF5Q0`1WIfL20451@@804Q8B1@00000202HV9P<0GemO0P2?Shl20<?3``<0bLW90P2`/;02
08B4Q080NWYj0`2BTY820;fm_@80a/K60`2SXj<206i^KP80D51@0`1RHV820:j^[P80fm_K0`3EeMD2
0:f][@80QHF50P2BTY830:b/[080Y:BT0P29RHTA000000@0dLfY00030=7=ZA4000000P2_[jl20<30
`080MWIf1`00000306=SH`80aLG50P32`/8308J6QP80@T920P0W9bL303dm?@80GemO1028R8P308f=
S@80De=C0P0H61P3000000801`L70P0U9BD303lo?`80H61P0P1/K6`305mOG`80C4a<0P0j>SX204m?
C`<0S8b<0P3MgMd20?Win@<0dM7A0P1gMgL203lo?`<0CDe=0P1iNGT209bLW0<0VIVI0P1hN7P205aL
G080KFe]0`2JVYX209^KV`80Ogmo4@0000040=7=Z@000`3AcJTA00000080[jn_0P30`<0207IfMPL0
00000`1SHf<20<G5a@80`/;20`26QXH20492@P809bLW0`0m?Cd205mOG`@0R8R80`2=SHd205=CD`80
61PH0`00000200L71`809BDU0`0o?cl2061PH080K6a/0`1OGel204a<C080>SXj0P1?Cdl308b<S080
gMgM0P3inOT30=7Ad@80MgMg0P0o?cl304e=C@80NGUi0P2LW9`309VIV@80N7Qh0P1LG5`206e]K@<0
VYZJ0P2KVi/207moOa400000103AcJT000<0dLfY4@0000020:n_[`80`<300P1fMWH7000000<0Hf=S
0P35aLD20<;2`P<0QXJ60P12@T8202LW9`<0?Cdm0P1OGel408R8R0<0SHf=0P1CDe<201PH60<00000
0P071`L202DU9@<0?clo0P1PH60206a/K0<0GemO0P1<C4`203Xj>P80Cdm?0`2<S8`20=gMg@80nOWi
0`3AdM4207MgM`80?clo0`1=CDd207UiN@80W9bL0`2IVIT207QhN080G5aL0P1]KFd309ZJVP80Vi^K
0P1oOglA000000@0dLfY00030=7=ZA4000000P2TY:@20;Fe]@80Lg=c0`061PH4000000<0E5AD0P2S
Xj<20:2PX0<0HF5Q0P0i>CT204I6AP<0IVIV0P2LW9`20;jn_P80][Jf0`2@T90205QHF0805ADE1@00
000200X:2P<05aLG0P0P820200T92@L000000P061PH306=SH`80b/[:0P3UiND30<g=c@80HF5Q0P0F
5QH300@41080;Bd]0P14A4@303De=@806ATI0P092@T202/[:`<0K6a/0P2ATI42079bLQ400000103A
cJT000<0dLfY4@0000020:BTY080]KFe0P1cLg<300H61P@000000`1DE5@20:>SX`80X:2P0`1QHF42
03Ti>@80ATI60`1VIVH209bLW080_[jn0P2f][H3092@T080F5QH0P0E5AD5000000802PX:0`0G5aL2
020P80802@T91`00000200H61P<0Hf=S0P3:b/X20>GUi@<0cLg=0P1QHF4201HF5P<010@40P0];Bd2
04A4A0<0=CDe0P0I6AT200T92@80:b/[0`1/K6`2096AT@80LW9b4@0000040=7=Z@000`3AcJTA0000
0080WinO0P2o_kl208V9R@<0>c/k0P092@T2020P80<0KFe]0P2MWId207inOP<0@d=30P0R8R82038b
<P<0IfMW0P2_[jl20=_Kf`80emOG0`2RXZ8206=SH`805aLG1`00000300820P800`<32`00000304];
B`80/[:b0P3Lg=`30;:b/P80Bd];0P020P85000000804Q8B1`00000201<C4`<0IfMW0P2:RXX207]k
Na400000103AcJT000<0dLfY4@00000209nOW`80_kno0P29RHT303/k>`802@T90P0P820306e]K@80
WIfM0P1nOWh304=3@`808R8R0P0b<S8306MWI`80[jn_0P3Kfm/20=OGe`<0XZ:R0P1SHf<201LG5`L0
00000`020P8200<30`/000000`1;Bd/20;:b/P80g=cL0`2b/[8204];B`800P821@000002018B4PL0
00000P0C4a<306MWI`80RXZ:0P1kNg/A000000@0dLfY00030=7=ZA4000000P2JVYX20=3@d080^;Rh
0`24Q8@205YJFP80MGEe0`2NWYh20;Rh^080U9BD0`0b<S8200L71`804A4A0`1=CDd208j>SP80_[jn
0P38b<P30:^[Z`80KVi^0P0I6AT7000000<0410@0P0C4a<201hN7P<04Q8B1000000202<S8`<0KFe]
0P3;bl/20>3Ph0<0[:b/0P1BDU85000000802PX:0P0/;2`302TY:@8071`L0P0K6a/204a<C0<0R8R8
0P2[Zj/208R8R1400000103AcJT000<0dLfY4@00000209ZJVP80d=3@0P2h^;P308B4Q080FUYJ0P1e
MGD309jNWP80^;Rh0P2DU9@3038b<P801`L70P0A4A4304e=C@80SXj>0P2n_[h20<S8b0<0Zj^[0P1^
KVh201TI6@L000000`0@410201<C4`807QhN0`0B4Q84000000808b<S0`1]KFd20<_;b`80h>3P0`2/
[:`2059BDPD000000P0:2PX202`/;0<0:BTY0P0L71`201/K6`80C4a<0`28R8P20:^[Z`80R8R84@00
00040=7=Z@000`3AcJTA00000080VIVI0P3GemL20>;RhP<0cLg=0P2j^[X20<C4a0<0e=CD0P3?cll2
08R8R0<0:BTY10000003014A4@80FEUI0P1lO7`209fMW@<0VIVI0P1XJ6P202LW9`D000000P020P83
01TI6@80Bd];0P1DE5@306][J`80LW9b0P1VIVH207alO0<0/[:b0P3EeMD20=CDe0<0VYZJ0P14A4@2
00<30`<05QHF0P1<C4`20820P0<0VIVI0P1iNGT207moO`80RXZ:0`2j^[X20<71`@80S8b<4@000004
0=7=Z@000`3AcJTA00000080VIVI0P3GemL20>;RhP<0cLg=0P2j^[X20<C4a0<0e=CD0P3?cll208R8
R0<0:BTY10000003014A4@80FEUI0P1lO7`209fMW@<0VIVI0P1XJ6P202LW9`D000000P020P8301TI
6@80Bd];0P1DE5@306][J`80LW9b0P1VIVH207alO0<0/[:b0P3EeMD20=CDe0<0VYZJ0P14A4@200<3
0`<05QHF0P1<C4`20820P0<0VIVI0P1iNGT207moO`80RXZ:0`2j^[X20<71`@80S8b<4@0000040=7=
Z@000`3AcJTA00000080VIVI0P3GemL20>;RhP<0cLg=0P2j^[X20<C4a0<0e=CD0P3?cll208R8R0<0
:BTY10000003014A4@80FEUI0P1lO7`209fMW@<0VIVI0P1XJ6P202LW9`D000000P020P8301TI6@80
Bd];0P1DE5@306][J`80LW9b0P1VIVH207alO0<0/[:b0P3EeMD20=CDe0<0VYZJ0P14A4@200<30`<0
5QHF0P1<C4`20820P0<0VIVI0P1iNGT207moO`80RXZ:0`2j^[X20<71`@80S8b<4@0000040=7=Z@00
0`3AcJTA00000080SHf=0P3=cLd20=kNgP<0hN7Q0P3MgMd20=WIf@<0emOG0P34a<@208B4Q0<0<c<c
1`00000201<C4`80Bd];0P1WIfL307EeM@80IVIV0P0c<c<300L71`803`l?0P061PH302<S8`80EEEE
0P27QhL30;Zj^P80];Bd0P2n_[h20;Rh^0<0b<S80P3GemL20:ZZZP<0MgMg0P0g=cL201<C4`<0ATI6
0P1oOgl20<[:bP<0d];B0P3<c<`20:n_[`80[Jf]0`2m_Kd20:NWY`80MWIf4@0000040=7=Z@000`3A
cJTA00000080SHf=0P3=cLd20=kNgP<0hN7Q0P3MgMd20=WIf@<0emOG0P34a<@208B4Q0<0<c<c1`00
000201<C4`80Bd];0P1WIfL307EeM@80IVIV0P0c<c<300L71`803`l?0P061PH302<S8`80EEEE0P27
QhL30;Zj^P80];Bd0P2n_[h20;Rh^0<0b<S80P3GemL20:ZZZP<0MgMg0P0g=cL201<C4`<0ATI60P1o
Ogl20<[:bP<0d];B0P3<c<`20:n_[`80[Jf]0`2m_Kd20:NWY`80MWIf4@0000040=7=Z@000`3AcJTA
00000080CDe=0P2?Shl20:BTY0<0^KVi0P2`/;020;Jf]P<0ZZZZ0P2?Shl205aLG0<09RHV2@000002
00l?3`80=SHf0`14A4@204U9B@8092@T0`020P820000008010@40`0L71`205ADE080QhN70`2/[:`2
0<71`@80][Jf0P2MWId309jNWP80SXj>0P1aLG4303De=@@04A4A0`0h>3P207emO@80][Jf0`34a<@2
0;^k^`80Vi^K0P2BTY8308b<S080MgMg0P1;Bd/A000000@0dLfY00030=7=ZA4000000P1=CDd208n?
S`80Y:BT0`2i^KT20;2`/080][Jf0`2ZZZX208n?S`80G5aL0`0V9RH9000000803`l?0P0f=SH304A4
A080BDU90P0T92@300820P8000000P0410@301`L7080E5AD0P27QhL30:b/[080`L710P2f][H209fM
W@<0WYjN0P2>SXh2075aL@<0=CDe100A4A4303Ph>080OGem0P2f][H30<C4a080^k^k0P2KVi/209:B
TP<0S8b<0P1gMgL204];Ba400000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
T03AcJT00900dLfY0000\
\>"],
  ImageRangeCache->{{{180, 323}, {347.25, 277.5}} -> {-80.2954, 120.421, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000005390ADB6A091855C2100001A5D86908C6B7D7E7C5821000134658D959C
ACA88E60250010518699A2948C89764600000000000000
000000000000007DC4DCE0B4B2B3954F07000F71A0D3CDD8C1C2A15311032668ABBFCEB9
BBCEB87D4D1B336CB6C4B6B0BAC5AB7500000000000000
000000000000008ED2D9C58F9EB5AE7F1B00084E94CEE2E0D2C47F3900002D8DCBCCAC86
749B846C2C161F58888C7E759CC4C28700000000000000
000000000000009DC0A0673B589BBF9834010021629FCCDCC197460D00002F9ACBC66F26
0619302900000D3036370B185689B58B00000000000000
000000000000009CBC8231002084CDB8600400000B5FA2C0A252120000004AADD7A85100
000000000000000C1C0800002A72A17F00000000000000
00000000000000A5C57C18000D86D4CA7D0E0000003481987B430000000663D2FDC4721F
0000010100000E3659432A2A4684B07D00000000000000
00000000000000BDD48619001396D8CD7A19000000326A88722B000000287FD6FFE7A06E
6165714A1F0C3C90C4B0938291AFCB8000000000000000
00000000000000C0DC922F001676DABF782300000D4278855B1E000004396FB8D5CEA596
A0BFBA8A49233692D3E0C7A6B8CEBA9300000000000000
00000000000000AACC8D1000005FB39E5713012451848B9B5D1A00000F274F6B706A5862
90D6E4AE450619538B9D8C798EBAB08800000000000000
0000000000000095B2770A00004588752D08214C8BB2AE8C550E0000000C1B0E0000000D
5CB8C5A52A0000022C2E20193F82A17700000000000000
0000000000000087AF7D2F000C557C5110001252A2D2CF995B0C00000000050000000000
3C9ABE8B19000000000000001C74937D00000000000000
000000000000007DB7A16D3F5B8299700800004389BCC7A96A0F0000000E152A26030122
60BACA8F2C000000141B171B5290B18800000000000000
000000000000007DBCC8B5A0ABBAB5690A0000116285A8A46E260000000E48577883717E
ADCBC78829000032709274808DC0C58A00000000000000
0000000000000077B8C8CCC8C3C1AE6F210000032764818E7A3C0408000E457FBEBBC8BC
C9D8A56F2800316BC0CACAADADC0A87400000000000000
000000000000003C8094ADA1A89A7F4D1D010000102F59656432020000003A74A3C2BBA0
A39376340A04276EA9BAB596918E784B00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000205=CD`80T92@
0P2][Jd30;Jf]P80X:2P0P2ATI4308F5Q@80G5aL0P0Q8B45000000806QXJ0`1MGEd208J6QP80T92@
0P2<S8`306][J`80OGem0P1nOWh307alO080F5QH0P0Q8B43000000800@410P0d=3@306EUI@80SHf=
0P2EUID209bLW0<0[:b/0P2XZ:P208j>SP<0H61P0P0U9BD2000000<0410@0P1ADE4208J6QP<0VIVI
0P2RXZ8209BDU080S8b<0`29RHT207IfMP80ATI64@0000040=7=Z@000`3AcJTA00000080De=C0P2@
T9020:f][@<0][Jf0P2PX:02096AT@<0QHF50P1LG5`2024Q8@D000000P0J6QX305eMG@80QXJ60P2@
T90208b<S0<0Jf][0P1mOGd207inOP<0O7al0P1HF5P2024Q8@<000000P010@4203@d=0<0IFEU0P2=
SHd209FEU@80W9bL0`2/[:`20:RXZ080SXj>0`1PH60202DU9@8000000`0@4102055AD@80QXJ60`2I
VIT20::RXP80U9BD0P2<S8`308V9R@80MWIf0P16ATHA000000@0dLfY00030=7=ZA4000000P1mOGd2
0<C4a080g=cL0`3Ph>020;Bd]080/[:b0`2c/k<209FEU@80Cdm?0`071`L2000000803`l?0`1aLG42
0:2PX080dm?C0P3=cLd30=SHf080`L710P32`/830:6QX@80De=C0P0A4A4300<30`809RHV0P1XJ6P3
0:^[Z`80_kno0P3>c/h20;Vi^@<0^k^k0P3>c/h20;Rh^0<0OGem0P1=CDd201/K6`<0<c<c0P1/K6`2
0;Jf]P<0a<C40P2f][H20;2`/080^[Zj0`35aLD20:^[Z`80MGEe4@0000040=7=Z@000`3AcJTA0000
0080OGem0P34a<@20=cLg0<0h>3P0P2d];@20;:b/P<0/k>c0P2EUID204m?C`<01`L70P00000200l?
3`<0LG5a0P2PX:020=?Cd`80cLg=0`3Hf=P20<71`@80`/;20`2QXJ4205=CD`804A4A0`030`<202HV
9P80J6QX0`2[Zj/20;no_`80c/k>0P2i^KT30;^k^`80c/k>0P2h^;P307emO@80CDe=0P0K6a/303<c
<`80K6a/0P2f][H30<C4a080][Jf0P2`/;020;Zj^P<0aLG50P2[Zj/207EeMA400000103AcJT000<0
dLfY4@00000207emO@80a<C40P3Lg=`30>3Ph080];Bd0P2b/[830;>c/`80UIFE0P1?Cdl300L71`80
00000P0?3`l3075aL@80X:2P0P3Cdm<20<g=c@<0f=SH0P31`L420<;2`P<0XJ6Q0P1CDe<2014A4@<0
0`<30P0V9RH206QXJ0<0Zj^[0P2o_kl20<k>cP80^KVi0`2k^k/20<k>cP80^;Rh0`1mOGd204e=C@80
6a/K0`0c<c<206a/K080][Jf0`34a<@20;Jf]P80/;2`0P2j^[X30<G5a@80Zj^[0P1eMGDA000000@0
dLfY00030=7=ZA4000000P2>SXh20=;BdP80fMWI0`35aLD208n?S`80WYjN0`2e]KD20:j^[P80Ogmo
0`0K6a/20000008020P80`1>CTh209BDU080c/k>0P3Rh^830>3Ph080d];B0P34a<@307moO`80>CTi
1@00000202d];@80SHf=0`3;bl/20<c<c080[:b/0P26QXH307AdM080Vi^K0P24Q8@306a/K080;2`/
0P0F5QH301lO7`80F5QH0P28R8P308b<S080OWin0P1eMGD209bLW0<0a<C40P32`/8208N7Qa400000
103AcJT000<0dLfY4@00000208j>SP80d];B0P3IfMT30<G5a@80Shn?0P2NWYh30;Fe]@80[Zj^0P1o
Ogl301/K6`8000000P0820P304i>CP80U9BD0P3>c/h20>;RhP<0h>3P0P3Bd]820<C4a0<0Ogmo0P0i
>CT500000080;Bd]0P2=SHd30<_;b`80c<c<0P2/[:`208J6QP<0M7Ad0P2KVi/208B4Q0<0K6a/0P0/
;2`201HF5P<07alO0P1HF5P208R8R0<0S8b<0P1nOWh207EeM@80W9bL0`34a<@20<;2`P80QhN74@00
00040=7=Z@000`3AcJTA00000080WIfM0P30`<020:2PX0<0IfMW0P0k>c/205QHF0<0Vi^K0P2o_kl2
09RHV0<0=3@d0P010@42000000<08B4Q0P1RHV8209nOW`80c<c<0`3Lg=`20<71`@80UiNG0`16ATH2
00d=3@D000000P0_;bl209ZJVP<0bl_;0P36a/H206m_K`809RHV0`061PH201TI6@80<30`0`0Y:BT4
000000<03@d=0P0`<30203Hf=P<0=cLg0P0;2`/201PH6080EUIF0`29RHT20;Fe]@80Rh^;4@000004
0=7=Z@000`3AcJTA00000080WIfM0P30`<020:2PX0<0IfMW0P0k>c/205QHF0<0Vi^K0P2o_kl209RH
V0<0=3@d0P010@42000000<08B4Q0P1RHV8209nOW`80c<c<0`3Lg=`20<71`@80UiNG0`16ATH200d=
3@D000000P0_;bl209ZJVP<0bl_;0P36a/H206m_K`809RHV0`061PH201TI6@80<30`0`0Y:BT40000
00<03@d=0P0`<30203Hf=P<0=cLg0P0;2`/201PH6080EUIF0`29RHT20;Fe]@80Rh^;4@0000040=7=
Z@000`3AcJTA00000080W9bL0P2l_;`208:2PP<0<C4a0P000002020P80<0Q8B40P3=cLd20;Rh^0<0
H61P0P0410@5000000802`/;0P1OGel20::RXP<0`<300P2RXZ82059BDP<04Q8B1`00000204Y:BP80
[Jf]0`3GemL20:RXZ080DE5A4`00000200`<308071`L0`0820P400000080:RXZ0`1bLW820:6QX@80
Ogmo4@0000040=7=Z@000`3AcJTA00000080W9bL0P2l_;`208:2PP<0<C4a0P000002020P80<0Q8B4
0P3=cLd20;Rh^0<0H61P0P0410@5000000802`/;0P1OGel20::RXP<0`<300P2RXZ82059BDP<04Q8B
1`00000204Y:BP80[Jf]0`3GemL20:RXZ080DE5A4`00000200`<308071`L0`0820P400000080:RXZ
0`1bLW820:6QX@80Ogmo4@0000040=7=Z@000`3AcJTA00000080W9bL0P2l_;`208:2PP<0<C4a0P00
0002020P80<0Q8B40P3=cLd20;Rh^0<0H61P0P0410@5000000802`/;0P1OGel20::RXP<0`<300P2R
XZ82059BDP<04Q8B1`00000204Y:BP80[Jf]0`3GemL20:RXZ080DE5A4`00000200`<308071`L0`08
20P400000080:RXZ0`1bLW820:6QX@80Ogmo4@0000040=7=Z@000`3AcJTA00000080YJFU0P35aLD2
07alO0<061PH0P00000200d=3@<0QXJ60P3De=@20<[:bP<0OGem0P0>3Ph700000080=3@d0P21PH43
09RHV080Ng]k0P13@d<7000000<01PH60P1SHf<20=;BdP<0oOgm0P34a<@2079bLP807alO1@000005
00410@@000000`0>3Ph203Hf=P80FEUI0`13@d<402XZ:P80ATI60`24Q8@20;2`/080OGem4@000004
0=7=Z@000`3AcJTA00000080YJFU0P35aLD207alO0<061PH0P00000200d=3@<0QXJ60P3De=@20<[:
bP<0OGem0P0>3Ph700000080=3@d0P21PH4309RHV080Ng]k0P13@d<7000000<01PH60P1SHf<20=;B
dP<0oOgm0P34a<@2079bLP807alO1@00000500410@@000000`0>3Ph203Hf=P80FEUI0`13@d<402XZ
:P80ATI60`24Q8@20;2`/080OGem4@0000040=7=Z@000`3AcJTA00000080_Kfm0P3De=@208J6QP<0
6ATI0P00000201<C4`<0UYJF0P3Hf=P20<g=c@<0NWYj0P0I6AT700000080<S8b0P1ZJVX308R8R080
LW9b0P0[:b/7000000<0:2PX0P1oOgl20=KFeP<0oooo0P3WinL20:2PX080KVi^0`1QHF4206EUI@80
LG5a0`1:BTX201lO7`8030`<0`0l?3`2092@T080a<C40`2`/;0209>CT`80PX:20P2ATI430:n_[`80
bl_;0P20P80A000000@0dLfY00030=7=ZA4000000P2m_Kd20=CDe080QXJ60`0I6AT2000000804a<C
0`2FUYH20=SHf080cLg=0`1jNWX201TI6@L000000P0b<S8206YZJP<0R8R80P1bLW8202/[:`L00000
0`0X:2P207moO`80e]KF0`3oool20>OWi`80X:2P0P1^KVh3065QH@80IFEU0P1aLG4304Y:BP807alO
0P0<30`303`l?080T92@0P34a<@30;2`/080Ti>C0P22PX82096AT@<0[jn_0P3;bl/20820P1400000
103AcJT000<0dLfY4@0000020<30`080g=cL0P2BTY8302l_;`8000000P0F5QH307IfMP80f][J0P2o
_kl307QhN0808b<S1@00000200d=3@80@T920P1hN7P308F5Q@80Fe]K0P0N7Qh50000008010@40`0i
>CT206m_K`80^;Rh0`3EeMD20<k>cP80YJFU0P2FUYH30:2PX080_kno0P2j^[X308Z:RP80BDU90P0S
8b<303Hf=P80TY:B0P3Cdm<30>3Ph080alO70P2VYZH20;Rh^0<0c/k>0P2j^[X209>CTa400000103A
cJT000<0dLfY4@0000020<30`080g=cL0P2BTY8302l_;`8000000P0F5QH307IfMP80f][J0P2o_kl3
07QhN0808b<S1@00000200d=3@80@T920P1hN7P308F5Q@80Fe]K0P0N7Qh50000008010@40`0i>CT2
06m_K`80^;Rh0`3EeMD20<k>cP80YJFU0P2FUYH30:2PX080_kno0P2j^[X308Z:RP80BDU90P0S8b<3
03Hf=P80TY:B0P3Cdm<30>3Ph080alO70P2VYZH20;Rh^0<0c/k>0P2j^[X209>CTa400000103AcJT0
00<0dLfY4@0000020:ZZZP80c<c<0P2=SHd3010@40@000000`1OGel20;>c/`80WYjN0`1GEeL201<C
4`800@410`0T92@2055AD@80Q8B40P2;Rh/309^KV`80GEeM0P0J6QX5000000803`l?0`0W9bL204m?
C`80Jf][0`1`L70206YZJP80F5QH0P1RHV83092@T080e]KF0P3Ti>@30:j^[P80ADE50P061PH301TI
6@80De=C0P2;Rh/309fMW@80S8b<0P1iNGT208j>SP<0^[Zj0P2`/;0208R8R1400000103AcJT000<0
dLfY4@0000020:ZZZP80c<c<0P2=SHd3010@40@000000`1OGel20;>c/`80WYjN0`1GEeL201<C4`80
0@410`0T92@2055AD@80Q8B40P2;Rh/309^KV`80GEeM0P0J6QX5000000803`l?0`0W9bL204m?C`80
Jf][0`1`L70206YZJP80F5QH0P1RHV83092@T080e]KF0P3Ti>@30:j^[P80ADE50P061PH301TI6@80
De=C0P2;Rh/309fMW@80S8b<0P1iNGT208j>SP<0^[Zj0P2`/;0208R8R1400000103AcJT000<0dLfY
4@0000020:ZZZP80c<c<0P2=SHd3010@40@000000`1OGel20;>c/`80WYjN0`1GEeL201<C4`800@41
0`0T92@2055AD@80Q8B40P2;Rh/309^KV`80GEeM0P0J6QX5000000803`l?0`0W9bL204m?C`80Jf][
0`1`L70206YZJP80F5QH0P1RHV83092@T080e]KF0P3Ti>@30:j^[P80ADE50P061PH301TI6@80De=C
0P2;Rh/309fMW@80S8b<0P1iNGT208j>SP<0^[Zj0P2`/;0208R8R1400000103AcJT000<0dLfY4@00
000209FEU@80/[:b0P1gMgL300X:2P@000000`15ADD208R8R080MGEe0`0];Bd200P820808B4Q0`1<
C4`208^;R`80/[:b0P2^[Zh308b<S080EEEE0P0>3Ph7000000<030`<0P0K6a/200h>3PL000000P0=
3@d305aLG080^;Rh0P35aLD30:FUY@80:RXZ1@00000200820P80;2`/0`0^;Rh2020P80806ATI0P0o
?cl308:2PP80XJ6Q0P1gMgLA000000@0dLfY00030=7=ZA4000000P2EUID20;:b/P80MgMg0`0:2PX4
000000<0ADE50P28R8P207EeM@<0;Bd]0P0820P2024Q8@<0C4a<0P2;Rh/20;:b/P80[Zj^0`2<S8`2
05EEE@803Ph>1`00000300`<30806a/K0P0>3Ph7000000803@d=0`1LG5`20;Rh^080aLG50`2UYJD2
02XZ:PD000000P020P8202`/;0<0;Rh^0P0P820201TI6@80?clo0`22PX820:6QX@80MgMg4@000004
0=7=Z@000`3AcJTA00000080QhN70P2_[jl207emO@<0;bl_0P00000200`<30<0EEEE0P1lO7`2055A
D@<0410@0P000002018B4P<0DU9B0P2RXZ820=;BdP80clo?0`2IVIT205]KF`8030`<2P00000200D5
1@/000000`0l?3`209ZJVP80_[jn0`2;Rh/201TI6A0000000P0L71`307AdM080Ti>C0P1mOGdA0000
00@0dLfY00030=7=ZA4000000P27QhL20:n_[`80OGem0`0_;bl20000008030`<0`1EEED207alO080
DE5A0`0@4102000000804Q8B0`1BDU820::RXP80d];B0P3?cll309VIV@80Fe]K0P0<30`:00000080
1@D52`00000303`l?080VYZJ0P2n_[h308^;R`806ATI4000000201`L70<0M7Ad0P2CTi<207emOA40
0000103AcJT000<0dLfY4@00000207emO@80]kNg0P2QXJ4306e]K@80?clo0P1KFe/308:2PP80VIVI
0P1`L70300P820@000000`13@d<208V9R@80_;bl0P37alL30:VYZ@80JVYZ0P0?3`l7000000<03Ph>
0P0E5AD202XZ:P<09RHV0P030`<200410@808R8R0`1PH6020;Zj^P80b/[:0`2?Shl202`/;0L00000
0P0D51@301/K6`805aLG0P0K6a/2059BDP<0T92@0P2a/K4208R8R1400000103AcJT000<0dLfY4@00
000207emO@80]kNg0P2QXJ4306e]K@80?clo0P1KFe/308:2PP80VIVI0P1`L70300P820@000000`13
@d<208V9R@80_;bl0P37alL30:VYZ@80JVYZ0P0?3`l7000000<03Ph>0P0E5AD202XZ:P<09RHV0P03
0`<200410@808R8R0`1PH6020;Zj^P80b/[:0`2?Shl202`/;0L000000P0D51@301/K6`805aLG0P0K
6a/2059BDP<0T92@0P2a/K4208R8R1400000103AcJT000<0dLfY4@00000207emO@80_;bl0P38b<P3
0;Fe]@80X:2P0P2[Zj/30;Zj^P80]KFe0P1YJFT300X:2P@000000`0A4A42069RHP80QHF50P2XZ:P3
0:BTY080KVi^0P0V9RH7000000<03Ph>0P18B4P205MGE`<0N7Qh0P23Ph<2075aL@80OWin0`2][Jd2
0<_;b`80alO70`28R8P202TY:@D000000P0b<S82071`L0<0TY:B0P1dM7@20820P080SHf=0`30`<02
0<G5a@80RXZ:4@0000040=7=Z@000`3AcJTA00000080OGem0P2l_;`20<S8b0<0]KFe0P2PX:020:^[
Z`<0^[Zj0P2e]KD206UYJ@<02PX:10000003014A4@80HV9R0P25QHD20:RXZ0<0Y:BT0P1^KVh202HV
9PL000000`0>3Ph204Q8B080EeMG0`1hN7P208>3P`80LG5a0P1nOWh30:f][@80bl_;0P37alL308R8
R080:BTY1@000002038b<P80L71`0`2BTY8207AdM080P8200P2=SHd30<30`080aLG50P2:RXXA0000
00@0dLfY00030=7=ZA4000000P1mOGd20;bl_080b<S80`2e]KD20:2PX080Zj^[0`2j^[X20;Fe]@80
JFUY0`0:2PX4000000<04A4A0P1RHV8208F5Q@80Z:RX0`2TY:@206i^KP809RHV1`00000300h>3P80
B4Q80P1GEeL307QhN080Ph>30P1aLG4207inOP<0[Jf]0P3;bl/20<O7a`<0R8R80P0Y:BT500000080
<S8b0P1`L70309:BTP80M7Ad0P20P80208f=S@<0`<300P35aLD208Z:RQ400000103AcJT000<0dLfY
4@00000207MgM`80^;Rh0P38b<P30<c<c080b<S80P33`l<30<71`@80[Zj^0P1_Kfl3024Q8@@00000
0`030`<202LW9`80I6AT0P21PH4308j>SP80NWYj0P0l?3`300@4108020P80P00000300h>3P80ADE5
0P1oOgl30;jn_P80^k^k0P38b<P20;bl_0<0bLW90P3Hf=P20:FUY@<0Kfm_0P0X:2P2000000<0<C4a
0P1[Jf/20<30`0D0b/[:102][Jd30<30`080Z:RX0P1dM7@A000000@0dLfY00030=7=ZA4000000P1g
MgL20;Rh^080b<S80`3<c<`20<S8b080`l?30`31`L420:j^[P80Kfm_0`0Q8B44000000<00`<30P0W
9bL206ATI080PH610`2>SXh207YjNP80?3`l0`0410@200P8208000000`0>3Ph204E5A@80Ogmo0`2n
_[h20;^k^`80b<S80P2l_;`30<W9b@80f=SH0P2UYJD306m_K`80:2PX0P000003034a<@80Jf][0P30
`<050<[:bP@0[Jf]0`30`<020:RXZ080M7Ad4@0000040=7=Z@000`3AcJTA00000080?3`l0P20P802
09BDU0<0[Jf]0P2QXJ420:RXZ0<0VYZJ0P1oOgl204e=C@<07AdM0P010@4500000080410@0P0_;bl2
05UIF@<0IFEU0P1TI6@2038b<P<00P821`00000203Xj>P80M7Ad0`2SXj<20<;2`P80^k^k0P2PX:03
0:>SX`80Ti>C0P1fMWH303@d=0802PX:0P0410@302LW9`80KVi^0P2YZJT30;Zj^P80]KFe0P2FUYH2
096AT@<0SXj>0P1hN7P204];Ba400000103AcJT000<0dLfY4@00000203`l?080P8200P2DU9@30:f]
[@80XJ6Q0P2XZ:P309ZJVP80Ogmo0P1=CDd301dM7@800@411@000002010@4080;bl_0P1IFET306EU
I@80I6AT0P0b<S8300820PL000000P0j>SX207AdM0<0Xj>S0P32`/820;^k^`80X:2P0`2SXj<209>C
T`80MWIf0`0d=3@200X:2P8010@40`0W9bL206i^KP80ZJVY0`2j^[X20;Fe]@80UYJF0P2ATI4308j>
SP80N7Qh0P1;Bd/A000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT00900dLfY
002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {436, 366.25}} -> {-80.2954, 159.166, \
0.436562, 0.436562}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000005697B4C1ABA3A17E4304083579A0A49B71888C936F3100023466919DAE
CDD3BF8E471219588B9AA3959093885A00000000000000
0000000000000084D2EFF7C8CCD4B96E2005248EB5E3D1DBC4D3BD6C220A2562A5B9D2C7
DAFFF0AD7129386EBCC7B3AEBBCFB88400000000000000
0000000000000095E6F5E5A9BCD6CD992807175F9FCFD7D0CBD096540C00237EB9BAA088
88CAB79C48211C528383736897CACE9100000000000000
00000000000000A8D6BD875874B8D8A8380500275F8FB4C6B7A15F2D00001F82AEAC561B
0D375D5319070926252500004A85BF9600000000000000
00000000000000A3D4A4581D3D9EE2C262030000004484AB9C5F330600003D94B9883900
00001911000000000B0000001A6EAB8B00000000000000
00000000000000A7DCA041002DA2E4CF7F0E0000001564867F62280000185DC2EBB16A22
0717211F08000D32563C1F1E3B83BC8A00000000000000
00000000000000BAE6A73F0032B3E6D07A1E000000164D7C8153301A184785CFF9E9AB83
7F8693622C0F429ED9BF9A818DAFD68900000000000000
00000000000000B6E5A84E002E86E8C27F34010705285C7968483B31446079B8D7DCBAB1
BCDBD1994F2539A4ECF7D4A3B1C8B79A00000000000000
0000000000000096C89416000063BAA2612A214056736C8D653E2E3E4C49596A7073666E
99E1EEB543031E629DAA8A6776A7A28600000000000000
000000000000007FA46C0000003784793A274F7099A48E715023112129201B0100000001
4EAFBFA82800001037280700105D8B6C00000000000000
0000000000000075A1691200003C725120183F77B1C5B1794D12000E0F01000000000000
1D85B78F2100000000000000004B7A7300000000000000
0000000000000072AF8F4E1334659179180320618FAAA78B5A0A00000004001718000001
3FABCC9F4600000024130000246FA18100000000000000
000000000000007CBCC09F7F89A3AF701A00061D5D6886895E1F0000000034416B795B62
96C0CF9F47001A568A9A61616BAEBF8800000000000000
0000000000000082C5C9C1B2A8AEAA773200000212445E767138010600002D6EB7AFB9A4
B5D4AB85451A588DDDD2C29797B6A47300000000000000
0000000000000048929BAB91978C7A51260B00000008384E5C2D000000002C6A9BB9A885
8D88783D1A173B80B5B8A9828084754800000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000205IFEP80UiNG
0P2d];@30<71`@80Zj^[0P2SXj<30:6QX@80OWin0P13@d<300@4108020P80P0e=CD307UiN@80X:2P
0P2TY:@209^KV`<0LG5a0P28R8P208b<S0<0Ti>C0P1_Kfl2034a<@<000000P020P8203@d=0<0IVIV
0P2ATI4209fMW@80[Zj^0`3=cLd20=?Cd`80_kno0`2>SXh204M7A`804Q8B0`0I6AT205QHF080Rh^;
0`2JVYX20:>SX`80UIFE0P2@T90309>CT`80R8R80P1JFUXA000000@0dLfY00030=7=ZA4000000P1F
EUH209NGU`80];Bd0`31`L420:^[Z`80Xj>S0`2QXJ4207inOP80@d=30`0410@200P82080=CDe0`1i
NGT20:2PX080Y:BT0P2KVi/3075aL@80R8R80P2<S8`309>CT`80Kfm_0P0a<C43000000800P820P0d
=3@306IVIP80TI6A0P2MWId20:j^[P<0cLg=0P3Cdm<20;no_`<0SXj>0P17AdL2018B4P<06ATI0P1H
F5P208^;R`<0VYZJ0P2SXj<209FEU@80T92@0`2CTi<208R8R080FUYJ4@0000040=7=Z@000`3AcJTA
00000080Q8B40P3Bd]820>o_k`<0moOg0P38b<P20<c<c0<0e=CD0P2i^KT206i^KP<0820P0P051@D2
02@T90<0SXj>0P2e]KD20>?Sh`80dM7A0`3Kfm/20<C4a080dm?C0`2m_Kd206a/K0808R8R0`0:2PX2
02DU9@80HV9R0`2UYJD20;Vi^@80d];B0P37alL30=[JfP80oooo0P3`l?030:f][@80LG5a0P0Y:BT3
03Ph>080KVi^0P2l_;`30<O7a`80/k>c0P2^[Zh20;^k^`<0clo?0P2h^;P208B4Q1400000103AcJT0
00<0dLfY4@00000208B4Q080d];B0P3_knl30?Ogm`80b<S80P3<c<`30=CDe080^KVi0P1^KVh3020P
80801@D50P0T92@308j>SP80]KFe0P3Shn<20=7Ad@<0fm_K0P34a<@20=?Cd`<0_Kfm0P1/K6`2028R
8P<02PX:0P0U9BD2069RHP<0YJFU0P2i^KT20=;BdP80alO70`3Jf]X20?ooo`80l?3`0`2][Jd2075a
L@80:BTY0`0h>3P206i^KP80_;bl0`37alL20;>c/`80[Zj^0P2k^k/30<o?c`80^;Rh0P24Q8@A0000
00@0dLfY00030=7=ZA4000000P24Q8@20=;BdP80kno_0`3gmoL20<S8b080c<c<0`3De=@20;Vi^@80
KVi^0`0P820200D51@8092@T0`2>SXh20;Fe]@80hn?S0P3AdM430=_Kf`80a<C40P3Cdm<30;fm_@80
K6a/0P0R8R8300X:2P809BDU0P1RHV830:FUY@80^KVi0P3Bd]820<O7a`<0f][J0P3oool20?3`l0<0
[Jf]0P1aLG4202TY:@<0>3Ph0P1^KVh20;bl_0<0alO70P2c/k<20:j^[P80^k^k0`3?cll20;Rh^080
Q8B44@0000040=7=Z@000`3AcJTA00000080UIFE0P3Vi^H20?Gem@<0iNGU0P2YZJT20;bl_0<0e]KF
0P3=cLd209VIV@<0:2PX0P071`L201LG5`<0GemO0P2OWil20<o?c`80emOG0`3@d=020<_;b`80d=3@
0`2FUYH205ADE08030`<0`00000202<S8`80OWin0`2i^KT20;Zj^P80X:2P1@28R8P20<[:bP80]kNg
0`2LW9`204Q8B0808B4Q0`0L71`2059BDPD0Ph>30P1cLg<206QXJ080UiNG0`3:b/X20<k>cP80TI6A
4@0000040=7=Z@000`3AcJTA00000080UIFE0P3Vi^H20?Gem@<0iNGU0P2YZJT20;bl_0<0e]KF0P3=
cLd209VIV@<0:2PX0P071`L201LG5`<0GemO0P2OWil20<o?c`80emOG0`3@d=020<_;b`80d=3@0`2F
UYH205ADE08030`<0`00000202<S8`80OWin0`2i^KT20;Zj^P80X:2P1@28R8P20<[:bP80]kNg0`2L
W9`204Q8B0808B4Q0`0L71`2059BDPD0Ph>30P1cLg<206QXJ080UiNG0`3:b/X20<k>cP80TI6A4@00
00040=7=Z@000`3AcJTA00000080Z:RX0P3Fe]H20;fm_@<0QhN70P1HF5P207AdM0<0^;Rh0P3Hf=P2
0:RXZ0<0>3Ph0P051@D2000000<09bLW0P1OGel208n?S`80];Bd0`36a/H20;Ng]`80XJ6Q0`1OGel2
02d];@D000000P0O7al208:2PP<0[Zj^0P2/[:`205IFEP806a/K0`0=3@d203Lg=`80GEeM0`1CDe<2
01TI6@801`L70`092@T202HV9PD09BDU1000000204Y:BP<0QHF50P2o_kl209JFUQ400000103AcJT0
00<0dLfY4@0000020:RXZ080e]KF0P2m_Kd308N7Q`80F5QH0P1dM7@30;Rh^080f=SH0P2XZ:P303Ph
>0801@D50P00000302LW9`80GemO0P2?Shl20;Bd]0<0a/K60P2g]kL20:6QX@<0GemO0P0];Bd50000
00807alO0P22PX830:j^[P80[:b/0P1FEUH201/K6`<03@d=0P0g=cL205eMG@<0De=C0P0I6AT200L7
1`<02@T90P0V9RH502DU9@@000000P1:BTX308F5Q@80_kno0P2FUYHA000000@0dLfY00030=7=ZA40
00000P2SXj<20=CDe080Y:BT0`1HF5P201dM7@80?Cdm0`2NWYh20>;RhP80`/;20`1RHV8200<30`L0
00000P14A4@208B4Q0<0Zj^[0P2LW9`205mOG`<0<c<c0P061PH500000080?Cdm0P2DU9@30;Vi^@80
R8R80P0i>CT7000000806ATI0`0A4A49000000802`/;1`00000201XJ6P<0KVi^0P2[Zj/208^;Ra40
0000103AcJT000<0dLfY4@0000020:>SX`80e=CD0P2TY:@305QHF0807AdM0P0m?Cd309jNWP80h^;R
0P32`/83069RHP800`<31`00000204A4A080Q8B40`2[Zj/209bLW080GemO0`0c<c<200H61PD00000
0P0m?Cd209BDU0<0^KVi0P28R8P203Ti>@L000000P0I6AT3014A4@T000000P0;2`/7000000806QXJ
0`1^KVh20:^[Z`80Rh^;4@0000040=7=Z@000`3AcJTA00000080Xj>S0P3De=@20:BTY0<0F5QH0P0M
7Ad203dm?@<0WYjN0P3Rh^820<;2`P<0HV9R0P030`<700000080A4A40P24Q8@30:^[Z`80W9bL0P1O
Gel303<c<`801PH61@00000203dm?@80U9BD0`2i^KT208R8R080>CTi1`00000201TI6@<04A4A2@00
000200/;2`L000000P0J6QX306i^KP80Zj^[0P2;Rh/A000000@0dLfY00030=7=ZA4000000P2WYjL2
0=cLg080X:2P0`11@D4200000080;Bd]0`2RXZ820>CTi080clo?0`1oOgl200h>3PL000000P0E5AD2
06ATI0<0QXJ60P1oOgl2069RHP<0:2PX1000000301PH6080GEeM0P32`/830>_[j`80/K6a0P1ZJVX2
028R8P<01`L70P0G5aL2024Q8@<07alO0P0820P2000000<03@d=0P0b<S8205IFEP<0?3`l0P0O7al2
01hN7P80>c/k0`23Ph<20;bl_080RXZ:4@0000040=7=Z@000`3AcJTA00000080YjNW0P3Lg=`20:2P
X0<0@D510P00000202d];@<0XZ:R0P3Ti>@20<o?c`<0Ogmo0P0>3Ph7000000805ADE0P1TI6@308J6
QP80Ogmo0P1RHV8302PX:0@000000`0H61P205eMG@80`/;20`3[jn/20;6a/@80JVYZ0P0R8R8300L7
1`805aLG0P0Q8B4301lO7`8020P80P00000300d=3@80<S8b0P1FEUH303`l?0807alO0P0N7Qh203/k
>`<0Ph>30P2l_;`208Z:RQ400000103AcJT000<0dLfY4@0000020;Zj^P80i^KV0P2WYjL303lo?`80
00000P0b<S830;>c/`80i^KV0P3@d=0307YjNP807QhN1`00000201HF5P80CDe=0`1lO7`20861P@80
De=C0`0`<30201XJ6P8061PH0`17AdL208F5Q@80clo?0`3inOT20>WYj@80Zj^[0P23Ph<307moO`80
QXJ60P2CTi<3069RHP80;2`/0P0?3`l30492@P80WYjN0P3IfMT30;no_`80VYZJ0P21PH4208f=S@<0
[jn_0P3Fe]H208V9RA400000103AcJT000<0dLfY4@0000020;Zj^P80i^KV0P2WYjL303lo?`800000
0P0b<S830;>c/`80i^KV0P3@d=0307YjNP807QhN1`00000201HF5P80CDe=0`1lO7`20861P@80De=C
0`0`<30201XJ6P8061PH0`17AdL208F5Q@80clo?0`3inOT20>WYj@80Zj^[0P23Ph<307moO`80QXJ6
0P2CTi<3069RHP80;2`/0P0?3`l30492@P80WYjN0P3IfMT30;no_`80VYZJ0P21PH4208f=S@<0[jn_
0P3Fe]H208V9RA400000103AcJT000<0dLfY4@0000020;Jf]P80iNGU0P2XZ:P304i>CP8000000P0^
;Rh308J6QP80j>SX0P32`/8307moO`80=3@d0P010@4300L71`801@D50P0X:2P205aLG0<0NGUi0P1X
J6P204Q8B0<0>c/k0P0a<C4204A4A0<0H61P0P1iNGT20;Rh^0<0emOG0P3Lg=`20;Zj^P80/K6a0`2l
_;`20=_Kf`80dM7A0`2IVIT204m?C`809BDU0`0i>CT20:BTY080k>c/0`3gmoL20=CDe080Xj>S0P2a
/K430<S8b080]kNg0P2JVYXA000000@0dLfY00030=7=ZA4000000P2f][H20>GUi@80Z:RX0`1>CTh2
00000080;Rh^0`26QXH20>SXj080`/;20`1oOgl203@d=0800@410`071`L200D51@80:2PX0P1LG5`3
07UiN@80J6QX0P18B4P303/k>`80<C4a0P14A4@3061PH080NGUi0P2h^;P30=OGe`80g=cL0P2j^[X2
0;6a/@<0_;bl0P3Kfm/20=7Ad@<0VIVI0P1?Cdl202DU9@<0>CTi0P2TY:@20>c/k0<0moOg0P3De=@2
0:>SX`80/K6a0`38b<P20;Ng]`80VYZJ4@0000040=7=Z@000`3AcJTA00000080UYJF0P38b<P209BD
U0<05QHF1000000306=SH`80^[Zj0P2RXZ83065QH@80:RXZ0P0Q8B430410@080EUIF0P1cLg<206a/
K0<0SHf=0P1UIFD203hn?P<0;Rh^0P0n?Sh204a<C0<0BDU90P1IFET206YZJP<0L71`0P1cLg<206IV
IP80KVi^0`2IVIT20>7Qh@80k^k^0`2e]KD204=3@`800`<30`0N7Qh2069RHP80WIfM0`2ZZZX208Z:
RP80IfMW0P1fMWH30:NWY`80XZ:R0P26QXHA000000@0dLfY00030=7=ZA4000000P2FUYH20<S8b080
U9BD0`0F5QH4000000<0Hf=S0P2j^[X20::RXP<0HF5Q0P0Z:RX2024Q8@<0@4100P1FEUH207=cL`80
K6a/0`2=SHd206EUI@80?Shn0`0^;Rh203hn?P80C4a<0`19BDT205UIF@80JVYZ0`1`L70207=cL`80
IVIV0P1^KVh309VIV@80hN7Q0P3^k^h30;Fe]@80@d=30P030`<301hN7P80HV9R0P2MWId30:ZZZP80
RXZ:0P1WIfL207IfMP<0YjNW0P2RXZ8208J6QQ400000103AcJT000<0dLfY4@00000209JFUP80b<S8
0P2DU9@301HF5P@000000`1SHf<20;Zj^P80XZ:R0`1QHF4202XZ:P808B4Q0`10@40205IFEP80Lg=c
0P1/K6`308f=S@80IFEU0P0n?Sh302h^;P80?Shn0P1<C4`304U9B@80FEUI0P1ZJVX3071`L080Lg=c
0P1VIVH206i^KP<0VIVI0P3QhN420>k^kP<0]KFe0P13@d<200<30`<07QhN0P1RHV8209fMW@<0ZZZZ
0P2:RXX206MWI`80MWIf0`2WYjL20::RXP80QXJ64@0000040=7=Z@000`3AcJTA00000080Ogmo0P2T
Y:@206a/K0L000000`0g=cL208B4Q080NGUi0`0j>SX202LW9`80Cdm?0`1`L70209VIV@80Y:BT0P2>
SXh3075aL@80D51@0P0S8b<3014A4@808B4Q0P0Y:BT3020P80806a/K0P010@47000000800@410`1>
CTh20:n_[`80_kno0`2XZ:P202PX:0D000000P0@410203Lg=`<0:2PX0P071`L200000080410@0`1M
GEd208^;R`80K6a/4@0000040=7=Z@000`3AcJTA00000080Ogmo0P2TY:@206a/K0L000000`0g=cL2
08B4Q080NGUi0`0j>SX202LW9`80Cdm?0`1`L70209VIV@80Y:BT0P2>SXh3075aL@80D51@0P0S8b<3
014A4@808B4Q0P0Y:BT3020P80806a/K0P010@47000000800@410`1>CTh20:n_[`80_kno0`2XZ:P2
02PX:0D000000P0@410203Lg=`<0:2PX0P071`L200000080410@0`1MGEd208^;R`80K6a/4@000004
0=7=Z@000`3AcJTA00000080MGEe0P2QXJ4206UYJ@<04Q8B1000000303`l?080LW9b0P1ADE43020P
808061PH0P0o?cl307MgM`80/K6a0P35aLD20;6a/@<0NGUi0P1=CDd2018B4P<000000P0>3Ph200l?
3`<00@413@00000301dM7@80QHF50P2g]kL308n?S`808B4Q4P00000304];B`80NWYj0P1cLg<A0000
00@0dLfY00030=7=ZA4000000P1eMGD20:6QX@80JFUY0`0B4Q84000000<0?3`l0P1bLW82055AD@<0
820P0P0H61P203lo?`<0MgMg0P2a/K420<G5a@80/K6a0`1iNGT204e=C@804Q8B0`00000200h>3P80
3`l?0`010@4=000000<07AdM0P25QHD20;Ng]`<0Shn?0P0Q8B4B000000<0Bd];0P1jNWX207=cLa40
0000103AcJT000<0dLfY4@000002079bLP80[jn_0P2?Shl304i>CP804a<C0P0d=3@306EUI@80TI6A
0P1iNGT301PH60800`<30P0P8203065QH@80Shn?0P2ZZZX20:NWY`<0Rh^;0P1JFUX200X:2PL00000
0`0410@2000000805aLG0`0H61P4000000800@410`0o?cl20:^[Z`80c<c<0`2OWil204I6APL00000
0P0T92@301<C4`@000000P0T92@306m_K`80XJ6Q0P21PH4A000000@0dLfY00030=7=ZA4000000P1b
LW820:n_[`80Shn?0`1>CTh201<C4`80=3@d0`1UIFD2096AT@80NGUi0`0H61P200<30`80820P0`1Q
HF4208n?S`80ZZZZ0P2WYjL308^;R`80FUYJ0P0:2PX7000000<010@40P00000201LG5`<061PH1000
000200410@<0?clo0P2[Zj/20<c<c0<0WinO0P16ATH70000008092@T0`0C4a<40000008092@T0`1_
Kfl20:6QX@80PH614@0000040=7=Z@000`3AcJTA00000080O7al0P2l_;`20<30`0<0WinO0P1oOgl2
08V9R@<0Xj>S0P2_[jl2071`L0<06QXJ0P00000200H61P<07AdM0P1MGEd206QXJ080QXJ60`29RHT2
05iNGP807alO2P00000203@d=080@D510`1[Jf/207UiN@80Fe]K0P1RHV8309JFUP80`<300P3?cll3
09nOW`80AdM70P00000301XJ6P80EUIF0P2:RXX309ZJVP@0HF5Q0P1[Jf/30:j^[P80_kno0P28R8PA
000000@0dLfY00030=7=ZA4000000P1lO7`20;bl_080`<300`2OWil207moO`80RHV90`2SXj<20:n_
[`80L71`0`0J6QX2000000801PH60`0M7Ad205eMG@80J6QX0P26QXH308V9R@80GUiN0P0O7al:0000
0080=3@d0P11@D4306][J`80NGUi0P1KFe/2069RHP<0UYJF0P30`<020<o?c`<0WinO0P17AdL20000
00<06QXJ0P1FEUH208Z:RP<0VYZJ101QHF4206][J`<0[Zj^0P2o_kl208R8R1400000103AcJT000<0
dLfY4@00000207alO080_;bl0P30`<0309nOW`80Ogmo0P29RHT30:>SX`80[jn_0P1`L70301XJ6P80
00000P061PH301dM7@80GEeM0P1XJ6P208J6QP<0RHV90P1NGUh201lO7`X000000P0d=3@20451@@<0
Jf][0P1iNGT205]KF`80HV9R0`2FUYH20<30`080clo?0`2OWil204M7A`8000000`0J6QX205IFEP80
RXZ:0`2JVYX4065QH@80Jf][0`2^[Zh20;no_`80R8R84@0000040=7=Z@000`3AcJTA00000080PX:2
0P35aLD20<W9b@<0`L710P2b/[820:RXZ0<0[Zj^0P2ZZZX207MgM`<0<S8b1000000300820P804Q8B
0P14A4@205iNGP<0MWIf0P1aLG4203Ph>0<00@410P061PH500000080;Bd]0P1^KVh30;Ng]`80[jn_
0P2i^KT20:BTY0<0]KFe0P3De=@20:^[Z`<0QHF50P15ADD201XJ6P<0F5QH0P2=SHd20=gMg@<0d];B
0P32`/8409NGU`<0][Jf0P2TY:@207=cLa400000103AcJT000<0dLfY4@00000208:2PP80aLG50P39
bLT30<71`@80/[:b0P2XZ:P30:j^[P80ZZZZ0P1gMgL3038b<P@000000`020P82018B4P80A4A40P1N
GUh307IfMP80LG5a0P0h>3P300410@801PH61@00000202d];@80KVi^0`2g]kL20:n_[`80^KVi0P2T
Y:@30;Fe]@80e=CD0P2[Zj/308F5Q@80ADE50P0J6QX305QHF080SHf=0P3MgMd30=;BdP80`/;2102G
UiL30;Jf]P80Y:BT0P1cLg<A000000@0dLfY00030=7=ZA4000000P18B4P209:BTP80Vi^K0`2[Zj/2
096AT@80UiNG0`2<S8`207YjNP80DE5A0`0V9RH200/;2`L000000P0820P203Ph>0<0CTi>0P1LG5`2
02d];@X000000P0/;2`206YZJP<0Vi^K0P2i^KT20:RXZ080QHF50`2=SHd208R8R080N7Qh0`0m?Cd2
01XJ6P805aLG0`0k>c/20820P080]KFe0`2h^;P20:VYZ@80PX:20P20P80308B4Q080MGEe0P18B4PA
000000@0dLfY00030=7=ZA4000000P18B4P209:BTP80Vi^K0`2[Zj/2096AT@80UiNG0`2<S8`207Yj
NP80DE5A0`0V9RH200/;2`L000000P0820P203Ph>0<0CTi>0P1LG5`202d];@X000000P0/;2`206YZ
JP<0Vi^K0P2i^KT20:RXZ080QHF50`2=SHd208R8R080N7Qh0`0m?Cd201XJ6P805aLG0`0k>c/20820
P080]KFe0`2h^;P20:VYZ@80PX:20P20P80308B4Q080MGEe0P18B4PA000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT00900dLfY002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {524.75, 455}} -> {-80.2954, 197.911, \
0.436562, 0.436562}}]
}, Open  ]],

Cell[TextData[{
  "As a final optional step, the total variation regularization can be \
applied on the restored image to obtain a sharper image;  the  vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Tau]",
          "TB"], TraditionalForm]]],
  " stores two regularization parameters used in the total variation step. "
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox["\[Tau]",
          "TB"], " ", "=", " ", \({1\ /\ 8, \ 10^\(-5\)}\)}], 
      ";"}], "\[IndentingNewLine]", \(\(Timing[\(r\  = \ 
            totalVariation[
              Take[restored, \ {m\_y\  + \ 1, \ 
                  m\_y\  + \ n\_y}, \ {m\_x\  + \ 1, \ 
                  m\_x\  + \ 
                    n\_x}], \ \[Nu]];\)]\)[\([1]\)]\), "\[IndentingNewLine]", \
\(showImage[extendImageMatrix[r, \ m\_y, \ m\_x]];\)}], "Input"],

Cell[BoxData[
    \(18.52000000000001`\ Second\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49153 
%%ImageSize: 144 70.7797 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0161421 0.011703 0.0161421 [
[ 0 0 0 0 ]
[ 1 .49153 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .49153 L
0 .49153 L
closepath
clip
newpath
% Start of gray image
p
.02381 .0117 translate
.95238 .46812 scale
59 string
59 29 8 [59 0 0 29 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000008FE0FEFDEDEFEABB662C2D3EA0D9DEE6CAD8D2CA903B292E559BD5D7E5
FEFFFDC166403E77BECACBCBCBCCCA9500000000000000
00000000000000CDFDFDFFF2EBEFE68E312E31A8D5E9E1E9E1E5D3852F32307ACAD5DAE3
FFFEFFC97E3E407AC3CBCACBCCCCCDC900000000000000
00000000000000E6FDFEFDEAEFEBEAC5352F2E70C5E1E9E1E7E1BC63322F349FD4CBD1C3
BDEFD8B2553E3D5792A29C9DC7CDCCCB00000000000000
00000000000000F1F0F2C598B5EAEBDD4D29293078BBDEE7E0CB7B3D2E3233B3CAD58E43
374A675934373439353A353977BFCBCB00000000000000
00000000000000F0F1E4885C6FE0E9EB7D2828282765A9C7BD85522F332E54C1D5C96B36
41353D353734373439353A364BADCBC900000000000000
00000000000000F0F0DB644951DAECE9A129282728328794907F46332F357BE5F1DF9E49
3541363C3437343D5A4D3C426DBEC9CB00000000000000
00000000000000F0F0D9574749DCE9EC9F30282828327D8C8B6E45413D549BEFEAF2CFBB
B2ABAB6D3D3640A9E5DFC1BFBFC7CBC700000000000000
00000000000000EFF0CF5E3446AAEDE197482928284D8987885D4743475F86D5F2EACFC6
CAE2DEB4503D3AB9E0E6D9C0C1CBC7CB00000000000000
00000000000000D1DABC3335327DC6B8774D474E6E8F898E7F514347444E667D8D938FA4
C8DEE2CF5232366CB9C9AF9AAAC3C6BD00000000000000
00000000000000BDC19B3432355C8D8E56484E79A6AFA38B733F312E322D252223222424
7DD6D2D23F2E2F2B342E302B3891AFA800000000000000
00000000000000C0BCA0343533668B8144424C86AFA6AF956C2D1E20201D202322232324
44C8D3C63B2F2A2F2A2F2B302C7EA8AF00000000000000
00000000000000BCC1BC7A3F598B928D392F3771A3AFA69A72221F1B1A1F1E2324222424
6CD2CACD552B2F2A302B302B4B9CB4AE00000000000000
00000000000000BFCBCCCAB6B9BBBA89322B232B72879690742D1A191A182C4478958293
C9CAD2C2583330639FB8858F9FB6B2B500000000000000
00000000000000C1CCCCCCC9BFBBBB8E3C2025202560787A7740181A181A3079C9C4C9C9
C8D2C9A44D405A9DDED7DCB3B6B2B6B100000000000000
000000000000007DCCCCCCC6C1BDB1753725202420276576793D1A181A183688C2CBC8C8
C9C4B767404C4EA8D7DED7B6B2B6B17D00000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 70.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000AR000`400?l00000o`00003oT03AcJT0
0900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY4@00000208n?S`80h>3P
0P3no_h30?gmo@80kNg]0P3_knl30>[ZjP80^k^k0P1VIVH302`/;080;Bd]0P0n?Sh30:2PX080fMWI
0P3Ng]h20>KViP<0b/[:0P3Hf=P20=;BdP<0b/[:0P2@T90203/k>`<0:BTY0P0^;Rh205EEE@<0Vi^K
0P3EeMD20=OGe`80iNGU0`3no_h20?ooo`80oOgm0`31`L4206IVIP80@4100`0n?Sh207MgM`80_[jn
0`3:b/X60<_;b`<0c<c<0P3:b/X209FEUA400000103AcJT000<0dLfY4@00000208n?S`80h>3P0P3n
o_h30?gmo@80kNg]0P3_knl30>[ZjP80^k^k0P1VIVH302`/;080;Bd]0P0n?Sh30:2PX080fMWI0P3N
g]h20>KViP<0b/[:0P3Hf=P20=;BdP<0b/[:0P2@T90203/k>`<0:BTY0P0^;Rh205EEE@<0Vi^K0P3E
eMD20=OGe`80iNGU0`3no_h20?ooo`80oOgm0`31`L4206IVIP80@4100`0n?Sh207MgM`80_[jn0`3:
b/X60<_;b`<0c<c<0P3:b/X209FEUA400000103AcJT000<0dLfY4@0000020<g=c@@0oOgm0`3oool2
0?;blP80jn_[0`3_knl20>KViP80SXj>0`0a<C4202h^;P80<C4a0`2XZ:P20=GEe@80jNWY0P3QhN43
0>WYj@80hN7Q0P3UiND30=?Cd`80QHF50P0_;bl3038b<P80<30`0P1jNWX30<[:bP80eMGE0P3Jf]X2
0>?Sh`<0oooo0P3no_h20?ooo`<0bLW90P1nOWh203hn?P<0@4100P1jNWX20<?3``<0bl_;0P3:b/X2
0<_;b`D0c<c<0P3=cLd20<W9bA400000103AcJT000<0dLfY4@0000020<g=c@@0oOgm0`3oool20?;b
lP80jn_[0`3_knl20>KViP80SXj>0`0a<C4202h^;P80<C4a0`2XZ:P20=GEe@80jNWY0P3QhN430>WY
j@80hN7Q0P3UiND30=?Cd`80QHF50P0_;bl3038b<P80<30`0P1jNWX30<[:bP80eMGE0P3Jf]X20>?S
h`<0oooo0P3no_h20?ooo`<0bLW90P1nOWh203hn?P<0@4100P1jNWX20<?3``<0bl_;0P3:b/X20<_;
b`D0c<c<0P3=cLd20<W9bA400000103AcJT000<0dLfY4@0000020<g=c@@0oOgm0`3oool20?;blP80
jn_[0`3_knl20>KViP80SXj>0`0a<C4202h^;P80<C4a0`2XZ:P20=GEe@80jNWY0P3QhN430>WYj@80
hN7Q0P3UiND30=?Cd`80QHF50P0_;bl3038b<P80<30`0P1jNWX30<[:bP80eMGE0P3Jf]X20>?Sh`<0
oooo0P3no_h20?ooo`<0bLW90P1nOWh203hn?P<0@4100P1jNWX20<?3``<0bl_;0P3:b/X20<_;b`D0
c<c<0P3=cLd20<W9bA400000103AcJT000<0dLfY4@0000020>KViP80oOgm0P3no_h30?gmo@80j^[Z
0P3_knl30>_[j`80j^[Z0P35aLD303De=@80;bl_0P0^;Rh3071`L080aLG50P3QhN420>WYj@<0hN7Q
0P3WinL20>7Qh@<0_;bl0P1SHf<2038b<P<0;bl_0P0d=3@209nOW`<0e=CD0P3;bl/20=7Ad@80`l?3
0`2m_Kd20>o_k`80f=SH0`2b/[8205EEE@80?Shn0`0m?Cd205MGE`80TY:B0`2RXZ8209bLW080WIfM
0P37alL30<g=c@80c<c<0P3;bl/A000000@0dLfY00030=7=ZA4000000P3Vi^H20?gmo@80o_kn0`3m
oOd20>[ZjP80kno_0`3[jn/20>[ZjP80aLG50`0e=CD202l_;`80;Rh^0`1`L7020<G5a@80hN7Q0P3Y
jNT30>7Qh@80inOW0P3QhN430;bl_080Hf=S0P0b<S8302l_;`80=3@d0P2OWil30=CDe080bl_;0P3A
dM420<?3``<0_Kfm0P3_knl20=SHf0<0/[:b0P1EEED203hn?P<0?Cdm0P1GEeL209:BTP<0XZ:R0P2L
W9`209fMW@80alO70`3=cLd20<c<c080bl_;4@0000040=7=Z@000`3AcJTA00000080lO7a0P3`l?02
0?;blP<0aLG50P2HV9P20;Fe]@<0j^[Z0P3[jn/20=gMg@<0CDe=100Y:BT3030`<080N7Qh0P2k^k/2
0=kNgP<0inOW0P3Ph>020<_;b`<0Ng]k0P0m?Cd202h^;P<0<S8b0P0c<c<20;>c/`<0b/[:0P3EeMD2
08j>SP80@d=30`0g=cL204Y:BP80IfMW0`1IFET203@d=080=cLg0`0d=3@203Ti>@80=CDe0`0j>SX2
03De=@80>CTi0P1gMgL30;no_`@0bl_;4@0000040=7=Z@000`3AcJTA00000080lO7a0P3`l?020?;b
lP<0aLG50P2HV9P20;Fe]@<0j^[Z0P3[jn/20=gMg@<0CDe=100Y:BT3030`<080N7Qh0P2k^k/20=kN
gP<0inOW0P3Ph>020<_;b`<0Ng]k0P0m?Cd202h^;P<0<S8b0P0c<c<20;>c/`<0b/[:0P3EeMD208j>
SP80@d=30`0g=cL204Y:BP80IfMW0`1IFET203@d=080=cLg0`0d=3@203Ti>@80=CDe0`0j>SX203De
=@80>CTi0P1gMgL30;no_`@0bl_;4@0000040=7=Z@000`3AcJTA00000080l?3`0P3alO420>CTi0<0
R8R80P1LG5`206m_K`<0h>3P0P3YjNT20>_[j`<0OGem1`0X:2P202LW9`80IFEU0P2YZJT30<O7a`80
_Kfm0P25QHD3059BDP80;bl_0P0c<c<302h^;P80E5AD0P31`L430=GEe@80bLW90P1[Jf/203Hf=P<0
@D510P0e=CD203dm?@<0=CDe0P0g=cL203@d=0<0=cLg0P0d=3@203Ti>@<0=CDe0P0j>SX203Hf=P80
Bd];0`2][Jd20<_;b`80bLW94@0000040=7=Z@000`3AcJTA00000080l?3`0P3alO420>CTi0<0R8R8
0P1LG5`206m_K`<0h>3P0P3YjNT20>_[j`<0OGem1`0X:2P202LW9`80IFEU0P2YZJT30<O7a`80_Kfm
0P25QHD3059BDP80;bl_0P0c<c<302h^;P80E5AD0P31`L430=GEe@80bLW90P1[Jf/203Hf=P<0@D51
0P0e=CD203dm?@<0=CDe0P0g=cL203@d=0<0=cLg0P0d=3@203Ti>@<0=CDe0P0j>SX203Hf=P80Bd];
0`2][Jd20<_;b`80bLW94@0000040=7=Z@000`3AcJTA00000080l?3`0P3alO420>CTi0<0R8R80P1L
G5`206m_K`<0h>3P0P3YjNT20>_[j`<0OGem1`0X:2P202LW9`80IFEU0P2YZJT30<O7a`80_Kfm0P25
QHD3059BDP80;bl_0P0c<c<302h^;P80E5AD0P31`L430=GEe@80bLW90P1[Jf/203Hf=P<0@D510P0e
=CD203dm?@<0=CDe0P0g=cL203@d=0<0=cLg0P0d=3@203Ti>@<0=CDe0P0j>SX203Hf=P80Bd];0`2]
[Jd20<_;b`80bLW94@0000040=7=Z@000`3AcJTA000000@0l?3`0P3Kfm/306ATI080BDU90P1ADE43
0=[JfP80k>c/0P3YjNT30:6QX@80:BTY0P0X:2P302LW9`80:2PX0P0b<S8208N7Q`<0U9BD0P2@T902
07moO`<0ATI60P0c<c<202l_;`<0=CDe0P1kNg/20>GUi@<0lO7a0P3Ogml209jNWP80BDU90`0e=CD2
0451@@80=SHf0`0l?3`203@d=080=cLg0`0d=3@203dm?@80FUYJ0`1=CDd203`l?080@T920P1]KFd3
0;jn_P80bLW90P3;bl/A000000@0dLfY00030=7=ZA400000103`l?020=_Kf`<0I6AT0P19BDT2055A
D@<0f][J0P3/k>`20>WYj@<0XJ6Q0P0Y:BT202PX:0<09bLW0P0X:2P2038b<P80QhN70`2DU9@2092@
T080Ogmo0`16ATH203<c<`80;bl_0`0e=CD207]kN`80iNGU0`3alO420=oOg`80WYjN0P19BDT303De
=@80@D510P0f=SH303`l?080=3@d0P0g=cL303@d=080?Cdm0P1JFUX304e=C@80?3`l0P12@T8206e]
K@<0_[jn0P39bLT20<_;ba400000103AcJT000<0dLfY4@0000040?3`l080fMWI0`1GEeL204M7A`80
BDU90`3Lg=`20>WYj@80k>c/0`2OWil2030`<0L0:2PX0P0b<S8207emO@<0S8b<0P2;Rh/206i^KP<0
ADE50P11@D4203dm?@<0E5AD0P2KVi/20>o_k`<0j^[Z0P3bl_820<o?c`80^k^k0`2b/[840:^[Z`<0
KFe]0P0m?Cd203Hf=P<0@4100P2YZJT20>GUi@<0gmoO0P31`L440;no_`<0alO70P3;bl/20<O7aa40
0000103AcJT000<0dLfY4@0000040?3`l080fMWI0`1GEeL204M7A`80BDU90`3Lg=`20>WYj@80k>c/
0`2OWil2030`<0L0:2PX0P0b<S8207emO@<0S8b<0P2;Rh/206i^KP<0ADE50P11@D4203dm?@<0E5AD
0P2KVi/20>o_k`<0j^[Z0P3bl_820<o?c`80^k^k0`2b/[840:^[Z`<0KFe]0P0m?Cd203Hf=P<0@410
0P2YZJT20>GUi@<0gmoO0P31`L440;no_`<0alO70P3;bl/20<O7aa400000103AcJT000<0dLfY4@00
00020>o_k`80l?3`0P3?cll305iNGP80=3@d0P16ATH30:ZZZP80kNg]0P3QhN4309NGU`80B4Q80P0Y
:BT502PX:080CDe=0P29RHT308N7Q`80R8R80P1MGEd304M7A`80@d=30P17AdL305mOG`80QXJ60P3E
eMD30?;blP80j^[Z0P3?cll20<K6aP<0b/[:0P3Rh^820=kNgP<0];Bd0P1@D50203dm?@<0>SXj0P2i
^KT20>3Ph0<0i^KV0P3IfMT20<30`080`L710`3;bl/20<O7a`80bl_;4@0000040=7=Z@000`3AcJTA
00000080kno_0P3`l?020<o?c`<0GUiN0P0d=3@204I6AP<0ZZZZ0P3]kNd20>7Qh@<0UiNG0P18B4P2
02TY:@D0:2PX0P1=CDd208V9R@<0QhN70P28R8P205eMG@<0AdM70P13@d<204M7A`<0GemO0P26QXH2
0=GEe@<0l_;b0P3Zj^X20<o?c`80a/K60`3:b/X20>;RhP80g]kN0`2d];@2051@D080?Cdm0`0j>SX2
0;Vi^@80h>3P0`3Vi^H20=WIf@80`<300P31`L430<_;b`80alO70P3;bl/A000000@0dLfY00030=7=
ZA4000000P3AdM420=[JfP80_;bl0`0c<c<203De=@80<S8b0`1mOGd20<K6aP80^;Rh0`1gMgL204e=
C@80AdM70`1>CTh206i^KP80Shn?0P29RHT308j>SP80Ogmo0P1ADE4304=3@`80AdM70P14A4@304i>
CP80IVIV0P1mOGd308f=S@80Ti>C0P2?Shl20:BTY0<0b<S80P3Ng]h20>;RhP<0clo?0P1BDU82038b
<P<0=SHf0P1/K6`20;Vi^@<0bLW90P2_[jl209ZJVP80ZZZZ0`33`l<20<K6aP80_Kfm4@0000040=7=
Z@000`3AcJTA00000080dM7A0P3Jf]X20;bl_0<0<c<c0P0e=CD2038b<P<0OGem0P36a/H20;Rh^0<0
MgMg0P1=CDd204M7A`<0CTi>0P1^KVh208n?S`80RHV90`2>SXh207moO`80DE5A0`13@d<204M7A`80
A4A40`1>CTh206IVIP80OGem0`2=SHd209>CT`80Shn?0P2TY:@30<S8b080g]kN0P3Rh^830<o?c`80
DU9B0P0b<S8303Hf=P80K6a/0P2i^KT30<W9b@80[jn_0P2JVYX20:ZZZP<0`l?30P36a/H20;fm_A40
0000103AcJT000<0dLfY4@0000020=7Ad@80f][J0P2l_;`303<c<`80=CDe0P0b<S8307emO@80a/K6
0P2h^;P307MgM`80CDe=0P17AdL304i>CP80KVi^0P2?Shl208V9R@<0SXj>0P1oOgl2055AD@<0@d=3
0P17AdL204A4A0<0CTi>0P1VIVH207emO@<0SHf=0P2CTi<208n?S`80Y:BT0`38b<P20=kNgP80h^;R
0`3?cll2059BDP80<S8b0`0f=SH206a/K080^KVi0`39bLT20:n_[`80VYZJ0P2ZZZX30<?3``80a/K6
0P2m_KdA000000@0dLfY00030=7=ZA4000000P2m_Kd20<71`@80Vi^K0`0d=3@2038b<P80=CDe0`1L
G5`208f=S@80SXj>0`1FEUH204Q8B080CTi>0`1iNGT20:JVYP80[jn_0P2SXj<308^;R`80Lg=c0P0o
?cl3034a<@80;Rh^0P0b<S8302d];@809BDU0P0R8R8302<S8`808R8R100T92@307emO@80e]KF1@3B
d]8203lo?`80;Rh^0`0_;bl202/[:`80=3@d0`0^;Rh2030`<080:b/[0P0h>3P3096AT@80[jn_0P2X
Z:PA000000@0dLfY00030=7=ZA4000000P2m_Kd20<71`@80Vi^K0`0d=3@2038b<P80=CDe0`1LG5`2
08f=S@80SXj>0`1FEUH204Q8B080CTi>0`1iNGT20:JVYP80[jn_0P2SXj<308^;R`80Lg=c0P0o?cl3
034a<@80;Rh^0P0b<S8302d];@809BDU0P0R8R8302<S8`808R8R100T92@307emO@80e]KF1@3Bd]82
03lo?`80;Rh^0`0_;bl202/[:`80=3@d0`0^;Rh2030`<080:b/[0P0h>3P3096AT@80[jn_0P2XZ:PA
000000@0dLfY00030=7=ZA4000000P30`<020;bl_080X:2P0`0d=3@203De=@80<c<c0`1VIVH208^;
R`80PH610`14A4@20492@P80C4a<0`26QXH20:n_[`80YZJV0P2_[jl309FEU@80K6a/0P0];Bd301hN
7P@0820P0`0M7Ad2020P80808b<S0`0R8R8402<S8`8092@T0`14A4@20<S8b080dm?C0`36a/H203/k
>`80;bl_0`0Z:RX202l_;`80:RXZ0`0_;bl202/[:`80<30`0P0/;2`307inOP80Z:RX0P2_[jlA0000
00@0dLfY00030=7=ZA4000000P30`<020;bl_080X:2P0`0d=3@203De=@80<c<c0`1VIVH208^;R`80
PH610`14A4@20492@P80C4a<0`26QXH20:n_[`80YZJV0P2_[jl309FEU@80K6a/0P0];Bd301hN7P@0
820P0`0M7Ad2020P80808b<S0`0R8R8402<S8`8092@T0`14A4@20<S8b080dm?C0`36a/H203/k>`80
;bl_0`0Z:RX202l_;`80:RXZ0`0_;bl202/[:`80<30`0P0/;2`307inOP80Z:RX0P2_[jlA000000@0
dLfY00030=7=ZA4000000P2l_;`20<71`@80_;bl0`1jNWX203lo?`80FEUI0`2;Rh/209:BTP80SHf=
0`0i>CT202l_;`80=cLg0`1aLG420:>SX`80[jn_0P2VYZH309ZJVP80LW9b0P0R8R8301lO7`806a/K
0P0J6QX301lO7`807QhN0P0S8b<302@T90808R8R100T92@306a/K080d];B0P3:b/X30<g=c@80EEEE
0P0[:b/302l_;`80:RXZ0P0`<30302/[:`80<30`0P0[:b/204];B`<0W9bL0P2d];@20:j^[Q400000
103AcJT000<0dLfY4@0000020;bl_080`L710P2l_;`307YjNP80?clo0P1IFET308^;R`80TY:B0P2=
SHd303Ti>@80;bl_0P0g=cL3075aL@80Xj>S0P2_[jl20:JVYP<0VYZJ0P1bLW82028R8P<07alO0P0K
6a/201XJ6P<07alO0P0N7Qh202<S8`<092@T0P0R8R8402@T90<0K6a/0P3Bd]820<[:bP<0cLg=0P1E
EED202/[:`<0;bl_0P0Z:RX2030`<0<0:b/[0P0`<30202/[:`80Bd];0`2LW9`20;Bd]080[Zj^4@00
00040=7=Z@000`3AcJTA00000080_kno0P3;bl/20<c<c0<0b/[:0P2f][H20;Vi^@<0^k^k0P2j^[X2
08V9R@<0<S8b0P0[:b/202<S8`<0:b/[0P1bLW8208N7Q`80UYJF0`2@T90207AdM080;Bd]0`0J6QX2
01TI6@806QXJ0`0H61P202`/;080A4A40`1hN7P209FEU@80PX:20P2CTi<30<W9b@80b/[:0P3Bd]83
0<;2`P80F5QH0P0c<c<3030`<080Hf=S0P2OWil30;Rh^080QHF50P2?Shl209nOW`<0][Jf0P2b/[82
0;Fe]A400000103AcJT000<0dLfY4@0000020;no_`80bl_;0P3<c<`30<[:bP80][Jf0P2i^KT30;^k
^`80^[Zj0P29RHT3038b<P80:b/[0P0S8b<302/[:`80LW9b0P27QhL209JFUP<0T92@0P1dM7@202d]
;@<06QXJ0P0I6AT201XJ6P<061PH0P0/;2`204A4A0<0N7Qh0P2EUID208:2PP80Ti>C0`39bLT20<[:
bP80d];B0`32`/8205QHF080<c<c0`0`<30206=SH`80WinO0`2h^;P208F5Q@80Shn?0P2OWil30;Jf
]P80/[:b0P2e]KDA000000@0dLfY00030=7=ZA4000000P2o_kl20<_;b`80c<c<0`3:b/X20;Jf]P80
^KVi0`2k^k/20;Zj^P80RHV90`0b<S8202/[:`808b<S0`0[:b/2079bLP80QhN70P2FUYH3092@T080
M7Ad0P0];Bd301XJ6P806ATI0P0J6QX301PH6080;2`/0P14A4@307QhN080UIFE0P22PX8209>CT`<0
bLW90P3:b/X20=;BdP<0`/;20P1HF5P203<c<`<0<30`0P1SHf<209nOW`<0^;Rh0P25QHD208n?S`80
WinO0`2f][H20;:b/P80]KFe4@0000040=7=Z@000`3AcJTA00000080`L711`3<c<`20<W9b@80_kno
1@2k^k/208j>SP<0?3`l0P0P820202DU9@<0820P0P0U9BD2061PH080N7Qh0`1jNWX207MgM`80@410
0`0H61P201XJ6P8061PH0`0J6QX2030`<080NGUi0`39bLT20<C4a0@0bLW90`38b<P20=;BdP80bLW9
0`2TY:@204e=C@80@4100`1JFUX209fMW@80g]kN0`3GemL20=cLg080/k>c0P2f][H30;:b/P80][Jf
0P2a/K4A000000@0dLfY00030=7=ZA4000000P31`L470<c<c080bLW90P2o_kl50;^k^`80SXj>0`0l
?3`2020P80809BDU0`0P820202DU9@80H61P0P1hN7P307YjNP80MgMg0P10@40301PH60806QXJ0P0H
61P301XJ6P80<30`0P1iNGT30<W9b@80a<C41039bLT30<S8b080d];B0P39bLT30:BTY080CDe=0P10
@40305YJFP80WIfM0P3Ng]h30=OGe`80g=cL0P2c/k<20;Jf]P<0/[:b0P2f][H20;6a/A400000103A
cJT000<0dLfY4@00000207emO@L0c<c<0P36a/H20<71`@<0_Kfm0P2a/K4207EeM@<0=cLg0P0U9BD2
020P80<092@T0P0P820202LW9`80IFEU0`1fMWH207UiN@80?Cdm0`0J6QX201PH60806QXJ0`0H61P2
03Hf=P80R8R80`32`/820<_;b`@0b<S80`39bLT20<C4a080]kNg0`1WIfL20410@080C4a<0`1>CTh2
0:RXZ080emOG0`3Ng]h20=OGe`80][Jf0P2b/[830;Jf]P80/K6a0P1mOGdA000000@0dLfY00030=7=
ZA4000000P1mOGd70<c<c080a/K60P31`L430;fm_@80/K6a0P1eMGD303Lg=`809BDU0P0P820302@T
9080820P0P0W9bL206EUI@<0MWIf0P1iNGT203dm?@<06QXJ0P0H61P201XJ6P<061PH0P0f=SH208R8
R0<0`/;20P3;bl/40<S8b0<0bLW90P34a<@20;Ng]`<0IfMW0P10@40204a<C0<0CTi>0P2XZ:P20=OG
e`<0g]kN0P3GemL20;Jf]P80/[:b0`2f][H20;6a/@80OGem4@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY
R@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {727.438, 657.688}} -> {-80.2954, 286.396, \
0.436562, 0.436562}}]
}, Open  ]],

Cell["Real Data", "Subsection"],

Cell[TextData[{
  "As a more realistic example, consider a real\[Dash]life image of Jupiter \
given in FITS format [10]. The ",
  StyleBox["FITS", "MR"],
  " package is loaded in order to read the data of the observed image ",
  Cell[BoxData[
      \(g\&~\_FITS\)],
    FontWeight->"Bold"],
  ", which is then visualized."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< FITS`\), "\[IndentingNewLine]", 
    \(\({FITSheader, \ g\&~\_FITS}\  = \ 
        readFITS["\<j889.fits\>"];\)\), "\[IndentingNewLine]", 
    \(\(showImage[g\&~\_FITS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0238095 0.00186012 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
252525252526262525252525252526262526252526252626252525262625252625262626
252625262525262525262626252525252526262525262626252526252626262626252626
252626252626262526262626262626262626262626262625262625252526262625252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262726262626262626262626262626262626262626272626
262626262626262626272626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262625262626262626262626262626
262626262626262626262526262626262626262626262626262626262626262626262526
262626262626262626252626262626262526252626262626262626262626262625252626
262526262626262526262626252626252626262626262626252526252625252625262625
252525262626262625252625252526252626252525252525252625252525252525252625
2526252525252525
252626252526252525262625262526252625252525252526252525252525252626262626
262526252626252525252626262625262625252625262526252625252626262626262625
252625262626262626262525262626252626252626262626262625262626262626262526
252626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262626262626262626262626262627262626262626262626262627262626262626272626
262726262626262626262626262626262626262626262626262626262627262726262626
262626262626262626262626262626262626262626262626262626262626252626262526
262626262626262626262626262626262626262626262626252626262626262626262626
262626262525262625262626262626252626252626262626262626262626262626262626
252626262626252525252626262526252625252526262626262626262526252525252525
252525262525262526262526252525252525262525262525252525262526262525252526
2525252625252525
252625252526252625252525252525252525252626252525262526252625252625262626
252526262626252625252625252526252526252626262525262525262526262525262626
262625262526262526262626262626262626262626262626262626252626252626262526
262626262526262626262626262626262626262526252625262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262726262626262726
262626262627262726262626262627262626262626262626262626262726262627262626
262626262727272626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262625262526262626262626262626262626262626262526262626
262626262625252626252526252625252526262526252625262526252526252626262626
262525252625262625262626252625252526262625252525252526252626252625252525
2526262525252525
252525252625252525252526252625252525252626252526262625262526262526252626
262626262526252526262626262626262625262525252625252626262626262626252626
262626262626252626252626252626262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626262726262626262626272626262626
262626262627262726262627262627262726262627272626262627262626272626262626
262626262627262626262726262626262726272727262626262626262626262626262626
262626262626262626272626262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262526262626262626262626262526262626262626
262626262626262626262626252625262626262626262626262626252626262626262626
262625262625262626252525262626252626252626262526252525262625262626262526
262525262626252626262525252626252526252525262625262525252525252525252525
2625252625252525
252625252526252625262626252625252525252625252526252526262625262626262525
262525262525262526262625252525262525252626262526262525262626262526262625
252626252626262626252626262626252626262525262626252625262526262626262626
262625262526252626262626262626262627262626262626262626262626262626262626
262626262626252726262626262626262626262626262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272726262627262626262726262726262626262627
262726272726262626272627262626262626262626262626262626262626262726262726
262627262626262626262627262626272626262626262626262626262626262726262626
262626262626262726262626262626272626262626262626262626262626262626262626
262626262626262626262626262626262626252526262626262626262626262626262526
262626262626252626262526262625262526262525262625262626262526262626262626
252626262626252625252626262626262626252626252526252526262625252625252625
252625252625252526252626252525262526252526252525252525252525262525252625
2525252525252525
252625252526252626252625262525262526262526252625262526262526252625252625
252625262525252526252625262525262525252625262526252525252626252526262626
262626262626262626262626262626262625262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262626262626262626262626262626262626262626262626262626272626
262626262626272626262626262626262626262626262627262626262626262627262626
262626272626262626262727262626262626262627262626262626262626262726262626
272627272626262726262626262626262727262727262727262726262626262726262626
262626262727262626272626262626272726262626262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626252626262526262626262526262526262626
262625252526252626262626262626252626262626252625252626262526262525252626
262626252526262526262625262526262625252525252626252525262525252525252525
2625252525252525
252625252526252626252525252625262525262526262626262625262525252625262526
262625252626262525262525252626262526252525262625262626252525262625252626
262626262626262626262626262626262526252626252626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262526
262626262626262626262626262626262626262626262626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626272626262626272626262626262626262726262626262726262626
262726272727262626262726262727262626262626262626262627272726262626262626
262727262626262727262626262626262627262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626262626262526252526
262626262626262526262626262626252526252525262525252526252626252625262625
252526262625252626252526252525252625252525252625252626262626252526252525
2525262525252526
252625252526252525252525252626252626252525252526262626252625252625262526
252625252626262626252526262525252625262626252626252625252626262626262526
262626262526262626262626262526262625262626262526262626262625262626262626
262626262626262626262626252626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262626262626262626262626262626262626272726262626262626262627272626
262626262626262626262626262626262727272627262627272626262627262626262626
262626262726272626272726262627262627272726272727272626262627272627262626
262626262727262626262626262627272626262626262726262626262626262626262626
262726262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626252626262626262626262626262625
262626262626262626262625262626262626262625262526262626262626252626262626
262626252626262625262526252625252626262526262626262526252626252526262525
252526262626262525252626252625252526252525252526262625262626252526252625
2525252525262526
252625262525262525252525252525252526252526262525262626262625262626252626
262626262526252526262625262526262626262525262626252526252526262626262626
262626262625252626262626262626262626252626262626262626262626262626262626
262626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627262726272626262726262626262626262727262626262726
272626272626262726262626262626262626262626262626262627272626262727262626
262627272626262626272626262727262626272726262626272726262626262726262626
262626272627272726262626272727262626262626262626272626262726262626262627
262626262626262626262626262727262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262625262526262625262625262625252625262625262626262526
262625262626252626262626262526262526262526252625252626262526252625252526
262625252526252526262526252525262526262526252526262525252525252525252525
2526262526262525
252626252525252526252525262625252526252525262626252525262526262626262626
262526262625252526262526252526252525262626252526262626252626262526262626
262525252625252525262625262526262626262526262626262526262626262626262626
262626262626262626262626262626262626252626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262627
262726272627262626262727262626272627262626262626262627272626262626272626
272626262727262626262627262726262727262627272626262726262627262627262726
272727262727272626262627262726262627262626272726262627262626262626262626
262626272626262626262626262626262626262626262626262726262626262626262626
262526262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262626262626262626262526252626252625262526
252526252626262626262626262625262626252526262526262626262526252625252526
252525262525252525262626252625262525262525262625252525252525252626252625
2525252625252525
252626252526262525252526262625252525252625262526262625262626262626262625
252526262626262525262626262625262626252625262625252626252526262626262626
262626262626262626262526262626262626262625262626262626262626252626252625
262626262625262626262526252626262626262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262626262626272626262626
262626262626272726262626272626262627262626262626262626262626262626262627
262626262627272627262726262726262626272627262726262626272627272727272627
272627272727272627262626262627262627262726262726272626262626272727272627
262627262626262627262726262727262726262727262726272727262726262626262627
262626262626262626262626262626272626262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262625262626262626252626252625262625262626262626262625
262626262626262626262526262625252526262526252526252626252625252625262525
262625252626252626252626252625252626262526252625252526252625252626262526
2526252525252526
262525252525252626262525252526262525262525252526252625262625252626262525
262626252626252626252526252625262525262626262625262625252626262525262625
262626262626262626262626262626262526262626262526262626262626262626262626
262626262626262526262626262626262626262625262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272626262726
262626262626272727262626262627262626262626262626262626262627262626262627
272626262726272727272726262726262626272626262726272626272626272627262726
272727262726262727272626272727272627272627272727272627262727272726262727
262626262627272727272726262727262726262627262626262626262626262726262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
262626262626262526262626262625262626262626262626262626262626262626262526
252625262625252626262626262626262525262525262626252626262626262526262525
262626252625252526262526262626262626252525262525252525252525252525252525
2526262525262525
252625252525252625262626252626252526252626262526262626252526252526252525
252625262526252525262626252625262625262625262626252625252625252626262626
262626262626262626262626262626262626252626262626262626262626252526262626
262626262626262626262626262626262626262626262626262626262626262C29262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262627262626262626262626262626262626262626262727262726272626262626
272627272627272626262727262626272626272726272727272627262727262726272627
272727262727262626262727262727262727272727262627272726262627262727272627
272727272626272726262726262727272626272626262626262726262626262626262627
262626272626262726262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262625262626262626262626262626262626262626
262626262526262626262625262626262626262525262525262625252626262626262625
252625262525262526262525252525252625252525252626262526252526262525252526
2526252525252526
252625252525252625262625262625252525252526252525252625262625252626252526
262526262626262526262625262626262625262626262626262526262525262626252526
262626262525252626262626262526262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262F2C262626
262626262626262626262626262626262626262626262626262727262626262626272626
262626262627262626262626262726262626262627262626272726262626262726262626
272626262626262726272727272627272727272627272727262726272627262727272626
272727272726262726272727272727272727272627272627272727272627272726272727
262727262726272727272727262727272626262627262726272726272726272727262626
262626272726262626262626262626262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262626262625262626262626262626252626262626262626262626
252626262626262625262526252625252626262526262625252526262626252525262625
262525252526262526262526262626252526252625262526262625252526252526262525
2525262525262525
252626262625262526262625252525252625262525252526262525252525262525262526
262525262626262625252625252525252625262625252526262526262626262625262625
252626262625262525252626252626262626262626262625262626262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
272626262626262626272626272626272627262726272626262727272627262626262626
262627272726272726272726262726272727272626272726272727272627262627262627
272727272627272627272726272727272727272626272626272727272727272727272727
262727272727272726272626272626272727262726262727272727272726272626262727
262626262726262626262626262726262626262626272627262626262627262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626252626262625262626262626262626262626262626262625262626
262626262625262526262626252526262626262625252625262626252525262625252626
252525252625262526252525262525262525252525252525252625262526252525252625
2526252525262525
252625262526252525252526262526252625262625262525262625252525252626262626
252525262626252525252626262526262626262526262626252625262625262626262625
252626262626262625262625262525262626262626252526262526262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262726262626262626262626
272627262627262627262627262726262626262727272627262727272726272626272627
272726272727272727272727262626272727272727262627272727272726272727272727
272726272627272727272727262727272727272727272627272727272727272727272727
272726272627272727272626262726262627272726272626262727272626262727262626
272726262626262626262627262626262626262626262626262626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252526262626262526262626262526262526262526262626262626
262626262626262625262526262626262626252626262626262526252626252626262626
262526252525252526262525262625252625262525252625252526252625262526252625
2625252625252525
252625252525252525252525252625252526262525252626262526262526252525252526
262525262525262526252526262526262626252626262526262626252626262526252626
262626262626252626262626262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262627262626262626262626262627262626262626262626262626262626272627
262626262627262726262626272627262626262626272626262727262726262626262726
272726272627262627272726262726262627272726272727272727272727272727272727
272726272727272727272727272727272727272827272726272727262727262726272727
272727272727272727272727262727272727272627272727272627272627272627262626
272626262726262726272626262626272626262626262626262727262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262625262626252626252625262526262626262526262526262526
262525262525252626262525252525252625262525252625262525262526262526262625
2525252525262526
252625252525252626252626262525252626262525252526252626262626252625262526
252526262525262626262526252525262626252625262626252626252526262626262626
262625262626252625262626262626262526262626252626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627272626262626262627262626262626272626262626262626
262627272627262727262727272627262726272626262627272627272627272727272726
272726262727272726272627272627272727272727272727272727272727272727272627
272726272727272727262727272727272727272727262726272727272727272727272727
272727272726272727272726272726262727262627272726272727272627262727262626
262626272726272626262627272726262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262625262626262626262525
262626262626252526262626262626262626252626262526262625262626252625262526
262626262625252525252525262525262526262526262625252525252525252526252525
2525252525252526
252525252525252625252626262625252626252526252526252626252526262526252525
252526262525252626262626262625252625262625262526262526262625262626252626
262625252626262626262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262626262626262626262626262626262627
262626262626262626262726272627262626262626272726262626262627262627272726
262626262626272627272626272626272727272727272726272726272627272627272726
272727262627272627272727272727272727272727262727272727272727272727272727
272727272727272727272727272727272728272727272727272727272727272727272727
272727272727272727272727272727272727272727262626272727272627262626262627
272627262626262727262626262626262626262726262626262626262626272626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252625262626262626262626252626262525262526262525262526
262626252626262626262526262625262526252625262525262626262626252525262526
262626262626252526252525252526262525252625252626262525252525252625252526
2525262525252626
252625252526262525262626262625252626252626262625252625252626262526262625
252525262626262626262526262525262626262625262525252626262626262626262626
262626252626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
262626262726272626262626262626262627262726262626262626272626262627272627
262727262727272626272726272726272726262727272726272627272727272727272727
272726272727272726272727272727272727262727272727272727272727272727272827
272727272727272727272827272727272727272727272727272727272727272727272727
272727272727272727262727272727272727272627262727262727272727272727272627
262726262727272626262626272626262726262626272626262626262626262626272626
262626262626262626262626262626262627262626262626262626262626262626262626
252626262526262626262626262626262626262626262626262626262626262626262526
252626262626262526252625252526262626262625262626262626262626262625262625
262625252626262526252626262626252625262526252626262526262525252525252626
2525252625262525
252625252526262525252625262625262626262526262626262526262626262626262626
262626252525262625262625262626252626262526262626252625252626252626262626
262626262625262626262626262626262626262626262526262626262626262626262626
262626262626262626262626262626262626262626262626262626272626262626262626
262627262626272627262626262626262727262626262626262626272627262726262626
262626262627262727262727262727272627272626272627272727262727272727272627
272727272727272727272727272727272727272727272727272727272727272727272727
272727272828272727272727272727272727272727272827272727272727272727272727
272727272727272727272726272627272727272727272727272726272627272727272727
272727262726272727262726272626262726262626272626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262625
262626262626262625262626262626262626262626262626252525262526262625262626
262525262526252526252626262525252525252525252525262626262626252626262625
2525252525252525
252626262626262525252526252525262526252626262626262525252526262626262526
262626262626262626262626262625262626262526262625262526252526252626262626
262625262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262627262727272726262626
262627272627262626262727272727272727272627272727272727262727272627272727
272727262727272727272727272727272727272727272727282727272727272727282727
272727272728282727272727272727272727272727272727272727272727282727272727
262727272727272727272728272727272727272727272727272727272727272727272727
272727272627262726262626262627272627262726262627262726262726262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262526262626262626262526262626262626262626262626262626
262625262626262526262626262625262526262625262626262626262625262526252626
252626252626262625252626262626262526262625252525252526252626252626262525
2526252625262525
252625252525252525262626262525262626262525262525252525252525262626252626
262526262525262526262525262526262525262626262526262625262526262626262625
262626252626262626262626262626262626262626252626262626262626252625262626
262626262626262626262626262626272626262626262626262626262626262626262626
262726262626262626262626262626272727262726262726262626262626272726262627
272726272727272626262726272727262726272727272727272727262627272727272727
272727272627272727272727272727272727272727272727272727272727272727272728
272827272727272727282727272728272727272727272728272827272727272727282727
272727272727272727272727272727272727272727272727262727272727262727262727
272627262726272726262727262627272727262626262727262626262626262627262626
260026262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262626262625262625262526262626262626252626
252626262626262626262525262626252626262626252626262625262626262526262525
262625262526252526262526262525262525252625262525262626262525252525252525
2525252625262626
252626262626262525262625252526262625252626262626262626262526252626252626
252626262526262626262626262626262625252626252626262626262626252626262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272626262626
262626262726262626262626262626262626272727272627272627272626262627272727
272726272626262727272627272627272726272727272727272726262727272727272727
272727272727272727272727272727272727272727272728272727272727272827272828
282728272828282728272728272727282827272828272827282728272828272827272827
272727272728272727272728272828272827272727262727272727272727272726272627
262727272727262727262626272626262726262626262626262626262626262626262626
262426262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
252626262626262626262626262626262626252626262625262626262626252625252625
262625252526262626262625262625262526252525262526252626252626262626262525
2526262626252625
252526262525252526252625262625252525262625262525262625262626252625252525
262525262525262626262626262626262626252626262626262626262626262626262626
262625262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626272627272626262626
262626262626272626262626262726262627262727262626262626272726262626262626
262626272727272627272727272727272727272727272727272627272727272727272727
272727272727272727282727272727272727272827282727272828272727272727272727
272728272727272828282827282727272827282828282728272827272728282728282727
282827272828272727282727272727272727272727282727272727282727272727272627
272627272727262626262726272627262627272627262627262627262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262526252626262626262626262626262626262626262626262526
262626262625262526262626262625262526262625262625262625262526252625262526
252626262526262626262526252626252525262625252625262526252625252526262525
2625252526252525
252626262526252526252525262525252626262626252526252625262626252525262525
252526262625262625262626262626262526262626262626262626252625262626262626
262626262626262626262626262626262526262626262626262626262626262626262626
262526262625262626262626262626262626262626262627262626262626262627262727
262626262626262726272627272626272727262726262626262726262627272727272726
272627272627262727272727272727272727272727272726272727272727272727272727
282727272727272727272728272727272727272828282727282727282827272727282828
272728282827282728272828282728282828282828282828282728282828282727272827
282828282827272828282827272727272728272727272727272727272727272727272727
272727272627272627272726272727272626272727272727262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262626262625252625262626252626262626252625252526252625
262526262625252525252625262625252525262525252525262525252525252525252526
2526262526252526
252625262526262626252525262525252526252626252526262526262626252625252625
262626252525252626262626262625252526262626262626262526262626262626262626
262626262626262626262626262626252626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262727262626262726272726
262626262627262626272626272726272626272726272727272627272626262726272727
272726272727272627262727272727272727272727272727272727272727272727272727
272727272727272827282727272827282728272828282727272828282728282828282828
282827282828282827282828282827282828282828282828282728282828282828282827
282827282827272828272827272727282727282728272827272728272727272727272728
272727272727272727272727262627272727272726262626262626262727272727262726
262626262626262626272626262626262626262626262626262626262626262626262626
262626262626262626262625262625262626262626262626262626262626262626262626
262626252526262626262626252625262626252626262525252626262626262626262526
252525252626252526252626262526262625262625252626262525262625262625252526
2526252625252626
252525262525252525252525262526252525252626252625262626252525252626262526
262625262525252626262625262626262626252626262526252626262626262626262626
252626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626272627
262727262726262626262626262627262726262626262727262626272727272626272827
272626272627272726272727272727272827272727272727272727272727272727272727
272727272727272827272828282828282728282728282828282828282828282828282828
282828282828282828282828282828282828282828282828282928282828282828282828
282828282727282728282727272727272827272727272827272727272727272727272727
272727272727262727272727272727262726272726272727262626272726262726262627
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626252626262626262626262625262626262625252625252626252626262626262526
252626252626252525252525252526262626252625262526262525252526252625252625
2525252526252626
252625262526252626262625262626252626252526252625262526252626262625262626
262526252626262626262626262526262626262625262626262625252626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626262726262626262727
272726262627272627262627262627262627262627272726272727262627272727272726
272727272727272727272727272727272727272727272727272727272727272727272827
272827272827282728272827282828282828282728282828282828282828282828282827
272828282828282827282829282828282829282928282828292829282828282828282828
282827282828282828282828282827272827282727282728272728272827272727272727
272727272727272727272727272727272726272726262627262726262727262727262626
262626262626262626262626262626262626262626272626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262626252626252626262626262626252525252626262626262626262526
262626262526262626252625262525252625262626262526252526262526262525252526
2626252525262625
252625252625252526252625252525252525262526262625252626262525262526252626
262525262525262626262626252626262626262625262626262626262626262626262526
262626262625262626262526262626262626262626262626262626262626262626262726
252626262626262626272626262626262626262626262626262726262626262626262626
262626272626272627272727262627272727272726272727272626272727272727272627
272727272627272727272727272727272727272727272727272727272727272728272727
282828282728282827282828282828282828282828282828282829282828282829292828
282828282928282829282829292829282929282929292829282828292828282828282828
282828282828282828282728282827282827272828272728282727272727272727272727
272727272727272727272727272727272727272726262727272627272626262626262626
272626262626262726262726262626262626262627262626262626262626262626262626
262626262626262626262625262626262626252626262626262626262626262626262626
252626262526262626262626262526262626262626262626252525262625262626262525
262626252626262525252626262626252626262525262625252625262525252526262625
2525252525262525
252625252626262625252526262525262526252626262626262626262626252626262626
262526262626262626262625252625262625262525252526262626262526262626262526
262626262626262625262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262726272626262626272626262626262726
272727272726262727262627262726272726272727272727272626272727272727272727
272727272727272727272727272727272727272728272727272728282727272728282827
272828282828282828282828282828282828282928282828282828292828292828292829
282929292928292929292929292929292929292929292929292828282928282928292829
282828282828282828282828282728282828282828282827282827282728272827272727
272727272727272727272727272627272727272627272727272626272627272626262626
272626262627262627262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625252626262526262626262626262626252625262626262625262626252526262526
262526252626252525262625262625262525262625252525262525262525262625262626
2625252625252526
252625262526252626262626252525262625262526252626252625252525252626262526
252626262526262526262625252626262626252626262626262626262626262626252626
262626262626262626262625252626262626262626262626262626262526262626252626
262626262626262726262626262626272626262626262727262626262726272626262726
262627262726272727272727262627262727272627262727262626272727272727282727
272727272727272727272727272727272728272728272728272728272728272828272728
282828282828282828282828282828282828282829282828292929282828292929292929
2929292929292929292A292929292A2A2929292929292929292929292929292929292929
292928282828282828282828282828282828282828272828272827282727272728282727
272728272727272727272727272726272727272727272727272727272627272726262727
272627272726262626262626262627272626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262625252626262626262626262626262625262625262625262626262626262625
262525262626252625252625262626252626262526252625262625252526252525262626
2625262526262625
252626262626262526252626252626262526252626252626252526262525262526262626
252626252526262626262626262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262627272626262626262626262626
262626262626262626262626262627272627262626262626262727262626272727262726
272626262727272726272726262627272726272727272727262727272727272727272727
272727272727272727272827282727272827272728282828282727282828282828282828
282828282828282728282828282829282929292829292929292929292929292829292929
292A29292A292A292A292A2929292A29292929292929292929292A292929292929292829
292929292928282828282829292928282828282828282828282827282827272728272728
272728272727272727272727272727272727272727272727272727272627262726272726
272627262626262626272626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262526262626262625262626262626262626
262626262626262626262526262626262626262626262526252625262626262526262626
252625262625262626262625252625262525252526262526262525252625252526252626
2625252526252525
262625262626252625262626262626252525262625262626252526262625262626262625
262626252526262626262626262626262626262626262626262526262626262626262626
262626262626262626252626262626262526262626262626262726262626262626262627
262626262626262626262626262626272626272626262627262626262726262626262626
262626262627272726272726272726272626272727272727272727272727272727272727
272727272727272727272827282727272727272827272727282828282828282828282828
282828282828292928292828282929292929292929292929292929292A292929292A2A2A
2A2A292A2A2A2A2A292A2A2A2A2A2A2A2A29292A2A2A2A2A292A2A2A2A292A2929292929
292929292929292929292829292928292928282828282828282828282828272827272728
272727272727272727272727272727272727272727272727272727272727272626262727
262627262726262626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626252626262526262526262626262626262526262626262626262525262626262626
262626262626262625262626252625252626252526252625252525252525252626262526
2626252625252526
262626252526262526262626252625252626262526262626252626262625252626252626
262525262625252625262525262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626262626262626272626262726262626262627272627272627262626
262627272726272627272627272726262727262727272727272727272727272727272727
272727272728272727282828282828282827272828272828282828282828282828282828
2928282828292828282928292829282929292929292A292A29292A2A2A2A2A2A2A2A2A2A
2A2A2A2A2A2B2A2A2A2A2A2A2A2B2A2A2A2B2A2A2B2A2A2A2A2A2A2A2A2A292A2A2A2A29
29292A2929292A2929292928292929292928292828282828282828282828282828282828
282827272828272727272727272828272727272727272726272627272727272727272626
262727272626272726272726262627262626262626262626262626262626272626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626252626262626262626252626262626262626262526262626252625262626262625
252526252526262525262625262525262626252625252526262526262625252625262525
2525262626252525
252626252526262525262626252626252626252525262626262525262625252525262626
252625252626262526252526262526262626262625262626262626262626262626262626
262626262626262626262626262625262626262626262626262626262626262627262626
262726272626262626262626262626262726262627262726272626272727272626262726
272627262626262727272726272727272727262627272727272727272727272727272727
272727272727272727272728282828282828282727272828282828282828282828282828
282929292829292929292A29292929292A292A2A2A292A2A2A2A2B2A2A2A2A2B2A2A2B2A
2B2B2B2B2B2B2B2A2B2B2B2A2B2B2B2B2C2B2B2A2B2B2C2B2B2B2B2A2A2A2B2A2A2A292A
2A2A2A292A292A2929292929292929292829292929292828282829282829292827282828
282828272827272728272727282827272727272727272627272727272727272727272727
262726262626272726262626272627262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262526262625252626262526262526262625262525252625252525
252526252625252625262626262626262525262626252626252625262625252626252525
2526252625262626
252625252526252526262526262526262626262625252626252525252626252626252625
252525252626262626262626252626262626262626262626262626262626262626262626
262626262626252626262526262626262626262626262626262626262626262626262626
262626262626262626262626262726262627262627262726262627262626262626262626
272727262627272727272627272727272727262727272727272727272727282727272728
272827272728282827272828272828282728282828282828282828282828282828292929
2929292A29292929292A292A2A2A292A2A2A2A2A2A2A2B2B2B2B2A2B2B2B2C2B2B2C2B2B
2B2B2C2B2B2B2C2C2B2C2C2C2B2C2B2C2B2B2B2C2C2B2C2B2C2C2B2B2B2B2B2B2B2B2A2A
2A2A2A2A2A2A2A2A29292A292A2A29292929292929292928292829292928282828282828
282828282828282827272727272727272727272727272827272727272727272727262727
262627272726272626272626262626262627272626262627272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262526262625262626262626262526262626252625252625262626262626262626
262526262626262526262525252526262526262625252626252625262626262626252625
2526252526252625
252526262626252625262525252526262625252626262626262626262526252626262626
252626262626262525262626262626252626262526262626252626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272626262626262726262626262726262627272727272626272626272627
272727272727262727272726272727272727272727272727272727272727272728272727
272727272727272828282828282828282828282828282829292928282829292929292829
292928292A2A2A2A2A2A2A2A2A2A292A2A2B2A2B2B2B2C2B2B2B2C2B2C2C2C2C2C2C2C2C
2C2C2D2C2C2C2C2C2C2C2C2C2C2D2C2C2C2D2C2C2D2C2C2C2C2C2C2C2C2C2C2C2B2C2C2C
2B2B2A2B2B2B2A2A2A2A292A2A29292A292A292929292929292929282828292828282828
282828282827272728282827272827272727272727272727272727272627272727272727
272627262727272726272726272727262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262625262526262626262626262626252626252626252526262626
262625262626262525262626262625262626252525252625252625252526262525252625
2526252526262525
252626252525252525262526252626262626262526252526262625262626252525262626
252625262626262626262626262626262625262626262626262626262626262626262626
252626262626262625262626262626262626262626262626262626262626272626262626
262626272626262626262626262627262627272626262627262627262726272627262727
272727262727272727272727272727272727272727272727272727272727272727272728
272728282828282828282828282828282828282929282928292929292929292929292A29
2A2A292A2A2A2A2A2B2A2A2B2B2B2A2C2B2B2C2C2B2C2C2C2C2C2C2D2C2D2D2D2D2D2D2D
2D2D2D2D2D2D2E2D2E2E2D2D2E2E2E2E2E2D2D2E2D2D2D2D2D2D2E2C2C2D2D2C2C2C2C2C
2C2B2B2C2B2B2B2B2B2B2A2A2A2A2A2A292929292A2A2929292929292929282928282828
282828282828282828282828282827272727272727272727272727272627262727272727
272727272726262727272627262627262626262627262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626252626262626262626262526262626252626262626262526262626262525262626
262526262626252626262626262626262626252625262526252626262526262626252626
2526262526252525
252626262626262626262526262625252626262626252626262626262526262626262626
262626262626262626262526262626262526262626262626262626262625262626262626
262627262626262626272626262626262626262626262626262726262626262626262626
262626262626262626262626262626272626262626272627262627272627272727262727
262727272727272727272727272727272727272727272727272727272827272727272827
272828282727272828282828282828282929282829292A292929292929292A292A2A2A2A
2A2A2A2B2A2B2A2B2A2B2B2B2A2B2C2C2B2C2C2C2D2D2D2D2D2D2D2D2D2D2D2E2E2F2F2E
2E2E2E2E2E2E2E2E2F2E2F2F2E2F2F2F2F2F2F2F2E2E2F2F2E2E2E2E2E2E2E2E2D2D2D2D
2D2D2C2C2C2C2B2B2C2B2B2B2B2A2A2B292A2A2A2A2A2A2A292A29292A29292829282928
282828292828282828282828272828272728282728272827272727272727272727272727
272727272727272727272727262627272626262726262626262627262626262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626252626262626262626262626262625262625262526
262626262526262625262626262525262625262626252626262525262525252625262526
2525252526262626
252625262625262625252626252526262525262625262625262526262625252625252626
262626262626262626252626262626262526262526262626262626252626262626262626
262626262626262626262726262626262626262626262626262626272626262626262626
262626262626262626262726262726262626262727272627262726272727272727272727
272627262727272726272727272827272727272727272727272728272727272727282727
2727282827282828282828282828292929292929292A292A2A292A2A292A2A2A2A2A2A2B
2A2A2A2B2A2B2B2C2C2B2C2C2C2D2C2C2C2C2D2D2D2D2D2E2D2E2E2E2E2F2F2F2F2F302F
30303030302F3030303030303030302F3130303030303030302F2F2F302F2F2F2E2D2D2E
2E2E2D2D2D2D2C2C2C2C2B2C2C2C2B2B2B2A2B2B2A2B2B2A2A2A2A2A292A292929292929
292928282828282828282828282827282728272728272727272727272727272627272727
272727272727272727272627272627272627272626262626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262526262626262626262626
262526262625252626252526252626252626252626252625252525252525262525252625
2626262525252625
252626252626262625262526262625262625262525252626262526262626252625262626
262626262626262626262625262626262626252626262626262626262626262626262626
262626262626262626272626262626262626262626262626262626262626262626262626
262726272627272726262626262626262727262727262726272627272627272727272627
272726272727272727272727272727272727272727272727272727272728272828282728
2728282828292828282828292829292929292A29292929292A2A2A2A2A2A2A2B2B2B2B2B
2B2B2B2B2B2B2C2C2B2C2C2D2D2D2E2D2D2E2E2E2E2F2E2F2F2F2F303030303031313030
31313031303131313231313131323132313232323131313131303130303131303030302F
2F2F2F2E2F2D2F2D2D2C2C2C2C2C2C2C2B2C2B2B2B2B2B2B2B2A2A2A2A29292929292929
292929292828282828282828282828282828282727282727272727282727272727272727
262727272727272727272627272626272727272627262626272626262726262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262526262626262625262626262626262626262626
262625252526262626262626252626262525262626252626262525252526252525262626
2525262525252526
252626252626252625252526252525252626262626252626262626262626262626262626
262626262526262625262526262626262625262626262626252626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262726262626262726262627272626262626262626272627262727272627272626272727
272727272727272727272727272727272727272728272727272728272727272828282828
282828282828282829282929292929292A292A2A2A292A2A2B2B2B2B2A2B2B2B2C2C2C2B
2C2C2C2C2D2D2C2D2D2D2D2E2E2E2F2E2E2F2F302F2F2F30303031303131313132313232
323232323332333232333333333233333333333433333332323232323231313231313130
303030302F302E2E2E2F2E2D2D2E2D2D2D2C2C2C2B2C2C2C2B2A2B2B2B2B2A2A2A29292A
292929292829282928282928282828282828282827282828272727272727282727272727
272727272727272726272727262627272626262627272727272626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626252625262626262626252626262626262626252526252526
262526262626262626262526262625252626252625252626262626262526262526262526
2626252525252525
252625252526262526262626252626262626262526262625262626262626262626252626
252526262626262625262626262526262626262626262626252626262626262626262626
262626262626262626262626262626262526262626262626252626262626262627262726
262626262626272626272626262627272627262627272727262627272726272727272727
272727272727272727272727272727272727272727282828272728272828282728282828
282828282828292829292929292A2A2A2A292A2A2B2B2B2A2B2B2B2B2B2C2C2C2B2B2C2C
2D2D2C2D2D2E2E2D2E2F2E2E2F2F2F2F3030302F2F303130313132323232333233333333
323333343434333435343335353534353434353434343434353334343432333333323232
3232303030313030302F2F2E2F2F2E2D2D2D2D2D2C2C2C2C2D2C2C2B2B2B2A2A2A2A292A
292929292929282928292929282828282828282828282827272728282727272728272727
272727272727272727272726262727272727262626272627262626262627262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626252626262626
262625262626262626262625252526262626262525262626252525252525252625252625
2525252626262525
262626252626252625262526252526252525262625262626262625252625262626262526
262626252626262626262626262626262526262626262626262626262626262626262626
272626252626262626262626272626262626262626262626262626262626262726262626
272626262627262626262726262727262726272727272626272626272727262727272727
272727272726272727272727272727272827282827272827282827282828282828282829
282928282829282929292A29292A2A2A2B2A2B2B2B2A2B2B2B2B2C2C2D2C2C2C2D2C2C2D
2D2D2D2D2E2E2E2F2F2F2F30302F30303030303131313132323332323333343334343434
343535353535363635363636363736353636363636373636363535353636353635353434
343333333232313131313030312F302E2E2E2E2E2E2D2D2C2C2D2C2C2B2B2B2B2B2A2B2A
2A2A2A2A2929292929282828282828282828282828282728282827272727272727272727
272727272727272727272727272726262727262627262727272627262627272627262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252625252626262626262626262626252625262626262626252626262526
262525262626262526262526262626262626252625252526252625252626252526262525
2526252625262626
252626262626252625252526252525262626262626262626262626262625262625252626
262626262626252626262626262625262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262626262626262627262626
262626262626262626272626272727262727272627262627272727272727272727272727
262727272727272727272727272728272727272728272728282728282828282828292828
28282829292A2A292A2A2A2A2A2B2A2B2B2B2B2C2B2B2C2C2D2C2C2C2C2D2D2D2D2E2D2E
2E2E2E2F2E2F2E2F30303030313030313132323232323234343335343435363535363637
353737373738383737373938393837373838383937383838383938373838383737363737
3635353434343333333332323130313030302F2F2F2E2E2E2D2D2D2D2C2C2C2C2C2C2B2B
2A2B2A2A2A29292929292929292828282829282828282828272827272727282827272728
272727272727272727272727272727262727272727272627262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262626262626262626252526262626262525262626
262626262626262626262526262626262625262525252626262526262526252625252626
2625252525252626
252625252625252525252526262525262625262626262626262625262626262626262626
252626262526262526262525262626262626262626262526252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627272726262727272726272727262727272727262727272727272727272727
272727272727272727272727272727272728282827272827282828282828282828282929
29292929292A2A2A2A2A2A2B2B2A2B2B2C2B2B2C2C2C2C2D2E2D2D2D2D2D2E2D2E2E2E2F
2F2F2F2F3030303031303131323232323334343434353535353535373636373839383838
3A3A3839393A3B3B3A3A3A3A3A3A3A3A3A3B3A3A3B39393B3B3A3939393A393939383938
3738373636363535353334343333323130313030302F2F2F2E2E2E2D2D2D2D2C2C2C2B2B
2B2B2B2B2B2A2A2A2A2A2929292929292828292828282828282827282828272727272827
272727272727272727272727272727272727272726262727262726272626262627262626
262626272626262626262626262626262626262626262626262626262626262626262626
262526262626262626262626262526252626262626262526262626262626262626262626
262626252626262626262525262525252526262525252626262626252625252526262625
2525262626252626
252625262626262625262526252625262626252626262526262626252626262625252626
262626262626262625262626262626252626262626252626262626262626262626262526
262626262626262626262626262626262626262626262626262726272626262626262626
262626262626272726262727272726272727272727272727272626272727272727272727
272727272827272727272727272727272727272728282828282828282829282928282929
29292A29292A2A2A2A2A2B2B2B2C2B2C2B2C2D2D2D2D2D2D2E2E2F2F2E2F2E2F2F2F3030
30303030313131323232333333333534353635363636373739393939393B393B3B3B3C3D
3D3D3C3C3D3D3D3D3E3C3D3B3D3D3E3D3E3D3E3D3D3D3D3E3C3D3C3C3B3B3A3B3B3B3A39
393939393839373837363635353434343332323131303030302E2F2E2F2E2E2E2D2C2D2C
2B2B2B2B2B2B2B2A2A292A29292929292929292928282828282828282828272828282827
272727272727272727272727272727272727272727272727272726272726272626262726
262626272726262626262626262626262626262626262626262626262626262626262625
262626262626262626262526262626262626262626262626262626262626262526262626
262525252626252526262625252626262625262525252625262525252526262525252626
2626262626252626
262626262526252626252526262526262626262626262625262526262626262626252625
262626262626262625262626262525262626262626262626262626272626262626262626
262626262526262626262626262626262626262626262626262626262626262626262627
272726272626272626262726272726272727262726272727262727272727262727272727
272727272727272727272728272727282728282828282828282828282828282929292929
292A2A2A2A2A2A2A2B2B2C2C2C2C2D2D2D2D2D2D2E2D2E2D2E2E2F2F2F2F303030313131
313232323333323434343435363637373737373839393A3A3B3C3C3C3C3D3E3D3F3F413F
3F41403F414141414241414140414241414041424040403F403F3F3F3F3E3E3E3D3C3C3D
3C3C3D3B3C3A3A39383738373736363534343333333332313231312F2F2F2F2F2E2E2D2E
2C2D2D2C2B2B2B2B2B2A2A2A2A292A292929292929292929282828282828282827282827
272828272727272727272727272727272727272727272627272627262726272726262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262625262626262625252626262626
262626262626262626262526262626262626252626252526262625262626262626252625
2626252626252525
252625262626262626262526262626262526262625262525262626262626252626262626
262626262526262626262626252626262626262626262626262626262626262626262626
262625262626262626262626262626262626262726262626262626262626272626262626
262626272627272626272727262727272727272727272727272727272727272727272726
272727272727272727272728272727282828272828282828282829292828292929292A2A
2A292A2A2A2B2B2B2B2C2C2B2C2D2D2D2D2E2E2E2E2E2E2F2F302F2F2F30313132323332
3333333435353536353636383839383A3A3B3B3C3D3D3E3E403F41424242434345454546
47464646474547484747464646464647464646444545454445444444434140414141413F
3F3F3F3E3E3D3D3B3C3B3B3939393838373735353634333332323131313030302E2F2F2D
2D2D2D2C2D2C2C2C2C2B2B2B2A2A2A292A29292929292928292828282828282828282828
272727282827272727272727272727272727272627272727272727262726272626262626
272626262626272726262626262626262626262626262626262626262626262626262626
262626262626262625262626262626252626262626262626262626262626262526262626
262626262626262626262625252525262525262526252526262525252625262626252626
2525262526252526
252625262526252626262625262626252626252626262626262525262626262626262626
262626262626262626262626262526262626262526262626262626262626262626262626
262626262626262626262626262626252626272626262626262626262626262626262626
272627262726272727272627272626272727272727272727272727272727272727272727
27272727272727272728282827282828282828282828282828292829292929292A29292A
2A2B2A2A2B2C2C2B2C2C2D2D2D2E2E2E2E2F2F2E2E2F2F30313131323132333334343435
353436363738383739393A3B3B3C3C3D3E3F3F404242444548464848484A4B4C4D4D4D4E
4D4F50504E4F514F504E4E4E4D4E4E4D4E4E4D4D4D4B4C4A4A4949494847464645444443
4343424241403F3F3D3E3D3D3C3B3A393938383836363636353433333231323130312F2F
2F2E2D2D2D2D2C2C2C2B2B2C2B2A2A2A2929292A29292929292928282828282828282828
282828272828272728272727272727272727272727272727262627262726272627262626
262626272726262626262626262626262626262626262626262626262626262626262626
262626252626252626262625262626262626262626262626262626262626262626262626
262625252526252625262626262626252626262525262626262626262625262526252625
2625262526262626
252625252625252525262625262526262625262626262626262626252626252625262626
262625262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262726262626262626262626262627262626262626
262727262726272726272727262727272727272727262727272727272727272728282728
2727272827282728282828282828282828282928292929282929292A2929292A2A2A2A2A
2A2B2B2A2B2C2C2D2C2D2C2E2E2E2F2E2F302F3030303231323233333233343534363637
363738373A3A3C3B3C3D3F3E3F40414344444545474948494B4D4C4C4D4E4F5051525453
545354555757575656565759585558585758595757575355545450514E4E4C4E4C4B494A
48474645444442424040403F3E3E3D3C3C3B3A3A39383837363736353333333232323130
30302E2E2E2D2D2D2D2C2C2B2B2B2B2A2A2A2A2A2A2A2929292929292829282828282828
282828272728282727272727272727272727272727272727272626272726272727262727
262627262627262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626262626262626252626262626262626
262626252626262625262625262626262626262625252626262625262626252525252626
2626252525262525
252625262626262626252626262626262526262626262626262626262626262625252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262726262626262626262626262626262726
262626262727262727272727272726272727272727272727272727272727282727272727
2727272727272828282828282828282828292828292929292A2929292A2A2A2A2A2B2B2B
2A2B2C2C2C2C2C2C2E2D2E2D2E2E2F30303030323232323333333434343536363839393A
3A3B3C3C3D3F3F404242434344444547464949494A4B4A4D4D4F4E4F5051525252545456
56575757585A5A5A5B5C5C5C5D5E5E5D5E5F5F605F5E605F605D5D5B5A57565456545250
4F4C4D4B4A4947464544434142403F3F3D3D3D3B3B3B3A3A393937363735353433333232
313030302F2F2F2E2D2D2E2D2C2C2C2C2B2B2A2A2B2A2A292A2929292929292828282828
282828282728282727272727282727272727272727272627262727262626262726262627
262726262727262627262627262626262726262626262626262626262626262626262626
262625262626262626262626252626262625262626262626262626262525262625262626
262626262526262626252526252526252626262526252626262626262625262625252625
2526262626252525
252625262626262626262626262625252626262626262526262626262626252626262626
252626262626262626262625262626262626262626262626262626262626262626262626
252627262626262626262626262626262626262626262626262626262626262627272627
262726272726262627272727262727272727272827262727272727272727272727272727
272827272727282828282828282828282828292829292929292A2A292A2A2A2A2B2B2B2B
2B2C2C2C2C2D2D2D2E2E2F2F303030303132333233333434363636373839393A3B3C3C3D
3E3E414141414342444446474647484747484A484B4A4A4F4C4F50515252525254555557
56575758595A595B5D5E5D5F6061606362626365636564646563646364606160605E5D5B
5A585453504E4D4F4C4A4847464443424141403F3E3E3D3C3C3B39383837373735353434
333232313130302F2F2E2E2D2D2D2C2B2B2B2B2B2A2A2A292A2929292929292928282828
292828282828282828272827282727272727272727272727272727272727262627272726
272627262726262627272626262726262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262526
262626262626262526252526262626252626252625262625262526262626252626262526
2525252625252525
252625262626262626262525262625262525252525252525262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262626262726262626262726262627262626262726262726262626262627262626
262626262727262626272727272727272727272727272727272727272727272727272727
2827282827272828282827282829292928292929292929292A2A2A2A2A2B2B2B2B2B2C2C
2C2C2D2D2D2E2E2E2F2F303030313131323333343535363738393B3A3B3D3D3D3F3F3F41
41424242434343454547474847484849494A4B4B4C4B4D4C4F5050515252535556545456
5756575859585A5B5D5E5E5F61606162646366646668676665686867696B696766686665
6462615D5C5958575452504C4A4A48474545434242403F3E3D3C3C3B3B3B393838383536
35343433323131302F302F2F2E2E2E2D2D2C2B2C2B2B2A2B2A2A2A29292A292929282929
282828282828272827282827282727272727272727272727272727272727272727272726
272727262726262626262627272626272626262626262626262626262626262626262626
262626262626262625262626262626262626262626252626262626262626262626262626
262526262626252626262526262626262525252626262526262526262626252526262625
2626262526262526
252626262526262626262626262626252626262626262626262626252626262626262625
262626262626262626262625262626262626262626262626262626262626272626262626
262626262726262526262626262626262726272726262626262627262627272626262627
272727272627262727272727272727272727272727272727272727272727272827272827
2827282828282828282829292829282929292A2A292A2A2A2A2A2B2B2B2B2B2B2C2C2C2C
2C2D2D2E2F2F2E2F2F30313132333232333635363839393B3C3D3E3E403F404142424241
4345444445444545474849494A494A494A4D4B4B4B4C4D4C4F4F50515152545455565555
57565959585A5A5B5D5D5E5F606162606163646765686868696B6B6C6C6B6C6C6C696A6B
6A696967656563615F5E5A5553504E4E4A4A48474645444241413F3E3D3C3B3B3B393938
3736363534333232323131302F2F2E2E2D2D2D2C2B2B2B2B2A2A2A2A292A292929292928
292928282828282828282828282728272727272727272727272727272726272727262626
262727272626262727262627262626262626262626262626262726262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262526
262626262626262626252526262625262626262626252625262626262625252626252626
2626262626262526
262625262626262626252626262626262626262626262626262526262626252626262626
262626262626262626262626262626262626262626262626272626262626262626262626
262626262626262626262626262626272626272626262626262626272726262727262627
272726272627272727272727272727272727272727272727272727272727272827282827
282828272828282828292929292929292A2A292A2A2A2A2B2A2B2B2B2B2C2C2B2C2C2D2C
2E2E2E2E2F2F302F3032323333333535363839393B3A3B3E3E3F40414142424242434445
44454546454645464948494B4C4C4B4C4C4C4C4C4C4C4D4D4E4F50535453535355575757
56575858595B5C5C5B5E5C5E5F60606061626563666869696B6C6B6D6E6F6D6A6C6E6E6D
6C6D6F6E6C6B6B6A686866645F5C585553504E4C4D4A4847464444423F3F3F3D3B3B3B39
39383737363534343332323130302F2E2F2E2D2D2C2D2B2C2C2B2A2A2B2A2A2A2A292928
292929292928282828282828282827282727282727272727272727272627272727272727
272727272626262626272726262626262727262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262625262526262626252625262625262625252626252525252625252625
2525252626252625
252626252526262626262526252626262626252626262625262626262626262625262626
262626262626262625262526262625262626262626262626262626262626262626262626
262626262626262626272626262626262626262626262626262626272626262627272726
272626272727272727272727272627272727272727272727272727272727272728272828
28282828282828282828292828292A2A2A2A292A2A2A2B2B2B2B2B2B2C2C2D2C2D2D2D2E
2E2F2F303031313232333334353637393A3B3B3B3D3F3F41404242434242444444444545
4647484747484849494A494B4C4C4C4B4D4C4C4E4E4D4F4E4F5051525254565556555857
5A585A5B5B595B5C5E5C5D5D5F5E606161626366656769696B6B6C6C6D6F70706F6E706E
6F6E72726F72706E6D6F6C6B676664605E5C595554504E4E4A48474645444240403E3D3D
3C3B3A3A393737373534343331313031302F2E2E2E2D2D2C2C2B2C2B2A2A2A2A2A292929
292929292929282828282828282827272827272727272727272727272627272727272727
272627272726272627272627262626262626272627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262525
262626262626262626252626262626262626262625252626262526262625262526252526
2626262525262526
252625262526252526262625252626262526262526262626262626262626262626262625
262626262626262626262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626272626272726262626262626262627272626
262726272727272727272726262727272827272727272728272728272827282828272827
28282828282828282929282929292A2A2B2A2A2B2B2B2B2B2B2C2C2C2C2D2D2E2E2E2E2F
2F2F303132323233333635373839383B3B3C3D3F40424141434343434445434546454546
4748484948474949494C4B4C4C4D4E4D4D4D4E4E4E4F4E50505152545354565656575957
5958595A5A5D5B5C5B5D5E5F5F60605F626363646567696A6C6B6A6C6D6F706F706E716F
7071727370716F717170706E6D6D6A6B686463615E5A585551504D4A494847444243403F
3E3E3D3B3A3B393838353634343333323131302F2E2E2E2D2D2C2C2C2B2B2B2A2A2A2A29
2A2A29292929292828282827282827282828272728272727272727272727272627272627
272627272726262627262626262726262627262626262626262626262626262626262626
262626262626262626262626262625262626262626262526262626262626252625262626
262626262626262626262626252526262626262626262626252626262626252526262626
2626252625252525
252625252526262625262626262626262626262526252525262626262626262526252626
262626262626262626262626262626262626262626262626262626262626262626262727
262726262626262626262626272626272626262626272726262626262627272626262727
272727262627272727262727272727272727272727272728272828272727282828282828
29282929292829292929292929292A2A2A2B2B2B2B2B2C2C2C2C2C2D2E2E2D2E2E2F3030
303131323334353536373739393B3B3C3D3D3F4043434243434545464745474747484849
484A4A4A4A4A4B4B4B4C4D4D4E4D4D4D4E4F4F50504F5150535255545556565657575859
595A595A5B5C5D5C5D5E5C5D605F616262626564636567696A6A6B6C6D706E7072707272
70727272727072727274717072706F6E6E6C6D696763645E5A5856524F4D4B4847464443
42413F3E3D3D3B3A39393737363534343231323030302F2E2E2D2C2D2C2B2C2B2B2A2B2A
292929292929282828282828282727282827282727272727272727272727272727272727
272727272727272627262627262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626252625262626
262626262626252626262626252526262626262625262626252625252625262625262525
2625262526252625
252626262626252526262625262526262625262626262626252626262626262626262626
262625262626262626262626262626262626262626262526262626262626262626262626
252726262626262626272626262626262626262726262627272627272627262727272626
272726272726282727272727272727272727272827272728282727282728282828282828
282828292929292929292A292A2A2B2B2B2C2B2C2C2C2C2D2D2D2E2E2F2E2F3030303032
3132343535353737383839393A3C3D3D3E3E40414343454544454547484749484948494A
4B4C4B4A4C4C4D4C4D4D4D4F4F505050505050515252525252545653555757575757595A
595B5B5C5B5D5C5E5E5E5E5F5F6061606465646463666769696A6B6B6D6D6D6F71717072
747574737272747375737473737272727271706E6B6B69686561615D595554504E4B4A47
46454242413F3E3D3B3B393A39373636343333323131302F2E2E2E2E2C2D2B2B2B2B2B2B
2A2A2A2A2929292929282828282928282728282728272727272727272727272727272727
272726272727272626262626272726262726262626272626272626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
252626262626252626262626262626262526262526262526262625252625252526262626
2625252525252525
252625262526252626262525262626262626262626262626262526262626252626262626
252526262626262626262626262626262626262626262626262626262627262627262626
262726262626262726262626262626262626272626272726262727272626272727272727
272727272626272726272727272727272727272827272828282827282827282828282829
292928292929292A2A2A2A2A2A2B2A2B2B2C2C2C2D2D2D2D2E2E2E2E2F30303131323233
34353537383738383A3B3B3B3C3D3D3E3F414142454546464746484949494A4A48494B4A
4C4C4C4B4C4C4E4F4E4E504F515051525151515354525354555554555656585559575958
5A5B5C5C5B5C5C5E5E5E5F6062626163636365656668686A6A6A6B6B6D6E6F7170717271
74747474747474767474747375747572757373716E6E6E6C6B6B686665625D5B5754504F
4B494745434241403F3D3C3C3A3A38373635343433323130302F2F2D2D2D2D2C2C2C2C2B
2B2A2A2A2A2A292929292829292828282828282828282828272728272727272727272727
272727272726272727262627262726262626272626272626262626262626262626262626
262626262626262626262626262626262626262526262526262625262626262626262626
262626262626262625262626262626252626262626262626262626262625252526252525
2625262626262526
252626262626262626262626262526262626262626262626262625262626252626262626
252526262626262626262626262526262626262626262626262626262626262626262627
252626262626262627272626262726262626262726272627262726272627262726272627
272727272727272727272727272727272728282827272827282828272828282828282929
28292929292A292A2A2A2B2A2B2B2B2C2C2C2D2C2D2D2D2E2E2F2E2F3030313132323436
363638383839393A3B3C3C3D3D3F403F424245464647464848484949494A4B4B4C4A4B4B
4C4C4E4E4E4E50514F505051515251505354535255535555565555555858565858575759
5A5B5C5C5D5F5C605E5F60606160616362636566676767676B696A6B6F6F6F706F707371
7372747473747675757274757574747373737372717071706F706D6D6B69686362605C55
524F4D4B4A4646434241403D3D3D3C3939383736353533323131302F2F2E2E2D2D2D2C2C
2C2B2B2A2A2A2A2A2A292929282929282828282828282827272728272727272727272727
272727272727272727262626262726272627272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626252626252525252626262626262626262625262525262526262625
2626262625252625
252626252625262626262626262626252526252625262626262526262526262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262726262626262627262726262627262627262627262626272727262726262627
272727272727262727272727272727272828272728282827282828282828292828292828
292A292A29292A2A2A2A2A2A2B2C2C2C2C2C2D2E2D2E2E2F2F3030313132333435353637
373939393A3B3B3C3C3D3E3F404042424445464847474948494A494C4B494C4A4B4B4D4D
4C4E4D4F505050515052515252525253525352535454555555575756565658575858585A
5B5B5D5A5D5B5F5D61605F61626061616463666465686869696C6A6D6E6E6C707070706F
72747373727476747476757575727576747776737474737372727370716E6D6B6A67635F
5C5A5552504C4A4746444442403D3C3C3C3A393837363534333131302F2F2F2E2E2E2D2C
2C2C2B2B2B2A2A2A292A2929292928282828282828272728282728282827282727272727
272726272727262727262627272626272627262626262626262626262627262626262626
262626262626262626262626262626262626262626262626262626262626252626262626
262625252626252525262626252626262626262626252526262626252526262625262526
2625262526252526
262625262626262526252626262626252626252526262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262726
262626262626262626262727272726272726272626272626262726272627262727272727
262727272727272727272727272728272728272728272828282828282828292929282929
29292A2A2A2A2A2B2B2A2B2B2C2C2C2D2C2D2D2D2E2F2F30303131323335353636363838
39393A3B3C3C3E3D3F3F404141424345454649484A4A4B4A4B4C4C4C4C4D4C4D4C4D4D4D
4E4F515052525353525355535253535454555455545656565656575658575857595A585A
5A5A5B5C5C5E5F5E5F5F6160616263646364656466646767696A6A6C6E6A6C6D6F707071
717271747676787877757678767575777576767576777574757573737270706E6E6C6A68
6464615B59534F4F4D4948444441403F3E3C3D3A3A393837363433323131302F2E2E2D2D
2D2C2C2B2B2B2A2A2A2A2A292A2929282828282828282828282828272727272727272727
272727272727262727272726272727262726262727262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262526262625252626262626262626262626262625262526252626262526262626
2625262625262526
252625252626262625252526252526262626262626262626262626262626252626262526
262626262626262626262526262626262626262626262626262626262626262626262626
262626262627262626262726262626262626262627262626272727272627262727272626
27272727272727272728272827272727272728282827282828282828292929282929292A
292A2A2A2B2B2B2B2C2B2C2C2C2C2C2D2D2E2E2F2F303030313233343436363838393939
3B3C3B3C3D3E3E3F404043434444454849484A4B4B4D4B4D4E4E4E4E4D4E4D4E4D4F4E50
51515252525253535354545556565656555656575556575857595A585A585A5958595A5A
5A5C5B5B5B5D5D5F6161606061616262636163646365676769676A6A6B6C6C6D6D6F706E
70727373747575777875777576757576767777767676777975767775757373747070706E
6B6A686663615C5854514E4B48444443413F3F3D3B3C3A3839373534333331312F2F2E2E
2D2D2D2C2C2B2B2A2A2A2A2A292929292929292928282828282828272827272727282727
272727272727272727272626272727262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626252626262626252625262625262625252526262526262526
2526262625262626
262526252526262625262525262526262626262626262526262626262526252626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262626262626272626262726262627272626272726272627262726272727272727
282727272727272727272827272728272727282828282828282828292829282829292929
2A2A2A2A2A2B2B2B2B2B2C2D2D2D2D2E2F2F2F303031323334343535373738383A3A3B3B
3C3D3E3E3E3E41414142444444454749494B4B4C4C4C4E4E4E4F4E504F4E4F504F505151
54535554555455535656555656565657575857565857575758575858585A5A595B595A5A
5C5B5A5C5D5C5C5E5D5F606060616262626363636465676768696A6A6B6D6D6D6D6E6F70
717371747375757477767777787876767876767674767675767576777674747373727272
72706E6B696664615F5955514D4C4847454242413F3D3C3B3A393836363433323231302F
2F2E2E2D2D2C2C2B2B2A2B2A2A2929292928292828282828282828282728282727272727
272727272727272726272726272627262626262626272726262726262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262525262625252626262626262626252526252626262526262626
2626252526262625
262626262526262625252625262626252626262626262626262526262626262626252626
262526262626262626262626262626262626262626262625262626262626262626272626
262726272627262626262727262727262626272726262626272626272727272727272727
2627272727272728272727272727272728282728282828282828282829282829292A2A2A
2A292A2A2B2C2B2C2C2D2C2E2E2E2E2F2F31303232333334363737373938393A3C3B3D3D
3E3E3F4041414243454344454647494A4A4C4C4C4E4F4E50504F50504F51515253525353
5354555554535557545757585858595A59595859575857595A59585859595C5A5B595C5A
5A5B5A5A5C5D5C5E5E5E60606262626264656465646566656667686A6B6B6D6E6F6F6F6F
71707271737476747675767977757A777777787678767978767877767574777573747274
727271726E6C6A6A66635F5B5852504D4A4845444240403E3D3A3A393837363434333130
302F2E2E2D2D2C2C2B2B2B2B2A2A29292928292828282828282828282828282827272827
272727272727272727272726272727272726262727262726262626262626262626262626
262626262627262626262626262626262626262526262626262626262626262626262626
262626262626262626262526262626262626262626262626262626252626262625262625
2625262626262525
252626252626252526262625262626262626262626262626262526262626252625262626
252626262626262626262626262626262626262626262626262626262626262627262626
262726272626262626262627262726262727262627272726272627262727272727262727
2727272727272727272727282727272828282828282829282829292929292A2A292A2A2A
2A2B2B2B2B2B2C2C2C2E2D2E2F2F2F30313133333434363537383838383A3B3B3D3D3D3E
3E41404041434545454548474849494C4C4D4D4E4F4F5051505052505151525454535455
555555555656575658585857575758595A5959595A595A5A5A595A5B5B5B5A5A5C5A5A5B
5B5B5D5B5D5D5E5D605B5E5E616160616164636665656565666665666A6B6C6F6D6E6F70
7170706F7173757576757777797A77797976777776787779777979777979777777777777
74747272747270706C696765635E5956514D4A48464343413F3F3D3D3B39383734343333
3231302F2E2E2E2C2D2C2B2B2A2A2A2A292A282828292828282828282828282827282727
272827272727272727272727272727272627262626262627272626262626262626262626
262626272626262726262626262626262626262626262626262526262626262625262626
262626262626262626262526262626262526262626262526262625262526262626252625
2526262526262526
252626262626262526262626262626262626262626262625262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262627262626262626272626272626262626272726272726272726272727272727262727
27272627272727272827272828282828282828282829282829292929292A292A2A2A2A2B
2B2B2C2C2C2D2C2D2E2E2E2F2F313131333333353536373737383A3A3B3C3C3C3F3E3F41
40424343434544464747474A4A4B4B4B4B4E4F4E50515152535252535252545453555654
5556565657575859575859595958595B595B5B5B5B5A5B595A5A5B5A5A5B5B5C5B5B5A5B
5B5B5C5B5C5C5D5C5B5E5E5E5F606060626264636464646465666666696A6B6C6C6E6F6D
6F6E706E727172747575777676767B797A7C7878777778787A7B797A7979787679777876
7575747373737473706F6F6C6967635F5C55524D4C49454542423F3E3D3D3A3937373535
343231302F2F2E2E2D2D2C2C2B2B2B2A2A2A2A2929292829282928282827282828282728
272827282727272727272727272727272726272726262726262626262726262626262626
262626262626262626262626262626262626262626262626262626262626262626252625
262625262626262526262626262526252526262626252625262626252626262625252626
2626252525262526
252625252526252626262625252625262626262626262626262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262626262626262627272627262626272727272727272726272727272727272727
2727272727272727272727272827282828282828292828292929292A2A2A2A2B2B2B2B2B
2C2C2C2D2C2D2D2E2E2F30303131323334353536363738383A3A3C3B3C3D3E3D3F404042
424344444546464848494A4A4B4B4D4D4E4F4E5050525353555454545555555455575557
545859595A5957585958585A5A5A5A5B5C5B5C5C5C5C5D5B5A5D5E5C5C5B5D5C5D5B5E5C
5A5B5B5E5B5D5C5D5C5D605F606060606161626562646563656566686768686A6B6B6D6D
6E6D6E6E707073737476777676797677797E777A7877797979797A7B787A7A78787A7879
79777775747575747472716F6E6C6B66635F5B58524F4A4946444242403F3E3B3A393837
3634333231302F2E2E2E2C2C2C2C2B2B2B2A2A2929292928292928282828282828272728
272727272727272727272727272726272726272726262727272627272627272626262626
262627262626262626262626262626262626262626262626262626262626262626262626
272626252526262626262626262626252626252626262626262626252626252626262525
2626262525252626
252626252525252626262626262626262626262526262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626272626262626262727272627272726272727272726272727272727272727272727
272727272728272727272728282828282828282829292829292A292A2A2A2A2B2B2B2B2C
2C2C2D2D2D2D2D2F3030303133323334353636383939393A3C3C3D3D3D3E3F4142424243
4445454647484A494A4A4B4D4C4D504E4F4F515152535454535556565556565858575658
58585958595A5A5B5A5B5B5B5B5E5C5B5E5D5E5E5E5F5E5D5D5E5E5C5D5C5C5C5E5C5C5B
5C5C5B5C5C5C5C5C5C5D5F5F5E5F60606060616163636363646365666665666A6B696C6C
6C6D6E6C707071727073757576777577777677777676797A78777A78797A7B797A797978
7B7877787776757574757272726F6E6C6C6A65635D5554504C4A4645434341403D3B3939
3836353433313030302E2D2D2C2C2C2B2B2A2B2A29292929292829292928282828282827
282727282727272727272727272727272727262626272726262726272727262626262626
262626262626272626262626262626262626262626262626262626262626262626262626
262826262626252626262626262626262626262626262626262625262626252626262526
2626262526262626
252625262625262526262626252626262625262625262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262726262626262627262727272727272726272726272727272727272727272728
27272727272728272728282828282828282928292929292A29292A2A2A2B2B2C2B2B2C2C
2D2D2E2E2E2E2F2F303132333435353637373838383A3B3C3D3E3E403E40414243444545
46464649474A4A4A4C4C4C4D4F4E4F51515252545454555557565556585858595858595A
5A59595A5A5B5A5B5B5C5C5D5C5E5D5D5D5D5D605F5F605F5E5D5C5E5D5D5D5B5D5D5D5D
5B5D5D5D5D5B5C5A5B5B5E5F5D5E5F5F615F6161626364636465646466646767666A6B6A
6B6C6D6E6E6F727070727474757675767776767777797A7C7A7778797A7A7B7B7B7A797A
79797A7A787877777776747574727171706E6B6966625E59554F4C4A46464442403F3E3C
3A38373636333331302F2E2E2E2D2C2C2B2B2A2A2A2A292A292828292928282828282728
282827272727272727282727272727272727272627272626272727262626272626262726
262626262626262626262626262626262625262626262626262626262626262626262627
262626262626262626262626262625262526252526262625252626262625262526252626
2525262626262526
252626262625252626262526262626262626262626262625262626262626262626272626
262626262626262626262626262626272626262626262626262627262626262626262626
262627272627262627262726262626262627272727272627262727262727272727272727
27282727272727282828282828292828282829292929292A2A292B2A2B2B2B2C2C2C2D2D
2D2E2E2E2F313031313333343636363738393B393A3C3C3E3D4040414242434344454646
4748484A4A4B4B4E4D4E4E4F5051525252555452555657575758585758595A595A5A5B5A
5C5C5B5C5C5C5D5D5D5D5E5D5C5F5F5E605F6160606162605E605D5F5E5F5D5D5D5D5D5D
5E5D5D5D5C5C5B5D5D5C5E605F605E606060606161646364626364646465676667686969
6B6C6C6C6D6E70707172727675767576777576767778797A7A7A7A7A7A7B787C7B7A7B79
787A797979797A7875777877777475727272716E6E6A68655D5855514D4846464343403E
3C3A3B39373635343231302F2F2D2E2D2C2C2B2B2A2A2A29292929282828282828292828
282827272727282727272727272727272727272726262726272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262526262626252626262626262626252626262525262626262626252626
2626262526262626
252626252626252625262526262626262626262625262626262626262626262626262626
262626262626262626262627262626262626272626262626262626272626262626262626
262727262626262626272727262726262627272727272727272727272727272727272827
2727272728272828282828282828282929292929292A292A2A2A2B2B2B2C2C2C2C2D2D2E
2E2F2E3030313233343435353637383939393C3B3D3E3F3E404041424244454446464849
4B4A4B4D4E4E4F4E504F4F5153545253555655565657565757595A59595A5A5A595B5C5C
5C5B5C5D5D5D5E5E5E5D5F5F5F5E6060605F61605F60615F625F615F615F5F5E5D5E5D5D
5D5C5E5B5E5C5D5D5D5D5F5E5F5E605F615E616162616064636463636564656467676868
6A696A6B6B6F6F6E6E7170727375747575767875797979777C7B7878787B7A7C7C7A7B7B
7A797B7B787A797878787776767675747474737070706D6A69645E5A534E4E4947464441
3F3D3D3B3938373635333231302F2F2E2C2C2C2C2B2B2B2A2A2929292929292828282828
282828282827282727272727272727272727272727272627262626272627262626272626
272626262626262626262626262626262626262626262626262626262626262626252626
262626262626252626262626252626262626262526262526262526252626262625262626
2626252525262525
262626262626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262626252626262626262626
262626262627262626272727262627262727272727272627272726272727272727272728
27272828282828282828282828282929292829292A292A2B2B2A2B2B2B2C2C2C2D2E2E2E
2E2F303132323434343537363838393A3A3C3D3D3F3D40404041434444444747484A494B
4B4D4C4D4F4F4E50505152525253555656575659575A59595A5B5A5B5C5A5D5B5C5C5D5D
5E5D5E5E5D605F5F605E5F616060616060615F61625F6261605F615F61606060605E5D5F
5F5D5F5D5D5D5D5D5E5D605E5D5E5F5E605F5F5F60616262636564656465656566686668
6968696A6C6C6C6C6F6F70707372737374737377777978797A7A797B787A787A7A7C797C
7B7B7A7A79797A787A797B7978787776767875747571716F6E6C68645F5853504C494746
42413F3F3B3B3A383735343232302F2E2E2D2D2C2B2C2A2A2A2A2A2A2929292929292928
282828282828282727282727272727272726272727272726262726262626262626262626
262626262626262727262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262525252626262525262626262525252526262626
2626252525252526
262626252526262526262626262626262625262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262726272626262626262626272627272727272727272727272727272727272727272828
2727272728282828282828282828292929292929292A2B2A2B2B2C2C2C2C2D2E2D2E2E2F
30303032333434353737383939393B3D3C3E3D3E3F4042434344444546474749494A4B4D
4D4E504F504F5153535454545556565758595A5A595A59595B5B5B5A5C5B5D5D5F5C5E5E
5E5E5E5F615F6160616061626061616261606262626160606160616161605F60605F605E
605E5E5E5E605D5F5F5F5F5E5F5F5F605F60605F62616261626264636364646566656767
69686969696B6B6A6E706F7071717273747275747474767779787A7A7A7C7C7A7A797B79
7A797B7A7B7A7B7A7A7C7B7A797979777777797675757472706E6E6B68625D5853504C47
45444340403C3B3B39373635333231302E2F2D2C2C2C2B2B2B2A2A2A2929292928282828
292828282828282728272727272727272727272727272626272727262626272726262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262526262626262626262626252626262626262526262626262625262626
2626252526262626
252626262626262626262626262626262626262626262625262625262626262626262626
262626262626262626262626262626262626272626262626262626262626262626262726
262626262627262627272627262726272727272727272727272727272727272727272827
272727282728282829282928292929292A2A292B2A2B2B2B2C2C2C2C2D2D2E2E2E303031
31313334343436363838383A3B3C3D3C3D3F3F404041434445454746484948494B4B4D4F
4F50525052525353545556565857585A5A5A595A5A5C5C5B5D5D5D5B5D5D5F5F5E5E6060
6060615F5F6262626263636362616262636060636263616263606361616360605F606060
605F5D5F5D605E5F5E5F5F605F615F5F5F5F606160606263626364646464646564676569
676768686A6A6A6A6D6C6D6C6F6F70727172727373737577787A797B7B797B79797A7A7A
7A7A777A797A7A787B7C79777A7A79797677777777777575737572726D6B67635D57524E
4E48464341403E3C3C3A393735343232312F2F2D2D2C2C2C2B2B2B2A2A29292929292929
292828282828282727272727272727272727272727272727272727272726262627262626
262626262626262626262626262726262626262626262626262626262626262626262625
262626262626262526262526262626262626262526262525262626262626262626252626
2526262526262625
252626252626252626262626262526252626252626262626262626262626262626262626
262626262626252627262626262626262626262626262726262626262626262726262626
262727262727262727272627272726262727272727272727272727272727272727272728
28282728282828282828292929292929292A2A2A2A2B2C2B2C2D2E2D2E2F2E2F30303033
3333343536363838383B3B3B3B3D3D3E3F40404042434545474647484A4B4C4C4C4F4E4F
4F5152525354545557555758595A5C5A595A5C5B5C5C5D5E5D5D5E5E5D605F60605E6162
626163636263626363646667656463636462636364626362616262636362626160636161
616161605F5F60605F5E615F615F5F5F6060606061606363636364646564646264656666
68686767686B6A6B696B6B6C6E6E6F6F707072727373747577777979787B7C7C7C7A7A7A
787979787A7A78787A7C7C7C797A7A7A7A797879777978757675737472716D6B67635D57
524D4A484544413F3E3C3A39373635343131302F2F2E2D2C2C2B2B2B2A2A2A2929292929
282928282828282828272728272727272727272727272726272726262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262526262626262526262626262626262626262626262626262626252626
2526262625262625
252625262625262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
272726272726272626262727272727272727272727272727272727272728272728282827
28282828282828282829292929292A2A2B2A2A2B2B2B2C2C2C2D2D2E2F2E2F3031323233
343436363638383A3A3B3B3C3E3F3F40414242434545454647484A4A4B4B4D4E4D505151
53515355545656545758595A5B5B5B5C5D5C5D5E5D5E5D5F605F5F616160616260636262
626262636564656465666566666465646764656565636463656363646364636061616261
6262616161605F6061615E5F605E5E60606161625F606262626464636363636365646466
666465656968696968686B6A6E6E6E6F70707071727372747475777878777979797B7C7A
7A787979797A7B7A7C7A7D797A7C797C7B787A7A7A787777767978757475746E6D6A6663
5C57514D49484443403F3D3B39383735333231312F2F2E2D2D2C2C2B2B2A2A292A292929
282828282828282828282828272727272727272727272727262627272627262726262626
262726262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262526262626262625262625262625252625262626262626252626
2526262525252526
262626262626262626262626262626262625262626262526262626252626262626262626
262626262626262626262626262626262626262726262626262626262626272626272626
262726262627262727272727272727272727272727272727272727272727272728282827
2828282828282828292929292A2A2B2A2A2A2B2C2C2B2C2E2D2E2E303030303133343335
3536363837393B3B3B3C3E3E3F414041434243444547484849494B4A4D4F4E5051505253
5454565757575758595A5C5A5C5E5D5D5E5D5F605F606162626062626462636262636463
636365646666666766686965666666666667676664656463646764646463626262626263
62616261626061626160605F5F60616060605F5F61606162646264636362626462646564
6567686766676768686969696A6B6D6D6C6E717172727173757574777677777A79797A7B
7978787A797A7A797A797B7B7A7B7B7B7A797A797A7C7A7B7B77777777757475716F6F69
65615A54514B494743413F3D3C3A3A383635343331312F2F2E2D2C2C2B2A2A2A2A292929
292929282828282828282828282827272727282727272727272726272726262726272627
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262625262525262626262626252625252526262626262625262626
2626252626262626
252625262626262525262626262625262626262626262526262625262626262626262526
262626262626262626262626262726262626262626262626262626262626272626262726
262727262727262727272727262727272727272727272727272827272727272728272828
2828282828282828292929292A2A2A2A2B2B2B2C2C2D2D2D2E2E30303131313334343535
363738393A3A3B3C3E3D3E3F414043444344454647474A4A4A4B4C4C4F4E505152545552
55565657585A595C5A5C5B5C5C5E5E5F605F616162616263616362636363626364676466
666566676566676767676968686665676967676869676668666565656564656564646363
626362636362626361616260636061606260626062606263656363636262606262636363
6565666767686869696A696A6B6C6C6C6D6D6F6F6F707071737574737576777778777B77
777A7978797A7B7B7B797A7A7B7B7B7D797A7D7D7B7A7A797A7B7779787776747472736E
6E6A646058544F4B484643413F3E3C39383736343331302F2F2E2D2C2C2B2B2B2A2A2A29
292929282828282828282727282827272727272727272727272727272627272726262727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626252626262626262525262526
2626252526262625
252625262626252626252626262626262625262626262626262626262626262625262626
262626262626262626262626262626262626262626272626262627262626262727262727
272726272726262727272727272727272727272727272727282727272728282828282828
282928282828292929292A292A2A2B2B2C2B2B2C2C2D2E2E2E2F30303132333335363638
38393A3A3B3C3C3D3F4040414242444445464848484B4A4B4B4C4E4F4E51515252545555
575857585A5A5A5A5D5D5D5E606060606260626263626364636565666664666464656666
6867666668686768666968696967686A686A686B69696968696868666866666564646665
646363636264636362626161626162616062646362636262646463636261616262616463
6464656567666567676768676B6A6B6A6C6E6D70706E7171727374747575767477777879
7778797A7A7A7B7A7979797C78797A7B797B7D7B7C7B7B7B7C7B79797A78797775767472
716D6C68645C57514E4B474442413F3C3B39373635343231302F2E2E2D2C2C2B2B2A2A2A
2A2A29292829282928282828282827272727282727272727272727272727272726262627
262627262627272626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262526262526252625252526
2625252625262526
252625262626262626262626262626262526262626262626262625262626262626262626
262626262626262627262626262626262627262726262626262726272627262626272627
272727272726262727272727262727272727272627272727272727272728282827282828
282828282929292A2A2A2A2B2A2B2A2B2D2C2C2D2D2E2E2F2F3031323434353536383739
3A3C3B3B3C3E3F404040424243444545464848494A4B4A4C4E4D50515151535355545759
5A595B5B5B5C5D5C5D5E5E5F626162616265626364666563666566666866666668676667
686867696967696969696A6A69696B6A6A6B6A6A696A6868686868696766686867656565
666665666564646463646263646162616262626263636262656363626363636362616363
6364666465656767666669686B6A6A6A6B6C6C6F6E707070717172737272737476777677
78797678787A7A787A79787A7B797A787B7C7D7D7B7D7C7B7B7B7C787C78787A78767674
7372716E6A65605954514D484442423F3D3C3B3836363432312F302F2E2D2C2C2B2B2A2A
292A2A282929282828282828282728272728272727272727272727272627272727262727
262627262726262626262726262626262626262626262626262626262626262626262626
262626262625262626262626262526262625262626252626262626262525262626252625
2525262626252525
252526262526262626262626262625262626262626262626252626262626262626262626
262626262626262626262626262626262726262726262626272726262626262626272727
262626272727272727272627272727272727272727272727272727272828282827272829
28282929292929292A2A2A2A2B2B2C2C2C2C2D2E2F2F2F3031323433353537363839393A
3B3C3C3D3F3F4040424242434445474649494A4C4B4C4D4E4E5051515253535455565758
5A5A5A5D5E5D5E5E5E5F6061616165646465656466666565666767696665696769676968
6868696769686A686B6A6B6C6B6C6B6C6C6B6C6A6B6C6B686B6A6B686969696867676767
666565676564666566636664656463636262626462636364626362636363626362626262
646363656464636666666866686A6A6A6C6C6B6E6D6F6F6F706E6E6F7372717371757575
76787779797A77787A787A7B79797A7A7C7B7A7C7D7E7C7D7D7C7C7C7B7A7C7B79787676
75757371706C69655E56534E49464542403E3C3B393736353332312F2E2D2D2C2B2B2B2A
2A2A29292929292828282828282828282728272727272727272727272727272727272727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262626262626262526262626252626262526262626262626262626
2626252626262625
252626262626262626262626262625262626252626262626262626262625262626262626
262626262626262626262626272626262626262626262626262626272626262726272627
272726272627272627262727272727272727272727272727272828282727282828282828
282829292929292A2A2A2A2B2B2C2C2C2C2E2E2F2E303032323334353637383A3B3A3B3B
3D3D3E404041424143434345454748494A4A4C4D4D4F4E50525251525355555556585959
5A5B5C5D5E605F5F606162616365676567666666676667676767666868686B6A696A6C6B
6B696A6B6B6B6A6B6C6B6B6C6D6C6C6C6D6C6C6C6D6D6C6C6C6B6A6C6B696B69696A6869
686867696667656665666866666564626461636362626363636363626362636162626362
616363656566666665676868686969696A6A6B6B6C6C6C6D6E6E70706F71737373747374
7678777577767678787A787879797A7A797C7C7B7E7A7F7C7E7B7C7C7C7A7C7A7B7A7978
76757575716F6E6A67625A56514C484544413F3C3C3A383635343231302F2E2E2D2C2B2B
2B2B2A2A2A29292828282828282828282828272727272727272727272727272727262727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262526262626
2626262526262626
252626262526262625262526262626262626272626262626262626262626262626262626
262626262626262627262626262626262626262626262626272726262627272627272627
272727272727272627272627272627272727272727272827282828272728282828292828
292929292A292A2A2A2A2C2B2C2D2D2D2E2E2E303031323334343537393939393B3C3D3E
3E3F404142414243464646474848494A4B4C4D4D4D50515052505455555656565759595A
5A5C5D5F6060606263646564656666666667676867676869696A6A686B6A6B6A6B696C6B
6C6C6B6B6C6C6C6D6D6C6C6D6D6D6E6D6F6E6D6E6D6B6C6C6E6C6C6C6C6C6B6B686A6A6C
696969686966676766686667666666646563636364646463626362626365636262626362
646363656463666565656567676767696869696C6B6A6C6C6C6D70706E70727072717474
75767677787677787879797A797A79797A7A7B7A7A7C7B7C7D7D7D7D7D7C7B7A7B7A7978
797778767574736E6D6A656059544F4A484543403F3C3A3A373635323130302E2E2D2D2B
2B2A2A2A2929292929282828282828282828282827272727272727272727272727272727
262726262727262626262726262626262626262726262626262626262626262626262626
262626262626262626262626252626262625252626262626262626262626262626262626
2526262626262626
252625252626262626262526262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262726262727272727262727262627
262727262627272627272727272727272827272727272728282827282928282828282929
2829292A292A2A2A2A2B2B2C2C2D2D2E2F2F2F303132333536373738393A3C3C3D3E3F3F
414142424444444546464849494A4C4C4C4F4F504F5251525454535558585759595A5B5B
5E5C5E5E5F6262616566656665676767686869696A6A6969696B6D6B6D6A6C6B6C6D6E6E
6E6C6F6E6F6D6D6E6F6D6E6F6F6D6E6F6F71706E6E6E6E6E6E6C6C6E6D6E6C6A6B6A6C6B
6B6B69696A67686968686767676566646465646364646562626363646363656462636262
6263626263656365666567666668676869696A6869686A6A6C6E6B6C6D6F6F7071737372
757575757577787779787979787B797A7C7C7B7C7B797B7B7D7D7D7C7D7C7B7C7D7A797A
7A79787776757573716F6C68645C56504D49464341403E3B3A373635343230302F2E2D2C
2C2B2B2A2B2A2A2929292928292828282828282727272727272727272727272727272627
272626272626272626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626252625262626262526262626
2626252626252625
252626262626252626252625262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262727272626262726272626272727
272726262627272727272727272727272728272827282728282728282828282828292929
292929292A2A2A2B2C2B2C2C2D2D2E2E2F303133333335363638393A3B3B3C3E3F404141
43434645444746474748494A4C4B4D4D4E504F515153525355565757595A5B5B5B5C5E5E
5F5E606061646263656567666868686A6B6B6B6C6C6C6D6C6C6C6D6D6D6D6D6F6F6E6F6E
6F6F6F706F6F6F6F6E6E706F6F6E70706F6F6F6F7071706F6E6F6D6F6D6D6E6D6B6D6C6A
6B6A6C6A696A6A6868696969686767666665666564646566646464646665646563636162
62646362656665646464666665646567686767686A6769686B6A6B6D6C6C6C6E706F7072
717473737473777676797A7779787A7A7B7A7C7C79797C7A7B7B7C7E7B7C7B7D7C7C7D79
77797879797774747571706E69665F58544E49474442403E3B3A383736343231302F2E2D
2C2B2B2B2B2A2A2A29292828292928282828282828272728272727272627272727262727
272727262726262626262626262726262626262626262626262626262627262626262626
262626262626262625262626262626262625262626262525262625262625262526262626
2625252626252625
252626262626262626262626262626252626262626262626262626262626262626262626
272626262726262626262626262626262626262726262627262626272626262627272727
272727262727272727272727272728272728282727282728282827272829282828292928
2929292A2A2B2B2B2C2C2D2D2E2F2F2F2F3132333434373739393A3C3D3D3E4041414244
4545464746474A494B4A4C4C4C4E4F4E4F50525253515555565658595A5A5A5C5D5C5E5E
5E606162636364666767686869676B6B6B6B6B6A6C6C6C6C6E6E6F6D6D6F6E6E70706F72
736E6F70727070727071707071716F707170716F707372727172706F70706F6F706E6E6E
6C6E6C6B6C6B6C6A6B6A6B68686968666667666467676466666466666666656462636465
6364646564666465656766656666656566686868686A6769686C6B696B6B6D6E6F6F706F
7171727374747777777677777679787A7A7A7C7A7A7A7A7A7C7D7C7D7C7B7C7C7D7D7D7B
7B7B7A7A7977787474747370706C68625C56514C4845433F3E3C3B393836343331302F2E
2E2D2C2B2B2B2A2A2A292929292828292828282727272727272727272727272727272626
272627262626262726272627262626262627262626262626262626262626262626262626
262626262626262626262626262626262626262626262526262626262625252526262625
2626262626262526
262626262626262626262526262625262626262626252626262626262626262626262626
262626262626262626262626272626262627262626262626272626272626262726272727
272727272726272727272727272727272727272728282827282828282829292929292829
2A2A2A2B2B2B2B2C2C2C2D2E2E2E2F31323234353537383A393B3C3D3F3F414243444446
474848494A4B4B4B4C4B4E4E4C4F4F4F505252535555545656585A5A5B5C5D5D5D5E5F61
60606365626666666668696A696B6C6D6E6D6E6F706F717070716E717170717173717471
71737271717271717070727171737171717073737373727272707371716F7070706F706F
6F6E6E6C6C6D6C6B6C6B6B6C696969686867676867676764656768676665666565646465
63646464656663656665636465666664656567666767676868696A6B6C6A6D6E6C6D6F70
6E71716F737273757678757678777877787B7A787A7B7A7B7B7B7E7E7F7B7A7B7C7C7E7C
7D797C7B7B79797776757475736F6C69665F58544E4A4644413E3D3B3A38373333323130
2E2E2C2D2C2B2B2A2A2A2929292829282828282728282727272727282727272627272727
262627262627272626262726262726262626262626262626262626262626262626262626
262626262626262625262626262626262625252626262626262626262625262626252626
2626262626262626
252526262626262626252626262626262626252626262626262626262626262627262626
262626262726262627262626262626262627262626262627262626272626272627262727
272727272727262727272727272727282728272828282828282928292829292829292929
2A2A2A2A2A2B2C2D2D2D2E2E2F303132333334363638393A3A3D3E3F3F40424445464647
4848494B4C4D4D4E4E4F5051505050525153535556575657595B5A5C5D5B5E5F60606063
6361636666666766696A6B6A6B6C6E6D6D6F717071707070727172717171727573757371
747373747372747471747272727573737473727173737372737372717472737172727171
6E716F6D6E6E6E6D6C6C6C6B6C6A6A6A6968696869676767676769686865666765646464
65656665666765636567656565666565636566656568676869686A6A6A6C6B6C6E6E6D6E
6F6E7172737473727573767678757878797A797A7B797C7A7E7B7D7B7D7A7B7C7C7D7D7B
7C7C7B7C7C787879777877757672706F6B68615B55504D4745433F3D3C3A383635343231
302F2E2D2C2C2B2B2A2A292A292929282828282728282827272727272727272727272727
262627262626262627262626262627262626272626262726262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
2626262626262526
262626262626262626262626252626262626262626262626262626262626262627262626
262726262626262627272726262626262626262726262627262726272627272727262626
262727272727272727272827272727272728272827272828282928292829292929292A2A
2B2A2A2B2C2C2C2E2D2D2E30303232323434363737383B3B3D3F3F404143454648474A49
4A4B4C4E4E4E514F505052525353545354565656565858595A5B5B5C5E5E5F6060616163
6265636667676969696B6B6B6D6D6E70706F727171707071737271727373737574757574
747476757477767575737274737374757474767573727472747274737272747370727371
7472716E6E6E6D706C6F6B6B6C6D6C6C6A6A686969696A69686969686766676865676665
6666656665656365646667656565646565666667676766676968696A6A696A6C6A6C6D6F
6E6F6F7071717473747574747475757878787A777879797A7C7D7B7A7B7A7D7C7A7D7C7D
7B7C7E7C7A7C7A7B7879767777747371706C68665F58534E4946433F3E3E3B3937373432
31302F2E2D2D2C2B2B2A2A29292A29292928292828282827272827282727272727272727
272727272627262727262626262626262627262626262626262626262626262626262626
262626262626262626262626262626262526262626252626262626262526262526262626
2526262626262626
252626262526262526262626262626262626262626262626262626262626252626262626
262626262626262626262626262626262726272626262627262727272627272727262627
2627272727272727272727282727282727282828282828282829292829282929292A2A2A
2B2B2B2C2C2C2D2D2E2E2F303032333436373838393A3D3D3E3F42424445474749484B4C
4D4E4D4F50525151545354555556575856585857575A5A5A5D5C5E5F5D615F6164636465
6564676667676A69696C6B6D6D6E6E6F7170717273737374757476767476757475767776
787775757778767675777978777575757576757674747675747374747673737374747573
75756F716F716F70706D6C6E6E6C6B6D6C6A6B6C6B6A6A6A6A6A6A696868676866686666
6666676566646564676566646566666464646565686568686868686A6A69696A6D6A6E6D
6E6E6E6F6F7070717071747574747475757779797A7A787B7A7B7A797C7A7C7B7C7E7C7C
7C7B7B7E7C7C7B7A7A7A78777877747472716E6B68605C534E4B4744423F3D3C3A383634
3232312F2E2D2C2C2B2B2A2A2A292A292928282827282728282727282727272727272727
272727272726262627272626272727262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262526252626262626
2526262526252525
252626262626262626262526262526262626262626262626262626262626262626262626
262626262626262727262726262727262626262726262627272627272626272727272727
272627272727282727272727282827282728282828282928282929292929292F2A2A2A2A
2A2B2C2B2C2D2F2E2F2F3031323333363638393A3B3D3D3E3F414344454748494A4B4C4D
4E5050525152545456565558565859585859595A5A5B5B5D5E5C5F5E6060626263646666
6666696966696B6A6C6C6D6C6E6D72707072727376747675737677767676767777787978
7879787977777A7776767877767775767476757576747576747577767577777574767275
76746F7073727171726F6F6F6F6D6D6E6D6C6B6D6B6C6D6C6C6C6A6A686A686868686867
676867666567666665666565666467646565646766676768686A67676B69696A6A6A6C6C
6D6D6F7071707271717272727273757575767678787979787A767A797B7A7B7A7D7C7D7D
7B7D7D7C7B7D7D7D7A7B7A7A797577757274716F6A68625D56504C4845433F3D3C3B3836
353231302F2F2E2D2C2C2B2B2A2929292929282828282828282728282727272728272727
272727272727272727272727272727262626262626262626262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
2626252626262525
262626262526262626262626262626262626262626262626262626262626262626262626
262626262626262626262627262626272626262726272627262626272627272627272727
272727272727272727272727272727272828282828282828292929292A292A2A292A2B2C
2C2B2C2C2D2D2E2E2F3031313235343638393A3B3C3E3F40424344464649494A4C4D4F4F
51535352545556575758595A5A5B5B5A5B5C5C5C5C5C5D5E5E5F60616061636164656567
676668686A6A6D6C6D6C6E6E707171717373737576757777767877787879777A7B78797A
7A7A7D7B7B7B7977787A7779787877787677777575777778767676757676767674757675
76747374737372727570706F706F6F6D706E6D6E6E716D6D6C6D6C696B6B6A6A6A686A69
69696A666866666566676666656767656565676466666866696968696869686A69686B6D
6B6C6E6E6F6F70717271727372737475757477767777797879797978777A7C7B7B7E7B7B
7C7A7D7D7E7E7A7C7B7C7A7A79797877777374716F6C6A65625A534E494643403D3D3A39
36353332312F2F2E2D2C2C2B2A2A2A292929292828282828282727272728272727272726
272627272727272727272626262727262627262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
2626262526262626
252626262526262626252626262626262626262626262626262626262626262626262626
262626262626272626262626272626262626272627272726262726262727272726272727
262727272727272727272727272827282828282828292929282929292A2A2A2A2A2B2B2B
2C2C2D2D2D2E2E2F3030323435363638393A3C3C3E3F41424344464749494C4C4E4F4F50
52535255545757585B5C5A5B5C5E5C5E5D605F5F5E5F5E5F616262626263646466666867
676769696A6B6D6D6F6F706F7171727473747474747677787A79797C7B79797B7A7A7B7D
7B7B7C7D7D7C7A797A797B777A7879797979797877787978787679797876767776767777
7578767676767773747372717270727172716E6E716F6E6B6D6E6D6D6C6A6B6A6A6A6A69
6968696A686666666567666665646566656465646465676767696668696968696A6A6A6B
6B6D6D6D6D6F6F6F707171727173727371757574777675787778797678777A797A7C7A7B
7C7C7D7E7B7D7B7B7D7C7C7C7C7A797976767574706F6F6B66625B544F4A4844413F3C3A
3A3836333331302F2D2D2C2C2B2B2A2A2A29282929282828282828282827272727272727
272727272627272727262626262726272626272626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626272626262627272626262727262726262727262727272627272727
272727272727272727282827282728272828282828292828292929292A2A2A2B2B2B2B2C
2C2D2E2E2E2F2F30313334343636383A3A3B3C3E3F4041434447484A494B4B4E4E505153
545656585758595A5B5E5E5D5F60615E6161606160606162606264646364646565696869
6A696E6B6C6C6E6F706E6F70727273767476757677777978787B7A7A7C7A7D7B7D797B7C
7C7D7D7E7D7C7D7C7A7B7C7A7C7A7C7A7979797A787A7778797977777978777776787978
78797678777776757674737374737171717172706E7171706E6F6E6E6D6E6B6C6B6B6A69
6A6A69686A68676867676668666566676666656664646766666767696B6A696A6A6A686C
6D6B6C6C6D6E6E6F6F7170707172727372737574757675747576757576797A78797B7D7C
7E7D7C7B7C7B7B7C7B7B7B7B797A797A787876767473716E6B68665D56504C4744413F3D
3C393836343332302F2E2D2C2C2B2A2A292A2A2928292828282828282827272728272727
272727272727272627262727262627272726262626262626262627262626262626262626
262626262626262626262626262626262626262626262526262626262626262626262526
2626252625262625
252626252526262626262626262626262626262626262626262626262626262626262626
262626262626272626262626262626272626262627262727262726262727272727262727
272727272828272727272828272727282828282828282929292A2A2A2B2A2B2B2B2B2C2C
2D2E2E2E2F3031313234353636383A3A3C3C3E3F4242444647494A4A4C4D4E4E50505253
56555858585A5A5C5C5D5D5E616062606363626263626562646464646465666666696869
6B6B6D6D6E6D6E706F717372727373737477777979777B797A7A7C7C7B7C7C7E7D7F7D7E
807F7F7C807E7E7E7D7D7D7D7B7C7B7B7C7C7A7C797C797C7A7C7A78797878797879787A
7A7B79797979797878787673747373727372717272716F70726E6D6E6E6C6E6E6C6D6D6C
69696969696868676867686767676666676767676465676568666A6A696A6869696A6A6A
6C6C6C6C6D6D6D6E6E6F6F71727273727271757475767876767676767877797878797B7A
7B797B7E7D7E7D7C7D7B7D7A7C7A7C7A7A78777674757371706E69645F58524C4945433F
3E3B3A383735333130302F2D2D2B2B2B2B2A2A2A29282928282828282828272727272727
272727272726272726272727262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
2626262626262626
252625262626262626252626262626262626262626262726262626262626262626262626
262626262727262627262626272627262626272727272727262727272727272727262727
27272727272728272828282827272828272828292928292A29292A2A2A2B2B2A2C2B2C2D
2E2D2F2F3031323335353738383A3A3B3D3F40414243464648494A4D4E4F515153525556
5556585A5A5D5C5E5E5F6162636263646461636563666566646666676768676A68686A6B
6A6C6C6E6D71707170737375757676767677797979787B797B7C7A7B7D7C7E7E7C7F7D7E
7F7E7F807D7E80808280807E7E7B7F7D7E7F7C7C7C7D7C7C7C7B7C7D7B7B7A7A7A79797A
7B797A797A797A7A7879777575757374737473727373737373716F716E6F6F6F6D6E6C6D
6A696C6A6B6A6B6A6A6A6666666768676868696767676568676667696768686A6A6B6A6D
6B6B6B6C6D6D6C6C6E6E6F6F707071727271737372747576767675777878797877767878
7A7A7B7C7B7A7B7B7F7D7B7C7B7B7B7B7A7977777676757273706E6B66625A544F494643
413E3C3B393736333130302E2D2D2C2B2B2A2A2A29292929292828282827282727272727
272727272727272726272726262726272726262626262726262626272626262626262626
262626262626262626262626262626262626262625262526262626262626262626262626
2626252526262626
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262727262726272627262726262727272627272727262727272727272727
27272728282727272727282827292828282828292829292A292A2A2A2B2A2C2B2C2D2D2D
2D2F30303132343535363738393A3D3C3D3F41434446474949494C4C4F51525254555758
595A5B5A5C5C60606160626264636566666565676867676666666767686A69686B6A6B6B
6C6D6D717070727271727475767776777779797A7B797C7B7B7B7B7F7A7C7C7E7F807F7F
828181818383808783807F7E807F807E807B7C7F7E7E7C7C7C7E7F7D7E7B7A797D7A7A7C
797A7A7B7C797C7A7C7978777677777474757374747374707371716F71716E6F6E6E6C70
6D6B6B6C6B6B6B6A6A6B6A6868686869696868676768676766666768666869696C696C6B
6A6A6C6B6C6C6B6D6D6D6F6F6F7170707371727674757374757574757877777A77777677
7A787A7A797A7D7B7B7C7C7D7D7B7C7A79797A7A7778747572706F6D6B67625C55504B47
44413F3C3A3837353332302F2F2E2C2C2B2B2B2A2A292929282828282828282728282727
272727272727272727272626272726262726262626272626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262625262626
262626262626262526262626262626262626262626252626262626262626262626262626
262626262626272627262626272626272627262726272627272727272727272727282727
272827272727282727282727282828282829292929292A2A2A2B2B2B2B2C2B2C2D2D2D2E
2F303131333336363737393A3B3C3D3F3F4142444746494A4A4C4D4F5153545455565757
595B5B5D5E5E616162646463636466656767686B69696869696A6A6A6A6B6C6D6C6E6C6D
6D6D6E706F71717374767475787777797979797A7B7C7C7A7C7E7C7C7D7D7D7C7E7E8280
7F8082828383838182828180807E80807F7E807F7D7E7F7F7C7D7B7C7D7E7B7D7A7B7B7D
7C7B7A7B7C7B7C7C797A79787879777576757574747473757274727271727170716F6D6D
6C6D6C6C6B6D6B6C6B6B6C6A69696A686A6968686A686768676867696766696C6A6C6B6A
6A6A6A696B6C6B6D6D6E6E6E6F6F706F7170737074717472737373767576777676757676
777A797A7B797C7B7B7A7C7C7D7E7B7C7C7A79787A797874767473706E6A69656057514C
484441403D3B3938363432312F2E2E2D2C2C2C2A2A292929292828282828282827272828
272727272727272726272627262626262727262626272626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626252526262626
2626262626252525
262626262626262626262626262626262626272526262626272626262626262626262626
272626262626262626262726262726272726262626262627262727272727272727272727
2727272727282728272727282729282828282929292A292A2B2B2B2B2C2C2D2D2D2D2E2F
303032323434353737383A3A3D3D3E3F4142424646484B4C4C4D4F4F5154555558585A5A
5B5C5D5D606161626664676566686868686B6A6C6E6D6C6C6C6C6D6D6D6E6D6D6D6D6F6E
6D6F7171707371727574757776787A777A7A7B7B7B7C7D7E7C7B7D7D7E7D7F7F7E818180
838183838384828282828285808280817F7E7F7D7F7F7F7F7F7E807E7E7E7D7F7D7D7C7C
7B807C7B7C7B7C7A7C7A7A787878787878787775767474737275737173747373716E6F6D
6F6C6E6F6E6F6E6C6C6A6D6B6B6A6A6B696869696968676968686B6A6968686A696A6A6A
786B6A6C6B6B6C6A6D6F6D6D6D6D6F6D6F6F717171727172727474747676777676767677
777778787A7D7B7C7B7C7B7D7D7B7B7C7B7A7A797577797974747472736E6F69665F5852
4D4844423F3D3B393736343331302E2E2D2C2B2B2A2A2A29292928282828282828272727
282727272727272727272727262726262627262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626252626262626262626
2626262526262626
252626262626262626262626262626262626262626262626262626252626262726262626
262626262726262627262726272627272726272626272727272727272627272727272727
2727272728272827272728282828282928282929292A2B2A2A2B2B2C2C2D2C2F2D2F2F30
3132323335363638393A393C3D40414043444748494A4A4D4E4F4F51535555565959595A
5D5D5E6061616164646468696968696B6B6A6C6C6C6D6E6F6D6D6E6F6E6F6F706E6F6F70
71707273747474737574747879797A797B7A7A7B7C7C7E7E7D7D7D7C7B7C7F8082828380
808182828285858484848583838182838082808080807E817F808180817F807F7F7E7E7D
7E7B7E7E7E7C7F7E7D7D7C7B7A7A7A7A7978787678787475757576757373737473707071
6E6F6F6E6F6F716E6C6E6E6F6B6B6C6C6B696B6A6B6B6A696B69696A68696C696A6B6B68
6A6969686B6B6C6B6A6A6C6D6D6D6E6E6F6E707170707271727272737576747676757576
7876777877797A7A79787B7C7A7C7E7C7B7B7B7A787978767776767473736F6E6B66605A
524D4845423F3D3C3A3836353331302F2E2D2C2B2B2A2A29292829282828282828282827
272727272727272727272727272727262726262726262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626252626262626
2626252626252626
252625262626262626262626262626262626262626262626262626262627262726262626
262626262626272626262627262727272627262627272727272727262727272727272727
2727272728272728282828292928282929292A292A2B2A2B2B2C2C2C2C2D2D2E2E2F3031
31323335363737383A3A3D3D3E3F414344464749494C4D4D5050515354555758595C5B5C
5D605E626263646566666569696A6A6B6B6F6C6E6F71716F716F71707071717272717272
727473727374747677757977797B787A7B7D7E7F7D7C7E7E7E7E7F807E7C7F7F80818484
848584868484848585858383858584848180838280828282817F80818081807F807F807E
7F7E7E7C7E7D7D7E7E7C7C7A7A7B7C7A7A7B78797A777978777674757574747374737271
7071706F6E706F6E6C6F6F706D6C6C6A6C6D6C6B6A6B6A686A6A6A6A6A6B6B6A6B6B6A6A
69696A6B6A6A6C6C6C6B6E6D6E6C6C6E6D6D6E6F7170716F6F7172727374747475737476
767877757678777A79797A7B7B7B7B7B7C7B7B7A7A787A79777676747573706F6E6B6861
5C554F4B46433F3D3B3A3936343331302F2E2D2D2B2A2B292A2929292829282828272827
282727272726272726272727262727272626272626272626262626272626262626262627
262626262626262626262626262626262626262626262526262626262626262626262626
2526262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272726272726262626262627272726272727272727272727272727272728
272827272828272828282828282829292929292A2A2B2B2B2C2C2D2D2C2E2E2E2F303132
333436373638383B3C3C3E3F414143444648494A4C4B4D4F51515455565858585A5C5E5E
5F606262646364656767696A6B6C6D6F6F6E716E71717172737272727473747375757372
7573747676757776767778797D7B7B7B7D7E7E7C7D7E7F7E8181807F7F7E7F8281808383
848286858684848585858582858585848483838382838581808181848181837F81818180
7E7E807D7F807E7E7E7D7C7D7C7C7D7E7C7B7A7B7A7A7777787677757575767475757375
7172717170706F707070706F6F6E6D6B6C6D6B6C6B6B6A6C6A686C6A6B6A6B696969696A
6C696B6A6B6B6B6B6C6C6B6D6D6B6C6C6C706F6D6F6F6F72717272747475767274767576
7476767475767779797A7B797A79797B7D7C7C7A7D7A7A797878767876747373706F6B68
635C554D4B4643403D3B3A383834333230302E2D2C2B2B2A2A2A29292928282828282828
272727282727272728272727272726262627262727262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625252626
2626262525262526
252626262626262626262626262626262626262626262626262626262626262726262626
262726262627272626272727262626272627262727272626272726272727272727272827
2727282728282828282828282829292929292A2A2A2A2B2B2C2D2D2D2E2E2F3030313234
34353637383A3A3C3D403F41424445464847494B4B4E4F505253545558585C5A5C5D5D5E
6062616365656666696B68696D6D6F6C6F6E717270737474737575747575777476767778
77787677757776767878797B7B797B7C7C7C7D7E7E7F8082807E80807F81818082828685
85868685898588878686848585898683848483838485838280818481818382838280837F
807F7F7F7E8181817F807E7D7E7E7E797C7C7B7B7B7B7A7B797879777877767676767673
7375717372717171706F7070706D6D6C6B6E6D6D6C6B6C6A6B6B6E6B6A6B6A696B6A6B6B
6C696A696A6A6B6D6C6C6C6C6D6C6C6B6C6C6E6D6F6F6F6F6F7272727373727476757575
74757574767578777878787977797B7B7B7A7A7B79797A78787978767675757471716F6C
68635D554F4B4843403E3C3A3837353332302F2E2D2B2C2B2A2A2A292929292928282828
282727272727272727272727272727272726262727262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252626262626262626262626262626262626262626262626262626262626262627262626
262726262626262626262727272726262626262727272727272727272727272827272727
27272828272828282828282829292929292A2A2B2B2B2B2B2C2C2E2D2E2F303131333334
35363738393A3C3C3E3F3F4244464747484A4B4D4D5051505354555858595B5D5D5E6060
6162656466686968696B6C6F6E6C6E6E6F71717375747675757878767677787877767878
7878767677797B787C797C7B7B7B7B7D7E7D7E817F828182838283808481828283848384
858885868688878886878989868688868686868686828383848382838483838482848283
817F7F7E80827F7F8081807F7E7E7E7D7C7E7C7C7C7B7A797C7C787A7779777777737676
747574737375737275736F6F706E6D6F6D6D6C6C6D6C6A6B6B6B6C6B6B6B6A6A6B69696B
6C6A696A6A6C6C6B6B6C6D6A6C6D6D6C6E6D6C6E6F706F6F6F7073737272727474747576
75747374757375797678777879797979787A7C7B7B7C7C787A79787C7777757575737170
6C69635C55514D4845423E3C3938363533312F2E2D2C2C2B2B2A2A2A2929282828282828
272827282727272727272727272727272726272626272726262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262726262626262626272626272726262726272727272727262727272727272726272727
272828282828282828282928282A2A29292A2A2B2C2B2C2C2D2D2E2E2F31313133343536
37373A393B3C3D3E41414244464747494A4C4C4C50515154545657595A5A5B5D5C5E6261
6063646668686A696C6C6B6D6E6E6F72717373757578737578787A787B797B7B7A787779
7A7978797979797A787B7D7A7A797A7D7D7D807D80828282838581838483858585858686
858685878787878A8988898B878788888888888887878684838584848483828484838284
83827F828182808181808280807F7F7F7E7F7E807D7F7B7C7C7B7B7C7B7A797B78777676
77787773747374757473726F716E6D6E6F6D6F6F6D6C6C6C6B6C6B6B6C6C696D696C6B6B
6D6C6C6B6C6D6C6B6C6C6D6D6D6E6D6D6D6E6C6A6F6D6F6E6D7072717071707273727375
7273737374747674767677797778777777797A797B7A7B7C7A79797A7777767676747270
6F6D6A655E57524B4745423E3C3A3836353432302F2E2D2C2B2B2A2A2929282929282828
282828282727282727272727272727272727272627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
262626262626262626262626262626262626262626262626262626262626262726262627
262626262627262626262727262727272627272627272626272727272727272727282728
27282828282828282928292929292A2A2A2B2A2B2B2C2C2D2D2E2E2F3031323334353738
39393A3C3D3D4040414344454647494B4B4D4D504F5253565558565A5C5B5D5E5F615F62
6364656867696A6B6B6D6D6E6F6F7272727473757476787B7A7B797A7A7B7D7B7C7B7B7B
7E7C797A797B7D7C7C7C7C7F7B7D7C7F7E80808381808181858583848284848586868787
8585888889898689888A8889878787878688858789878687858883838484848483848583
8283828283838382828381838080818280807E7E7F7E7E7F7C7C7E7B7C7B7B7A7B7A7678
7876767475757475757573717170716F6E6E6C6D6D6C6C6C6B6B6A6C6B6B6A696A6C6B6C
6C6A6B6B6B6C6A6C6D6B6D6F6C6E6D6D6C6C6D6D6D6E6E6E6D6D6F6F716F726F71727272
7173757273747275747677767777767676787778787A7A7B7B7B787B7778787674767472
706F6D68646057504C4745413F3C393837353332312F2E2D2C2B2A2A2A29292928292828
282828272828272727272727272727272727262726262626262727262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
2626262625262625
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262726262727272627272626272727262727272728272728282727282727
2728282929282728292829292929292A2A2B2B2C2B2C2D2E2E2F2F313132333536373739
3A3A3B3E3F40424244444647474A494C4C4E4F50535255555758585A5C5B605F5F626263
66656568676A696B6A6D6E6E707271747573747477777A787B7B7A7B7C7B7D7F7F7D7B7D
7D7B7D7C7D7C7E7F7E7E7D7D7F7B7F7E8080818081828184858586848585848587868686
86888788888987878B898989888A88888889898887858886888887868786858687878885
848483838382848283818282828081828480807F807E7F7E7F7D7E7E7C7E7D7E7D7B7A7A
7B777875797676747572747171716F706F6F6E6E6E6C6B6D6D6D6D6E6C6C6D6B6B696B6B
6C6B6C6B6D6B6F6C6C6C6C6C6E6D6E6E6D6D6E6E6D6D6D6D6D6E6F6F706F6D6F706E7173
747272717272717274757576767677777577787979787979797A7A787A77787775767574
7372716C69666058524C4844423F3D3A3936353332302F2D2D2C2C2B2A2A292929282828
282828282728272827272727272727272727272627262626272726262626262626262626
262626262626262626262626262626262626262626262626262626262626252625252626
2625262526262526
252626262526262626262626262626262626262626262626262726262626262726262626
262626272727272626272726262726272727272727272726272627272727272727272828
282828282829282929292A292A2A2A2A2A2B2B2C2C2D2D2D2F2F3031323434353638383B
3B3D3E3E40434344454648484A4B4D4F4F4F525255565557575B595C5C5F5E6060616164
65676A68696A6C6B6D6E6E7071717376767677767779787B7C7B7C7D7C7F80817D7E7E7D
7E807C807F7F7E817E7F7F80808180808180808283818384838387878685858785858889
888886878A888A8A8A8A888A8A8B8A8B8B898A8B8988888A888988878887898886888587
8583858686858283838382827F818382828181818182817F8082807F7F807E7E7D7B7C7C
7A79797778777577767674747371707271726F6F6D6F6E6E6E6C6D6D6C6D6B6C6A6A6B6A
6B6B6B6C6D6B6C6D6D6E6B6E6C6C6D6C6C6F6E6F6D6E6E6E6F6E6D6D6E6E6F6E70706F70
7272727172737173717373747576757676747577777679797A7A7A7A7A79787976777676
7373716D6D68676059524C4845413F3D3A3937353332302F2E2D2C2B2A2A2A2928292828
2828282827282727272727272727272727272727272726272726262626261F2626262626
262626262626262626262626262626262626262626262626262626262626262625262626
2626252626262526
262625262626262626262626262626262626262626262626262626262626262626262626
262627262726272626272627272727272727272727272727272727272727282727272827
282727282828282829292A2A292A2B2B2C2C2C2C2D2D2D2E2F30313234353638393A3A3B
3E3E41414243454646474A4A4C4D4E4E5151535354555759595A5B5B5F5F606061636364
6567686868686C6B6C6D6E70717072737777787778797B7B7D7C7F807F7F808081808180
818181818081818280808180808381808283838386828485838486858886868886888788
8A8788898887898C8B898B88888B8A8C898B8C8B8A8B8B89888988888A89888888888886
878786868685878683858385848384828182808383828081807F80807F7F807D7D7E7E7E
7A7B7978787A7877767877767675727171707070706E6F706F6C6D6F6E6E6C6D6B6C6B68
6C6A6C6B6D6B6D6C6E6C6C6D6F6E6E6D6F6E6D6C6F6C6E6D6E6D6E6E6C6E6D6E6D6F7170
7170717070737272707174737473747474757676767878787A78797878797A7979797675
73737171706C6B66615B524D4944423F3F3A3937353332302F2E2C2C2B2B2A2A29292829
292828282828282827272727272727272726272626272626262626262626262726262626
262626262626262626262626262626262626262626252626262626262626262626262626
2525262626262626
252625262626262626262626262626262626262626262726262626262627262626262626
262726262726262627262726272726272727272727272727272727282727272827282728
282828282828282929292A2A2A2B2B2B2B2B2D2D2E2E2F2F30313334353638393A3B3C3D
3F40414345464748494A4C4B4D4F4F51525354565558585B5A5C5D5E5E5F5E6163646365
686A69696C6A696B6C6D6E6E7175727676787979797B7C7C7D7E7E808282808081838283
828184848381818481848283828182838283828283848486868686868786858787898888
8A8988878A8A8A8C8B8B8B898A8C8C8A8A8D8C8D8C8B8C8B8B898B8B8A88898A8988898A
8A88888887878886868485868385858483848383848181837F808081827F7F8080817F7E
7D7C7A79787B7B79767A77767575747473727271716E6F6D6E6D6E6D6D6D6C6B6B6D6C6C
6B6C6A6D6B6C6B6D6D6D6C6D6D6D6B6E6C6E6D6F6C6D6E6D6E6C6F6D6B6E6E6D6E6E6F6E
6F6F6E7272707071727070737373737575747374757576767678797A7879797778797878
76757473726F6D6C666159534D4945423F3D3A38373533312F2F2D2D2C2B2B2A2A292929
282828282828282727282728272727272727272726272627262627262627262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
272627262726272626262627272726262727262727272727272727272727282728272828
282928282929292829292A2A2B2B2B2B2C2D2C2D2E2F2F3131333434363838393B3C3E3F
404244454648494B4B4C4D4E505052535453575656585A5B5D5C5D5E6061616163656665
676A696A6A696C6C6E6F6F7072747276787779797A7C7C7D807E7F7F8281828486848585
858583848583858385838385868685838283858485868685858787878686888987878888
8989898C898B8C8C8D8A8A8C898B8B8C8D8C8E8E8C8B8D8B8C8C8B8A8B8A888C8C8B8D8B
8A89898A8A8A8987888787858685848585848683838383818180817F8381828081807F7F
7E7E7C7E7B79787B78767678767777747374727171706F6F6E6E6F6E6F6C6A6C6C6B6C6C
6B6E6B6B6D6B6C6B6C6E6C6D6C6D6D6C6C6D6D6D6E6D6C6E6E6E6D6E6E6C6D6E6D6E6F6E
6E6E6F6F726D6E6E7071727073707372757474727474757776777A777979777A7A787877
77777574716F6F6D6A67625B534D4946423F3C3A3838353332302F2E2D2B2B2B2A292929
292828282827282727272727272727272727272627262627272726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
262626262526262626262625252626262626262626262626262626262626262626262726
262626262626262726272626272726272726272727272727272727272727282827282728
27282828282929292A2A2A2A2B2B2B2B2D2D2D2E2E2F30323234353638393B3B3E3F3F40
42444747484A4A4C4E4F4F505353555456565658595C5B5C5E5E5E5E6163626364646666
666A6A6A6C6A6D6C6E6E717273737575767879777A7C7E7E7F8082818183858385868486
8486888788888986858585838685858385868685878787868689868A898988878A898A89
8A8A898B8B8A8B8C8B8A8C8B8A8B8C8A8C8E8D8D8E8F8C8E8C8E8D8C8D8C8C8C8F8D8D90
8A8B89888A8A888989888686858585858483858686868483828184838281838281808084
80807C7D7C797B797A7A7A7A76777675757772737572717270716F6F6F6E6D6C6C6B6B6C
6B6B6B6D6B6D6A6B6D6D6C6D6B6C6C6B6D6B6D6E6D6E6C6F6E6C6D6E6D6D6C6C6B6E6F6E
706F6F6F6F70706E6F7170727074737072717273747474737476777877777878787B7675
787677747471726E6D6A65625B534E4947433F3B3939373433312F2E2D2D2C2B2A2A2929
292928282828282828272827272727272727262727262627272726262726262626272627
262626262626262626262626262626262626262626262626262626262626262625262626
2626262625252626
252626262626262626262626262626262626262626262626262726262626262627262627
262626262626262626262627272726272727272727272727272727272827282727282828
28282828292829292B2A2A2A2B2C2C2D2D2E2D2E2F303233343636383A3B3D3D3F414243
454649494B4B4C4F505152535455545858585A5A5B5C5B5E5E6062616162616463686666
68686B6B6B6D6D6E6F6E70717473757576787A7A7B7D7D7F7F8080848286838786848787
8787878888878789878788878785888787868688878685878687878888878A8988888988
898989888A8C8B898B8C8D8C8E8C8D8E8C8B8F8B8F8C8E8E8E8D8D8D8E8D8D8C8D8F918D
8E8C898B8B8A8B8A8A8B8B89888688878586838682858483828584868584848382828281
817F81807D7E7C7A7D7C7A79787977787676757572727071706F70706E6D6F6B6D6B6C6C
6B6B6A6A696B686A6B6C6D6C6A6C696C6A6B6C6D6A6A6E6E6D6D6E6F6E6B6E6C6D6E6F6C
6D6E6F706E6E6E716F716E7071716F7172727172737372727473737477757778797A7978
78777777747373726D6E6A666059524E4B47423E3B3938363533312F2E2E2C2C2B2A2929
292828292828282827282727272727272727272727272727272626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626252525262526
252626262626262626262626262626262626262626272626262626262626262627262627
272726262626262726272627272627272727262727272727272727272827282728282828
282828292929292A2A2A2A2B2B2C2C2D2E2E2F2F303132343537373A3B3D3E4041424446
48474B4A4C4D4F4F5554545657575859585A5A5C5A5C5F5F5F6161606164636467686768
696A68696B6D6E6E6E707272737376777778797D7C7E7F80828283838486858488878988
8A8B89898B8D8A8A8989888B8A87888887858985888987878687878886878A878A878989
8B8A8A8B8E8A8B8B8C8D8B8C8C8B908D8E8D8D8D8F908E8E8E908D8D8C8E8C8D8F908E8F
8D8D8E8B8D8D8A8C898B8C8C8A8A88888687868786878583858887858585868483848282
808084817F7E7D7D7E7C7C7B797B7A777676757674747370727170726F6F6D6C6B6B6D6C
6A6C6A6B6A6B6B6B6C6C6C6C6C6D6B6A6B6C6B6B6B6D6B6C6C6D6D6D6F6D6C6C6D6C6F6E
6D6C6D6C6F6E6F6E6F70717070706F716F6F707171727373737275747576777878797876
797778777575747271706C6A676159534E4A46423E3C3A38363533312F2E2D2D2B2B2A29
292929292828282828282828282727272727272727262626262627262727272626262627
262627262626262626262626262626262626262626262626262626262626262626262626
2626262626262526
252626262626262626262626262625262626262626262626262626262627262726272627
262626262627262726272727272727272727272727272727272728272727282828282828
2828282829292A2A2B2A2C2C2C2D2D2D2E2E2F303232343536393A3C3C3E404144454748
494B4D4F4F505252535657575A585A595B5B5C5E605F5F60626262636365646566666767
6A686B6C6D6C6E6E6F6F72737274767478777B7A7C7E818081818383858487878888878B
8A888B8A898B8D8A8B8C8D8B8B8B8B88898B8A8B8B898A898989868788888A888C89888B
8B8A8B8A8B8A8D8C8A8C8E8E8E8E8B8C8F8C8E8E8E8C8E8F8F908F8E8F8D908D8F8F908F
908F8D8B8B8A8D8E908C8C8D8C898A878986858588848687878687848586878385848385
84848180827E827F7D7D7C7E7B7B797A79787776747575737271726F716F6F6E6D6F6E6D
6A6B6A6B6B6A6C6C6B6C6B6A6B6C6C6B6B6A6C6A6B6C6A6C6D6B6B6B6D6D6D6D6C6D6D6E
6D6D6C6E6F6F6E6F706F706F6E706F707171706E71717070707472747475777679797879
797878767575757673716F6C69665E58534F4A45413E3C3A3736343231302E2D2D2B2A2A
2A2929292928282828282827272727272727272727262727272727262627262726262626
262627262626262626262626262626262626262626262526262626262626262626262626
2626252626262626
252626262626262626262626262626262626262626262626262626262626262627262626
272627262627262726272727272727262727272727272727272727282727282728282828
2829292929292A2A2B2B2B2C2D2D2D2E2F2F30313234353739393C3D3F4242444748484B
4B4E4F50525353555658585A5B5C5C5D5E5E5F605F606162626363646567666766666669
6A6B696C6C6C6E6E6E70737273737477767B7A7D7E818183808285858487858787898A8A
8B8C8A8C8C8D8D8E8D8A8D8E8F8D8C8D8A8C8C8D8B8D8B8A88878989898B8B898A8B8A8A
8B8D8C8B8B8D8B8D8B8D8A8D8C8C8E8F8E908E908D908F8F8F8F8F908D918F919091918E
908F8F8A8C8B8D8C8E8F8F8D8C8C8A8C8A898A8789898787878987898684868585848385
8382828480848280807F7D7E7D7A7A7B797A787775757675727272707171706E6F6F6E6C
6C6C6B6C6B6A6C6D6A6B6C6C6A6C6A6B6A6B696969696A6A6C6C6C6E6E6C6B6D6B6B6C6C
6B6C6D6C6C6D6E6D6F6E6F6F6F6F7070707171706F707072727273717273727574787878
78797979757675747573706F6C6A655F59544F4844413F3C3A37363432312F2E2C2C2B2B
2A2A29292829282828282827282728272727272726272727262727262626262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626272626262626
272626262726262626272727262727272727272727272727272727272727282828282828
2829292929292A2A2A2C2B2C2C2D2E2E2F30313134353738393C3E3F4144454647494A4D
4E4F525353555658585B5B5C5B5E5F625F60626263636563646565656467656667686869
696B6B6C6D6C6E6F6F7071737473767579797A7E7F8180838281878585878789898B8A89
8A8C8C8A8D8D8D8E8F8F8F8F8F8F8F8D8F8D8F8F8F8B8D8D8C8A8B898A898A888B8A8B8D
8C8A8C8B8F8D8C8D8E8E8F8C8E8D8D8D8F8C8B8F8F90918F9092918F8F8E8E9193909191
908F908E908F8E8D8E8E8D8C8C8C8B8C8D8C8C8B888A8A89888686858785848286858787
85848583838482828282807F7E7D7E7B7D7B7A77787874777676737372736F706F6E6F6E
6E6B6C6D6C6D6C6B6B696B6A6C6B6B6A6C6D6A6B696B6B6B6B6A6A6D6B6D6B6B6C6C6A6A
6C6C6C6C6C6D6D6D6D6E6F706E6F7070706F6E70716F7070707171727273737577767579
7878797877777675737172706F6C6964605A544F4945423F3B393735343230302E2C2C2B
2B2A29292928282828282827272727272727272727272627272627262626262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626252626262626262626262626262626262626262626262626262626262626262727
262726272627272627272726272727272727272727282727272727272828282728282929
282928292A292A2B2B2B2C2D2D2E2E2F303033333537383A3C3D3F41424546494B4C4E4F
515254545659595B5C5E5D5E616261616261626565666466656765666669686869686969
696C6C6D6C6A6D6E71707073727375777A787B7E7F808081848384888889898A8789898C
8A8C8C8D8B8E909090908E908F909190908F8F90908E8D8C8C8C8A8A8A8B8C8C8B8D8B8B
8B8A8C8F8E8E8C8D8F8C8D8E8D8B8F90908E929192918E9092909392919191918F909090
90919190908E8F8F8E8D8F8E8B8D8D8C8E8F8C8D8C89898B898A86878784858682878687
8786848586828484838183827F817E7E7F7D7B7B7A7A7878777675747473726F7171706F
6C6E6C6E6B6C6B6C6C6B6B6C6C686B6B6B696A6B6A6B6B6B6B6A6D6A6B6B6A6A6A696A6A
6D6C6C6A6D6C6C6C6E6D6D6E706D6F6E71716F706E716F72706F71736F72737474747676
777777767676757674727271706D6B67645F5A514C4844403C3A3837343432302F2D2D2C
2B2B2A2A2929292828282827282828282827272727272727272726272627262626272626
262626262626262626262626262626262626262626262626262626262626262626262625
2625252626262526
262626262626262626262626262626262626262626262626262626262626262726262627
262627272626262627272727272727272727272727272728272827272728282828292928
2929292A292B2A2B2B2C2C2E2D2F2F2F3133333436383A3B3D3F41434446484B4C4E5051
53545658585A5D5D5E60606263626465646567666868686865696868696968696A696969
6B6B6B6C6E6F6E6E6E6F727473757876787A7D7D7E7F8080838584898A888B8C8C8A8E8C
8C8B8C8C8E90929291908F9191909293938E929290908E8D8D8A8D8D8B8D8E8A8C8E8D8F
8D8E8D8D8D8F8D8D8F8E8E90918E908F9091929093929190928F92939391939393909090
919291919292909092918F9090908F8D8E8B8D8E8D8B8A8B8B8887868788868686868886
86868584868285858483838480808181817D7E7D7A787A787A7875767474747271726F6F
6F6D6D6D6C6B6C6B6B6B6D6B6C6C6C6D6B6B6C6A696A6A6A6A69696B696B6B686B6B6A6B
6C6B6C6A6C6A6D6D6C6C6E6F6E6E6E6F706E6F6E6F6E6E70706F70717272727172717674
747576767977757775757274716E6E6B6965615A534C48443F3C3A3837353332302F2D2D
2B2B2A2A2A29292929282928282827272727272727272727262627272727262727262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626272626262626262627262726272626
262727262726272726272727262727272727272727272727272727272828282829292828
28292A2A2A2B2B2C2B2D2D2D2E2F30313233343638393C3C4041434547474B4C51505254
5458585C5C5E5E616062646564666666656869686A69696B6A696A6C6A6D6C6C6B6C6B6D
6C6C6D6D6E6C6C6F6E70717374767878797B7B7E7C8080808384878989878A898B8E8B8C
8C8C8F8F90908F919392939493909393929291939293919190918F8F8D8F8D8D8C8C8D8E
8D8E908E8E8F8F8E8F8F918F8E92908F9191939295929193909293929193929291929293
9391929290919191918F908E8E8E918F908E8D8F8E8C8B8C898989888988888887868787
8587878687878784878784858382828583817D7D7D7C7D7A7A787679787476757472706E
6E6F6D6E6D6C6E6A6C6B6D6D6B6D6E6D6D6B6C6C696B696A6A6A696969696968696A696A
6A6B6A6E6A6C6B6A6C6D6C6D6E6C6E6E6F6E6C6E6D6E6D706D706E6F6D6F707171727473
74747576747675757475727371706F6D6A6864615B544C47433F3C393836343331302E2E
2D2B2A2A2A2A292928282828272827282727272727272727272626272726262627262626
262626262626262626262626262626262626262626262626262626262526262626262626
2626262625262526
252626262526262626262626262626262626262626262626262626262626262626262626
262626262626262727272727272726272727272727282727272728282728282829282929
29292A2A2B2B2B2B2C2D2E2E2F2F3132333436383A3B3C403F434346494C4D4F53535555
59585B5D5F5F62626465656666676A676A696A6C6D6B6B6B6C6B6C6C6E6D6B6C6C6C6C6B
6F6D6B6D6E6E716F7171747375777779787A7C7D7F80848286878688878B89898D8B8D8C
8D8E8E8F929394919294949191959593979795949494949495939291918E8D8E8D8D8F8F
8F8E8E8F8D8F8E8E8F909091918F8F909291929192929493939292939191939594949393
939396939394939393939390908F91928E918E90918D8E8F8C8D8A8B8B8B8A8A87898B88
87888887868788898687868585838282828180807E7E7E7D7D7B7C787879777373737070
6F6F6C6D6E6D6E6C6D6B6D6B6C6E6C6C6A6A6A6B69696A696B6B68686A6B6A68696B6B6B
6A6B6A6A6A6C6C6B6D6B6A6C6C6D6C6D6D6D6F6D6D6E6D706C6E6F6F70706E7070717271
7173737575767574757374757371706E6C6A67646159524B4743403D3A38363432312F2E
2D2D2B2A2A2A2A2928282827282827282827272727272727272727272626272626262626
272626262626262626262626262626262626262626262626262626262626262526262626
2626262626262526
252626262626262626262626262626262626262626262626262627262626262726262726
262726262627272726272626262727272727282727272728282828282828282828292929
292A2A2A2A2B2B2C2D2D2E2E303131323536383A3B3D3F404343474A4B4E4F5154565858
595B5D5D6062636466676867696C6C696C6C6C6C6F6D6C6D6F6F6E70706D6F6D6F6F706D
6E6F6F716F7071737275757577767879797B7E7C7F82828384868589898A8A8C8A8C8B8C
8E8D91918F92939192929093949393969698969596969696959494929090908F8F908F90
918D918F8F8E91929090908F8F9193919392939490929493939494939393939494939694
95949395949596929394959492959493939490929192908E8E8C8C8C8C8C8B8A88898888
888987898887888887888787868383848585828182807E7E7C7C7C7A7A7978787673726F
706E6F6E6D6D6F6C6D6D6B6D6B6B6B6C6B6A6B6A6C6B6B696A696A686868696969696869
6B6A6B6A6A696B6A6B6C6B6B6C6C6E6C6E6D6E6E6D6D6D6C6E6D6F6E6E6F716F71717170
73727273737575767775737371726F6F6C6D6B67646156504A4643403C3A37363532302F
2E2D2C2B2A2A2A2929292829282828282727272727272727272727272626262627272726
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262625
262626262626262626262626262626262626262626262626262626262626262726262626
262726272727272727272727272727272727272727272827272827272828282829292929
2A2A2A2A2A2B2C2C2C2E2E2F303032333637383B3C3E40424546494B4D50525355565A5B
5B5E5F626465666767696A6A6C6E6C706E6E6F6E706E7170717173706F70716E71707271
70707373717173747273737576767878797C7D7E8081838385878687898B8A8C8D8D8D8E
8F8F91908E91929191969394939295969696979495969797969796939292919192929091
8D8F9190918D92908F919391919191929294949394939192949494919293939395959694
949595949392959795969594939295939293939191929092908F8C8D8D8B8A8A8B8B8788
8A888989898A878887898887868786858587848280827E7F7C7D7D7B7B797A7776767472
7070706F706D6E6F6D6C6F6B6A6D6C6B6B6A696B6C6B6B6A686868696867686A696A6B6A
6A6B686B6A6A6A68696B6A6A6D6C6C6C6D6F6F6D6D6F6D6E6E6B6D6E6D6F6F706E706F71
7171747274757473747374726F71726F6D6D6C6B67635D544E494541403C393836343230
2E2E2D2C2B2A292A29292829282828272828272727272727272727272727272627262626
262727262726262626262626262626262626262626262626262626262626262626262626
2626252626262626
262626262626262626262626262626262626262626262626262626262626262626262726
272726272726272726272727272728272727272827272728272828282828272829292929
2A2A2B2B2B2C2C2C2E2E2F303033333536393A3C3D40424548484A4C4F515456585B595B
6062646465666969696B6E6D6E7170717072717270737372737271737472717172727273
737372727477717474747675767879787B7D7E807E7E82858488888B8A8B8A8B8C8B8F8F
908F91908F9090949794969794939496999998989B959898969895999694929393929190
9293908F91929092939191918F9491949393949295969593919492939393939696949496
96979693969595969598969494939494969495939193928F929191908F8D8D8D8C8D8A89
8B8889898A89898A8D898A8B8489858685848684828381827D7E7C7C7C7A7A7A79767672
70706F70706C6E6F6F6B6D6C6B6B6B6A6A6B6A6A6A6B6C696A696969686969696A69696A
6969696A6A68696A696A6D6B6A6B6D6B6C6A6C6C6C6D6E6D6D6B6C6C6D6E6E6E6F706F70
6F7171737376747373747472707072716F6E6D6A6A67615C534C4844413E3B3937353431
302E2E2D2C2B2A2A2A292928282828282827272727272727262727272727272727262627
262626262626262626262626262626262626262626262626262626262626262526262626
2626262626262626
262626262626262626262626262626262626262627262626282A28262626262626272626
26262727272727262727272727272727272727272727272828282828282828282829292A
2A2A2B2A2B2C2C2E2E2E30303233353637393C3E3F41424648494B4E51535658595B5D5E
606264666969696B6C6F6F70707274727373757575737474767574757473757474707475
7573757575777575757575747878797A7A7D7B7D8180848386868989898C8B8C8D8C8E8E
8E919191909090929397979896969496979998999897969699979B999899979598959492
929295929191939291919290909093929396939495959694919493939392949495959596
989597979997969A9A999998999A95969398909393939291909191928F8F8E8C8F8E8C8B
8D8B8C898A8C898A8B8988898A8987878685848485838382827F7F7C7D7C7B7A7A7A7775
75737071716F6E6F6E6D6C6C6D6D6C6B6E6C6C6A6A6A696A6A6969696969686B6A69696A
696A6A696A69696A696A6A696B69696B6B6C6B6C6D6E706B6E6D6F6D6C6D6D706F6E7070
7172717071707173717373727171716E6E6D6C6C6B6A67615B534C4744413E3B38373433
31302E2D2C2C2B2A2A292928282828282828272727272727272727272727272626262626
272626262627262626262626262626262626262626262626262626262626262626262626
2626262526252625
262626262626262626262626262626262626262626262626262627262626262726262626
272627262726262727272727272727272727272727272728282728282829282829292A2A
2A2B2B2C2C2D2D2E2E2F3032323435373A3C3C3E40434648494C4D50535658585B5E5F61
63646567696B6D6D6F707073737474757477777778797877767577797877777776767576
757774767578777677777776767A797B7C7E7E7C7F8283858486898989888E8D8D8D8F8E
90908E8F8E91919094969A9A989897949796999C999A99989A9A9C9A999C999998989795
969492949492919491939394939292949794969797979693949394939694949593949396
9798979696979697999B9B9C9B979A99959594929393929292928F8F8E8C8F8F8E8F908B
8D8C8E8C8A8C8A8A8B89888B8A8A888789888785868684848382837F7F7D7E7A7A7B7878
7875717172706F6F6E6E6E6E6D6C6D6B6A6B6A6A6C696A6B6A6B696A696A69696A696A69
6A686A69696A686B6B69686A6A696B6A6A6A6C6D6E6E6D6D6C6B6C6B6E6B6D6C6D6E6F70
706F706F707272717171737170716E706E6F6E6E6C6B6865605B514B4742403D3A383735
33302F2E2E2C2C2B29292929282928282828272827272727262727272727262627272727
262627262626262626262726262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262526262626262626262626262626262726262626262726272727
272627272627272727262727272727272728272727272828282828282828292929292A2A
2A2A2C2C2D2D2E2E2F303032343537383B3C3E3F4145464A4C4F4F52555759595C5E5F62
65676B6B6C6C70707274737475767979797A79797A7A7B787A7B7B787979797979777977
78787678767778757876777677787A797D7D7D7C8082868688878687898B898C8C8D8E8E
90928F9190918F9093989A9A98989692989A999C9A9A999A9B9B999C9C9A9B9B99969597
999798949596969392929492949593979496949497979796979595959393989795959596
9595999798959497999A9C9D9B9A98989795939796949393939190908F8E908E8E90928F
8F8E8E8C8B8B8B898B898A8B888B898989888984868384858284848283817E7D7D7B7B7B
79777775737373716E6E6E706F6E6D6E6E6C6D6A6B6A6D6C6B696A6A6B6A6B6B69696868
6C696A6A6A696A6A696B6B6868686A696A696A6B6C6D6B6D6B6B6A6B6C6A6B6E6C6E6D6C
6C6D706F6F6F7070706F707170706F6E6E6E6D6E6D6C6B68665F58514B46423E3C3A3836
3432312F2E2D2C2C2A2A2929292829282727282828282727272727272727272726272726
262626262626262626262626262626262626262626262626262626262626262626262626
2625262626262626
252626262626262626262626262626262626262626262726262627262626262626272627
2727262726272727272727272727272727272728272827272828282928292929292A2A2A
2B2B2B2C2D2D2E2F303032343437383A3C3D40424446494B4E505154565A5B5C5F606365
6668696E6D707074747577777879797A7A7C797C7C7E7D7E7F7E7C7C7C7C7B7A7A797979
7B79797979797A797978797879797B7E7E7E7E8080818085868787878687898A8D8A8C8E
8E928F8F8E93939393969A999A9997979496989B9C999A9898999D9B9E9C9B9A9E999898
999A98979697979595949594959295969695959596979898979795959697999798999496
95949797979798989898989A9B9B9B989995989894939495939090909191909091928F92
8F8D8D8E8B8C8D8D8C8B8C8C8B898A8A878B8A888786868587868384848480827F7E7D7B
7B7877757475737270716E6D6E6F6D706E6F706D6D6C6D6D6D6C6C6C6B6C6A6B6A6A696A
6B69696A6A686A6A6A6A6A6A6A68686969696A6A6C6C6B6B6C6C6A6D6C6C6B6D6B6D6C6B
6D6E6E706D706E71706F6F706E6E6E6C6A6E6C6D6C6C6A6B67645F594F4944403E3C3937
353432312F2D2C2B2B2A292A292929282828282827272727272727272726272727262626
262626262626272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262627262627262626262727
2726272727272727272626272727282728272727282728282828282829282929292A2A2B
2B2B2C2D2D2D2F2F3032323436383A3C3D3E404446464A4C4F515256585A5D5F61626567
696B6B6E7171747276787B797C7A7D7C7E7E7F7E807F80807E7E807D7C7C7D7B7C7B7C7D
7D7C7B7B7A7B7A7978797A797C7C7C7C7E7F81828181838384858587878A8A8A8A8B8B8D
8C8D8D8E929391959395969B95969A9698989A9A9B9A9C9899999D9B9E9B9B9D9D9B999C
9C999C999799989596979697949594969897979796989A989A9899969797989998999899
9696979A9798969897999B9C9B9C989B9999969795959596939492929391929093919492
928E908E8F8E8E8F8E8D8C8C8A898A8B898B8A89888788888786858686818280807D7E7E
7B797977787674737171736F706F70726F6E6F6D6D6E6C6E6E6E696D6C6C6B6C6A686A69
696B686A6C6A6A6A6A696A686A6869696A68686A6B6A6C696B6A6A6B6C696A6C6B6A696B
6C6D6C6D6C6E6E706E6D6F6F6E6F6D6E6C6C6B6B6D6A6A6B6865625E554E48443F3D3B39
373634322F2E2D2C2C2B2B2A292928282828282827272727272727272726272726262726
262626262726262626272626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
26272626272727272727262727272727272727272828282828282828292829292A2B2B2A
2B2C2C2D2D2E2F30313234353738393D3F41434547494C4D50525556595D5E5F6362686A
6C6D6F7172757476777A7A7B7C7E7D7F7F818381808080818280838181817F817F7E7D7E
7E7E7C7E7B7C7B7D7D7C7B7C7A7C7D7F80817F817E8183838484898687888A8B8B8A8A8B
8C8D90929095939492959494969C989B9798999AA29A9C9C9A999B9B9D9D9C9DA09D9C9C
9B9D999B9998989898969497959597959897989996979A9998989699969B979798989897
97979B96999999989897999C999A98999A97969595979695949595939391939193919291
919290908E908E918F8E8D8C8D8D8A8C8C8C8B8A8A87878788888788858485838180807F
7E7D7C79797975767574747371727172716F71706E6E6C6E6D6D6C6D6B6C6C6C6B6A6A6B
6A69696A6A6A6B69686A696B686D696B696A6969696A6B69696B6A6C6B6C6A6B6B6B6A6A
6B6B6A6C6E6E6D6D6E6D6E6E6D6D6E6E6C6B6B6C6A6B6B6B696764615D534D47433F3D3A
39363433322F2E2D2B2B2B2A2A2928282828282727282727272727272727272726272627
272627262626262626262626262726262626262626262626262626262626252626262626
2626262626262626
252626262626262625262626262626262626262626262626262626262626262726262727
2627262727262727272727272727272727272727272728282828292928292A292B2A2B2B
2C2C2D2D2E2F303132343536383A3C3E41424446494A4E50525457595A5E62626566686A
6C6E707375767879797A7E7E7E8082808382828482848283848182858383848283828381
818281817F7F7F7F7F7E7E80807F817F81808282828082848383878588868A8B898B8B8A
8A8A8C8F959392939192919096A8999C9A99A6A29C9B9C9D9D9B9E9E9F9EA09E9F9FA09D
9D9E9C9C9D9A9B9797989794989696979597979A99999A99989898989999999799989796
98999A969A9999969899979B9899989D9898979896979797979796949697949592929292
909291918F8F8F8E8F8E928F8E8E8D8B898D8C8A8A898989898988888886848583827E80
7E7E7B7C7B79777776757473737273717172706F6E6F6D6F6F6C6F6D6C6D6C6D6B6B6B69
6A6A686A6A6A69696A69686B6A6B676869676968696A6C6B696A6B6A6A6A69696A696B6D
6A6A6C6E6C6D6E6E6E6D6C6E6E6D6D6C6D6A6B6C6B6A686969696763615B524A4743413C
3A38363432302F2E2D2B2B2A2A2929282828282827282827272727272727272727272626
272726262726262626262626262626262626262626262626262626262625262626262626
2626262626262626
252626262526262626262626262626262626262626262626262627272626272727272727
2626272727272627272727272727272727272828272827282828282829292A2A2A2B2B2C
2B2D2D2D2E303132343536383A3C3E41414546484B4C4F535454585A5C60616467686A6E
6E7171737578787B7C7E7D7E818482848584858585848683868686888485858484848686
8482828181818181827F818081807F838082808382838483868686868588888988878889
888C8C8F8F929291918C909095989797999A9A9A9B9A989C9D9C9D9E9D9FA0A29FA09E9F
A09E9C9C9A9D9E9B9B9B9B9A979A989996989A9997999A999A999B9898989897999C9A97
9999989998999A9A9A9A9A979A9A9C989698979897999999989696979696959593929191
92959290929293928F8F8D8E908D8E8D8E8C8B8B8B8A8888898A88898788848485848380
7E7E7E7B7B7A7879777874737374727473716F71717071706E6E6C6E6C6D6E6D6C6D6C6C
696A686A6A6B69696969696A696A6C6A6A696969696A69696A6968696B696A6868696968
6A6A6A696C6B6C6C6C6E6C6D6D6E6B6C6D6E6D6C6A6C6A6A68686A69635F59504A45413E
3C3937373332302F2D2D2B2B2B2929282829282828282728272727272727272727272627
272726272626262626262626272626262626262626262626262626262626262626262626
2625262626262626
262626262626262626272626262626272626262726262627262626272726262727262626
2727272727272727262727272727272727272727272727282828292929292A2A2A2B2C2B
2C2D2E2E2F303233333538393B3D3F414445484A4C50515355585A5B5E61636667696D6E
7073737677797C797D7E818384848587848588888886878788898B898C8A8A8786848987
8586848585858284838184848083828382828282838285848686858586868889898A898B
8B898C909093918F908F8E93929798999A999699999B9B9B9C9D9B9D9FA0A09FA1A0A3A1
A09F9D9EA09E9E9F9E9C9E9C9B9C9A9A9B9997999B969A999B9A98999898979A989B9999
999A9A999C9A9A979A999C9B9B9B98999A99989A97979698989798989998989796939394
9393929093918E8F91908F909390908F8C8F8A8D8B8A8B8C8A898B898987878685848584
80817F7F7C7B7B7A77767675747575747172727274727071706F6F6D6E6F6D6B6D6C6C6A
6B6B69696969696A6869696A6A6A696A696969696A6768696967696A6A6966686968686A
6969686A6C6D6D6C6C6D6D6E6C6D6B6C6C6D6F6D6B6A68696869696869645E56504A4341
3E3C3A363433322F2E2D2C2B2B2A2A292929282828282827282727282727272726272727
262627262626262627262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262625262626262626262626262626262626262727262627272727272727
272727272727262727272727272727272827272827282828282829292A2A2A2A2B2B2A2C
2D2D2E2F303132343636393A3D3F40434447494B4E4F525556595C5F626264676A6B6C6F
72747576797B7D8080818285858685868889888A8B878B898C8E8C8B8C948A898C898A89
898A87888786848684878585858482868285848485858483858684858986878689898889
898A8B8B8D8E90908F90919294979997989897979898989C9C9E9DA09F9FA1A3A2A5A1A3
A1A19FA2A0A29FA09E9E9D9E9D9D9C9A9C9A99979B98999A9A98999B9B99999A9B9D9C9D
9B989A9997999B9C9B9B979A9C9A999C9B9B989B9B999A9998989A999B9A989997959393
919394929492919192919191908F8F918F908F8F8B8B8B8A8B8C8C8C8989888888888785
8382837D7C7E7C7D7B7A79787776757473737470717372727071706F6E6D6C6D6C6D6C6D
6A6B6968696B696A6A6A696A6A696A686A6869696A686A6A686A68696867676869676965
686A68696A6C6C6C6E6E6C6D6C6E6E6E6B6C736F6C6A6A6A69696B6B6865625C564D4843
3F3C3B39373432312F2E2D2C2B2A2B292929282928282828272727272727272727272626
262726272727272626272626262626262626252626262626262626262626262626262626
2625252626262625
262626262626262626262626262626262626262626262626262626262727262726272726
26262727272727272727262727272727282728272828282828282829292A2A2A2B2C2B2D
2C2D2E2F3031333536383A3C3D3F414345494A4C4F515456595B5E5F6464656A6A6E6D72
7376757A7B7C7E7E81818486898889898A8B8B8B8B8A8D8D8F8F8F8D8D8C8A8D8C8D8D8B
8B8A8A8A8C8A898A88898689878887868783868688858786878687868986888885888887
868889898B8A8D8F909093919496989494939797969B9A9B9B9C9EA19FA1A0A0A2A2A2A6
A2A3A1A2A0A2A0A3A2A19EA09EA0A09C9C9B9A9A99989C99989B99989B999B9A9B9A9B9C
9B9A9A989A999B9B999B9C999A999E9D9D999C9E989C9A9799989A9A959A989897979496
9494959493929295939293938F8F91908F8F8F8E8C8C8C8D8C8B898C8B89898987888785
848383837E807D7D7A7979777876777575737472717272717273716F6F6B6F6E6C6B6D6B
6C6B6A6B6B6A6B6B6A696A6A6B6A69696968686969686A68696A69686A68686868686869
68686769686A696B6A6C6B6C6D6D6C6C6D6C6B6D6C6A6B696A6869696866635F5B534C45
413F3E3A37353432302F2D2D2C2B2B292929282828282828272727272727272626272726
262626272726272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627262626262626262626262626272627
27272727272727272728272727272727272727282828282829282929292A2B2A2B2B2C2C
2D2D2E303133333537393B3E3E414345474A4C4F4F525657595D5E62626468696C6E7174
747878797E7C7E8182828586878B8B8B8C8B8E8F9090919191929091908F909090919090
8D8E8E8C8E8D8A8C8B8A8A8B898A88888688848787858587878487868686888688878889
878888898A8B898D8E90929394979493919295989B9A9A9D9C9E9C9FA1A09EA0A0A5A4A2
A5A5A5A6A4A2A2A3A3A1A2A09FA19C9F9D9D9D9B9B9E9B9B9B9C999A9B9A9C99999A9D9C
9B9D9A999A99999799999898999C9C9B9E9B9B9A9E9B9B9C9A9A99999B999E9898979697
95959493949391959495939591929091908F90918E8D8C8C8E8E8D8D8B8D8A8B8B898887
858485838481817E7C7D7B787677787776767373747372737373736F6D6D6F6E6D6D6C6D
6C6B6C6A6A6A6B6B6B6A696A68696969696A686B69696A6A6A6969686967676767676569
666767676868696A6B6C6C6C6D6D6E6C6C6D6D6B6B6C6B696A696769666666635F595149
4442403B3837353432302E2E2C2C2A2A2929292929282827282727272727272727272726
262627272626272626262627262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262627262626262626262726262626272627262626262727
272726272627272727272728272727272727272728282828282929292A2A2B2A2B2C2D2D
2E2F303032333537393A3D3D4042464549494D50525355595C5E61636767696A6D707374
77787A7D7C7F84818485888988898B8C8C8C8F8F93929395939493929294939295929493
909191909090918E8D8D8C8B8C8A8A8A888A8B8A88888887868688888786858786878887
868A8888898C8C8C8A8D8E9092949393929797989A9C9C9C9A9CA09EA1A2A0A2A2A0A2A4
A4A4A3A5A6A4A4A6A4A2A4A3A3A2A1A0A09E9F9B9A9A9C9D9B9B9A9A999B9A9A9B9B9C9E
9A9B9B989C9A9C979A99989A9A9C9E9E9E999B9D9D9E9A9D9C9A9B9A989A9B9E9B999B99
9694969593949693949495929392919190918E8F8D908D8F8B8E8F8D8B8D918C8C8D8886
87858586838383807F7E7D7B7A787978777575767373737374747472716E6F6F6E6E6D6C
6B6C696C6A6E6A6B696A6A696C686A6968676A686A69686B6A6B6A686669676668696767
67666666676868696969696B6C6D6D6C6B6E6E6B6C6C6C6A6B696A6867666663625E5750
49453F3D3B3737353231302E2D2C2B2A2A29292828292828282727272727272727272727
262627262626262626262626272626262626262626262626262626262626262626262626
2626252626262625
262626262626262626272626262626262626262626272626262626272627262627262627
2627272727262727272727272727282728272828272828282829292A2A2A2B2B2C2C2D2E
2D2F3131333536383B3B3E40414246484B4D4F515456585B5C60616565686B6D70737376
78797C7D7F7F81858687888A8C8F8E8D8E90909192939699949697959596959795959695
96949292939392908F908D8E8F8E8B8D8C8C8A8B8A898988878987898785878685868687
878A888888898B8B8C8C908F928F8C90929497979B989C9B9DA09E9E9F9F9DA1A0A1A2A3
A3A7A6A7A5A8A6A6A5A3A7A4A5A3A2A3A2A19F9D9F9E9B9E9B999C9B9B9B9A9B9A9B9E9C
9B9C9D9D9C9C9B9B999B9A9B9A9FA09F9A9A9C9C9D9D9F9F9E9A9B98989A9B9C9A9A9C9B
99999797989796959495949595929291918E918E8D8F8D8E8E8E8F8E8D8E8D8E8B8A898A
898588838586848282817D7D7E7C7C7B7A787776757575777574747273726F706F706F6D
6C6C6B6C6B6C6A6A6A6B6A696D68696969696969686969686A6868666867686667686766
656867676767686A68696B6C6A6D6E6E6D6C6C6C6C6C6B6B696869686664666461615E55
4D4743403C3A38363433302E2D2D2B2B2A2A292829282828282727272727272727272727
272727262627262726262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262726272626262626262627262626272626272727262727
2727272727272726262727282727272727282728282828282829292A2A2A2B2B2D2D2E2E
2E303133343637383B3D3E41424446484C4E505355565A5B5E616366696B6B7071727477
7A7A7F817F82848687888A8C8C8D8E8E8F92939293949799969699999A97979897999798
989596979594959292949291929091908F8D8C8D8E8C898B8A8A8A898A88898988878787
89888A8A8888898B8D8C8F8E8E9293919294979598979B9B9E9F9E9EA1A1A19FA1A2A2A4
A5A6ABA9AAA9A8A6A8A6A4A5A5A6A4A5A2A2A3A1A1A1A09D9E9C9D9A9D9D9C9A9B9C9C9C
9C9D9B9D9F9B9D9D9A9C999B9D9E9E9D9D9C999B9EA19F9F9E999A999C9C9B9B9C999A99
9B999998979797959695979794969393929394918D908D8D8F8E8E8B8D8F8E8C8B8B8889
8687858887888586828281807E7C7E7B7B797A7978777876767674767471727172706F6C
6D6B6E6E6E6D6B6A6A6B6C69696B6B6A6A6A6969696A676A6A6869676765676765656667
6665686767696666676868696B686B6C6C6B6C6C6B6A6C696A6A6867666766656563605B
534B45433E3C3938353331302F2D2C2B2B2A292929282828272827272727272727272727
272727272727272727262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262726272626262627262627262726272727
2727262627272627272727272727272828272828282829292929292A2A2B2B2C2D2D2D2E
303031323437383A3B3E40424346494B4D4F525457595C5D616265696A6B6F7073757779
7D7B7D8082848586898A8B8F8E8E9090939193969596989896989C9A979B9A9E9B9B999A
9C9C9A99989696969694949594929290918F90908E8D8E8B8A8B8A8C89898A8989888788
8687888687898B8B8C8C8D8C8F8F9092929596959897999B9D9C9C9FA0A1A19EA0A3A6A2
A6A5A8AAA7A6A9AAA9A8A8A6A7A7A5A3A5A5A3A3A1A0A0A29E9F9C9E9E9A9D9D999C9D9C
9E9C9A9B9D9C9D9F9D9C9B9D9D9E9F9E9E9A999D9D9FA2A09F9B9C9C9C9F9C9E9D9A9C9A
9B9B9D9A999895989798969595939293929393939190908B8E8E8E8E8F8F8F8C8D8B8A8B
89898588888885858585848482817F7E7D7C7A7A78787A7776777774767473737371706D
6F6E6E6F6E6C6D6D6A696B6B6D6C6B6A6A6C6B696B6969696A6768676766666666676366
68676766676766686868676869696B6A6A6C6C6B6B6D6B6B69696967676667666564625E
58524943403C3B3937343331302F2D2C2B2A2A2A29292928282827272827272727272727
272626272627272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262627262726262727272727
2726272726272727272727272727272728282828282929292929292A2B2C2C2C2C2E2E2F
3031323436383A3A3D40424445474A4C4E515556595C5D5F6065666B6B6C707074757879
7D7F7E83848588888B8C8B8C8F8F8F949395959496979997979A999DA09D9D9D9DA19D9C
9E9B9A9D999A9999999997959695949492939091908E8F8E908F8C8B8D8B898889898A89
888788868A8A89898B898D8C8F8D9090959593979797999A9C9FA09DA09FA1A1A2A7A4A7
A4A6A4A8A7ABA7A7ABA8A8A7A7A8A7A7A6A6A7A2A5A1A1A0A1A0A09E9F9D9D9D9B9B9C9E
9F9B9A9A999E9E9F9D9C9C9E9E9F9E9E9D9D9D9B9C9E9FA39F9C9E9F9E9E9F9D9B9A9B9B
9D99999A9B98969799989899979796939393929293928E8F9090918F8E8C908B8D8E8C8D
8B8A888888878885878586858383817F7E7E7D797B7C797A787877747677777573737370
6E706F706F6E6D6D6B6D6D6C6969696A6A6B6A6B6A696B6B6A696A696767666566666665
6565666666676766686A696968686B6C6B6B6B6B6A6B6B6A6B6B69686868676865656360
5C564E48433F3C3938363431302F2D2C2C2B2A2A29282829282828272827272727262727
272727272727272626272626262626272626262626262626262626262626262626262626
2626262626262626
262626262626262626272626262726272626262626262626272626262627262727272727
2726262727272727272727272728282828282828282829292A292A2A2A2B2C2C2D2E2E30
3032333537383A3C3F41434647494C4D505255585A5B5E606364676B6C6D71727478777D
7E7F8082848585898A8E8D8F8F9291909794979797989B979B9D9D9E9C9E9E9E9F9F9F9F
9D9EA09E9C9C9D9D9998989997999695949492939492928D8E8E8E8E8C8C8C8C8B8B898A
8A8B8989888A89898B8B8C8E8C8E8F93939693939695999A9A9D9E9D9D9DA1A3A1A3A4A6
A5A6A8A8A7ACA9ACACAAA9A8A7A9A9A7A6A8A6A6A6A4A1A4A1A3A2A0A09E9B9F9C9F9D9D
9D9B9E9B9C9A9EA09E9D9FA1A19E9D9D9D9E9C9D9D9E9FA19F9B9DA09E9F9EA19E9C9E9D
9C9E999B999A989A9997999698969798969593959493919291908F8F8E8E8D8D8D8E8C8E
8C8A8A8B87898889888384858583828081807D7D7C7A7B7A7B7979787877757675737270
70727172706F6F6D6D6C6D6D6B6C6B6D6A6A6C696A6B6B696B6868666767656666666665
65686466646565676668686869686769686A696A6C6B696C6B6B6A6A6968686867656562
5F5A544D46413E3B3937353332302F2D2C2B2A2A2A292928282728282827272727272727
272727272727262726272626262626262626262627262626262626262626262626262626
2626262626262626
262625262626262626262626262626262626262626262627262726262726262727272727
272627272727272727272728272728282828272828282929292A2A2A2B2B2C2D2E2E2F31
31323536383A3C3E40424446484C4D505254575A5C5F60646767696D6E6E737379797A7D
7F818183848889898C8E90919295949495959999999A9A9C9B9D9F9FA1A1A0A2A4A5A1A2
A2A2A3A1A1A09D9D9E9F9B9D9B989A99989796949793939292918E918C8E8D8E8D8D8C8C
8B8A8B8B8A898C898B898C8A8D8E908F90939693969797999C999D9FA1A0A0A2A4A3A5A4
A3A2A7A6A7A6AAA8ACACA8ACA9A8AAAAA8A8A7A7A5A7A6A4A4A3A3A4A09FA29F9F9F9F9E
9D9E9D9C9B9A9B9C9DA0A0A0A2A1A09D9E9E9D9F9DA0A0A09E9C9D9D9E9E9F9F9F9E9F9F
9F9D9D9B9B9A9B99999C999898969695939694939492919391938E918F8E8F8C8E8D8D8F
8E8A8D898A898A86888787828585838381807F7E7E7C7B7C7B7A7A787876757677757171
7172747471706F6D6E6D6C6C6D6A6B696B6C6A6A6B6B6C6B6A6A68676766676565676367
6666676765646564676869696767676A696A6B696D6B6C6B6C6A696A6968676865666463
625D59524A45403D3A38363532312F2E2D2B2B2A2A292929282928272827282827272727
272727272727262626262726262626262626262626262626262626262626262626262625
2626262626262626
262626262626262626262626262627262626262626272726262626262627262726272726
272627272727272727272727272727272828282828292929292A2B2B2B2C2D2D2E2E2F31
32343537393B3D40424446474A4A4D505456575B5C5F626466696C6D70737377797A7A7E
7E8284858689898B8E8F8F929297949597999A9A989C9B9D9E9FA1A3A1A3A2A3A4A2A5A3
A0A4A2A2A1A2A1A29FA49FA29F9F9D9D9B9B9A9A979794969594929391908E8F8E8E8D8E
8C8B8D8A8C8C8A8C8B8C8C8B8D8E9092919091939597999A9A9A9B9D9FA0A0A3A1A6A4A6
A3AEA6A5A6AAA9A9A8A8ABABACA8ABA9AAA9A7AAA9A9A8A7A6A4A4A5A29FA1A39F9F9F9F
A1A09C9C9C9C9D9E9EA09FA09FA39F9D9F9D9F9EA09FA09D9C9E9D9C9F9EA0A1A0A2A29F
A09E9D9C9B9B9C9B9A9B99989A9798969795969695959595949291908F908F8E8E90908F
8F8F8C8C8C898A8A8889888686848485828381807F7D7E7B7A7C7B787879777877757470
7374737272716E6F6D6C6C6C6E6E6B6B6A6C6B6A6A6B6A6B6B69696A6768666565656565
67666566666767666565676867676767676A6A69696A6B696B6D69696967676666676362
61615E564E48423E3C3A37363332302F2D2C2B2B2A2A2928282828282827272727272727
272727272726262626262626262627262626262827262626262626262626262625262626
2625262626262626
252626262626262626272626262626262627262626262626262626262626262626262727
2727272727272727272727272728282828282828292928292A2A2B2B2B2D2C2D2E2F3031
33353738393B3D40434347494B4E4F5354565A5B5E626267676B6D6F72747678787D7E80
818384858A898B8C8E90919293949897979C9A9C9A9E9BA0A1A0A3A4A2A4A4A6A4A5A5A6
A5A5A4A6A5A6A4A4A2A2A4A3A1A09F9EA09E9D9A999A99979796939492939290928F8F8E
8D8E8C8D8E8C8B8E8C8B8C8E8E8F908F928E91929495989A999A9B9EA09FA2A5A4A3A6A4
A8A8A8A8A8A9ABA9AAA7ABAAACACA9ACAAA9A8A9AAAAA9A9A7A6A6A4A6A5A6A2A3A0A0A2
A09F9D9C9D9C9E9C9C9F9F9F9FA1A2A0A0A19E9F9E9DA19D9D9C9D9E9C9FA19FA3A8A3A5
A19F9F9C9D9A9C9B9B9D9C979B9798989895979696969697939292918E9091908F8E8F8E
908F8E8E8E8C8B8A8B8A8987878786858685878381807F7D7C7D7C797979787A78777376
7273757373706F6E6D6C6E6C6E6D6E6B6B6B6B6A6C6B6B6B6A696A696868666565666665
666467666665656665666567666867676868686A6A6C6A6A6A696A686968676868666564
62605E5A544C46413D3B3837353331302E2D2B2A2A2A2929292828282827272727272727
262727272627262627262626272626262626262727262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627272626262626262626262727262727
2727272627272727272727272727282828282829282929292A2A2A2B2C2C2D2E2E303132
3335363A3B3C3E424346484A4D4E505454585B5E5F6365686A6A6E71717577797B7B7E81
82848587868C8C8E8E928F939395969A98999A9D9C9F9DA1A1A1A2A3A4A4A7A6A5A7A7A8
A7AAA6AAA5AAA3A5A6A7A3A5A6A2A1A3A2A29D9E9C999A999B9899979893969192929190
8F8E8F8D8C8B8D8D8E8E8C8D8E8F8E8E8D9290929293979A999B9C9D9D9D9FA0A1A3A3A5
A5A8A6A8A6A9A6A9A7A9AAABADABADAFAAAAAAA9A8ABAAABAEAAA7A9A7A7A6A7A2A1A29F
A19E9FA09F9E9EA0A0A0A09D9F9F9EA19EA2A09FA1A09E9B9E9B9B9E9EA19D9DA4A6A5A7
A2A29E9F9DA09EA09E9A9B9A9798999B9799979897979894949494929492959391908F8F
90908E90908E8C8B8B8A8C8B8788868785868686848381807F7E7B7D7B7A797878787674
7374757473726F6E6C6F6D6E6E6E6C6C6C6B6C6B696B6B6B6B6C6B696868656765676665
646666656566676466646666666767686867696A6869696A6A696A686969686866676565
62625F5D59524A45403D3A38363433302F2E2D2B2B2A2A29292829282828272727272727
272727262727272727262626262626262726272626262626262626262626262626262626
2626262626262626
252626262626262626252626262726262626262626262626262626262626272726272726
27272727262727262727272828282828282828282829292A2A2A2B2B2C2C2D2E2F313132
3437393B3D3E40434447484B4E50555457595C5E616265686B6D71707477777A7B7D7F83
848687888C8B8C8F8F90949594979897979B9C9C9EA1A1A2A1A2A6A4A7A5A6A8A9A6ACAB
A8ABA8ABABA7A7A7A8A6A8A7A7A5A3A4A3A3A2A19F9F9E9E9C9A97989795959592929092
91928F908D908F8D8C8E8E8F908F908D8F8E92909592989698979C9E9EA0A0A0A0A3A4A4
A3A5A5A7A6A7A8AEA8A7A9A8A9ABACABACADABACABAEAAABADA9AAABAAA7A8A6A6A7A4A4
A1A3A1A0A19F9FA09E9F9D9F9EA09FA0A0A3A09CA1A09F9D9F9C9D9D9F9D9E9DA2A3A7A5
A4A2A09FA09D9E9C9F9E9C9C9C9A9C999997989697969594949694949394949592909091
918F90908E8D8D8C8B8A8C89878A8887878A868685848381807F7F7C7C7A7A7A79787676
767778747473726F706F6F6E6E6D6C6D6B6C6B6B6C6C6B6A6A6C6A6A6965656667666465
676666656665666666646766666767686768676768696B696B696A686C6B6A6967656765
6562615F5B584E49423E3B3937353332302E2E2C2B2A2A2A292828282827272728272727
272727272727262726272626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262626262626262626262626272727262726
272727272727262727272728282828282828282929292A2A2A2B2B2C2C2D2E2E2F313134
3537393B3D3F414345474A4D4F505355565A5C5E6263676A6D6F72747776797B7D7F8181
838689898C8D8D90939592949799989B9B9F9D9D9CA0A3A2A5A2A4A6A4A6A6A8ABACABAA
ACACA9ACAEABABA8A7ADAAAAA8A8A9A9A9A6A5A3A0A29FA09E9B9C9A9A99979796949595
90939390928F8C92918E8E8F918F90929091908F9393939798989A9D9C9D9F9E9EA1A3A5
A3A4A7A5A8A6A7A8A8ABA8A9A7ABAAABADACADACACAAABADACAAABADAAAAA9A7A7A7A3A5
A3A3A2A1A1A29FA09FA09F9FA2A1A2A0A1A1A2A0A0A0A09D9EA09CA09E9D9DA1A0A1A3A2
A39E9E9F9C9EA19F9C9E9C9A9D9E98979998979695979896969695959596979693929192
92919091908F8E8F8E8B8B8A898B898A888884858687848281817E7E7F7D7E7A7A797977
76777776767472726F727071716D6D6C6B6D6C6C6C6B6A696C6A6A6B6866676668666466
64656666666667646566656666656766676768686869686A6A6A676A6C69686965676666
646561605D5B544C45413D3B3836353331302E2D2C2B2A29292928282828282827282727
262727272727262727262627272626272626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262726272627272727272627
27272727272727272727272827272828282829292929292A2B2B2B2C2D2E2E3031323336
36383A3C3F40424446494B4D4F525556595B5E606564686A6C71727374777A7C80818284
85898A8A908D8F9093959595979A9C9A9F9FA0A0A1A3A3A1A4A6A5A6A5A8ABA9AAADADAD
ADAFACABACAEADA9ACAEACACABADADABAAA7A6A7A1A6A4A39F9F9C9E9C9A9A9899959695
9594949394919093908F928F8F92928F918F919293939497969898989B9D9C9DA0A0A1A4
A5A7A2A6A5A7A7A5A9A7A5A8AAA8A9A8ACADADAEADABACABAEADADACACACAAAAABA8AAA6
A8A2A3A3A3A2A19FA0A0A1A2A09EA0A2A1A1A19FA1A19D9F9F9F9F9D9D9E9F9F9F9FA1A0
A1A19F9E9E9E9E9D9E9B9F9C9E9C9B9C9A9A999796949795979597999895959692959191
9090908F92918E8E8E8D8E8C8A8B8B8A88888787878583858482837F7E807C7C7B7B7A7A
777977777675747373727071706F6E6D6D6C6C6D6D6B6B6A6B6C6B6A6969676664676565
666665666666676666656465656667666669676667696A686A6A6A686969696766676565
6663615E5E5C585149433F3C3938363432312F2D2D2B2A2A292929282928282828272727
272726272727272626262626272626262626262627262627262626262626262626262626
2626262626262626
252626262626262626262626262626262626262726262726262626262627272627272727
272727272727272727272727282828282829292929292A2A2B2B2B2C2D2E2E2F31323435
373A3B3E3F414346474A4C4F515355575C5D616465686A6B6D707373757B7D7E80858485
87898B8C8D8E9191929694979A9D9CA09F9F9FA2A4A1A0A5A6A5A5A5A7A9ABABADABADAC
AEB3ADAFB0B0ADAEADB2AFB0AFAEACABACA8AAA6A8A3A3A3A2A19F9F9E9C9D9C99999898
9594959595959293949290918F918F92939092919192959596969698989C9D9FA0A1A1A3
A4A6A4A6A7A5A8A8A5A9ABA7A6AAA9A9ADABACADAFAEAAAEACAEAEAFACADACAAA9ACAAA7
A6A6A6A4A5A3A5A2A0A1A1A2A2A3A1A0A1A1A1A0A19C9EA09FA1A1A0A0A09EA1A2A09E9E
9FA09E9D9E9E9E9C9B9D9E9E9D9C9D9B9C9C989998959594969997999897989796949394
929090918E928F8D8D8C8F8D8E8F8A8D88888988888987848486848280807F7D7C7B7C7A
79797877777675757473736F70706F6D6D6F6E6D6D6C6D6C6B6C6A69696A676666666566
6565646666666666666464656565656669666767686968696B6A68686968696768676766
666463605F5E59554E47413D3B39363533312F2F2C2C2A2A2A2929282828282828272727
272627272727262727272626262626262626262626262626262626262626262626262626
2626262626262626
262627262626262626272626262626262626262627262726272626272627262627272727
27272627272727272727282727282828282828292A292A2B2B2B2C2C2D2E2F3032333436
393A3C3D41424547494B4E50525458585C5D616466696B6D6F7275777B7B7D8183868688
8A8D8A8D90919193939598979B9BA2A0A1A2A3A1A4A5A7A8A5A9A8A6AAAAA9ACAAADAEB1
AFB0B0B1AFB3B1AFB0B0B1B4B1B2B0ACAFADACABA8A5A7A7A3A2A4A2A3A1A0A29F9C9997
98959897959692949393909192959293929293959294949295969997999D9B9CA09FA2A1
A5A3A4A5A4A5A6A9A7A8A7A8ACA7AAA9A9AAADADAEB1ACADADADADAEB0ADACACAAAAABA8
A9A7A8A4A6A6A1A2A2A0A39FA1A39EA19FA19EA09E9EA09D9F9FA19F9EA1A1A09FA29F9F
A19E9EA09E9FA19D9D9E9C9EA09EA09C9B9B9A9C9C99969899989996979A989797979593
9392909092908F90908F908F8D8F8E8C8B898989898B8786868686838280817D807C7C7B
7A797978777775747573737270726F6F6F6E6E6D6F6E6D6B6D6B6B6A6867676865666766
646566666666676767646766656567656666676665686867676868686968676868686766
65636363605C5C58514B45403C393736343230302E2C2C2B2A2A29292828282828282827
272727272727262727272626262626262726262626262726262626262626262626262626
2626262626262626
262626262626262626262626262626272726262626262627272626272727262726262626
272727272727272727272827282828282928282A2A2A2A2A2B2C2D2D2E2F303132333537
393B3C3F40444649494C4E515355585B5C60606568686C6C70727577777B7D8182838989
8C8A8C908F9393969899999B9A9D9FA1A0A3A3A5A6A6A6A9ABA9AAABACAEADACAAADAEB0
AFB0B1B3B2B1B2B3B7B3B4B1B5B1B1AFB1ACAFAFADABAAA9A7A6A6A6A6A4A1A19F9D9C9C
989998989797999596969492929192929192949293969597969696969D9A9C9C9D9EA0A1
A1A4A4A5A4A4A6A8A6A7AAA8A9AAAAABA8AAAAACACAEB0AFAEAFADAFAEAFB0ACAAABABAA
AAA8A9A7A6A6A4A29FA4A1A39F9FA19CA1A19C9E9F9FA1A19F9EA1A1A1A2A1A1A1A09EA1
A0A29DA2A0A19F9F9FA09DA0A0A09F9F9E9E9B9A9B9B999A989A999A9999999A98959696
9594939293928F91919090928E918D8D8B888A8B89898A8988868586848280807F7E7D7E
7C7A79797A7876797676757371716F71706F6F716F6E6D6B6B6B6C696868686866676667
646565656466666664656665666665676767666668676867696967676869696769666665
65666463615F5E5B574E47433F3B38373533322F2F2D2C2B2A2A29292928282828272727
272727272727262726272627272726262626262626262626262626262626262626262626
2626262626262626
262626262626262626262627262626262626262626262627272727272727262726272627
2727272727272727272827272828282829282929292A2B2A2C2C2D2D2F2F303134343639
3A3C3D40424447494B4D4F525457595B5E616466676A6E70717374767B7C7F818486898C
8C8C9090939292969A989D9C9C9FA0A0A1A2A5A6A8ABACAAACAAABAFACAEAEAEADB2AFAF
B0B2B3B1B4B3B4B4B4B6B4B3B2B4B3B3B1B1B0AFAFACACAAAAA7A7A8A8A6A6A3A1A29F9C
9F9B9A9C9A9798989897979593959292939395959495949495959698999B9B999B9C9F9E
A1A1A4A1A5A4A5A7A8A7AAA8A7A8ACACACAAACAAAAACAEAFADADB1B1B1AEB0B1B0ACADAA
A9A9ACA9A8A9A8A5A6A3A4A1A2A1A1A0A1A09E9C9F9DA0A19FA19FA1A0A0A1A1A1A3A3A1
A0A0A09F9FA3A2A1A1A1A09EA19D9E9F9E9F9D9C9E9A9E9A9D999A9B9A999D9B9C989A97
9897959394929192928F909293918F8D8A8A8C8A8B8889898A8687838484848281807F7D
7D7B7B7C7A7779787775757574727271727270716F6E6F6C6C6C6B6B6A69696B67696765
666463666466666565666365666766646564676667656765666769696867676865686667
6763626361615E5C58534C45413D3A38353532312F2E2C2B2A2A2A292828282828282727
272826272726262626262727262626272626262626262626262626262627262626262626
2626262626262626
262626262626262626262627262626262626262626262626272627272627272726272727
27272727272727272727272828282828292929292A2A2B2B2B2C2D2E2F30313333353739
3B3C3F41444647494C4D505355575A5E5F6263666B6B6D717275787B7D7F7E848486888C
8C8E9091939395999C9B9B9D9FA0A0A1A2A2A4A8A7ABABADADADADAEAEAEAEAEB1B1B2B1
B0B3B3B3B6B6B5B5B4B4B7B5B6B6B1B3B3B5B4B2B2B2AFAEAAABACAAAAAAA8A9A6A5A4A4
9DA19F9C999D9D9C9B9B9696959795949694949596959493979795979A99989A9C9D9FA0
A2A0A0A5A4A4A5A4A5A6A7A9ABA9AAABAFABACADAAAEADAEB0B0B1AFB0B3B2B0AEADAEAD
AAA9AAADA9AAAAA6A4A5A4A5A3A3A5A2A1A1A1A29E9F9D9FA0A0A0A1A1A19DA2A1A2A0A2
A1A2A2A2A1A09EA1A0A19E9C9D9D9F9F9FA0A09EA0A09F9F9D9D9E9D9C9B9A9B9C9C9998
999797979794929192938F929190918F8E8E8C8D8D89898B8A8889868585848382808180
7F7F7D7C7A797A7777757475737472727172727271706E6B6E6B6C6C6A6B686867666667
656364656564656664666567666664656666666567656666666767696867676666686765
6664646361605E5C5A574F49433E3C3937363332302E2D2C2B2A2A292928292828282827
272727272727262727272627262627262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262626262626272626272626262727272727
27272827272727282728282828282828282929292A2A2B2B2C2D2D2E2F30323435353839
3C3E40414545494A4C50535456595D5B606265686A6B6F737276797A7D7F80838686898A
8E919092929598979C9B9EA09FA19FA3A4A3A6A9ABACAEADABAEAFAEAEB0B2B1B0B1B1B3
B4B0B4B3B5B7B5B7B6B4B8B4B4B4B5B4B5B6B4B4B4B1B3B3B1B0B0ACAFACAAA9A6A7A6A6
A3A3A49F9F9C9D9A9A9B9A9A98979598959696979696969695979897989A98999B9D9F9D
9FA1A19FA1A1A2A5A8A6A7A6A7A8A9ABABABACABACAEAEAFB3AFB0B0B3B0B2B1B2B0AEAC
ACACACABABABAAA9AAA8A4A2A7A4A3A4A3A1A0A39FA0A0A1A0A0A1A1A1A0A29F9FA0A0A3
A4A2A2A4A4A1A19D9F9FA09F9C9E9F9FA4A1A0A0A09F9E9F9F9E9E9E9E9D9F9C999A999A
999A9999979693959394909390919091918F8C8D8F8C8E8B8B8B8A868887848384848183
7F7E7E7A7A7A7979777776777673737274737272706D6F6E6D6C6C6B6C6B696969696865
666564656564626564656768666563636466656565676565656666676866686765686566
656664636363615E5B58544B46413D3A3836353231302D2D2C2B2A2A2929282828282828
272728272727272626272627262627262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262627262727262626272727262626272727
272727272727272728282728282828292929292A2A2A2B2C2C2D2D2E2F3032333537383B
3D4041434547494A4D515155585B5D5E626366686A6C6F707475787C7D7E828487888C8C
8F9393939597989A9C9D9B9F9FA2A2A8A4A6ABA9AAAAAFACADB1AFB0B0B1B4B6B5B3B1B2
B5B3B5B4B4B5B5B8B6B5B5B6BAB4B6B8B8BAB5B6B7B6B4B4B3B3B0B1AFAEAFAFACABA9A8
A5A4A3A4A2A19F9D9E9D9B9B9998989897989797989796959796979899989998999B9C9B
9E9D9FA0A29FA1A3A5A3A5A7A5A9A7A9ABABAAAEADACAFB1ADB0B2B0B0B3B2B1B0B2B2B2
B0AEADACADAEA9ABAAA9A7A7A6A6A4A5A3A2A2A1A1A0A1A1A0A0A0A09F9DA09F9FA3A2A3
A3A2A3A1A1A0A09D9E9E9F9F9E9F9EA0A1A1A3A09FA49FA2A09FA09EA0A09C9D9D9C9A9C
9B999B9B9B9A989493948F9193909190908F8F8F8C8D8C8D8A8D8A8A8887858585858383
8281807D7B7D7A7B7A77787776767674727273727272706D6E6C6C6C6B6C6A6967696667
656566646464646563646566686565646567656566676663656666666766666668676666
66666563626160605C5A56524B443E3B3938363432312F2D2C2B2B2A2929292828282827
272727272627272727272727262626272726262626262626262626262626262626262626
2626262626262526
252626262626262626262626262726262626262626262726262626262726262726262726
2727272727282727272728282828292829282A2A2A2A2B2C2C2D2E2F3032333435383A3C
3E40424445484A4D50515355595A5E5F616366696B6D6F737476797B818082848787898D
8F8F94949699999B9E9D9EA0A2A2A3A1A7A6A8ABAEAFAEADAEAEB0AFB4B2B3B2B5B2B4B6
B6B5B5B5B9B5B6B7B8B7B7B7B8B8B8BAB7B8B7B7B6B7B7B5B6B4B5B4B1B4AFAFB0ADADAB
A9A9A8A7A6A1A39F9FA0A09EA09B989998999A9B9994969795979899979A9A9998999A9C
9D9A9D9E9CA0A1A2A3A5A5A5A6A6A9A8A8AAACAEADACB0AEABB0B1B0AFB1B3B0B3B3B1B0
B1B0B2AFAEACAFABADAAA9A8A7A7A9A7A4A2A3A2A0A2A0A2A0A2A0A1A19FA19FA0A3A1A3
A5A7A3A4A2A39FA19EA09F9D9EA19DA2A4A2A2A0A2A1A1A1A0A29F9FA09EA09F9E9D9C9B
9A999B9C9D9B9596969492949293949493928F8D8E8B8D8D8D8C8B898988888587888486
84828180807C7B7D797979787874757675737473727271706E6F6C6D6B6B6B6769676A66
656566646463626364656565656566636564666563646666676365656667656768666863
666464636161615F5E5B5B544E47423E3A3836343331302E2C2C2B2A2A2A292828282827
282827272727262726262627272726272626262626262626262626262626262626262626
2626262626262626
252626262627262626272626262626262626262627262627262626272727272627272727
272727272727272727282828292828282929292A2A2C2B2C2C2D2E2F2F32333637383A3D
3E41424446494C4E51535556595C5E606364666B6B6E717375777C7C7E82828487898A8D
91919397999A9C9D9E9E9DA2A2A2A4A8A9AAAAACADACAEAEAEB0B0B4B3B4B4B7B5B5B5B5
B6B7B8B7B5BBBAB7B7B6BABAB7BBB7B9B6BBBABBB9BABBB9B6B6B7B6B2B2B0B6B2AFAFAF
ABAFAAA8A6A4A2A5A0A1A1A09E9A9C9B99999A99989A9898999999999999979B9A999C9C
9C9A9E9C9D9E9FA0A0A1A4A4A5A6A5AAA9ABADACAEAEAFADACADAFAEAEB1B2B2B2B6B5B4
B6B0B1AFADB1AFACAEACA8AAA8A7A6A7A4A5A4A3A1A3A1A1A1A09EA3A1A2A2A2A2A0A2A1
A3A29FA1A19F9D9FA1A1A09FA0A09FA1A2A3A5A39DA3A2A2A0A0A1A2A2A19E9D9C9F9A9D
9B999B9C9C9B9899979695939494939495908E8F8D8B898C8E908E8A898B898885868785
828480817F7E7B7B7B7B7777777778747473737372727071716F6D6C6D6B6B6967696767
676665666466646464656463656763666465636466656664656364666666666465656865
646564646262605F5E5C5A57524C45403D3A37353332312F2D2C2C2B2A2A292929282827
272727272727272727272727272627262727262726262626262626262626262626262626
2626262626252626
262626262626262626262626262626262627272626262626262727262627262727272727
272727272727272827272728282828292A292A2A2A2B2C2C2E2E2E3031323436373A3D3D
3F424445484A4E50505355585A5C5F616366696B6D6E707576777D7C7F8184898A8A8B90
90949495999A9D9C9FA0A5A3A3A5A8A8A9A9A9ADAEAFADAEB1B1B5B2B4B3B6B8B7B7B8B6
BAB9B8B6B7B9B7BBBBB9B9BABABCBAB8B9BCBABABABBB8BBBBBBB8B6B7B5B2B6B3B4B3B2
AFAFADACA8A7A6A3A5A6A3A1A09D9C9C9A9C9E9B9C989B9A9B999A999B9A97999A9A9A9C
9C9D9B9DA09C9E9C9EA2A4A3A5A4A4A8A7AAA9AAABACAEADACAFB1AEB2B2B2B2B0B3B4B5
B4B3B2B2AFAFB0B0AEADAEACA8A9A8A6A7A3A7A5A4A2A1A2A1A2A4A1A19FA3A39FA1A1A1
A4A2A1A19EA19FA29FA0A1A3A1A19FA1A1A3A2A2A3A1A2A4A0A3A1A1A2A2A29D9F9F9D9B
9D9C9C9B9A9A9B979596959894939492938F90918C8D8E8E8D8F8C8B8A8B898887878884
87848382827F7F7B7A7B7A79787977787576747572726F72716F6D6D6C6A6B6969696867
666766656765646364646565656465646465646466646464646364626666666566666565
64646464636261615F5C5B59554E48423E3A38373533312F2E2D2C2B2A2A292929282828
272727272727272727272727272726262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627262627272727272727272627272727
27272728272727272728282828292829292A2A2A2B2B2C2D2D2E2F2F32333536383B3D3D
3F424447494B4E5052545559595D5E606467686C6D71707477797B7D7F81858787898D8D
93919496989B9CA1A1A1A4A7A6A7A7AAAAAEABADADAFB1B0B0B2B3B4B3B8B8B8BAB8BAB8
B8BABBB8B6B8BAB9B9BABCB9BBB8B8BBBCBBBCBCBBBFBCBCBABABDBCB8B9B6B9B6B8B4B6
B2B2B0ABAFA8A9A8A7A7A4A3A3A19FA09D9C9D9D9C9B9A9A9C9A9B999A9A96989A9A9A9A
9B9E9C9B9B9B9DA09FA0A0A2A2A1A4A6A7A9AAABACAAADAEAFB0B0B0B0B4B2B0B1B2B2B8
B2B6B4B5B5B1B1B3AEB1ACAFADABABAAA8A8A7A6A7A5A4A3A5A3A1A0A0A4A2A2A3A1A39F
A0A0A0A1A3A3A3A3A49FA19FA1A0A0A39FA3A2A3A2A2A5A2A2A5A3A1A0A0A2A0A0A1A19E
9C9D9B9C989B98969897949697959496939592918F8F8E9190908D898B8A8C8988878685
8685838282817E7E7C7E7B7A797A777876767474737472727171706E6E6D6A6A696A6968
686667656465636465646365646665646565656564636363636365636466636464666765
6666656462626161605C5C5A57524C45403C3A38363532302F2D2D2B2A2A2A2929282828
272827272727272727272727272626262726262726262626262626262626262626262526
2626262626262626
262626262626262626262626262626262626262626262627272726262627262727272727
27272728272728282828282828292829292A2A2B2B2B2C2D2E2E303131343536393B3D3F
414446484A4C4F50535457595C5E61666567696B6E737274797A7B7E7F828387888C8C91
92949696989A9DA0A0A5A3A2A6A7A9A9ACADACAFAFAEB2B2B6B5B6B8B8BBB9B9BCBABBB9
BCBBB8B8B7B8BABBB9BBBABCBBB9BCBFBCBFBEBCBDBFBBBDC1BFBCBCBCBBBBB8B8B9B5B5
B6B3B4B1B0AEAEABAAA9A8A5A6A5A4A3A2A09FA09F9C9E9C9A9C989B9A98999999999B9B
9A9B9A9B9C9C9D9D9E9E9FA1A1A0A2A5A7A6A6A9ABABACADACAFB2B4B2AFB3B0B1B3B2B5
B5B4B4B3B1B3B1B2B0AFB0B0B0ABADABA9AAA7A7A9A4A2A3A4A3A1A1A2A5A1A3A0A1A3A1
A19FA39FA2A4A2A2A49FA1A2A2A1A2A3A2A5A4A4A2A2A3A1A4A1A4A5A2A2A4A1A1A09EA1
9F9D9E9B9B989998979897989696959894949393928F90909090908F8C8C8A898A898886
86858385828483817E7E7C7A7B78787778757575747473727170706D6D6C6B6A6C6B6A69
686A67676667656565636465646664656465646364636362646465636262656464656364
63656365646661605E5E5D5C59545048423F3C38363533312F2E2D2C2B2A2A2929292828
282728272727272727272726262726262626262626262626262626262626262626262626
2626262626262626
252726262626262626262726262626262627262726262627272627272727272727272727
272727272728282728272728282929292A292A2A2B2C2D2D2E2F3031333435383A3C3F40
424445494A4D4E50545657595D5F616365686A6C6F707473767B7D80808485888C8D8E8E
92959597999E9D9EA2A3A6A4A5A9A7A9A9ABADAEB0B2B3B4B4BABAB9BAB8B9B7BABBBABD
BCBDBABBB9BABCB6B7B8BDBCBCBEBCBDBEC0BEBDBEBEBDBEBCBCBDBCBABCBAB8BDB8BBB7
B7B7B5B3B1B2B0AFABAAABA9A8A7A5A4A3A1A09E9F9EA09C9E9C9A9D9B98979A9A9A9C9A
999B999B9B9B9B9F9D9D9DA19FA1A3A3A5A8A7A8A9ACAAABAFB0AEB0B1B2B0AFB2B2B2B5
B2B6B5B7B2B4B2B2B3B3B2ACADB0AEAEABAAAAA8A5A7A5A6A5A5A3A4A3A5A3A2A5A4A19F
A0A3A0A1A2A2A5A6A3A2A1A0A4A1A1A0A1A3A3A1A3A4A4A3A2A2A4A2A4A3A2A5A2A1A2A1
9E9F9E9D9B9C9999989A979699959696989695919391929291908D8D8E8C8E8B898C8988
8886858586838181817F7D7D797A7A7A7778767676747572737370706F6D6C6C6B6C6B6B
696968686769686664646364656565656463636263626462636463636263636764646564
6463636362626362605D5C5D5957544D46403E3B38353432302E2E2C2A2B2A2A29292828
272828272727272727272627272626272726262627262626262626262626262626262626
2626262626262626
262626262626262626262626262627272626262626262727262727272627262727262727
272727272827272828282828282829292A2A2A2B2B2C2D2E2F2F3031333536383A3C3D41
4345474A4C4E505254555A5B5D5F646467696A6D6F73767879797E80818186898A8F8F90
91959798999C9F9CA4A0A4A8A9A9AAABADAFB0ADB3B0B3B4B7B8BBBAB8BBB7B8BABBBDBC
BABFBABBBBBDBDB9B8B9BFBCBFC0BEBEBEBFBEBFBCC0BCBCBFBEC1BDBFBEBEBDBAB7BABB
BABCB8B9B9B4B2AEB0AEACAAA7ABA8A5A6A6A1A1A2A19E9FA09D9D9C9C9A9A999B9A9898
9C9A989A9B9B9B9C9B9D9CA09E9FA2A5A2A5A6A6A8A9A9ACABAEAFACAFB1B1B4B4B2B1B2
B3B4B6B4B5B4B5B3B3B2B3B1B0B0AFAEAEADACABA9A8A6A6A6A6A4A4A3A4A3A5A4A5A5A0
A0A1A0A3A3A2A5A2A5A5A3A3A0A1A3A0A4A09FA4A1A1A1A5A4A4A2A4A2A3A5A4A3A1A0A3
A09FA09E9D9B9A9698979998979898989A97959493939390928F918E8E8D8D8B8C8B8988
898885878684848482807C7D7C7B797A7978777976757674757272726F6F6F6E6C6C6C6A
6A6869676968666564636465656565636363626263636264636363616361626462636565
64646463626460605F5F5D5C5B59554F49433F3B38363533312F2E2D2C2B2A2A29292828
282828282727272727272727272627272727272626262626262626262726262626262526
2626262726262626
262626262626262626262626262626262626272626262626262626262727262727272727
2727272727282828282728282829292A2A2A2A2A2B2C2D2E2F2F3133343637393B3E4041
434548494B4D51525658585B5E606366686A6C6F707275787A7A7D7E828586888C8B8D90
9295969B9B9A9CA2A3A6A6A7A7A9AAABAEB0B0B2B1B2B0B2B6BAB8BAB9B8B8BCB9BBBCBD
BCBCBABCBCBCBDBDBDBFBBBFBFBEBDC2BFBDC1C0C3BFBCBEBCBEC0C0BEBFBEBBBFBDBEBD
BEBBB9B9B7B7B6B5B1B1AEB1ADA9AAABAAA8A7A9A6A2A2A2A1A1A0A09F9B9C9B9B9B9B9B
9A9A9B9C999B9C999A9C9C9C9DA09EA0A2A4A4A5A5A7A8AAAAADAEAFAEAEAFB2B1B2B4B1
B2B1B4B2B2B4B6B5B6B3B2B3B0AFB0AFAEAEADACAAA7A8ABA6A6A4A6A5A4A5A6A5A4A2A2
A29FA4A3A2A3A5A4A2A1A4A4A2A2A0A1A0A0A3A0A2A2A4A4A5A5A1A5A4A3A3A5A5A2A2A4
9FA29F9F9C9C9D9C9B999B9A9797969698979594939393939192908E8D8E8E8E8D8A888A
8B8A8986858684858181807D7C7C78787979777774767575767473747070706E706C6B6C
6B6B69696766676466656365656564636363646361636162626262626364626363646363
6263636364626261605F5E5C5B5A57524C46413D3938363432312F2D2C2B2B2A2A292928
282828272727272727272627272727262627262626262626262626262626262626262626
2626262626262626
262626262626262626262726262626262627262627262726272626262627272727272627
272727272727282827272828292929292A2B2A2B2C2C2D2E2F3032333436373A3B3E4041
4346494A4E4F51535458595C5F616267676B6D70727477787A7D7D7F828686898C8D9090
929495999A9C9EA0A0A1A4A8AAA8AAAFAEB0B0B0B5B5B4B7B6B8BBB8B9B9BAB9BDBFBEBC
BEB9BEBCBEBCBEBBBDBFBEBFC0C1BFC0C0C1BFBFC0BFC2BFBFC0C4C1BFC1BEBFC0BDBEBF
BCBEBCBEBCBABCB8B9B4B4B0B2B2B1AEACA9ABACA8A7A6A4A5A1A2A1A09FA09B9E9C9C9B
9B99999C999A989D9A9B9B9B9E9F9F9EA1A3A0A4A8A5A9AAAAACAAABAEADB0B1B3AFB1AF
B2B3B2B3B7B4B4B5B4B3B2B4B1B1B2AFB1AEACABABACABABAAA8A6A6A4A4A5A4A4A6A2A2
A1A1A3A3A3A0A2A5A4A4A5A2A2A1A6A19FA3A3A3A3A2A2A3A4A3A39FA3A0A4A6A5A3A4A3
A2A2A2A0A19E9D9C9B9A9A999899979898979698959695949394928F8C8E8F8E8E8C8E89
8A89878789858883838381807D7F7E7D7D797878787574767573737272706F706F6E6E6C
6B6C69696767676565666664656563636363656361626263626161616262616263636364
6362636260636260615F5E5D5C5B59554F4A433F3B3837353431312F2C2C2B2A2A292928
282828272727272727272727272726262726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262627272726262627272727272627272727272626
2727272727272828282828282929292A2A2A2A2C2C2D2D2E2F3031343536373A3C3F4144
4547484C4D50515555585B5D5E6364686A6B6D71737478797C7E7E828586858A8A8D8C90
939496999B9C9C9FA2A4A3A8A8A9ACADAFB1B2B3B5B6B6B6B9B9B4BAB8BCBBBEBCBDBCBA
BCC2BEC1BDBFBEBFBEBEBFBEBFBDBEBFC2BFC2C1BFC1BFBFBCC4C2C3C3C3C3BFC2C0C1C4
BDBCBEBFBCBBBFB8BCB8B7B7B6B3AFB1B2AEACABAAADA9A6A6A4A3A5A29FA09C9F9C9D9B
9B9A9C9D989A9B9B9A9A9D9C9A9C9D9EA1A2A0A1A5A7A7ACA8ACAAADACADABADB0B0AFB0
B2B3B2B0B3B6B4B5B5B3B4B5B2B0B0B1B1AFAFAFAEADAAABA9ACAAA7A6A5A7A5A5A4A5A4
A8A2A2A2A4A3A0A3A3A3A3A2A4A3A0A2A3A0A1A4A2A2A5A4A3A4A0A2A1A3A3A3A2A4A1A2
A2A2A19E9F9E9E9E9D9C9B98989898989796969796969793948F93908E8F908E8D8D898B
8C8889878B858687858482827F807F7E7C7B78797779777674747575737272706F716D6D
6C6B6A6A6A68696767676465656564636362636263636362636261626161606262626264
6361626262625F605F605E5E5D5B5857534D46413D3937353332302E2E2C2B2A2A292A28
282828272827272727272727272726272626272626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626272626262726272727272727262727272627
272727272727282828282829292929292A2A2B2B2C2D2D2F2F30333436383A3B3C3E4143
46474B4D4F505355585A5B5F606367676A6C6E70747677787C7E82828284878B8C919191
939597979B9C9CA1A1A2A4A7A8ABAFAFB3B0B4B3B7B6B8BBBBBBBDBABDBBBDBDBFBEBBBE
BEC0BFBFC0C2C0BFC0C2C0BCBEBCBDC0BEC4C0C1C6C1C2BFC1C2C3C3C2C4C1C2C2C3C3C3
C0C1C1BEC1BFC2BFBEBEBEBABCB7B7B8B1B2B2AEB0B0A9A8A7A5A6A5A4A2A1A0A09F9F9D
9E9A999B9C9A9C9C9C9C9C9A9B9D9E9E9FA19FA0A1A3A5A8AAAAA9ABAAAAACADAFADB1AE
B2AFB0B3B4B3B2B4B3B5B3B3B4B3AFB1B2B1B2B0AEACAFADACAAA8AAAAAAA8A6A6A3A6A5
A7A3A5A4A3A2A2A0A19FA2A1A1A0A1A2A3A1A3A2A4A2A4A5A1A2A2A0A09FA3A3A2A2A4A3
A3A1A1A1A09FA1A19E9C9D9A9A9997999A95959695959596939390908E8E8E928E8F8B8B
8D8A8B8A8689878687848382827F7F7D807D7D7A79777875767475767473747073706F6C
6D6E6C6A6A69686867666767656465636562626263626262626261626161616261636162
646163616260626060605F5E5E5B5A5955504B433F3B3836343331302E2D2C2B2A2A2929
282828282827272727272727272627272726262626272626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262627262727262627262727272727
262727272727282728282929292A2A2A2A2B2B2C2B2D2E2F303133353539393C3E3F4243
46494B4D4E515255575A5D5E626367686B6D6F707475787A7D7E81838485878B8C8F8F92
959498989B9C9FA0A2A3A4A7A8AAACACAEAFB3B4B6B7B6B8B8B8BABCBDBDBFBEBEBDBEC0
BDBFBCBDC1C0C1C3C2C0C2BDBFBDBEBFBDC0C1C6C6C5C2C2C3C4C3C6C4C3C3C5C1C6C6C8
C1C5C1C2C3C4C3C4C2BEC0BDBDBAB9B9B8B6B4B4B3AFADAFAAAAA8A6A6A6A5A3A2A29F9E
9B9D9A9B9B9C9A9A9B9B9B9A9D9C9B9D9E9FA29FA0A4A4A4A7A9AAA9AAAAADACAFAEAEB0
B2B1B0B0B1B5B1B5B2B1B1B3B2B3B3B2B2B3B0B2B2B1AEB0AEAFAEAAACA8A7A8A5A7A8AA
A6A6A4A5A2A0A1A3A3A4A2A4A0A2A3A1A1A6A0A4A2A2A2A2A2A3A1A1A0A2A1A1A3A2A5A3
A3A7A2A2A1A09FA0A2A09B9C9A9A9D9D979A969692949394939290918F908F8F908E8B8A
8A8A888B8A898A8986858682827F8182807F7C7D7B7A797976757474747272727171716F
6E6D6B6B6A69696767676667646365636265636362616262616061615F61626061626162
6261616262605F60605F5F5E5E5B595956544D46413D3A37353332312F2D2C2B2A2A2929
292828272727272727272627272726272727262727272626262626262626262626262626
2626262626262626
252626262626262627262626272627262626262626262627262627272727272727272727
2728272728282828282828282829292A2A2B2B2C2D2C2E2F3032333537383A3B3E404145
46484C4D50535355595B5D5E626667696C6C72737474797A7E808185848588888D909090
9395999C9D9C9EA0A1A3A6A7ABAAB0ADB0B0B1B2B6B5B8BABCB8BCBBBEBDBFBDBDBFC0BC
BDC2C0C1C1C0C0C2C4C6C3C1BEBFBDC1C1C2C2C6C7C5C2C0C5C3C5C3C5C5C5C4C8C6C3C8
C6C5C8C8C6C6C3C5C2C4C3C4C0C0BDBCBAB9B9B9B6B4B3AFAFADAAAAA9A7A6A5A7A3A0A1
A09DA09F9E9D9C9C9D9B9D9D999E9D9C9CA0A19CA0A1A2A0A6A6A6A8A9AEACADADAEADAF
B0B0AFB0AEB0B1B0B0B2B0B1B2B0B3B3B3B3B0B0B3B0AFAFB2AEB1ADADACA9A8A9A9A9A6
A8A5A7A4A4A6A4A3A3A2A1A1A3A4A1A4A1A4A3A3A2A2A1A1A09FA0A3A1A2A6A4A3A2A0A1
A3A2A2A4A0A1A1A0A39F9B9E9B9B9A9A9B9B999897949593929491929092918E918E8E8E
8D8C8A898A898A8786898785848482828281807E7C7B7979797876767573737271727270
7270716C6B6A69686865646565656465636363626261616061616060605F5F6160616360
60616162626060605F5F5F5C5E5D5B585755504B433F3A3836343331302E2D2C2B2A2A29
292928282727272727272727272727262726272627262726272626262626262626262626
2626262626262627
262626262626262626262626262626262626262626262727262627262627272827272727
2727282727282828282828282929292A2A2B2C2C2D2C2E2F3132333537393B3C3D404245
46484B4E4F515557575D5E62626467686A6E70727476797C7C7F7F84868788888D8E9095
979496979A9C9DA0A1A5A7A8ACABAAAEAFB1AFB3B4B9B8B9B9BBBABCBCBFBEC0BFBEBEC0
C1C3C0C1BFC1C3BEC2C4C2C1BDC0BEC3C1C2C2C7C5C5C2C2C4C3C5C3C6C6C5C5C8CBC8C5
C7C9C6C9C7C8C7C3C6C5C5C5C2C4C0C0BEBCBBBAB9B7B3B1B0B3AEABA8A8AAA8A6A3A5A3
A19E9E9F9E9E9E9D9D9E9D9E9D9D9FA09F9FA0A19FA1A2A3A5A4A4A7A9A9ABA9A9ACADAC
AEACAFAEAEB1B2AFB0B1B2B2B2B5B4B4B2AFB0B3B3B2B2B1B1B0B0B1AEABA9ABAAABAAAB
A9A5A4A5A4A1A4A3A4A1A3A3A2A3A3A2A2A1A1A3A1A1A2A1A1A19FA2A4A2A0A2A3A3A5A2
A1A2A3A2A2A2A1A2A0A0A39E999B9C9D9A9C99989898959495949593909292928F8D8E8E
8C8A8A898B898888868987898586848581847F7F7E7E7D7C797878787474747373737371
7171716F6D6D6B6B6967666665676464636364626362626260616162616062625F606061
60616161606261605E5F605F5D5E5C595857524D46413D3938353331302E2D2C2B2A2A29
292828282827272727272727272727262627262727262626262626262626262626262626
2626262626262626
262726262526262626262626262626262626262626262626272726262727272727272627
27272727282828282828282929292A2A2A2A2B2D2C2E2F3031333435373A3A3E3E404345
46484B4D505255585A5C5E60636566686B6F6F7174757A7A7D7F81838588888A8B8F9290
94979799989D9BA1A2A2A7A6A9AEABAEADAFB0B3B7B4B8B9BBBABCBBBDBFC0BDBEBFBFC0
C0BFC1C0C2C3C2C0C2C1C0C1C2C0BFC3C3C3C4C5C9C4C4C4C6C7C7C5C6C8CBC7C9C7C7C8
C9C8CACCCBCBC7C5C6C8C7C5C7C3C1C5BFC0C2BDBDB9B6B5B4B1B0B0AFADABA8A8A7A4A7
A3A0A09DA09E9F9F9EA09D9D9E9D9C9EA09E9E9FA0A0A1A0A4A2A5A5A5A8A7A7AAA9ABAD
ABADAFADADADAFACB1ADB2B4B3B1B4B0B0B4B3B4B2B1B2B3B3B5B3B1B2AFACADABABADAB
A8A9A8A7A3A6A5A5A3A4A3A4A2A4A3A3A3A3A4A1A3A4A3A19EA0A3A1A1A0A6A2A2A3A2A1
A1A0A3A1A4A0A1A0A2A1A09EA09B999D9C9D9B9B989997979691939393929092908F908E
8F8C8A8B8A8A8A888789888688858684858480827D807F7D7C7B78787874767474747572
737772716F6F6A6C6B676967666564646463636363616261616162626160625F6161605F
6161616160605E5F615E5E5F5D5D5C59595755504A443F3B39373432312F2E2C2C2A2A29
292928282827272727272727272726272726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262627262627262627262626272627272727272727272727
2727272728282828282829282929292A2A2B2C2C2D2E2F303234353638393D3D3F414345
474A4C4D525356585A5C6061616566696D6E707274767C7C7D7E81848589898B8D908F95
959696969B9D9FA0A1A5A6A9ABA9ADADAEB1B1B4B6B6B9B8BBBEBCBBC0BEBFC0C2BFBFC1
BEC2C1C1C3BFC0C1C0C0BEC0C3C3C1C4C4C6C5C6C4C4C4C7C3C6C7C8C9C7CBC7CCCEC6C9
C8C8C9CBCBC8CACCCAC7C8C7C9C9C4C3C1C0C2C1C0BDB9BAB7BAB6B4B0B0ADACABA8A7A7
A7A4A4A29FA0A19FA19E9F9E9D9F9D9E9F9DA19FA2A0A0A1A2A2A0A1A3A5A6A7A8AAA7A9
AAAAAEADAAACAEAEAFB1AFAFAFB3B0B1B2AFB0B0B2B0B0B1B3B3AFB1B2B0B0AFADAFACAA
A9A9A8A8A6A6A8A4A4A7A4A3A4A4A3A2A1A29FA2A1A2A4A1A1A2A1A0A5A3A2A4A3A2A2A3
A1A2A4A3A3A0A0A1A2A2A19E9E9D9E9D9A9D9F9D9A999997979795959392929290908E8E
908C8D8A8B898A8988878787898784858183837F8381807E7B7B79797875787675737574
737573726F706E6E6C6D6768686666636464636463636164615F606161605F5F605F6062
60605F605F5F5F5E5E5E5E5F5E5E5B5B595955534E47413C3836353331302F2D2C2B2A2A
292928282728272727272727272727272626262727262626272626262626262626262626
2626262626262626
262626262626262626262626262626262626272726272727262627272727272727272827
272727272728282828292928292A2A2B2B2C2C2C2E2F303132333636393A3C3E3F414346
484B4B4F4F5354585A5E60616366696A6C6F6F737577777D7D8083838686898D8D909193
9496989A999C9BA0A4A4A6A7A9ACABAEB0B1B1B4B5B6BBB9BBBCBCBEBFBFC1C0C0C0C3C1
C0C2C3C3C0C5C1C0C1C2C3C2C6C2C1C7C6C4C2C4C4C4C0C5C7C6CBC7CAC9CAC9CAC9C8C9
C8CACDCECDCBCBCACCCDCACDC9CACCC9C6C7C8C4C1BFBEBABCB8BBB8B6B1B0B0AEADACA9
ACA6A5A2A3A3A3A3A0A3A1A2A19F9E9F9F9E9F9FA0A1A1A1A0A1A2A2A3A1A4A5A8A5A6A7
A8A9ABA9ABACADAEB0ADACB1B1AFB1B0B2B3B1AEB3B5B4B1B3B1B4B4B2B0B5B2B0ACABAD
AAA9A8AAA7A7A7A5A7A4A6A6A5A6A5A2A2A1A2A2A6A3A4A1A29FA1A0A19FA2A29FA3A3A2
A1A1A2A2A2A1A19FA1A19FA09FA09D9E9D9CA09A9C999B97989698939690918F91908F90
8F8F8A8E898B8A898A87878786868583848383818082817E807E7B7B7976787675767575
757574736E6E6F6D6C696A696867656464636461636363636361626262615F5F5E5F6160
60605F5F5F5F5E605F5E5F5F5E5D5D5C5A5856545149423E3B3835343231302E2C2B2B2A
2A2829282828272727272727272727262726262727262726262627262626262626262626
2626262626262626
262626262626262626262626262626262626262627262626272726262727272727272727
272727272827272828282929292A2A2B2B2B2C2D2E2E303133343636393A3D3F42434446
494B4D4F505355575C5C5F61656667696D6F717374777A7C7D7E8184838688888E8F9191
959798999A9B9EA3A2A5A3A9A8ABADADACB2B4B2B3B9BABBBBBCBDBFBFBFBDC1C2C2C3C5
C2C3C2C4C1C6C2C2C3C3C4C3C2C2C7C6C5C3C4C6C4C5C6C7C7C6CACBCBCBCBCBC9C9CACD
CCCDCDCECDCDCDCECDD0CFCED0CECDCFCCCBC9CAC6C4C2BFC1BDBDB9B5B5B6B2B3AEB0AE
AEABADA5A6A6A5A4A0A2A0A1A19E9FA1A1A39EA0A2A09FA2A09FA19FA0A2A1A5A5A2A6A8
A6A8A9A9A9A8ABAAABADACAFACB1AFB0B0B3B0B1B1B2B2B0B3B4B2B3B3B4B1B0B2B1ADAE
ABACADAAA9A9A7A7A6AAA4A8A3A6A4A2A2A4A4A4A1A5A2A2A3A2A0A2A1A2A3A4A2A0A3A1
A1A2A19FA19FA2A0A2A2A3A4A2A0A09C9FA19B9B9C9C9899979B989695929291918F8D90
908D8A8A8A898A888A8A8888868586828484838482828181817D7E7D7C79757675777474
7477767471716E6F6D6C6B6A6A6866646563646363636362616261615E61605E5F606161
5F605F5F5F5E605E5E5F5D5E5D5E5C5A5A595754524C463F3C3936353331302E2D2C2B2B
292929282827282727272727272727272726272726262626262626262726262626262626
2626262626262626
262726262626272626262626262626262626262726272627262727262627262727272727
272727282828282828292829292A2A2B2B2C2D2D2E2F303233343637393A3E4040434547
494B4D50525456585A5E60636465696A6C70717376767A7C7D8080838487878D8B8F8F94
9196979A9A9F9EA1A2A3A3A7AAACADAEAFB2B2B4B3B7B8B8BABCBEBEC0BDC2C2C2C3C0C6
C5C2C7C0C4C3C2C3C4C6C6C3C5C4C7C8C6C6C6C4C5C8C8C7C9C8CDCACBCACBCDCCCCCFCD
CFD1D1D0CFD0D0D2D0D0D1D2D1D4D2CFCFD0CECCC9C8C4C1C3BFC1BEBDBAB7B7B4B2B5B2
B4AFADABA9A6A6A2A5A4A4A2A4A1A29E9F9FA19F9E9FA2A0A0A2A19FA2A0A1A3A3A2A3A4
A7A4A6A6A8A9A9ACA9AAAEACACADAFAEB0AFB3B3B3B3B4B1B2B2B2B4B3B1B4B3B2B4B3AE
B0AEACABADACA7A8A9AAA8A3A7A4A6A5A4A1A6A4A4A4A5A0A1A2A2A1A2A1A29FA19EA0A0
A29CA2A0A1A3A0A2A1A2A2A3A4A29E9F9C9D9D9A9D9C999A999999989694929290929090
928E908C8B8D8B8A8D8A8989898683858384858581818283808081807C7A797878777876
757675727371716F6E6C6A6B6969686666666463616163636262626161615E5E5F605F60
5F60615F60605F5E5F5E5E5D5E5C5C5C5A5A5A56554F49433E3A38363332312F2E2C2B2A
2A2A29292828282727272727272727272726262726272626262626262626262626262626
2626262626262626
252626262626262626262626262627262626262726262626272726272727272727272727
2727272828282828292829292B292A2B2C2B2C2E2F2F303234353739393C3D3E41434748
494B4C505353555A595C60616566696D6C6E717175777A7A7E7E81818488888A8C8F9093
92959899989C9DA1A0A4A3A9A9AAACB0AFB2B1B3B5B8B5B8B9BCBEBFC0C0C2C4C0C2C3C4
C3C6C2C6C4C2C4C3C3C7C7C6C4C5C5C5C5C7C9C8C7C5C8C9C8CBCFCCCECCCCCDCBCFCED0
D2D2D3CFD0D1D2D1D4D3D3D7D7D6D7D6D5D1CDCBCBCBC8C7C7C4C3C4C1BCBDBABCB9B3B9
B5B0B2AEAEA9A9A7A8A8A3A6A4A3A2A3A1A1A1A0A1A19FA1A1A0A1A2A19FA1A1A1A1A3A2
A2A5A3A4A6A8A8AAAAAAABA7ABAEAFB0AEAFAEB3B2B2B3B2B5B6B4B5B2B4B4B4B7B4B2B3
B1B1B1ACAAADADA9ABA9A8A9A8A5A6A5A2A4A2A4A5A3A3A2A4A1A0A19EA1A1A29EA0A19F
9FA5A2A1A1A39EA1A09FA3A4A3A09F9D9E9C9B9E9E9C9D9B97979A979694919191929092
90908E8D8E8C8A8C8A8A8A888686848583828583848282848585837F7E7C7B7A797C7879
78767473706F706E6E6E6C6D6B69686967666564626360636261626161605F5F5F60605E
5F6060605E5E5E5E5E5E5D5D5C5D5D5B5A59595854504D463F3D3837343331302F2C2C2B
2A2A29292829282727282727272727272727262626262726272626262626262626262626
2626262626262626
252626262626262626262626262627262626262627262627272726262726262727272727
272727272728272828282929292A2A2B2C2C2D2D2F303132343537373A3C3E4042434548
494D4E4F535557585A5C5F626366676A6D70737475767C7D7E7F7E848486888B8A8F9391
94979999999A9F9EA2A2A4AAAAADAAADADAFB3B5B5B5BABCBBBCBBBCBFC0C1BFC1C1C5C4
C7C1C5C5C7C7C6C4CAC7C4C4C4C4C3C6C5CCCACACCCACBCAC8CCCACED0CED0CBCDD2CECE
D1D2D2D0D1D1D1D3D6D7D5D7D6DCD6D7D9D3CFD0CDD1CCCBC9C8C9C6C1C1BFBFBABBBAB7
B7B7B3B1B0AFADACAAA8A7A7A5A3A4A3A4A1A2A1A19FA1A3A0A3A0A0A19EA0A0A49FA2A3
A3A1A3A5A7A6A8A7ABABAAA9A9ACABAEADACB1AEADAFB2B2B3B5B3B3B2B4B6B8B5B5B2B5
B6B2B3B0AFAEABACADAAAAA9A7A6A6A8A7A7A3A8A5A3A5A3A4A4A19FA09FA19FA0A0A29F
A1A2A0A2A1A0A1A1A0A5A1A6A1A2A09FA09F9E9AA09D9A9997989897959593909492918F
90908D8E8D8D8D888B898A8889888686868685848584848585858681807F7D7B7B7B7979
777677737371726F706E6F6D6C6A686A686766646462636462636061625E5F5F605F5F5F
5F60605F5E605F5E5E5E5F5E5E5D5E5C5C5B595755514F48423D3937353430312E2D2C2C
2A2A29292928282727272727262727272627262726262627262627262626262626262626
2626262626262626
262626262626262626262626262626262626262727262627262726272727272727272727
2728272828272828282829292A2A2A2B2B2D2D2E2F303232343636393B3C3E4040444647
4B4C4E5152555759595E5F616366696B6E6F70727477777B7C7E8182868688898E8D9093
959596999C9D9FA1A3A4A7A6A7ABAEB1AFB1B2B1B4B8B7B9B7BABDBDBDC2BEC0C1C5C1C4
C5C4C4C7C3C8C7C7C7C7C6C6C5C3C4C6C6CACACBCACBCBCACBC8CCCDCECECCCDD1D2D2D0
D0CDCDD1CECFD1D3D8D8D6D6D8D6D9D7D5D5D6D0D1CDD2D0CDCAC9CCC6C3C4C0C2BEBFBB
B7B3B4B3B0B2ADAFABADA9A9A8A8A8A1A4A3A4A5A4A0A1A2A2A2A0A0A1A09FA09FA1A1A2
A2A0A2A0A5A5A3A6A9ABA9AAA7AAAAACACABAEAFAFAFB2B4B0B1B3B4B6B5B5B8B7B4B7B6
B6B3B5B5B1AFAEADAEADABA8A7A8ACAAA8ACA4A4A4A5A1A4A3A3A3A2A1A2A0A0A1A39FA0
A3A2A2A0A0A0A1A1A1A0A2A2A1A1A1A29E9E9FA09E9F9C9A9A9A98969695959593929192
8F928E8D90908E8F8A8C898A8986878887868586858583858686868580817F7D7B7B7B7B
787775757371716F6F6E6E6D6D6B6B69676865666564636362626162615E5E5F5F5F5E5E
5E5F5E5E5F5F5E5E5F5C5C5E5C5B5D5A5C5B5B585655514B443F3B38353332302F2E2E2C
2A2A29292928282728272727272727272727272727262626262726272626262626272626
2626262626262626
262626262626262626262626262626262626262626262626262626272727272727272727
2727272828282828282929292A2A2B2B2C2D2D2E2F313233343737393A3D3F4042454748
4B4C4E50525557595C5C5F5F6367696B6C6E71727578787B7C7E81818587898A8D8E9294
959598999A9C9FA1A3A3A6A7AAAAAAADAEB1AFB3B3B7B7B7B8BBBCBBBDBFBEBEC2C5C5C3
C4C7C6C8C8C7C6C6C8C7C3C9C4C7C5C6C7C9CCCDCCCACACCCCCBCCCED2CFD1D2D4D0D3D0
D1D1CFCFCFD1D4D5D6D5D4D3D5D8D8DADAD9D5D7D2D0D3D1CDCBCBC9CACBC7C7C6C5BEBB
BAB9BAB5B7B6B4B1B2B0ABAAABACA9A8A7A6A5A4A2A0A0A2A3A0A09EA0A0A19F9FA1A0A0
9E9F9D9FA2A2A3A8A6A5A8A6AAA8A7ACABABADAFAFAFB2B5B3B5B0B2B4B6B3B7BAB4B4B5
B6B7B8B6B3B5B1B0AEAFABADA9ABAAAAA9A9A5A4A4A3A3A2A3A2A5A3A3A2A2A2A1A0A0A2
A0A0A0A1A0A0A5A1A3A3A2A4A2A1A2A1A2A4A09FA09C9D9E9E9D9A989794949595959292
9393909190908E8C8D8A8D8B8B8A878887878785868684858587868682837F7F7D7C7B7B
787877767473716F6F6E6E6C6C6B6A6969686766646464656260616161606060605F5F5F
5F5E605E5F5D5F5D5C5D5C5D5C5C5B5B5B595A595853514D47403B3936353331302E2D2C
2B2B2A292828282827282727272727262727272626272726262726262626262626262626
2626262626262626
252626262626262626262626262626262626262627272726272727272727272727272727
27282828282828282929292A2A2A2B2B2B2C2E2F30313133353737393B3D3F3F42434649
4C4D4E50535658595D5D5F616366686A6A6F7271737579787E7E8084858789878B8B8E93
95949698999C9F9EA3A4A5A8A7AAACAEADB0B1B4B3B6B7B8BABABFBBBBBDBDC2C3C3C4C5
C6C4C8C7C6C5C5C8C7CBC8C8C7CAC5C8C5CBCCCACCCCCED1CBCECECFD2D2D1D2D3D5D6D2
D1D2CECFCBCED0D3D4D5D4D6D6D9DBDADCD7D6D7D4D8D4D2D1D5CFCDCDCCCDCACAC4C5C1
BDBCBBBABBB8B8B5B3B0AFB0AEAFACABA9A8A8A6A4A5A1A2A0A2A0A09EA19E9D9F9EA09C
9EA09F9D9FA0A0A1A3A1A4A5A5A7A8A8AAADABACAEADAEB4B3AFB5B2B6B4B8B8B5B9B8B6
B5B4B6B7B8B4B3B4B0AEB0AFACACACAAAAA9A6A6A5A3A5A5A5A5A4A0A0A3A1A1A1A1A0A2
A19EA0A1A4A19FA2A2A6A3A5A3A3A1A2A2A2A29FA09F9C9E9B9E9F999999979795959492
92939190908F8E8D8F8C8C8C8B8B888A86878885868584858586858582837F7E7E7D7B7C
7B797678757472726E6F6D6F6C6B6A6A6A696A6A6766666462626262626160615E5E5F5D
5D5F5E5F5E5D5E5E5E5D5E5C5C5B5B5A595A5B595856535049433F3A38353331312F2E2D
2C2A29292928282828272727272727272727262727262626262726272626262626262626
2626262626262626
252626262626262626262626262626262726262626272726272627272727262727272728
2727272828292828292929292A2B2B2C2B2D2E2F303233343637383A3B3C3E4142454748
4B4C4F515355585A5C5F5E63646768696B6D6F727677787C7B8082828584868B8B8D9090
92949596989E9C9FA3A4A5A6A8A9ABAEAEB2B1B3B2B6B9BBB8BBBBBFBEC0C1BEC1C2C4C3
C5C6C4C4C3C6C8C7C8C7C9C9CBCAC6C8C9CAC9C8CDCACACDCFCFCDD1D5D3D2D4D4D4D6D2
D1CFCCCDCECED2D2D5D6D7D7D9DDDCDADCDAD8DBD7D7DBDAD5D1D1CFCECDCECDCDC7C6C3
C1C2C0BFBFBDBCBBB6B4B3B2B2AFADA9AEAAA7A9A4A5A2A3A3A19F9FA19F9F9D9D9F9D9E
9D9E9E9E9E9D9E9EA1A3A1A4A5A7A6A8AAABACABABAEAFB1B5B2B3B1B3B6B5B4B8B6B5B6
B5B4B8BAB7B7B4B5B3B3B1AEABAEACABACADA8A7A4A5A7A3A7A5A3A3A5A2A1A0A1A2A19E
9F9FA0A2A1A4A2A1A4A1A3A2A2A4A3A2A1A2A29E9F9F9F9D9C9E9C9C9C9A9B9997959497
94939090928E8C908F8E8D8C8C8C8D8B8A8888888785848685858483827F80817F807C7B
7A7C78787675727272706F6E6D6B6B6A686A68686665646364626362616060605E5F5E5E
5E5D5F5C5C5D5F5C5E5D5E5E5C5B5B5B5B5B5A5A585753514C46403B3835333232302F2D
2C2B2A2A2928282828282727272727272727272726262626262626262626262626262626
2626262626262626
262626262626262626262627262626262626262627272627272727262727272727272727
272728282828282829292A2A2B2B2B2C2D2D2E2F313233343537393A3C3E3F4244454749
4A4D51525457585B5C5E5F636566686A6B6F6F737474777B7E7E81838587878B8B8F9091
93959595999B9F9EA2A3A6A5A7A9ABAEAEB0B0B0B0B3B4B9BBBDBCBBBDBDBFBEC2C3C3BF
C6C6C7C6C4C4C7CACBCDCBCCCACCCCCBC7CCCBCECACCCFD0D2CFD0D3D5D7D4D4D5D6D4D4
D1D2D1D3D1D1D2D5D9D9D7D8D8DCDDDFDCDBDDDDDFDDD9D4D5D5D1D3D2D2D2D0CDCEC9C7
C5C5C3C3C5C1BFBBBBB7B8B5B4B3B0B2AEAFABA9AAA7A6A4A49FA0A1A09F9DA09D9C9F9C
9A9E9B9E9C9E9CA19D9FA2A1A1A5A2A4A7AAA9A9AAAEAEAFB0B1B1B3B5B5B6B7B7B7B4B6
B6B6B6BCB9B8B8B7B6B5B5B4AEAEAEABACA9A7A7ABA6A6A8A5A7A7A1A3A5A4A4A1A1A19F
9FA29F9EA29DA0A3A1A3A0A4A2A0A2A0A3A2A2A09E9F9E9C9D9F9D9D9D9D9D9B9A979493
9594929290908E8D8D8E8F8C8C8C8C8B888A8B868787868584868682818181817E7E7E7D
7C7B7B797875747471706F6E6D6D6C6C6B6A6967676566656564626260605F5F5F5E5E5D
5D5F5E5C5E5D5D5C5C5C5E5B5B5C5B5A5A5B5B58585654514F49413D3937353331302E2D
2D2B2A2A2929282828272827272727272727272727262727262726272626262626272626
2626262626262626
252626262626262626262626262626262726262726272727272727262726272727272727
272727282828282828292A2A2B2B2C2C2D2E2F2F303233353737393B3D3E40414345474A
4B4C50515457575A5C5D5F64646668696B6E7070737677797B7F81828388888D8A8C9090
93929593999C9E9FA0A3A3A5A7A7ACAEADAFB1B3B2B6B6B7B7BBBAB8BDBFBFC0C0C2C3C3
C5C6C6C4C5C7CBCBCDCBC9C8CACDCDCCCDCDCDCBC9CBD1D2D4D0D1D1D4D5D5D5D5D2D5D6
D3D3D4D3D4D2D3D6D9DADAD8DADFE0DFDFE1E4E1E2DEDCD9D8D7D7D5D3D7D6D1D1CDCCCC
CBC8C7C5C5C6C3BEBEBBB9B9B8B5B3B1B2ACB0AEABACACA7A4A4A5A2A0A19DA09F9E9C9D
9B9B9D9D9D9AA2A09D9E9DA0A1A3A3A3A5A6A7A9A8A9ACADB1AFAFB5B4B5B7B5B7B8B5B4
B5B6B8BBBDBBB8B7B7B5B8B3B3B2B1B0AFADACABAAAAA8A7A6A7A3A3A2A0A2A3A2A3A1A2
A2A09FA3A0A09FA3A1A2A0A1A0A4A3A3A19F9F9D9E9D9E9B9C9C9E9B9E9D9D9B99989895
96939392928E8F8E8E8E8D8D8B8B8B8A8A8986878786878684848282828280807F7E7D7C
7B7B7C7A797775747270706C6E6E6B6B6C6A6A68696966676665636361605F6060605F5E
605E5D5E5C5D5D5E5D5B5B5C5C5D5A595A595959575654534F4B453E3A37363332302E2E
2D2C2B2A2929282828282827272727272627272726262626262626262626262626262626
2626262626262626
262726262626262626262626262626262627272627272627272727272727272727272727
282828282828282929292A2A2A2B2C2C2D2E2F303133343635383A3C3D3F404243454749
4C4D4F535557595A5D5F62636465686B6D7071737574777B7B7D8282848786898B8E8F91
92949696979B9D9F9FA0A3A3A7A9ABACAEB0AEB4B5B6B5B7BCBDBBBBBDBDC0BFC0C2C4C4
C5C5C6C5C8CCCBCECACDC9CCCDCFCECCCDCDCECBCED0CFD5D4D2D4D3D1D3D3D4D2D5D3D4
D6D3D4D7D6D7D6D9DADBD8DCDDDEE1E1E2E4E3E4E3E1DEDCDCD9DADAD9D9D7D6D2D2CFD0
CECCCCC9CBC7C3C2C2C1BEBDBCBAB5B5B1B5AFAFADACAAAAA6A6A5A0A1A19F9F9F9D9E9B
9C9A9E9D9C9B9D9B9D9D9C9D9C9EA09DA3A3A1A4A4A5A8ADACACAEAEB4B8B5B5B4B7B6B8
B3B9BABCB9B9BABBBAB6B7B5B4B4B2AFAEADACA8ABABA9AAA5A9A3A4A2A3A5A3A3A1A19F
A2A0A1A2A1A1A0A19FA2A3A0A0A2A2A29FA39F9F9D9D9D9C9D9DA0A09E9F9C9C9B9B9596
9697959491908D8F8E8D8F908C8D898B898A8888868585858584838483837F7F817F807E
7D7C7C7A7A7978737470716E6C6D6D6C6B6A686B6A67656866666462616160605F5F5F5D
5E5D5A5B5D5C5C5C5D5B5B5B5C5A5A5A59595A5757565653514C47403C3A36343231302F
2D2C2B2A2929292928272827272727272727272727262626262626262626262626262626
2626262626262626
262626262626262626262726262626262726262626272727272727272727262727272727
272828282828282929292A2A2B2B2C2D2D2E2F303132353636383A3B3D3E41414446474B
4C4D50515455595B5D5F6062666667686C6E6F71747677787B7E7F81848587898C8D9092
92949495989B9B9D9EA2A1A5A4AAABACACAEB1B2B0B1B5B6B9BBBBB9BEBDBEBDBFC1C6C4
C4C6C6C9C7C8CAC9CECAC8C9CDD0CCD0CED0D3D4D0CED5D0D6D0D1D1D1D5D2D4D6D3D6D4
D5D6D8DCDAD8D7D7D8DADDDADEDFE1E2E2E3E5E4E5DEE0E0DEDBD8D9DADDD7D6D6D5D4D1
D0CFD1CDCDC7C8C6C4C2C3C0C0BABBB8B6B2B3B2B0AFACAAA6A5A5A3A3A1A4A19F9E9B9C
9E9E9D9B9C9A9D9C9C9D9C9A9C9D9D9F9FA3A2A5A2A4A6A8ABACADAFAFB5B3B2B4B5B7B6
B9B9B9BBB8BCBCB9B9B9BAB9B4B6B4B2B3AEAEAEAAAAAAABA6A6A6A5A2A1A2A3A6A3A1A0
9FA1A0A0A09EA09FA09F9FA3A1A39FA0A09FA09F9F9C9C9E9C9D9B9F9E9E9F9D9C9C9796
969594949391908F928E8D8E8D8C8C8B8B8A8B8C89868686878585838282828080807D7D
7D7D7C7B7B78787676747270726D6C6B6C6B696A6B68686667656462645F60605F5E5E5E
5C5C5D5C5D5E5B5C5B5C5C5B5B5A5B5959585858565655534F4E49413F3A373532312F2F
2E2D2C2A2A29282928282827272727272627272726272626262627262627262626262626
2626262626262626
262626262626262626262626272626262626272626272727272727272727272727272727
2727282728292929292A2A2A2B2B2B2C2D2E2F313133353539393B3B3E3F42444447484A
4D4F51515358585C5C5F62616467686A6E6D6F71737676787B7D7E7F868786888C8C8E8F
929496969898999D9FA1A1A5A7A7A6AAACAEAEB1B4B2B3B8B5B7B9BCBBBDBCBFC0C0C3C2
C2C4C6C6C7CACBCACBCBC8CFCFCECFD1CCD2D1D4CED3D3D4D0D3D3D4D3D4D5D9D6D5D4D5
D5D8D9D6D9D9D5D6D7DADBDCDDE1E1E1E4E7E1E0E0E2E0E4E3E0DFDEDBDDDBDBD7D6D7D4
D1D2D3D3D2CCC6C7C6C7C6C6C3BFBCB8B8B6B5B2B3B1B0A9AAA6A5A4A1A2A1A1A0A09EA0
9C9D9F9E9D9A9B9C9B9D9A9C9A9C9CA0A1A19FA3A3A0A3A6A9A9ACACAEB0B1B4B1B4B6B7
B6B6BABCBBB9BBBAB8BBB8B9BBBAB7B6B5B4B3AFAEADADAFA9A9A5A3A5A4A3A4A3A4A3A3
A3A0A0A0A1A29FA3A0A09FA0A0A09E9DA29DA0A19C9D9D9C9F9DA09F9F9F9E9D9C9C9B99
9797949694959390918F8F8F8C8D8D8C8C8B8A888887878886848687838383837F807D7F
7F7F7C7C7B7A7778767372716F6E6F6E6B6A696B6968686766676664646261615F5F5F5D
5B5D5B5B5D5C5D5C5A5B5B5C595A59585858585857555452514E4B453E3C38353331302F
2E2D2C2B2A2A282828282827272727272727272727272726262626262627262626272626
2626262626262626
262626262626262626262626262626262726272626272727262627262727272727272728
2828272828282829292A2A2A2A2B2D2D2E2E30323333353638373B3D3E3F42434546484B
4C4F4F52555758595C5F6163656667696C6E6F707374767A797C7C7E818487878A8B8E8F
91929597989C9C9B9B9EA5A4A4A5A7AAABADB1AFB3B2AEB5B6B8B8BBBCBEBDBEBFC2C1C2
C5C3C5C7C9C8CBCACBCCCCCBCDCFCED0D1D2D6D5D2D4D6D6D6D2D7D3D4D6D9D7D5D6D4D1
D6D5D8D8DCD9D6D7D7D6D8DDDEE0DEDFE2E5E3E1E3E3E1E3E3E4E0E0E0DEDEDCD5D9D6D5
D7D7D3D2D3CFCBCAC8C9CAC8C2C5BFBEBDBCB8B6B7B3AFB0ADA9A7A4A8A3A3A0A1A09F9F
9F9D9C9C9B9B9B9A9C9A9B9C9A9C9E9C9FA0A19FA2A2A0A2A7A8ABA9ABADB0B0B1B3B3B4
B7B8B9B7B7BABAB8BDBCB7BAB9B8B9B9B7B6B6B4B1AEAEAAAAAAA8A9A6A3A5A3A2A1A4A2
A1A6A4A2A1A1A1A2A0A09FA19F9FA09FA19EA09E9F9D9D9D9E9EA09E9EA09F9F9E9C9B98
97979894959694939291918F908D8D8C8E8B8B878B888A88888486848683848380827F80
7E7E7D7E7C7A7978767675737171706F6D6C6B6A696A68676767646665616261605E5C5E
5E5C5C5B5B5C5C5B5C5C5B595B5B58595756565654555352524F4C48433C38363331312F
2E2D2C2B2A2A292828282828272827272727272626262627272627262626272626262626
2626262626262626
252626262626262626262627262626272626262626272627272727272727272727272727
2728282829292929292A2A2B2B2C2D2D2F2F303233333636383A3B3C3E4043434548494B
4D4F51525455595C5C5E6163666768696C6D707171767678797A7E8182868385898E8C8F
9093959698979D9C9AA0A0A1A3A5A8A8AAAEADB0B2AEAFB3B3B8B8BBBBBFBEBBBFC2C0C3
C2C4C4C7CAC9CBCCCBCCC9CDD1CFD0D0CFD2D4D3D6D8D3D5D6D8D5D8D5D8D5D7D5D7D3D7
D6D2D4D5D7D9D7D8D6D8DADBE3DEE6E7E4E3E3E2E2E1E2E4E6E4E0DFE0E0DDDDDDDCDCDA
D9D5D6D4D3D4D0D2CECACCC8C7C7C5C0C1BCBAB8B6B3AFAFABAAA9A9A7A5A3A5A4A0A0A1
9F9EA09B9A9E979B9A9B9C9E9A9C9C9F9E9E9E9F9FA19DA2A5A6A6A9A9ABABB0AFB1B2B2
B3B5B5B7B5B9B8B9BBB9BEBEBBBDBDB9B9B5B6B5B3B0ACABABABAAAAA7A8A5A5A6A6A5A5
A2A3A1A3A2A2A1A1A1A0A19FA0A29FA0A0A09FA09CA19E9E9D9F9F9F9C9B9B9D9C999C9B
989B96979695949291928F908E8F8E8F8D8B8C8C878A878A87878586888581838281817F
7E7E7D7E7C7B7A797877757573727272706D6D6B6A6A686A6869676764646360605F5F5E
5D5D5B5D5C5C5C5B5C5C5959595959585757575557565452514E4D4A443D393634323230
2E2D2C2B2A2A282928282828272727272727272626262626262626262626262626262626
2626262626262626
262626262626262626262626272626262627262727272627272727272727272827272728
27272828282929292A2A2B2B2B2C2D2E2E30313333353637393A3C3D3F4043424546494B
4D4E51525555595B5E5F61626368696B6D6C707273757676797A7D818383848688898E8D
909396949899999C9D9CA1A1A2A4A6AAABABADACB1B0B5B3B6B8B6B9B9BDBDBCC2C3C6C5
C4C4C7C4CBC7CCCBCBCECCCCCED1D2D0D2D3D0D4D4D4D7D7D7D5D3D7DAD7DADADDDADCD7
D5D8D6D6D4D5D8D4DBDADAE0DFE2DEE3E1E3E2E3E4E1DFE5E6E5E1E6E3E4DFE4DFDCDBDA
DCD8D3D6D5D3D8D1D1CECFCACBC8C8C6C0C2BFBAB9B5B3B1AEAEABA9AAA6A7A7A6A1A1A4
9F9E9D9F9E9C9D9A9C9A9C9D9B9C9F9C9E9B9C9FA0A0A1A0A1A4A7A6A8A8A9ADADAEB3B3
B1B6B5B6B6BAB9BDBBBBBABBBABBBBBCB8B8B6B5B2B3B1AEAEAEADABABA7A8A6A3A7A5A4
A3A4A6A3A2A4A1A0A2A2A1A09EA1A29FA29E9EA09F9AA19E9E9F9D9E9F9D9E9E9B9B9A98
9697979796969692929291918F908E8D8D8C8A8B8B89898B898786878686858483828081
817E7E7D7C7B7C7B7779787576757372706F6E6C6C6A696B686668666564646461605E5F
5D5C5C5C5C5C5C5D5C5A5B5A595A58575557555453525252504E4D49463F3A3734323230
2F2F2D2C2B2A2A2928282828282727272727272727272726262626262626262626262626
2626262626262626
262626262626262626262627262626262626262727272727262627272727272727282827
2828282829282929292A2A2B2C2C2D2D2F30313333353737393B3C3E3F42434446474A4C
4E4F515354575A595D5E60646566686A6A6F717372747677797B7C80818283848789898C
8E9091959996999C9C9F9FA1A4A5A4A4A8ABAEAEB0B2B2B1B4B5B4B4B9BBBBBDBFC4C3C5
C3C3C5C4C6C8CECBCECDCDCED2D0D2CFD3D3D2D2D3D6D7D9DDD5D5D8D8D8DADBDBD9D9D5
D6D5D6D6D7DADCDCDCDDDEDFE0E4E3E3E3E1E1E5E4E4E4E8E4E4E5E5E2E1E5E1E3E0DFDC
DDDCDDD8D5D9D7D6D6D1D1CFCFCCC7C9C6C6C1BFBFB8B5B4B2B0ADABA9A7A6A5A7A4A3A2
A1A09E9E9E9E9A9B9A9C9A9A9B9B9C9E9D9F9D9C9E9FA0A1A2A6A1A6A7A7ABA9ADADB1B2
B5B3B6B5B6B9BABCBBBEBCBDB8BCB9B7B9BABBB9B4B2B1B0AFAEAEADADACAAA8A7A6A7A5
A4A3A5A4A1A3A1A4A2A0A1A0A19FA29FA09E9F9E9EA19D9D9E9E9E9C9A9A9B9E9C9B9A9A
99979A9997979693949090908E8E8C8D8C8B8D8A8C8B8A88868788868485868383818180
80807F7E7E7C7A7B7A7B7A767675757471706E6E6C6B6A6B6A6A6869686764646262605F
5D5D5C5D5B5B5B5A595A595A5959585757565554545351514F4F4D4C48423D3936333231
302E2D2C2B2A292928282828282727272727272726272727272627262627262626262626
2626262626262626
262626262627262626262626262626272626272726262727272727272727272827282728
272828282929292A292A2A2A2C2D2E2E2F303233343537393A3B3C3D404142454748494B
4E5151545455585A5C5F6162646669686C6B70727374757879787A7D808286858685898B
8B9094949499999E9C9BA0A0A2A4A3A7A9ABA8AEADB0AEB2B4B5B6B7BABDBDB9BFC0C4C5
C5C3C7C8C6CAC9C9C3C3C5C5CCD2D2D1D0D1D3D3D2D3D9D9D6DBD9D6D8D9DADADBDADAD8
D7D9D7D4DBDBDBDADEDBDCE1E1DFE5E2E5E5E2E6E6E7E5EAE9E6E8E3E5E4E6E4E4E2E1DD
DEDFDBD9DCDBD7D5D5D9D3D1CDCECDCCC7C8C3C0BCB8B9B7B4B1AFACADACA6AAA7A6A5A5
A1A39F9EA09D9D9D9B9C9B9D9A9B999A9E9C9B9A9F9DA09D9F9FA2A7A4A8A8AAABACB0B0
B1B4B5B6B7BAB7B9BABBBCB9BCB8B9BCBABABBB8B7B5B5B5B3B2B1B0AEADAAA8A9A8A7A4
A5A4A4A3A3A2A2A2A3A3A0A09FA1A1A1A09DA09E9D9D9E9E9D9F9F9C9D9D9C9A9A989A99
9999979896989595939190908F8D8E8F8F8C8A8C8C8C8B89898685878685868383828280
83817E7F7D7C7D7D7D7A7979787675737172716F6F6D6C6A69696968676766666261615E
5F5D5B5D5C5C5B5B5A5A5A595958595855555453535252514F4E4D4C48443D3B37343331
302E2D2D2B2A2A2A29292828272727272727272627272626262726262626262626262626
2626262626262626
262626262626262626262626262626262626262627272727262727272727272827282727
28282828282929292A2A2B2B2B2D2E2F30313233343738393B3C3D3E40434445464A4B4C
4D5050535556575A5A606162646568696A6D6F7173757678797B7A7F7F80848488888B8B
8E8D909497979A9A9A9EA0A0A0A3A6A7A6A7AAAAACAFB0B2B3B5B4B7B7BBBABEBDC1C2C5
C7C5C5C3C7C7CBC9C9C7C7CECED3D1D2D1CED2D3D4D8D7D6D5D9DAD9DAD7D6DCDBDAD8DB
DAD9D9D6DADBDEDFDDDEE1E2E3E6E6E7E5E6E8E9E5E7E6E8E4E8E4E5E5E9E6E5E8E6E2E1
DFDFE0DCDADDDDDAD8D8D5D5D1D3D0CBC8C9C4C0C3BDBDBCB9B7B1B4AFAEA9ABA9A6A5A5
A4A2A3A29F9D9E9E9CA09D9B9B9A989B9B9B9C9C9D9D9DA09DA0A1A0A5A6A6A9A9A9ABAF
B3B1B4B7B5B6B6B8B9BBBBBEBCBFBCBDBBBCBABBBAB9B8B5B4B5B1AFAFAFADABABABA8A6
A7A7A4A6A4A0A4A1A0A1A0A1A2A09E9F9F9F9F9F9E9F9D9DA09C9DA09C9F9B9C9C9C9A9A
98999997949797959494929490928F8E8E8F8A8C8B8A8A8A878986868483848484848284
83817F7F807E7C7C7C7A7B7A787874737373726F6E6E6D6B6B6A6A6A686968656262605F
5E5F5D5D5B5C5A5A5A5A59595A58575755555455535551514F4D4C4B4A46403B38343331
302F2E2D2C2A2A2929292828272728272727272726262727262726272626262626262626
2626262626262626
262626262626262626262626262626262727262626262727272627272727272727282828
282828282829292A2A2A2B2C2C2D2D2E30323334353738393A3D3E3F4143444749494B4B
4E5152535656595B5C5E6062636566696B6B6D7172747877797C7C7E7F83828486878788
8E8E8F9195969A9A9B9D9EA0A1A2A4A5A9AAA8AAABACAEB2B4B4B4B6B9BCBABCBFC0C1C4
C0C3C4C7CACACCC9CACACECED1D4D1D4D4D2D1CED7D5D4D4D8D8D7D9D7D6DADCDADBDDDA
DBDDDCDFDFE0DEE0DFE3E2E5E2E4E7E2E2E4E4E3E7E8E5E8E8E5E8E3E8EAEAE6E7E6E6E3
E3E1E1E1DFDEDEDCDCD7DAD8D4D3CFD1D0C8CAC4C4C1C2BDBAB7B4B0B0B0ADABADA8A4A5
A6A4A6A3A2A0A09D9F9D9D9D9B989998999A9B9B9E9C9C9B9D9D9DA2A3A2A4A7A6A9AAAC
B0B2B5B3B6B5B6B7B9B9BDBABEBABBBBBCBDBBBDBDBBB8B7B6B5B2AFB0B0AEAEACACAAA7
A9A6A7A4A5A5A3A1A3A2A2A0A2A1A09F9F9E9E9C9D9F9F9E9C9D9E9E9C9E9A9D9D9A979A
9C999998979494959494959192918F8F8D8D8D8D8A898B87888887868687858784868483
80817E7D7E7E7B7D7E7B797A78777774737573706F6F6E6A6A6969696A68666565626261
5F5E5F5C5D5B595A595A595857565756555555545452524F4E4E4C4B4947413C39363432
302F2E2D2C2A2A2A29292828282727282727272727262726272627272626262626262627
2626262626262626
262626262626262627262626262626262626262626272727272727272727272728272727
2828282829292A2A292B2B2C2C2D2E2F303234343738393A3A3C3F4041434546484B4B4E
4F4F52535559595B5F5F5F6363656769696C6F6F7374757779787C7B808085858788868B
8C8E8F919597989A9C9B9CA09FA3A5A5A6A6AAAAAEADB0AEB3B5B6B2B7B7BBB8BDC2BFC1
C4C3C5C7CAC9CBCBCDCCCDD0D1CFCED0D4D3D6D4D7D4D5D4D7DADBD9D6D9D8DCDADDDCDF
D9DDDEDEE0DFE0E0E1E0E7DFE3E4E3E8E8E5E5E8E8E8E6E6E6EAE6E9E8EAEBE8E7E7E5E4
E0E3E2E1E0DEDFDDD9D8D8D7D4D7D4D2CFCAC7C7C5C2C1BEBCB8B5B5B4B1AEABA9A9A9A6
A6A4A6A4A2A3A0A09F9F9D9F9D9A999C9A9A9A9C9C9C99989A9A9CA09FA1A4A8A7A8A9AE
ADB1B0B5B4B3B6B7B9BBB9BEBABFBCBBBBBDBDBBBBBCBBB8B9B8B4B2AFB1AEB1ADACA8AB
AAA6A5A7A3A6A4A6A5A2A1A4A1A39F9EA19F9FA19C9D9C9E9A9B9D9D9C9D9C9B9B9E9B9C
999B98979895959395949691938F938F928F8C8D8B8B8B8B888988878886858485838282
838080817D7E7E7E7C7C7B7C787876767574717270706D6C6B6C6A686969666665636261
5F5F5E5E5D5D5A5A59575857565658565553555454514F4F4E4C4C4C4B48433E3A373533
31302E2E2C2B2B2929292828282727272727272727272727262626262627262626262626
2626262626262626
252626262626262626262626262726262626262727272727272727272727272827272728
2828282829292A2A2A2A2B2C2D2D2F2F323335363639393B3C3E404242454649494A4C4F
4F50525556575A5A5C5E5F6164646768696B6F7072747477787C7A7A7E8083848487898A
8B8C8F90929497969A9D9D9A9EA2A2A3A7A9AAA6A9ADAAAFAFB2B2B3B5B4B8BBBABFC1C3
C1C2C5C6C7CACDCACDCCCFCFCFCED0D4D8D5D6D4D6D5D6D5D8D7D9DADCD7D8D6D9DDDCDC
DDDEDFE0E0DDDEE1DEE2E4E6E4E5E5E3E6E6EAE8E3E7E6E9E6E6E9E6E9EAE7E9EAE8E8E8
E8E7E5E4E0E0E3DDDEDED9D9D9DAD6D3CED0CAC9C8C5C5C0BCBCB8B4B3B6B1AFAFAEABAA
A6A7A8A7A4A3A39FA0A0A09C9E999A9C999A999C9B9C99999C9AA0A19FA0A2A5A7A9AAA8
AFAFB2B0B2B6B8B9BABAB8B7B7BAB9BEBCBDBFBEBBBBBDBDBCB7B7B5B5B3B2B3B0AEAEAF
AAAAA8ABA7A4A5A6A3A4A3A2A2A09F9E9FA0A1A1A09F9E9E9B9C9C9B9D9E9D9D9A9B9A9A
9A9C9999979796959795949492938F908F8E8F8C8C8B8A8C898989898786868584838282
818180807D7E7E7E7D7C7D7879777674747373727171706D6D6B6A6B6869676764646262
615E5D5D5D5C5B5A5B59575656575355545553545451534F4E4D4D4C4A4A46413B373533
31302F2E2D2B2B2A29282828282828272727272727272626262726262726262626262626
2626262626262626
262726262626262626262627262726262626272626262726262727272727272727272827
2828282929292A2A2A2B2B2D2D2D2F303133333637383A3B3B3F4041434447484A4B4D4F
4F51535457585A5B5C5E60616366676A6A6B6C6F7373757777797C7C7F8081838688878B
8A8D8E9190939598989D9C9BA19FA4A4A8A3A4A9A8ADABACAFB2B2B2B5B6B7BABCBDC0C3
C3C3C3C4CAC7CACCCCCCCDCED0CFD1D2D3D6D4D7D5D8D6D5D6D7DBDBDBDBDCDBDFDEDFDC
DDE0DFE0E1DFDDE2E0E4E5E3E4E5E5E8E4E4E5E8EBE6E6E6E8E7E8E6E8E9EAE8E9EAEAEB
E8E6E9E2E3E2E3DEDFDBDADADAD8DAD6D5D1CFCCCBC8C7C6C1BEBBB9BAB6B6B5AFB1ACAC
AAA7A7A6A8A5A4A3A1A19F9C9F9E9C9C9A9C9B9A97989A9B999C9C9E9FA0A2A1A7A4A7A9
AAADAFAEB3B6B6B7B8BBBBB9BDBBBCBBBBBDC0BCBBBCBDBBBABBB8BAB6B5B3B4B4B1B0B0
ACAAA9A9A9A6A7A7A6A4A2A2A3A19F9E9FA0A0A3A09F9D9E9D9E9F9C9E9D9D9C9E9B9B99
9B9C9B9A97989697949696949492928F918F8E8C8D898B8A8A8A89888784868386848585
8384828081807F7E7D7B7B7A7B787777777473757170706E6D6C6A6B6967676566646362
606060605D5C5D5B5C5858565655565554545353525251504F4C4C4B4B4946413C393634
31312F2E2D2D2B2A29292828282727272727272727272726272626262626262626262626
2626262626262626
262626262626262626262626262627272626272627262627272727272727282728282828
292828292929292A2A2B2C2D2E2E2F303234343739393B3D3D3F4143434747484A4C4D4E
505154575758595C5E5E6163656567696A6D6D6E7274767878787C7C7F8184858586878B
8C8D8E90939393969698999D9E9D9FA4A5A7A6AAA8AAADADAEAFB0B3B5B6B7BAB6BCBCBF
C2C1C3C5C6C8CAC9CCCDCFCBD0CFCFD1D2D2D7D3D7D6D5D8D6D7D8DBDDDEDCDEDBDFDDDC
DEDDE2E2DDE1E1DEE2E2E3E4E7E6E8E9EAE8E7E9E5E2E5E6E7E8E7E7E8ECE8EBE8EBEAEA
E9EBEAE7E7E5E2E2DEDFDDD9DBDBD9D8D6D1CFCDC8CBC6C5C4BEBCBDB8BBBAB7B4B1AFAE
ACABAAA8A6A6A6A8A1A1A0A19F9E9F9D9C9E9A9B9B9D9A9B999A9BA09FA3A5A5A4A6A8A8
AAAFABB0B2B5B6B7B7B7BABAB8BABDBCBDC0BABCBFBCBABBBDBBB9BAB9B6B7B8B3B1B1AE
AEAEA9ABA8AAA5A8A5A5A4A2A4A4A1A1A2A0A0A49D9F9E9E9F9D9D9F9A9B9F9E9C9C9B99
9B989798979999979694949593959191908F8F8E8E8E8B8B898988878788868785838182
8082807F817E7F7D7F7D7D7B7B797775767475737272706F6E6C6C6A6968666765626261
615F5E5D5F5C5A5B5B59565656575355545454525252514E4D4D4B4A4B4946453E3A3734
32302E2E2C2C2B2B2A292928282828282727272727272727262727262726262726262626
2626262626262626
262626262626262626262626262727272726262626262727272727272727272727272828
2828282929292A2A2B2C2C2C2D2F2F3032343636393A3B3D3E414143454547494B4C4E4F
5053545557595A5A5D60606163656669696C6D6F72727676797B797B7E8081838883888B
8A8F8F9190939594969A999B9CA0A1A5A5A8A8A6ABAAAAADADAEAFB2B0B6B7B8BABBBFBD
C0C2C6C6C7CBCBCACBCDCCD0CDD0D0D1D4D4D3D7D6D7D5D6D3DBDDDCE0E1E0DEDDDFDEDE
DEE0DFE1E0E0E1DEE2E2E4E4E2E6E5E8E6E7E5E9E7E4E6E9E3E7E7E8E9E9E6E7E8EDEFED
EDEAEAE9ECE7E5E2E3DEE1E0DBDBDBDADAD6D6D4CEC9CAC6C4C2BEC3BFBDBCBBB5B6B3B2
ADAFADACAAA8A9A5A4A5A2A0A19FA09F9D9D99989B9A9D9C9A9A9AA09FA1A4A4A6A5A7A7
A9A9ADB0B0AFB5B8B8B7B8B7BABBBCBDBDBDBBBCBDBBBDBCBEBBBBBAB9BBB6B5B7B4B0AF
B1B0B3AEABA9A6A5A6A6A5A3A5A39FA29F9F9FA19FA09E9F9DA09D9D9F9E9E9C9A999A99
9A9997989A9995969696949595949393928F928F8F8F8C8B8B8888888786878684858283
848280817F807E7D7F7D7A7A7A78787775767274727271706C6E6C6B6968666666626562
605F5E5E5D5C5C5C5A595757565755555454535352515150504D4D4B4A494845413B3735
32312F2E2D2D2B2B2A292828282827272727272727272726262626272626262626262626
2626262626262626
262626262626262626262627272626262626262626272727272727272727272727282828
28282929292A2A2A2B2C2C2D2E2E3031333437383A3B3D3E40404243464748484D4E5050
5253545758595B5C5E5E6061646568666B6A6D6F7072747578787C7F817F828485868687
8A8D8E8F919191939897989B9A9E9FA0A6A3A5A9A9A8A6ABA9ADB0B0B1B2B6B9B9BABDBF
C1C1C6C3C9C8C8CCCCCAD1CCD0CED1D0D3D4D6D9D7D6D7D8DBD9DDDBE0DCDDDCDDDEDEDE
E2DFDDE2E1E3E3E2E4E3E5E4E6E2E7E7E5EAE7E8EAE8E7E4EBEAE8EAE7E9E9E9ECEAECE9
ECECECECEAE7E6E4E0E4E1DFE1DBDEDBD8D9D5D6CFCBCAC7C7C4C6C3C2C2C0BDBBB6B5B7
B3B0B0ADABACAAA7AAA6A4A4A4A3A09F9F9B9B9B9C9D9C9C9D9D9A9C9F9FA2A5A9A6A7A6
A9A8A9ADAEB2B2B5B4B6B6B6BBBABBBABBBBBEBBBBBCBBBEBABBBCBDBCBBBAB8B6B6B5B4
B1B1AFB1AFACADA9A7A6A5A5A5A4A5A3A1A0A19FA29E9DA09E9E9D9D9E9D9D9D9C9B999A
99999B98979995959A94959594949293929395908F918F8B8C8989878A87878683838583
81828280837F807D7D7C7D7B797A7878767573747270716F6D6D6D696B69666664636262
605F615D5E5C5C5B5B5B58565855565555545252515251504F4E4D4B4B4B4947423C3835
3331312E2E2D2C2B2A2A2928292827272727272727272626262626272626262627262626
2626262626262626
262626262626262626262626262626272626262627262727262727272727272827272828
2828282929292A2B2B2B2C2D2E2F3032343537393A3B3E3E404142464848484C4D4E5051
5255555758595B5C5E60616265666768696B6E6F6F737674767A7A7E7E81828386858587
8A8C8D8E8F919394969695999C9C9CA0A2A3A5A8A9A6AAA9ADAEADB1B1B7B6B8B7B9B8BB
C0C0C3C6C6C7CACACBCFCDCDD1CFCFCFD0D6D6D7D6D5D7D9D8DBD9DCDBDEDEDDDFDFE2DF
E2DFDAE0E0E4E2E3DFE4E6E2E4E9E4E6E5EBEAE8E6E7E8E8ECEAEDE9EDE6EDEBE8EBEBF1
EFEAEEEDEBEAE9E8E9E5E7E3E2E2DDDCDBDAD8D2D2CDC9CAC6C5C6C5C4C4BFBEBFBBB8B8
B8B6B3B1AEAEAFACA8A8A7A7A5A39FA3A19F9B999C9C999A9A9A999A9A9EA2A3A6A5A7AA
A9ABABABABAFAFAFB4B4B5B8B7B9B7BABABABBBCBDBABCBDBDBABBBEBDBBBAB8B8B7B9B6
B4B5B4B3B1AEABA9A9A9A7A6A7A3A4A3A2A2A1A1A09E9E9E9E9E9E9E9E9B9B9B9D979B9B
98989B97959997969795989594929592929191908F8E8D8B898A88898787878485828482
8382827F81807D7E7C7C7D7C7C7B7A7778767672757372706F6F6E6D6B6B676664646262
615F605F5D5D5D5A5B5A585758555655555352525151514F4F4D4D4C4C4A4A47443E3936
3431302F2E2D2C2B2A292829282827272727272727272627262626262626262626262626
2626262626262626
262626262626262626262626262727272627262627272727272727272727272728282828
28282929292A2A2B2B2C2D2E2F2F30343436373A3B3C3E404142444646484A4B4D4E5152
52545556595B5A5D5E606364676767676C6D6D6D71737375767B7A7D7D7F808283858587
8B8A8D8D8F939295949598989B9C9B9FA1A3A5A8A7ABA8ADAAACAFAEB3B3B2B5B7B5BBBC
BFBDC0C4C3C7C6C9CAC8CCCFCED2CFD2D5D6D3D6D3D8DADBD9D7D9DED8D9DCDBDEDEE0E1
E0DED6E3E2E1DFE4E2E6E6E8E7E6E1E4E8E4E8E7E9E8EAECE7E6ECEBE9E9EAEDECEAEDED
EDEDECECECEEE8E8E8EAE5E7E3E3E2DFDDDBDCD5D2CCCCCCCBCBCAC9C5C4C2C0C0BABBB9
B6B9B5B5B2B5B2AFACA9A9A8A5A6A7A4A19F9E9F9E9E9E9D9D999C9D9B9EA0A0A1A5A8A7
ABA7A8A5AAAAADAFB2B5B3B6B6B7B9BDB9BBBDB9BCBBBABBBABABABBC1BEBCBCB9BAB8B5
B4B4B5B4B1B2AFACA9ABA9A6A6A4A3A3A3A3A19FA0A09C9E9E9E9E9D9C9D9D9C9A9B9B9A
9A98979A999A98969898959695949495939091918E918E8E8A8B8A8A8787878586838383
8182817F807F7F807D7C7C7A7D7C7977787675747375727071706E6D6B6B686765656562
64615F5F5D5C5D5C5B5A59595857555654535453525152514F4E4B4C4C4A4948463F3B36
3332302F2E2D2C2B2A292929282828282727272727272727262626262626262626262626
2626262626262626
262626262626262726262626262626262727272727272627272727282727272827282828
28282929292A2A2C2C2C2D2E2F2F3232343738393B3D3E4043454548494A4D4E4E4F5252
55575759595A5D5E60616263646766686C6D6C6F6F73727676797B7C7B7E808082838586
888C8B8E8E90929394979899999B9E9F9FA2A7A4A6A7A9ABA9AFAFB0AFB0AFB8B7B8B9BA
BABDC4C1C0C7C6C9C9CACACCCFD1D3D1CFCFD5D4D6DBD8D7D6DBD7D8D7DBDBDCE1E1DFE1
DDE2DFE2E2E5E2E7E2E1E6E1E1E6E3E7E8EAE9E7E9E8E8EBE8E9E8ECEAECEBEEEBECEDEB
EEECEFEFF0EFEEEAEBE9EAE7E5E5E1E2DEDDD8D9D6D1D0CFD0CECCCBC9C4C0C2C0C0BFBD
BEBAB8B9B6B7B3B1AFAEACAAA8AAA6A6A4A1A0A09E9E9E9C9A9B9A9C9A9D9DA0A0A2A2A6
AAA6A8A6A8A9ACAFAFB0B1B5B9B9B7B8B6B8BABBB9BCBCBABABBBCBDBCBDBDBABABAB8B7
B7B6B6B6B5B3AEAFACAEA9A9A7A7A4A3A4A2A0A09F9FA09E9F9DA19F9F9E9D9F9A9D9C9A
989B9A989995989896969494969793929093928F8F8F8F908F8B8A8A8889878687848483
81838381827F807F7C7D7C7E7B7C7979767576757574727270706E6D6C6B6A6967666565
63615F5F5C5E5D5B5A5959585756565754555352525151504F4E4D4B4C4A494946413B37
343231302E2E2D2B2B2A2A29292827272727272727272727272627262626262626262626
2626262626262626
262626262626262626262626262627272727262727272727272727272727272728272828
282929292A2A2A2B2C2C2E2D303032333637393A3C3E404143444748494C4D4F50525154
575858595A5C5C5E5E626263656669696B6D6C6F71737477767A7A7C7C7C7B8282838587
858A8B8E8F90919093939499999D9B9D9F9FA3A3A8A8A9AAA9AEADAFB0AFB3B1B4B8B6BB
B9BDBFBFC2C2C3C7C8C8CCD0D0D0D1D2D0D4D4D9D5D5DBD7D8DAD7D9DADCDBDCDDE0E1E2
E2E1E1E1E4E4E3E2E1E6E4E6E4E3E5E3E7E6E7E8EAE8E9E9EAE9EBEDECEAEBEBECECE9ED
F1F2EEF0EFECEEEDEBEAE9ECE8E7E7DFE0E0DBDAD5D3D1CED1D0CFCFCAC7C7C4C3C4C3C2
C0C0BCB7B8B8B5B4B3AFAEACADAAA9A7A6A1A3A1A0A39F9E9B9C9D9F9BA09F9E9FA0A3A6
A9A7A8AAA5AAADADAEAFB1B6B5B8B7B7B7B6B8B7BCBEBCBCBBBABCBABDBCBBBCBBBCB9BB
B8B7B9B6B7B6B3B3B0AEACA9AAA6A6A6A5A4A29F9E9E9EA0A1A0A0A09D9D9D9B9B9B979B
9D9A9A9997979699969795959495949394919091918F908F8C8B8B8B8A89888A86858484
83828280817F807E7C7D7C7C7A79797A77797775757473716F716F6D6B6C6A6968666566
636361605F5D5E5C5B58595857575656555555535252504F4E4D4D4C4C4A484846433D37
353231302F2E2C2C2B2A2929282828272727272727272727262727262626262727262626
2626262626262626
252626262626262626272626262726272627262627262626272727272727272728282828
282929292A2A2A2B2B2D2D2E2F3032353638393A3C3F4142434748484B4C4E5051525353
57585A5A5B5D5D5F616163646767696B6A6E7070717373757578797A7C7D7D8082848286
87888A8C8D91909291939998989A9C9D9DA1A2A2A4A7A7A9ACACADAEB2B1B5B4B5B7B7B9
BBBBBFC0C0C1C2C4C8CAC8CFD2CECECFD1D2D4D5D5D8DAD6D9DBD7D8D9DADBDDDDE1DDE0
E1E2E1E2E2DDE5E7E3E4E2E5E3E5E6E2E4E6EBE8E9E8E5E8ECE7E6EAEAEEEEEBEAEDEEEE
EEEDEFEFF1F1EEEFEDECEDEBE9E6E5E2E0E2DDDBD7D6D3D2D3D3D2D3CBCCCAC9CAC6C6C6
C4C2BFBFBCBAB8B8B7B3B4AFADAEAAABA9A6A5A5A5A3A29E9E9F9BA09E9E9DA09F9FA1A6
A6A7A7A7A8A8A9A9ACADB0B1B4B3B7B7B4B7BABCBABDBBBAB9BBBBBCBABCBEBEB9BBB8B9
B9BBB9B6B5B6B2B5B6B0B2ABABABA8A6A9A6A2A1A1A0A0A19E9DA09F9D9D9C9C9B9D9B9C
999B97999A9998979697979594939395939292929090918D8C8D8C8B8B89898887878586
84808182817E7E7F7C7C7B787A7A797776777576757274716F6E6F6F6D6D6B6A68676667
656462605F5F5F5C5C5B585757575657555454525252504F4F4D4C4B4B4A494646433F3A
3533312F2F2D2D2C2B2A2929292828282727272727272627272626262626262726262726
2626262626262626
262626262626262626262626262627272626272627272627272727272727272727282829
292829292A2A2A2B2C2D2E2F303133353638393B3E3F4244454649494C4F4F5152535555
57585A5A5C5E6060606364656667696A6D7070717272727476777A7C7C7B7F8282838484
87888B8A8C8E91919395959698989B9AA0A0A1A1A4A3A5AAA9ADACADACB0B1B1B3B6B8B5
BDBBB9BEC1C2C4C7C7C9CACCCDCFCFD1D4D4D6D5D4D7D8D7D6D9D8DADAD9D9DDDFDBDEDE
E3E0DFDFE3E6E4E3E3E5E6E6E6E4E7E8E6E5E4EBEBE9E6E7E9E9EBECEBECEDEAEEE9ECEE
EEEBF1ECF3EEEEF0EEE9EBEAE9E5E4E3E3DEE1DCDDD8D8D4D5D7D7D2D5D1CDCCCBC9C8C7
C8C4C3C0BFBEBAB8B9B8B5B5B4B0B0ABADA9A9A6A8A4A4A2A0A3A3A29EA09F9EA1A0A1A3
A6AAA6A6A8A9A7A7AAAEADB0B0B3B3B5BAB6B8B9BABABBB9BCBCB9B9B9BCBCBABBB7BBBB
BEBBBBB5B5B5B4B2B3B3AFAFACAAA9A7A9A9A5A4A5A19FA2A19FA19E9C9D9B9D9C9B9C9C
9E9B999A9797969997969698969592949292939291918F8E8E8C8C8D898B898886888785
84848282837F7F7F7D7B7B7A7A7979797876767473747271737070706E6D6B6B6A686664
6564636161605D5E5D5C5B5959575656555554535352514F4E4E4E4C4A4948474743403A
373332302F2E2D2C2B2B2929282828282727272727272626272727272626262627262626
2626262626262626
262626262626262626262727262626262726262726272727272727282727272827282928
282829292A2A2B2B2C2D2F303032333437393A3C3E4042454647494B4D4F515253535657
595A5A5B5E6060616263646367686A6A6D6E7072717374747577797A7A7B7E8081838286
84898A898B8E8F949493959798969B9D9E9FA0A1A4A6A4A6ABA9ABAEB0B1AFB4B5B5B6B9
BCBBBABDBEBEC4C2C4C7C9C8CFCFCFCFD4D1D2D2D1D4D9D5DAD9D8D7D7DADCDADAD9DADE
E0E3E2E1E1DFE4E5E6E4E2E5E6E7E6E4E8E6E8E7E7E8EAE8ECEBEAE9EAE9E9EDEBECECED
EDEDF0EFEDF0EFEAEDEDEDEBECECE9E5E3E2E0E0DBDAD8D6D8D6D8D7D7D3D2CFCFCDCCC9
C5C7C5C4BDC0BFBCBBB9BAB7B3B3B0B1ACACAAAAAAA6A6A3A2A3A6A2A4A0A29FA19FA2A5
A4A2A6A4A6A8AAA9A9A7A9ADB0B2B2B6B5B7B8B7BAB8B9BBBBB8BCB8BAB8B9B9B7BBBBBA
BDBCBAB8B5B6B7B6B5B5B1B2AEABABAAACA7A9A5A3A3A5A2A19F9F9B9D9D9C9D9C9C9B9A
9A9B9B9999989898969697939393929292929191908F918E8D8D8D8B8B8B8B8887878686
838383838181807E7E7C7A7B7B79797779757775757472717170706E716E6B6B69676765
6565656261605E5C5C5C5B5A5A5957565353525352525151514E4D4B4A4948474743413B
37343330302F2D2C2B2B2A29282828282827272827272727272727272626262626262626
2626262626262626
252626262626262626262626262626272626262727262627272727272727272827282828
282929292B2A2A2B2D2E2F2F3031343638393B3C3E424244464A4B4C4F50525254565858
5B5B5C5D5E606161626364656769696A6B6D6E717474757575767A7C7A7C7E8182848486
8787888A8F8F8F9391929497999A9C9B9C9E9F9FA1A1A4A3A6AAAAABACAEB2B1B5B4B6B5
B6B8BBBCC0BCC1C1C2C7C8C9CCCDCFD0CED2D4D3D5D4D6D9DBDCDAD7DADBD8D9DCDDDDDE
DFDEDFE1E0E4E4E6E0E6E6E5E8E5E5E6E8E7E6E8E9E7E8E7EBE9E8E8E9E9EBE9EAEAEAEA
EBEFF0F0F1EEEFEEEFEFEEEBEBEBECE7E5DFE3DFDFDCDADCD8D9D8D9DAD8D5D4D3D1CFCD
CDC7C5C8C5BFC1C1BFBBBBB8B8B5B5B2AEAEACAAAAA6A6A7A5A7A4A6A3A4A1A0A2A09FA5
A6A5A7A5A4A7A6A8A8A8ACABAEB0B0B3B3B6B7B7B9B7B9B9BBB7BBBBBBB7BBB9B8B8B9BB
BBB9B9B7B7B7B6B2B8B7B5B2B1AEADAAAAA8A9A8A6A5A4A3A29FA09E9F9F9F9C9D9B9C9B
9D9B9A98999998969997959495949294959290928F908F8E8F8E8D8D8B8A8A8989868784
848281828282807F7E7D7D7C7B7A787778767776747373747271706F6E6D6D6C6A696766
666564636361605D5D5D5C5A5A5758565654545352535251504F4C4B4A4948474745423C
373432302F2F2D2C2C2B2A29282828282728272727272727262726262726262726262626
2627262626262626
262626262626262626272626262627272627272627272727272727272727272828272829
2829292A2A2A2A2B2C2E2F2F3032333638393B3D3F41434548494C4D4F52525356585A59
5B5D5D5E5E6063636566686869696A6A6D706F7173717479777A79797B7E7D8282828387
8487888A8C8B9091929595949899989CA19E9D9FA3A2A1A3A3A7A9A9ABABB0B1B5B5B4B4
B7B8B9BCBDBFBEC0C2C6C5C8C8CACCCECECED0D3D1D2D7D7D9D6D7D9DAD8DADDDAD9D5D7
DCDFDFE1DFE4E0E4E5E1E7E6E8E4E4E8E7E6E8E8E6EBE6ECE8EAE9E7EBEAEAEAEAECEAEB
EBEDEDEFEFEEEFEFEEEBECECEBE9EBE8E6E7E4E2DEDEDADADBDBDCDCDBDAD7D9D7D3D2D0
D0CCCCC6C8C6C7C6C1BDBDBAB9B4B6B7B4AEAEADACA9A5A7A8A9A8A7A5A4A4A3A2A1A3A1
A5A1A5A3A4A5A5A5A6A7ABABACAEADADB0B4B4B6B8B9B8B7B8B8B9BABAB8BBB7B8B8BBB8
BCB8B9B6BAB6B8B9B7B6B3B2B1AEADACACAAA8A8AAA5A4A4A4A1A09E9F9E9E9F9E9B9A9B
9B9A999C999A9799939796969493919492919291919090908D8D8E8C8D8D898B89888886
85818282838181807F7D7E7D797B797C787876737672727171716E6F6F6E6C6969696869
686866656461605F5E5E5C5C5958575555545252535250514F4F4C4B494947484644413D
383533312F2E2E2C2B2A2A29282928282727272727272727262627272626262726262626
2626262626262626
262626262626262626272626272727262727262627272727272727272727282728282828
28292A2A2A2B2B2B2D2E2E2F31313436383A3C3E3F41444647494B4E505054565759595D
5D5D5E5F61636464666669676A6B6C6D6E6E707073757675797A7A7C7D7C7D7E81828387
878586878B8B8F919193929597989A9A9B999EA29FA2A2A6A6A6A9AAA9AAAFAFB1B2B2B4
B7B5BABCBCBDBEC0C0C1C6C9C6C6CBCCCBCED1D4D1D0D4D6D5D8D6DBDAD8DBDBDAD8D6D6
DEDCDDDEE1E3E7E3E8E6E5E7E5E6E8E2E6E5EBE7EAEAEAEBEAE5EAECEEE9EDE8E9EAECEB
EBEFEBEEEDEBEFEDF1EDEFE9EDEDEDEAE8E9E5E5DBDFDEDCE1DEDDDCDFDBDCDBD8D8D4D5
CFCFD0CECBC6C7C5C3C1BFBDBDB9B6B7B6B0B3AEACABA8A9A9A8A9A9A6A4A4A3A2A3A2A2
A3A4A3A0A2A3A7A5A6A7A9A8A8ABADABADB0B2B2B9B8B7BAB7B8B9B9B9B8B8B9B7BBBABB
BCBAB8B9B9BAB8B7B7B7B5B6B4AFB3B0ABAAAAA9A9A6A6A5A2A2A1A19EA09F9D9C9D9C99
9C99989A9A97999598979793939494939190929191908F8D908E8D8E8C8C8B8B8B888685
88868584818282807D7E7C7B7B7C797979777975747472727271706F6D6E6C6A6C6C6B69
676665646463615F5E5E5D5C595A58585656545354515252514F4E4B494A47474643413E
39363331312E2E2D2C2B2A29292928282727272727272727272626262726262626262626
2626262626262626
262626262626262626272626262626272727272726262727262727272728282827282829
2929292A2A2B2B2C2D2E2F3031333536383A3B3D40434446484B4D4F51535456595C5C5D
5D5E6060626264656767686A6B6B6C6D6F6F7273737577797A7B7D7D7D7D817F80828384
85858688878A8E8F91919494969599989C9C9E9EA2A2A1A4A1A6A9A7ABAAADAFAFB0B3B6
B5B9B5B8BBBCBCBEC4C1C3C5C9C7CACBCDCDCCD1D4D3D1D1D2D5D7D7D9D6DBDADADADBDD
DEDCDBE0E0E5DEE1E2E3EEE7E8E9E6E5E5E8E5E7E7E6EAEAEDEBEAE9EBE9EEEBE9E8ECED
ECEBEEEDEDEDEFEDEAEEEAEFEDEBEEE6EBE6E5E4E2E2DFDEDADDDFE0DEE3E0DEDBDBDBD9
D4D3D3CFCECFCBC9C6C4C2C2BEC0BCBAB8B8B2B2ADACACABA7A9A7A9A6A8A3A4A5A4A2A3
A0A1A1A2A4A4A5A5A3A6A7A9A7A9A9A9AAABACB0B4B5B4B5B4B5B7B8B8B7B8B9B7B9BABB
B9BBB9B9B9BBB9B8B9B7B5B6B3B3B5B1AFAEAAA8AAA9A5A4A5A2A2A29F9F9E9D9C9B9D9B
9A99999499989599999895959495929291939291918F8F908F8F8D8E8E8C89898A8A8687
8783848483838180807F7D7E7D7D7D787A777675747373717271706E6E6D6D6C6B6C6B6A
6969676563646361615F5E5B5A595857575454525352535152514E4D4C4B47454442423F
3A3734322F2F2E2D2B2B2A2A292828282828272727272726272627262626262626262626
2626262626262626
262626262626262626262626262626272627272727272727272727272827272828272829
28292A2A2A2B2B2C2D2E2F2F31333537393B3D3E3F424546494B4D4E52535757585A5C5E
5F6161636464666768696B6C6B6F6E6F6E707173737677797B7A7B7C7C7F7E8081838287
878587888A8C8C8D8D9093949596999C9B9B9E9C9E9EA3A3A3A6A6A8A8AAABB0B1B0B5B2
B4B5BBB9BEBDBDBDC1BCC1C1C4C5CAC7CBC8CBCBCED0D1D2D2D3D3D4D7D8DBD8D9D9DBDA
DDDCE0DFE0E2E0E3E5E5E4E6E5E5E6E6E5E7E5EBE7E5EAE7E9EBE7EDEFEBECE6ECEBE6EA
EDEAECEBEDEEEFEEEEECEFECEBEAEAECE9E8E4E6E6E2DFDFDFDFDFE2E2E2E8DFDDE0DBD9
D8D6D4D3D0CDD0CCCAC8C5C1C1C1BEBEB9B8B6B2B4B0B0AEABAAA9AAA8A7A6A6A6A6A5A4
A2A1A3A1A4A3A2A2A4A5A8A6A9A7A6A9A7A7ABACB2B0B3B3B1B2B8B6B8B8B8B5BBB7BAB8
BDBBBAB9BAB8BAB8BABAB9B5B5B4B4B2B2B1AFADACAAA8A7A6A5A2A2A3A09F9D9D9C9E9D
9B9B9999989C97989796949593929292919291908F8F8F918F918E8C8B8C8B8C89888985
878785868182837F7E807F807E7A7D7C7978777475757372736F706E6E6D6C6C6D6D6A6A
686667666663626261605E5D5B5A5958575555535251525150524F504E4C47454442413E
3C363432302F2D2D2C2B2A29292828282827272727272726272727272626262626262626
2626262626262626
262626262626262626262626272626272626272727262727272727272727272828282829
2829292A2B2B2B2C2C2E2F3031333638393B3C3E41444446494D4D51535556565A5B5D5F
61636466666765686A6A6D6C6D6E6F6F71727374747678797A7B7B7C7D80807F81838384
858687898A898C8C8C8F909395969A9A9B9B9BA19FA0A3A2A3A3A7A5A9A9ACADACADB1B0
B4B6B7B7BABABABEBBBBBEC3C2C4C7C6CAC9CCCCCFCECFD0D0D3D3D6D5D6D7DBDAD9DBDC
DCDDDDE0DDE2E0E6E6E1E5E2E7E6E8E9EAE8E8E9EBEBE7E9EAEAEBE9ECEEEBEEEBE9E9E9
ECEAEAEDE8EAEAEDECECEDEBEDEBEDEBEDEDE9E9E6E8E7E5E4E1E2E3E2E5E4E5E1DFDCDD
D8D6D3D5D1D0D0CDCBC8C8C5C4C0C1C2C1BDB8B9B2B7B5ADACAAACABA9A8A6AAA6A7A6A3
A3A2A1A4A4A4A3A3A4A5A6A6AAA9A8A7A8A7A8A9ADADB1AEAEB3B3B5B5B8B6B8B9BAB6B9
BCB8B9BAB8BAB9BBBEBBB8B7B9B6B8B5B4B2B1B0AFACAAAAA7A5A5A6A1A19E9E9F9E9D9D
9C9B9A9A9A9797969A989696969495929492918F8F8F8E8C8E8D8E8E8C8F8E8B89898988
898686868584818181807E7E7E7C7D7A7A777876767573737270706F6D6E6D6B6C6C6C6B
6867666364646363615F5E5D5C595A5957565553515150514E4F4E4F4E4F48444240403F
3C373432302F2E2C2C2B2A2A292928282728272827272727272727262726272626262626
2626262626262626
262626262626262626262626262626272627262726262727272727272727272828282828
292929292A2B2C2D2C2E2F3132343538383B3C3F41434647494B4F51515355595B5D5D5F
616465656968696A6B6A6A6E6F71716F707276767678787A7A7C7B7C7F81818285828385
85838788898C8D8E8C8E91939494989A9E9D9D9C9F9FA2A1A4A6A4A7A7AAAAABAFB0B1B4
B1B4B4BAB7BDBCBDBCC0BEC0C1C4C6C5CBC9C5CCCECCCCD1CED2D5D2D5D4D7D7D8DADBDA
D8D8E1E1DFE0E1E1E3E3E6E3E4E7E7E6E8E7EAE7EBEBEAECEEEAE9EEE8E8EAEDEAEDEDEB
EBECEAECE8EBEDEBEAECEFECEEEEEEECEBE9E6E7E9E4E5E7E6E3E5E3E3E4E6E2E3E2E1E2
DEDDD9D5D7D4CFCFCEC8CBC5C8C7C4C1BEC0BBB9B8B8B5B4B3B0B0ACABAAA8A9A6AAA8A4
A4A4A5A6A1A4A2A3A5A5A5A9A8A5A6A9A7AAA9A8ACADACACADAFAFB1B7B4B6B7B8B7B6BA
B9B8BABABABBB9B9BAB8BAB9B8B9B6B7B5B1B5B0B0AEADADACAAA7A7A4A3A1A09F9E9F9B
9D9D9B9A9899989B9797969795959592919295919090908E8F8E8E8C8C8D8A8A8C888A89
87878585868483827F7F7F7E7D7C7D7D78777877767675737171706E6F6D6A6A6D6B6D6A
6968676564646362615F605E5D5B5B5957575453535051504F4F4E4E4F4C4A4441414040
3C383532302E2E2E2C2C2B2A292828282827272727272727262626272726262626262626
2626262626262626
262726262626262626262626262727272627272627272627262727272727282828282828
2929292A2A2B2B2C2D2E3030323436373A3B3D40414346484A4D4F4F535657595A5C5F5F
6163676767686A6C6B6D6E6E717373717374747577787B7B7B7C7C7B7C81818483848586
88868A8A8D8B8B8D8E92919395979A99999A9C9B9D9EA1A1A2A3A4A6A7A6A7A9ABACAFB1
B4B7B6B5B9B7BABABCBDBBBEC3C4C2C3C6C8CACBCACDCECDCFCFD0D1D0D2D7D4D7D6D8DB
DADEDEDCE0DDE2DCDFE2E2E5E6E6E6E5E8E9E9E7E8E6EAECE7E9E9E9ECEAEBF0EFECEAEA
EAECEBECE9EDECE9F1EDEDEFE9EFEDEFF1ECEBEBE6E6E7E7E8E8E7E4E7E7E8E6E8E1E6E0
DFDBDBD7D7D3D6D3CECFCEC9C8C9C7C4C6C1BEBEBBB8B8B8B2B3B0ADACABA9AAAAA9A9A8
A4A7A4A4A4A2A3A3A1A2A2A2A4A7A4A3A6A5A8A9A8AAAAAAACADB0B0B0B1B3B6B6B7B9B8
B8B6B9BABCB8BAB9B8B8B6B7B6B9B8BAB6B6B5B2B4B2ACACACACA6A6A6A2A3A0A19FA0A1
9E9D9F9C9A999A98979795979797959595929291918E8E8D8E8E8E8C898B8A898B8A8A87
87888686858385828380807C7D7C7E7B7C797878767575757272726F6E6C6C6C6D696D6A
696867656563656463605E5D5C5B5A59565554545452504F4F4F4D4D4A48474242413F3E
3E38353331302E2E2C2B2B2A292929282827272727272727272727272626262627262626
2626262626262626
262726262626262626262626262726272626272726272727272727272728272827282829
28292A2A2A2B2C2C2D2E2F30323336373B3B3D3F42434647494C4E50535456595B5E5F61
64656767686A6B6D6D6C706F707474737477767779797B797B7C7C7F7E81828584868688
8788888A8D8E8F8E918F939293939498999A9C9EA19EA0A0A2A2A6A5A8ABA7AAABABAEB0
B0B6B2B6BBB6BCBBBCBDBEBFC1C1C3C6C6C8C8CBC9C9CCCACDCFCECED0D1D1D1D5D3D6D9
DADBDEDFDEE0DFDDE3E4E5E8E4E6E7E7E7E7E9E2E6EBEAE6EDECEAECEAEBEBE8EAECEDE9
EBECEAEAE7EBEEE8EBECEDEEEFEDEDECEDE9EDEAECE9EAE9E8E7E8E8E8E7E8E9E7E4E4E6
E2DBDDD8D8D5D8D4D3D0CFCEC8C9C8C6C2C4C1BEBCBBBAB8B7B4B2B1AFB0ADACA9AAA9A8
A7A9A7A5A5A3A1A3A1A1A3A3A3A3A3A3A8A7A7A8A7A5A8ABABACABAFACB0B2B3B4B3B7B5
B4B6B6B6B6B7B8B9B8B6BAB6B8B9B7B8B8B6B5B7B4B1AFADABABABA9A8A6A5A3A1A09EA0
9F9E9D9E9D999899989899959494939494919293918E918F8E8D8C8C8B8B8A8A89888B89
898885878684818282817F7F7F7D7E7D7E7C79787975757572716F706F6D6C6A6B6D6C6A
68676765636464656361605C5D5B595A58565553525150504E4D4D4B4948474343423F3E
3E3B373331302F2E2D2C2B2A2A2929282828272728272627272726262626262626262626
2726262626262626
252626262626272726262626262626262726262627272727272727272727272828282829
2928292A2A2B2B2C2D2E3031323435373A3B3D40414445474A4D4F505355575A5B5E6162
62636768696C6E6F6F71707174757475787877797A7B7A7D7B7D7E7D7F80808481868787
898A898B8E8D8F8F8E93919193949597989B9A9D9F9E9FA0A2A2A5A4A5A8A7AAABACAEB0
B3B1B2B3B7B6BABBBEBDBFBFC1C2C3C5C7C8C8C8CCC7CBCDCACBCDCDD1D0D1D0D2D3D6D6
DCDADCDCDEDFDEE0E0E2E4E4E5E4E3E5E5E8E6E3EBE6EDEEE8ECEAF0EAEDEDEFEDECEDEC
EBEAEDE9EDE9EDEDEAEEEAEDECECEFEEECEBEBEAEAEAE4EAE8E8E9E6EAECE9E8E7E7E5E3
E3E0DFDDDBD7D7D3D7D2D3CFCDCBCBC7C6C4C2BFBFBCBBB7B7B5B3B0B4B0AFAEADADABAA
A9AAABA5A7A5A4A4A4A29EA2A4A0A4A1A3A2A3A3A7A6A7AAA9AAA9ABB0ADB0B3B3B2B4B4
B6B7B4B8B7B8B7B6B9B6B8B5B6B6B8B5B6B8B7B5B5B3B1B0AEABADA9ABA7A5A4A4A2A2A1
A19D9B9A9C9B9B9A9999979796959494939291918E8F91908C8D8D898B8B8B898A88888A
878485848483848382818280817F807D7D7C7C7A7976777473737170706E6D6D6B6C6B6B
69686666666466646262615D5D5B5A59575555545451504F4D4D4C4B4A4947454342403F
3E3A373331302E2D2C2C2B2A292929282827272727272727262627272626262726262626
2626262626262626
252626262626262626262626272627272626262727272727272727272727282828282828
2929292A2A2B2C2D2E2F2F30323435383A3B3D3F41434548494D4E515457585A5B5E5E62
6466676B6B6E6E72707170717276777578787D7B7C7B7D7D7D7E807F7E80818282868687
8A888B8B8B8F8F8D8E9092939295979498989A9C9D9FA2A1A3A1A4A4A4A6A7AAABACADAC
B1B2B2B3B6B8B6B9B9BEBDBFBBBEC2C2C4C4C4C5C7C9C9CACACCCBCCD2CFD0D1D1D7D3D8
D9D9DCDCDDE1E1E2DFE2E3E0E6E2E5E9E8E8E7E7EAE9EDE8E9E9EAECEDEAEFEBF0E9EDED
ECECE8EDE8EBEAEBECECEBEAECE8EFECEAECECEDEBE8E9E9E8E7ECE8EAEDEAECEFEAE5E4
E2E1DFE0DFDBD7D6D4D6D2D0CECECECAC7C7C4C4BEBEBCBBB9B8B5B4B4B4B3B0AFB0AEAB
AEABABA6A9A6A4A3A5A3A3A4A4A29FA2A3A6A5A8A5A5A7A9A7ABABA9ABADAEAEAFB1B3B7
B5B4B6B5B5BAB8B8B8B6B8B5B7B6B7B9B8B6B6B6B4B3B1B0B0AEADABA8A5A9A6A6A2A2A0
A09D9B9C9C9C9B9A9B979A9698969694959393909091908E8E8D8F8C8C8A8B8889898888
888686878485868282828280807E7F807E7D7D7B7A79777873747173716F6D6B6C6B6A69
696967676565646162605F5E5D5C5C59575654535352514F4D4D4B4B4A4747444442413E
3D3B383431302F2E2D2C2B2A292928282827272727272727262627272726262626262626
2626262626262626
262626262626262626262626262626272727262627272727272727272727272828282928
29292A2A2A2B2B2C2D2F3030323436373A3B3E40424446484A4C4F52535557595B5F6162
636667696C6D706F7171727576777879787A7B7B7D7D7C7E7F807F808080828381838687
8B888A8B8C8F8E8E90908F9392939595969697999C9EA19FA2A2A4A6A6A8A9A8ABABADAC
AEB0B1B1B4B6B6B7B9BBBBBCBDBFBFC3C4C5C2C6C4C7C8C8CACBCCD0CED0CFD1D2D3D5D3
D7D8D9DBDBDDDFE0E1E1E3E4E0E2E1E5E3E4E6E8E8E8E7E9E9EAEEEEEAECECEFEFEFECF0
EFE9EAE9ECECECECE7EBECEBEEEDECE9EDEDECE9EBEBEBEBE8E8EBECEBEAECEAECE9E7E6
E4E0E1DEDDDBDADAD8D4D7D2D0CFCDCBCBC5C4C4BEBEBEBCB9B9BAB9B4B5B2B2AFAEAFAE
ABACADABA9A7A7A9A3A4A4A6A4A1A4A3A4A1A4A4A6A4A5A6A7A7A7A8ABABACADB0B0B1B4
B5B4B6B3B4B3B4B9B6B3B6B8B6B8B6B8B9B7B7B3B2B5B4B1B2B0AFADAAAAAAA8A4A3A6A0
A09D9F9D9B9B9B9B9B9A9B999594959495949092919293908E8B8B8B8B898B88878B8A8A
87878885888487848381828381807F7F7E7D7B7B787A787674737171716E6F6D6C6A6B6B
6869686665646364635F605E5D5C5A59575655545352514E4C4D4B4A4A4746434342403F
3E3B383431302F2D2C2C2B2B2A2929282828282727272727262727272627272626262726
2626262626262627
262627272627262627262626262726272627272727272727272727272727272728282828
28292A2A2B2B2C2C2D2D2F3032343539393B3E3F424446484A4D4E50545559595D5F6063
6466686A6B6D6F707372757677767A7C7D7A7F7D7D7E807E828183818282848383858688
8B8A8B8C8B908E8E8F8E8F92929491959A989A9C9C9C9FA1A3A2A3A4A7A9A9A9A9ACABAE
AFADB0B2B1B5B5B5B6B8B9BCBDBBBCC1C1C1C1C5C6C6C7C8C9C7CCCDCCD0D1D5D4D1D3D6
D8D9DAD9DBDCDDDCE4E1DFE1E2E1E5E4E5E3E4E8E6E6EAE6E9E9E9EDEDECECF0EDEBEEF1
EEEDEAECEFECEAEAE9EBE9EBE9EBECECECEAECECECE9EBEBEBECEBE9ECEAEEE9ECEAE9E3
E5E4E3DEE0DCDCDBDAD8D4D3D3D2CECEC9C7C6C6C4BFBDBFBBBDBCBABBB7B5B4B3B2B1AE
AEAFACA9A9A5A8A4A8A5A6A2A1A2A1A2A3A3A5A3A2A2A4A7A4A7A3A7A9A9ABABABAEAFB3
B2B2B2B5B6B5B6B6B8B7B6B4B7B7B6B6B8B6BAB7B6B4B6B3B0B1AFACAAACAAAAA8A6A3A2
A2A19F9F9D9E9C9B9A99999998989897959391939191908F8F8D908E8D8B8B8A89888889
86888884858586858381818280807F7E7D7D7C7B797A78757675747271716F6C6C6C6A6A
6A6967676665666361605F5D5D5B5A5A575655545552514F4F4B4B4A494646444341403F
3E3B393632312F2E2D2C2B2A2A2929282828272727272727272627272626272726262626
2626262626262626
262626262626262726262726262727262626272627262727272727272727272828282929
29292A2A2B2B2B2D2D2E303032343738393B3E3F414246474B4C4F525455585A5B5F6062
6366686A6B6C717074737474777B7B7D7B7E7E7D7E7F8080838383808281838486868888
8A8B89898A8D8B8B8F8F93939491959898979A9A9DA09FA1A0A2A3A5A4A4A8A8AAABABB0
ADB1B0B3B3B2B2B4B8B7B9BBBDBDC0C2BEC1C1C2C5C4C5C6C6CACDCBC7CECFD2CFD4D0D4
D6D7D7DCDADBDCDCE2E0E2E6E2E6E3E7E3E4E7E2E7E8E8E8EAEAEAE9ECE9EDEDEEEDF0EF
EFEDEDEBECEBEFEAEAE9EBEDEAEBEAEDEBEAEDEAECEBEBE9EEEBE9EAEEE8E8EBEAE8EBE4
E7E5E5E4DFDEE0DBD9D9D9D9D7D3D1CFCFCBC8C8C7C5C4C0BEBEBDBBBABAB7B5B4B5AFB4
B1B1AEAFAAA8ACAAA8A9A8A7A5A4A3A2A4A2A3A3A4A2A5A4A4A6A6A4A6AAA8A8AAACB0AF
B0AFB2B3B5B2B4B2B6B7B6B3B6B7B7B8B4B7B5B5B4B4B4B5B3B4B0AFAFACACACA8AAA4A5
A5A2A29F9E9C9C9B9B9C98999A979693949393939190928F918E8F8E8B8C8A89888A8A87
88888685848686848384828381807F7D7B7B7B7B7B7A7977787575727170716E6D696969
676769666765656260605F5D5D5A5C5856575454535251504F4E4C4A494847464341403E
3D3B3A3633312F2E2D2C2C2A2A2929282827272728272827262626262627272626262626
2626262626262626
262727262626262726262626262726262727272627272727272727272727272828282828
29292A2A2B2B2C2D2D2E2F3032343638393B3D3E404344474A4D4E4F5455585A5B5D6063
6465686A6C6F6F7071737877797B7C7D807E7E7F7F80818482838384848385858A898889
8C8C8B8B8A8B8D8D8F92919193949696979799989A9C9F9EA0A2A4A7A6A9A7A8A8A9ACAC
AEAEAFB1B3B1B2B1B4B4B4B8BABDBCC0C0C1C0C4C5C1C7C4C7CCC8C9CCCACCCECED2D1D4
D6D5D7D8DADDDCDCE0DFDFDFE2E4E3E6E6E4E7E5E9E4EAE9E8E6EBE9ECEBECF0ECECEEEC
EEECEDECEEEEEEEAE9ECE9EAE8EBEBECECEBECECEDEBEFE9EAE8ECEAEAEBEBEDEAEEECEC
E9E5E5E1E5E5E1E0DED9DAD6D8D6D6D3CFCFCDCEC8C7C6C2C2C0BFC0BDBBB8B9B7B7B5B2
B3AFB2AFABACAEABA9ABA8A7A7A5A5A1A3A3A09DA0A3A2A4A1A5A6A6A5A9A7A7ABAAABAB
AEAFAFB2B0B2B1B4B6B5B4B4B5B5B7B7BAB9B5B6B6B6B2B2B5B4B4B0B3ADB0ABADABA7A6
A7A5A6A3A19F9C9B9899989A9696969495949393939392918D8E8E8D8B8C8B8989888787
87878585858684838485838181807E7D7C7E7A7B7B7A7978777575737272716F6D6C6A6A
6A6769676763656160605E5D5D5B5B58585655545452504F4E4F4C4A494746454441403F
3F3C3A3633312F2E2D2C2B2B2A2929292828282827272727272727272727272626262626
2626262626262626
262626262626272626262626272627272727272726272727272727272727272828282829
29292A2A2A2B2C2C2E2E303132343638393C3D3F424245484A4B4F525355575A5D5E6262
646768686A6F6F7172757477787A7C807F807F807F828183848684858785878989898A8D
8D8D8C8E8D8F908E8F91939496949796989A979B9C9D9C9EA1A3A2A6A6A7A7A6A8AAADAB
ACADAEB0AEB2B1B2B3B4B9B5B8BCBBBCBFC0BFC2C1C2C1C4C8C6C6C7C4CAC7CCCDD2D4D4
D5D4D4D5D7DBDCDDDCDDDEE2E5E2E3E5E5E5E7E4E7E7E7E7EBE7E9E7E9ECF0EDECEDECEF
E9EEEFEDF1EFF0EBEDECEBEAECEEECECECEDEEEBECEAECECEBEBEDECECECE6EAEDEAEEEC
E9E9E3E7E7E0E1E0DDE0DBDBD9D7D9D2D1D1CCCDCCC8C9C7C1C3C2C2BCBFBBBAB8B9B8B4
B6B1B3AFB0AEADACABAAA9A7A5A6A5A4A4A2A0A0A2A2A2A0A2A2A4A7A6A8A5A8ABA9AAAF
ACAFB0B1B0B3B2B1B7B4B5B6B7B7B7B6B9B9B5B6B5B7B6B4B0B5B0B2B2B0AFAEAEABAAA5
A8A8A4A4A0A2A09E9D999B989A989599959496919292919190908F8D8C8B8C8B8A8B8888
8786878687848585838483838280827E7E7E7B7B7C7B7B7977787573747471716E6B6A69
686768666564636260605E5E5C5B5A595657565552535151514D4D4A4A47454444434240
3E3C3B3833312F2D2D2C2B2B2A2A29292928282827272627262727262726262626262626
2626262626262626
262626262626262626262626262626262726272726262727272727272727272728282828
29292A2A2B2B2C2D2C2E303033343637393C3E3E41434648494C4D50525557595C5D5F62
6367686A6B6E6F727474787678797E7E8180808184848485888986868787888A8A8C8B8D
8C8B8F8D8F9294928F94939494959599989A98979D9C9C9EA0A0A4A5A5A8A6A8ABA8A8AC
ADABADAFB0B0B3B4B3B3B3B5B6B8BCBCBBBFBFBEC1C2C1C6C6C6C5C5C6C4C8C8CACED1D0
D4D3D9D6DBD9DCDCDBDEE1E2E1E4E4E6E5E3E6E4E5E4E5E8E8EAE6E9E8EBE8EBEDEBEEE8
EEEEEEEEEEF0EDEDECE9ECEAEAECEBEBECECEEEEEAECEBECEDEFEAEBEBEAEDEEEBE8E9E9
E8ECEBE7E4E2E3E3DFDEDFDFDEDBD8D6D6D3D1CFD0C9C8C8C6C4C5C2C2C2BFBBBEBDBCB8
B7B6B4B1AFAEB0AFACAEAAA9A9A9AAA6A6A1A4A3A2A1A0A1A2A1A4A5A5A3A4A4A6A3A7A8
AAADAEACB0B0B2B3B3B1B2B4B2B3B3B5B5B5B7B6B5B5B6B6B5B5B3B1B2B3B3B2B0B0ABA9
AAA6A8A6A5A0A19E9F9B9A99999799959796969493929191908F8D8D8D8C8B8B8C898789
898686888586848383828383828181807F7F7D7C7C7B7A7977767575737370706F6D6D6B
6B6964666663626261605E5E5C5A5B5A59585555535151504E4E4C4B4A4846434443413F
3F3D3A373431302F2D2D2C2B2A2A29282829282827272727272627272727272726262626
2626262626262626
252626272626262626262627262726262726272727272627272727272727272828282829
28292A2A2A2B2C2D2D2E303133343638393A3C4041424546484A4D50535557585B5D6061
646567686C6C6E70737479787B7C7C7F7E80838484858687898887868884898D8C8E8B8D
8A8E8C90949492949494949393939696979998999A9B9F9E9F9FA2A4A5A5A6A7A6A8A9AB
ABADADAFB0AEAEB1B1B5B4B5B6B8BBB9BCBCBEC0C1C0C4C1C4C6C3C4C3C6C4CAC8CBCFD0
D2D2D3D3D5D9D8DADCDFE0DFE0E1E5E5E4E4E5E8E1E6E8E6EAE9EAE8ECE8ECEDEEECEDEF
EDECEDECECF0F1ECEFECEDECEEEAECEBEBEBEBECEDECEDECECF0E8EBEEECEDEDEEEAEDEA
EBEBEBE7E9E6E3E3E5DDE3DDE0DDD8D7D3D2D5D2CFCCCBCAC6C8C8C7C6C2BEBEBEBCBDBC
B9B9B5B3B2B1AFAFAEAAAAABAAA7A8A7A6A5A4A1A1A19FA1A0A0A1A2A0A1A5A7A5A4A6A8
A7AEABACADACB0B0B1B0B2AFAEB2B3B3B4B5B1B6B7B3B7B3B6B3B4B3B3B1B5B0B0AEAEAA
A8A9A8A5A5A3A2A09E9D9B999B999A97969796949493929290918F8F8D8B8C8C8A8B8C8A
878784848485838584808483807F828080807C7E7C7A7A797876757674727371716E6E6C
69686766656463615F5F5F5E5C5C5C5A58585754545351504F4C4D4B4A4848454343403F
3E3C3B373431302E2E2D2C2B2B2A29292928282727272727272727272726262626262626
2626262626262626
262626262626262627262626262627262627272627272727272727272727282828282828
29292A292A2B2C2C2D2E3031333435383A3C3D3E40424547474C4C5052545758595C5E61
6467696A6C6C6E71727677767A7C7C7E82808485868886898A8A8888888C8A8D8E8C8B8D
8B8B9091929394939392949395949497999A989A9D9B9C9EA1A09E9FA4A4A5A6A6A7A7AA
ACABAEABABB1B0B1B0B1B6B5B3B6B6BAB9BCBFBDC2BEBFC5C2C4C2C4C5C5C7C7CACACDCE
CDCCD0D3D2D7D6DAD9DDDDDFDFE1DFE1E3E3E5E5E7E6E6E8E7E7E8E7E7E8EAE9ECEEEBED
EAE9EBEEEDECECECF0EFF0ECEDEAEAEDECE9E7EDEEEEEBEFEFECEEEBEAE9ECECECEDECE9
E7E6E7E8E7E4E6E3E0E0E0DFDEDEDADAD9D7D9D4D1D0CECCCCCBC6C5C7C7C3C2C2BFBEBD
BDB8B6B4B4B0B4AFAFAFADABAAA8A9A6A7A3A2A1A0A3A09FA0A2A0A3A1A1A3A3A2A5A6A5
A8A6AAA9ABABADADAEADAFB0AEB3B3B1B3B2B4B8B4B1B4B3B3B2B3B4B4B4B3B3B2B1B0AD
AEABA7A7A7A7A2A1A09D9C9C9B99999A97969793969493929292908F8D8C8B8C8C8A8988
8888888587868584848085828480807F7F807E7D7C7A7A7979787876757370726F6F6E6B
69696869666462625F5F605D5D5B5B5958565654545352514E4E4D4B494745454442403E
3D3D3B393532302E2E2C2B2B2A2A29292928282728272727272726272726272726262626
2626262626262626
262726262626262626272626272726262726262627272727272727272727282728282829
29292A2A2A2B2C2D2E2F2F3233353536383C3C3E3F414646484A4D4F525355585A5B5E63
636666686B6C707175727678787B7E7F8083868586888B8A8C8B888A878A8C8C8F8D8F8E
908E908E9595939494939496989595979B9B9A9A9C9B9A9C9C9BA1A0A4A4A4A6A7A8A7A8
A9ABACABADADAEB0B0B1B2B7B3B6B2B8B9B7BCBEBFBEBFC0C2C5C4C5C8C5CAC7C7C1CBCD
D0CACFCFD1D2D7D6DADADBE0DFDCE0DFE1E4E2E4E7E9E9E6E5E8E8E9E7EAE7E9EBE7ECEF
ECEEEEEBECE9ECEFF3E9F0F0EAEAEEF0EEEEEAEAEEE9EEEEF0ECE9EBE9EBEAEBEEF0EFE9
EAE7E9E9E4E4E7E7E3DEE0DFE1DEDDDBD9D8D5D6D6D4CBCFCDCDCCCBC7C6C5C5C3C2C2C1
C0BABBB9B8B8B5B2B3AEAFAAAAA8AAA7A6A4A6A3A5A2A3A09FA2A2A1A3A1A1A0A2A5A4A2
A2A4A7A8A8ABA8ABAFADAFAEB1B0B2B3B0B4B3B2B6B2B2B5B6B4B4B4B2B3B4B4B4B0AEAD
ADAEACA9A6A5A3A3A4A09E9E9C99999A9797979594939291908E908F8E8F8D8B8B8A8988
888B878585838586818382818183817E817E7F7D7C7A7A77797878757473756F706F6E6D
6A6A6A686665636262615E5E5D5C5A5B5858585554535150514D4D4B4949484544434040
3E3C3A383532302E2E2D2C2B2A2A29292828282827272727272726262627272726262627
2626272626262626
262626262626262626262626262626262726272626272627272727272728282828282928
2929292A2A2B2C2C2E2E303233343538393B3C3F4143454648484B4E51545455595B5D5F
626465676B6C6F717374767A7A7D7D7D808285858689878A8C8B8B8A8A8E8C8F9190908F
908D9293949492959495969496979595999B9E9B9A9B9A9D9D9D9EA3A2A3A4A5A7A5A7A8
ABACACABADAEAEB1B0B4B4B3B3B6B2B2B6BABABCBEBDC0C0C1C4C5C6C9C8C9C3C8BBCBCB
CDCFD1D0D3D2D2D3D8D7DBDDDEDFE0E3E0E3E0E5E5E3E4E8E6E3E8E6E7EAEAE8E8EBECEB
EFECECE8EAECEFEFEEEDECECEBEEEDF0ECECEDEFEDEFEDEEEDECEDE6ECE8ECEEECEEEAE9
EDE8E7E4EAE8E8E3E7E2E0E3E3DEE2DFDEDCDBD8D7D7D3D0D2CDCECCCDCACAC6C3C3C4C1
C1BFBCBAB8B8B5B3B1AFADAFACAAA8ABAAA6A5A5A5A3A39EA2A09EA09FA0A1A2A1A0A3A1
A4A4A3A7A5A6AAAAABABAFB0B0ADB0AFB0B1B3B3B2B2B3B4B3B2B3B3B3B2B2B1B3B4AFAF
ADADAAABA7A7A8A4A3A6A2A0A19B9C9A979898939595929293919290908E8D898C8A898B
8B8A868685868583828283818183817F817F7F7D7E7B7A7A7B78797775737372726E6E6D
6D6B6A6766656463605F605F5C5D5B5A58585756545252514F4E4D4B4B4947474443423F
3E3C3C393633302F2E2D2C2B2B2A29292828282827272727272727272626272626262626
2626262626262627
262626262626262626262626262626262727272726272727272727272727272827282928
29292B2A2A2C2B2D2E2E2F3133343537393A3E3E4043424648494C4E50515356575B5C60
626465686B6B6F727277787879797E7C7F818384858785898C8C8C8C8D8F91908F92908F
8F8E909294939593959593979896979798989C9B9C9C9C9E9FA0A1A0A2A2A3A2A5A5A6A9
ABACAAADB0ABACAFB0B1B3B2B5B2B2B5B7B8BCBBBCC0BDC0C1C2C5C7C7C4C5C6C7C4CACA
CDCACBCCD1D0D3D5D3D5DBDADBDCDDDDE2E0E0E4E3E5E3E7E7E5E8E7E6E8EBE7E7E9ECEA
E9F0EFEEF0ECEAEDF1EDF0EEEDEBECEEEDEEECEFEEECE9ECEBEAECEAEAEDEAEDEFEEECEC
EAE9E9E6E5E8E6E7E4E6E2E2E0E3E5E0DFDED9DBDAD6D5D1D0CFCFCDCCCCC9C9C7C6C7C3
C4C1BFBDBEB8B6B5B4B1B0ACAFACAAAAA9AAABA7A9A4A2A2A39FA1A2A0A2A09FA1A0A1A3
A3A4A4A3A4A5A6A6A8A7ABB0ADAFAFAFACB1B0B3B3B2B5B2B4B4B3B3B2B2B3B0B3AEB3B0
AFAEAEAAA9A7A8A5A5A3A39F9E9E9B9C9B99999796949593908F938F8E8C8D8B8D8A8C87
8B88888784848584818382828182807F7E817D7E7D7B7B787A78777576747472716F716E
6E6C6A6B676665636360605E5D5C5B5A59575754555352504F4E4C4C4A4848464443413F
3E3C3B393633312E2D2D2B2B2A2A29292828282827272727272727272727262727262626
2626262626262626
262626262626262626262626272626272726272727272727272727272727272828282828
2929292A2B2B2C2D2D2E2F3133343538393B3D3E3F414244474A4C4E4F50525657595B5D
606365686A6C6E7073757776797B7C818181828485878A888B8C8E8F8F90919293949193
939292949595949594969796959999989A999B9E9C9CA09F9E9D9E9EA0A1A2A2A4A5A6A6
A9A8ABAEADACADAFAEB1B1B3B1B4B5B6B7B6BABBBBB7C0BFC2C0C4C3C4C5C6C4C5C5C5C8
C9C9CBCFD1CCD0D0D5D5D7D7DDDBDADCDFE3E1DFE5E2E4E4E6E6E7EAE6E7E9E7EAECEBEA
EAEBEAEBEDEEECEDEDEFECEFEBEAEFEFEFEDEAECEBE9EAEBEFECECEBEEEEEFEAECEBEAEA
EAEAEAEAE9E9E7E6E4E6E4E3E7E4E2E2E2E1E0DBDBD8D6D5D9D4CFCCCDCACCCCCBCCCCCA
C8C5C1C1C0BDBCBAB6B4B4AEADAFAEACAAABA9A6A7A4A4A3A2A2A2A09FA1A09FA09FA0A2
A1A1A2A1A4A1A4A3A5A6A7AAAAAAAEADADB0B0B0B0B2B0B3B2B2B3B3B1B0AEADB0B1B0B0
B3B1B0ACADACA9A6A3A2A3A2A0A09D9F9B999699959493949191918F918F8F8D8C8C8B89
8B8889898884868486858281817F80807F7C7D7D7D7B7A797B7A7877777675747372706E
6D6C6B69696767656362605E5D5D5A595857575555545152504F4E4B4A4A474645424040
3E3C3A393734312F2E2D2C2B2A2A29292928272727272727272626272726262626262626
2626272626262626
262626262626262626262726272627272727272726272727272727272727272827282828
29292A2A2B2C2C2D2D2F2F3133343638393A3C3E4043434546494B4E4E515354555A5B5D
61616466686B6D6F717476797A7A7D7E8182848487878A8A8D8F8F949093929294959394
9294939898979897979896989A97979A9B98999C9C9E9A9E9F9EA19EA09EA0A2A5A4A4A5
A7A7AAABABAFADB0B0B0B3B1B4B5B5B6B5B6BBB8BABCBBBDBDBCBFC0BEC3C5C1C5C4C6C7
C7C9C8CBCDCCCFD2D3D6D4D3D9DCDCDCDCDEE5DDDFE0E1E5E4E3E7E6EAE6E7E9E8EAE9ED
EEEBECE9EDEBECEEECEDEEEFEEF0EEECF0EBEAEAEBEEEAE9E9EEECEBEDEEEDEDEEEDE9EB
EBECECECECE9EBE9E8E5E4E7E4E7E0E3E1E2E1E1DCDBDBD8D3D7D2CFD0CFD1CECBCDD0CE
CBCACBC5C3BFBDBDBCB7B4B2AFB1AEAEABA9ABA8A8A8A6A5A6A5A2A19FA0A1A19EA09EA0
A19F9F9FA1A2A2A4A5A6A5A6ABABADADABADADACAEAFB4B1B3AFB1B1B1B2B2B0AEAFB0AF
AEAFB1AFADAAA7A9A7A4A2A2A2A2A09E9D9B9A9797949591938F92918F8E8F8E8C8D8E8A
898D8787878684848785838281807F7E80807C7B7A7A7B797A7A7979777674747471706E
6C6B686968686766646361605F5D5B5A5A595854555352504F4D4C4C4B4948464542413F
3E3D3A39373332302E2D2C2B2B2A29292828282727272727272726272626272626262626
2626262626272626
252626262626262626262626262626262627262727272627262627272728282828282928
2929292A2A2B2C2D2D2F303133353537393B3C3F4042444647494B4D5051525358575A5C
5E606166676A6B7072747675787A7D7F7F8384868886898A8C8E91919192919395959695
989797999A989997979798999A9B9D999C9B9A9A9E9E9D9D9FA09E9EA19FA2A1A3A6A5A5
A7A5ACACADACB0AEAFB2B1B6B4B6B5B4B9B8B8B9BBB9B9BABBBAC0C0C1C3C6C4C5C1C4C6
CAC7CCCACCD0CDCFCECED4D1D6D7DAD8DCDAE1DEE1E1E1E5E6E6E7E4E5E6E5E8E9E6E6E7
E8EAEAEBEEEBEEECEFEFF1F3EEEEF0ECECEEEEECECEDEFEEEDEDEEEDEEEDEEEDEEEAEBEB
EBECEDEDEBEBE9E7E8E6E9E6E9E6E8E6E5E4E2E1E1DBE0D9D4D2D3D1D3D0D0D2D3D2D4D1
D1D0D0C9C6C4C5C0BEBABAB7B3B1B0ADAEACACABA7A6A6A5A7A3A5A2A5A2A39EA29F9FA0
9EA09FA09EA1A2A1A5A2A6A4A5A9ADABADAEACABAFB2AEAEAFB0B0B1B0B3B2AFADB0ACAE
B0B1AEAEACABABABA9A6A4A5A6A3A1A19E9B9B999797959495929193908D8B8D8D8C8A8B
8C888A8789888785838585857F837F7E7F7D7D7B7B7B7A7A78787778767774747472706F
6D6C6C6A69686865656362635E5D5A59595857565452524F504E4D4C4C4A484644444240
3E3C3B39363431302E2D2C2B2B2A29292928272827272727272727272726262626272627
2626262626262626
262726262626262626262626262726272727272727272727272727272727272828282828
29292A2A2B2B2C2D2D2E303133343637393B3D3E3F434444464A4A4C4F4F51545558595C
5D61626367686B6F7172757476797D7F7F848584858889898B8E9091909093959698989A
999A979C9999979A999B9B989A9B9B9B9C9C9B9B9B9C9D9D9EA1A0A1A0A2A2A3A4A3A5A7
A7A9ABABABADADB0AFB1B4B6B5B3B5B5B7B4B6B7B6B9B9BAB9BBBBBCBDC2C2C2C4C1C0C5
C5C6C7C9CECDCECBCECFCED2D5D3D5D9D9D9DBDEE1E3DDE2E4E5E8E8E8E7E8E7EAE6EAE7
E9E8F0ECEBE9F0E9F0F0EEF2EFF1F2EFEFEDF1EFEDEDECF0ECEEEAEEEDEBEFEEECECEDEB
EBF0EEEBEAEAE8EAE8ECEAE4E9E7E3E5E4E5E3DFE0DDDEDBD8D7D3D3D5D3D6D2D4DAD8D7
D5D4D2D1CCCAC4C4C0C0BCB8B6B7B4B0B0AFAFAFA8AAA7AAA7A6A7A5A5A4A2A3A2A09FA1
A09D9EA0A1A0A0A0A1A5A3A1A5A7A8A7AAAAADABACACACACAFADB0AFAEB1ADAFAFAFAFB0
AFB0B1AFB0ADACABAAA9A6A3A2A4A19FA29A9D9998989892949391939090908E8D8D8C8A
8B8C888986868687858482828180807F7E7D7E7B7B7A79797A7776767878767573727270
6D6E6C696A6767666663625F5F5D5D5A5A59575653535150504D4C4B4A4947454543423F
3F3C3C39373432302E2D2C2C2B2B2A292828282727272727272727262726262726272626
2626262626262626
262626262626262626262627272626262727272727262726272727272727272827282829
29292A2A2B2B2C2C2D2E303233343537393A3D3E4043434547474A4B4E5051545557585B
5D5F626366696A6D6F72737576787C7D808282858785888B8C8E908F9192939396969898
9B9B9C9B9C9C9B999D9B999B9B9B9D9C9A9C9D9E9F9D9F9EA09FA1A1A1A3A2A2A4A7A5A7
A4A7A6ABAAABAFB1B1B3B3B2B0B2B5B3B3B6B6B8B7B7B8B6B9B7BBBCBDBCC2C2C2C2C5C4
C5C7C9C8C9CBCDC9CDD2D2D1D4D3D7D3D6D7DADBDDDDE0E0E1E1E6E8E5E7E8EBE7E5E8EA
E9EAEAEAEEEEEBEDF0EFEEEEEFECF2F0EDF0EFF0EBEEEDEFEBF0F0ECEBEDEDF1EAEEEFEC
EFEAEFEEEBEBE9E7E9EAEAEBEDEBE6E7E8E9E8E6E8E4E1DDE0D9D8D7D5D4D6D6DAD7DBD9
D7D7D8D5D3D0CBC7C4C2BEBDBBB7B3B1B1B1AEACABA8ABA9A9A7A7A9A5A3A2A3A1A0A0A1
A0A0A19F9DA09F9EA2A0A2A4A5A4A5A8A3A9A9ABAAACACACADB1ADB0AEB0B0ADB1ADACAF
AEAFAFB0AEABAEAEA9AAA6A5A3A3A4A3A09D9C9C999A959794949592918F8E908F8C8D8B
8C8A8A8A8A898886868583838180807B7E7D7E7C79797878797879787775767575727272
6F6D6C6A6B696866656361615F5E5D5D5B59595554545251504F4C4B4B4847464544413F
3E3E3B393734322F2E2D2C2C2B2A29292929282727282727272727272727272626262627
2626262626262626
262626262626262627262626262627262726262727272726272727272727272828282828
29292A2A2B2B2B2D2D2F303133343537393A3C3D4042434545484A4D4E4F535356575A5B
5C5C60616467696A6D70747578787C7E7F818381848787898D8E8F909191929595989798
9A9B9A999D9D9E9D9B999D9C9C9C9C9C9E9C9D9D9E9F9E9FA1A3A0A5A2A4A4A2A5A5A4A5
A6A6AAA6A9ACADAEAFAFAFAFB2B0AFB2B4B2B7B9B7B5B7B8B8B7BABABEBEBEC2C2C4C4C6
C7C3C5C6C9CBCCCECFCCCFCFD1CFD1D3D4D5D6D7D8DEE0E2DEE2E0E3E6E7E5E3E8E8E8E7
EBE9EDECECEBEFECECF0ECEDEEEFEEEEF0EDF1EDEBF1F0EDEEEDEDEBEEEEEFEEECEDEEE9
EEEEEEEEEAEBEBEBECEEEBEBEAEBEDE9EAE8EBE6E5E4E7E1DFDDDBD9D7D9DBD7DCDDDDDF
DDDCDDD9D6D2D1C8C8C4C6C1BFBBB8B7B6B2AFAFAEADABA9AAA7A8A6A6A4A4A3A5A0A2A4
A2A0A1A19FA29E9F9FA1A29FA2A0A3A2A4A3A9A9A7AAAAACAEACAEACB0B0ADADB0AFAFAF
ADAEAFADADABADACAAAAA6A7A7A5A5A6A0A19F9B9C999A9995959491928E8F8F8F8E8B8A
8B8A8A87888787888585828481828180807E7C7C7C7B777A79787778787875767473726F
6F6F6C6B6A6968666465626160605E5D5B5A5956545351504F4D4D4C4A49484745434040
3F3C3B39373532302E2E2C2C2B2A2A292828282827272727272727272626262626262626
2726262626262627
262726262626262726262626262726262726262727272727272727272727272828282829
2929292A2A2B2C2C2D2D303233343637383A3B3E3F42434546494B4D4E51525455575859
5B5E5E616366676A706E7074787A7C7C7E827F828887888A898D8E91909394959495989A
999B9D9D9B9B9C9E9C9D9C9B9F9E9D9FA19C9FA09E9E9F9F9FA1A1A2A2A2A3A1A1A5A6A4
A5A9A7A7A8AAAEAEAFB0B0AFAFAFB0B2B4B3B7B8B6B9BDB6B8BABDBBBEBEC1C1C0C4C7C6
C2C2C5C8CACBC8CACCC9CDCBD0CFD2D5D5D5D3D6D9D9DDDEE0E2E3E2E5E4E4E7E8EAE8E8
E8E9E8EAEAEBEDECECEDECEDEFF0ECEFEFEBEDEDEDEFF1F0EEEEEDEDEEEBF1EBEFEFF0EC
EAECEFEDEBE9EBEAECEDEAECEDECEBECEBEBEEEBEAE8E9E6E2E1E0DFDFDDDBDDDDDDDEDC
DFDEDFDCD9D7D3D2CCCBC7C7C0C1BFB9B8B6B6B3AFABADABABAAAAA7A7A7A7A5A5A2A3A1
A2A1A09FA09F9F9F9EA0A1A0A1A0A0A1A3A5A6A6A9AAACABAAABADAAAEAEAEADAEADB0AF
B1ABAEB0B0AFADADABA9A9A8A8A6A7A7A5A2A19F9D9B9A989897939292928F91918C8C8D
8B878B8A888988858685858282838080817F7D7E7B797976787779757676747474737270
706D6B6B6B69676565646362605D5F5D5A585858565352514F4D4D4B4B48474644424240
3F3D3A38373432302F2E2C2C2B2A29292928282728272727272727272627262726262626
2626262626272626
262626262626262626262626262627262727262627272727272727272727272828282828
2929292A2A2B2B2D2E2F303133353536383A3C3D3F42424546494B4B4D4E52525556575A
5B5F5F61636567686C6F737476777B7C7C7F7F8384858687898B9090909294949697989A
9C9C9A9C9C9E9F9FA09EA09D9EA0A19EA0A0A29FA09FA2A1A3A2A0A1A2A4A4A3A4A5A6A7
A9A5A7AAA8ABACADADA9AEADB1B0ADAFB2B1B6B4B9B8BABABABABBBCBBC0BEBFC4C3C4C4
C1C5C2C8C7C7C8CBC9CFCACDCCD1D2D1D2D2D3D2D2DADADFDFDEDFDFE3E2E5E4E4E3E9E9
E6E9E8EBE8EBEDEEEBECEBEEEEEDEFF0EFEFF1ECEDEDF2EDF1EEECEAEBEAEEEAEEECEFEE
EFEEEDECEDEEECEEECEBECE8EEE9EBEDEEEDECECE9E9E8E8E4E4E3E4E3DEDDDCDFDFDFDF
DFDFDFDBDEDAD9D7D6CECCC6C7C1BFBFBDB9B7B5AFB0ADABABACAAA9ABA7A8A6A3A3A3A3
A3A2A2A09E9FA1A09F9EA09F9FA09EA3A1A2A3A4A4A8A6AAAAACAAADACABACACAEB0ADAE
B0AFB0ABB0AFADACA9ABAAA8ABA9A7A5A6A5A1A2A09E9D9999969596929090918C8D8D8D
8B8A888B8A88878785878484838183828080807E7C7A7A78777777767776757572737170
6F6F6D6C6A6A696768656462605E5E5C5C5B585856525351504F4D4C4B4A48484543433F
3E3D3A39363431302F2E2C2B2B2A29292828282727272727272727272726272626262726
2626262626262627
262626262626262727262626262626262626262726262727272727272727282827282929
29292A2A2B2B2C2D2D2E30313233363638393B3D4042434445494B4C4E4D4F5153555858
5A5C5C616364666A6C6C6F737578797A7B7E808286888887898B8D91918F93959797979B
989A9B9BA1A1A0A0A1A2A09FA29F9EA0A1A0A2A0A2A2A2A29EA1A2A2A3A5A4A3A5A7A4A7
A8A7AAAAA7AAABABAFADADB1B0AFB0B0B4B4B6B8B9BABEB8B6BBBABABABEBCC0BDC3C0C1
C2C6C3C4C5CAC8CBCACACCCACBCCCED0D2D2D4D6D5D6D9DADEDADEDEDFE3E8E4E4E7E5E7
E8E8EAEAEDEAECEDEDECECECEDF0F3F1F2F0EFEEF1EFEDEDEEEFEDEDEBEDECF0F0EDEAEC
EFEFECECECECEFECEEEDEFEDEEF1EFEBECECEEEDEBE6EAEAEAE7E8E7E4E6E1DEE0E0E0E2
E4E3E3E0DFE0D8DCDAD4D2CFCCC8C4C4C1BDBBB9B5B4B0ADADACAAABA9A8A7A5A6A3A4A4
A5A3A2A1A19F9F9DA09E9D9D9F9E9F9FA19FA5A1A2A7A7A7A7A7ABA8ACABAAACAEABAEAE
ADADAFABAEACADACADAAADABABA9ACAAA6A5A4A39FA09E9B9A97989593938F938F8E8E8B
8B8C8989898989868685858583878384837E7E7D7C7B7A77797776757674757473717373
706F6F6E6D6A686866656463615F5D5D5A59585656545452504F4E4D4A4948474444433F
3E3C3A38373532302F2D2C2C2B2A2A2A2928282827282727272727272627262626272626
2626262626262626
262626262626262626262726262626272626262727272726272727272727272827272829
29292A2A2A2B2C2B2D2E30313234353638393C3C3F40434546474B4B4D4E505355555759
5B5D5F61636266686B6D7071757678797A7D7E808387878987898B8B8F91959697979A99
9A9A9C9C9F9FA0A1A0A2A0A4A1A2A1A1A1A1A6A2A4A2A4A0A2A3A2A2A5A5A6A6A4A7A8A9
A9A6A9AAA7AAA9A9AAADAEACAEADAFB0B2B4B5B5B9B9BDB7BDBABBBABDBCBEBFBEC0C2C2
C1C5C5C4C6C5CACACAC8C8C9CCCAD0D2D0D2D5D1D2D5D5D6D9D7DBDCDCE2E4E3E2E5E5E5
E7E7E7E6EBEBEDECECEDEBEEEEECF4EFF1EEEFF1EEF2F0F0EDEFF0F0EAEFEDEDF1EFECEF
EFEFECF0EEEDEEF1EDEFEEEDEDEDF1F4EEEEEEEEEDEAECEAF3EDEEEDEBE6E4E2E2DEE0E1
E3DFE3E2E1DFE0DADAD8D4D3CFCBC7CAC5C2BDBDB8B4B3B1AEAEAEAAA8A9ABAAA6A5A4A4
A4A3A1A2A19EA0A09F9A9D9D9D9E9D9DA09F9DA1A0A3A3A6A6A7A8A5A6A8AAACACABACAB
ACADAEABACAEAAADAAAAAAABACACAAAAA9A9A3A4A3A2A09D9D99979696959592908F8E8C
8D8B89898988888686828686868485848080827E7D7B7A7A7A7975767475757375727273
70706F6D6C6A6A676665636361605F5E5B5A585856555352504F4E4C4C4B484745434140
3E3D3B39373532302E2E2D2B2B2A2A292828282828272727272727262626272726272726
2626262626262626
262626262627262626262626272626272627272727262727272727272727272827282829
2829292A2A2B2C2D2D2E303132343637383B3B3D3F4042454548494C4D4F515155575858
595C5D5F626366676A6A6D7172757579797D7F7F84838587898B8B8C909094959796999A
999C9C9DA0A1A1A1A1A3A4A3A2A3A4A5A5A3A3A4A4A2A5A1A6A4A3A6A4A4A5A7A5A9A7A6
A7A9A8A7A9ACAAABAAAAABADAEAFB0B1B1B2B4B3B6B6B9BBBCBCBCBABABDBABDBEBFC2C2
C2C3C5C5C7C3C8CAC8C8CACCC9CCCCCFCCCECECFD0D2D5D7D4D8DBD8DADCE0E0E5E3E4E7
E6E5E8EAEBEDEBEEE9ECEEEEEDF1F2EFF0F1EDEDEEEEF0F0F1F0EEECEFEFF1F1F0EDF0EF
EEEEEEF1F0EFEAECEDF2ECF0F0ECF0EFF0EFF2EEEDEDEDEDEFF1F2EDEBE9E9E5E3E4E2E2
E6E5E3E1E2E1E0DFDBDDDBD9D6D1CECAC9C4C4C0BBBAB6B5B2B1B0AFACA9A9AAA9A8A8A9
A4A4A4A1A1A1A19FA19E9D9B9C9D9D9D9D9D9F9EA1A1A2A3A4A3A6A7A7A8A8AAA9ABACAB
ADADAFAFAEABACACAAACADACABAEACA9A9A8A8A5A4A2A19F9D9A979796949492918F8E8E
8C8C8C8A888987858885838584828383827F7E7E7C7C7C7B7A7876757675767573737470
726F716E6C6B69696764636262605F5E5B5A595757575553514F4E4D4C4948464642403F
3E3D3938363533312F2E2D2B2B2A2A292828282827272727262727272626272627262627
2626262626262626
262626272626262627262626272726262627262626262727272727272728272828282828
292929292A2B2C2C2D2E303133343637383A3B3D3E4041454648494C4C4D4F5152555759
585B5F6061626567676B6D7070747777777A7F7E8083848587898C8C8F8F909295979898
98989B9F9E9EA1A0A2A2A3A5A5A4A7A3A4A6A5A1A4A6A7A6A6A5A6A4A6A4A8A7A8A8A8AA
A6A7A9AAA9ACAAAAACA9AEACACAFAFADB2B1B3B2B5B8B8BABABABEBABDB9B9BCBBBBC4BE
C3C1C5C4C2C4CAC6C8C9C7C7C8CAC9CACECCCDD2D0CED0D0D9D4DAD9DBDEDCDFE0E0E2E1
E6E3E8E9E6EAEDECEEE9EFEBEFEFEFF3F0EFF2ECF0EDF1EDEEF2F2EEECF0F1EFF1EFEEEF
F1F3ECEEF1EEF0EFEBEFF0EDF0EDEFECEDEEECF1ECF0EFF3EDEEF3EFEAECECE8E9E6E5E6
E5E8E6E4E3E0E3DEDFDFDFDCD7D3D3D0CCC7C7C1BEBFBAB6B7B4B1AFAFACA9A9AAA9A8A7
A4A5A5A3A3A19FA0A09FA09D9E9D9D9C9C9D9C9D9E9FA0A39FA3A2A4A5A5A5A8A7A7A9AB
ACABACAAABACAAACACABADAEABABACA9AAABA8A5A5A3A39F9F9C9B98999494959393928F
8D8D8C888A88868A86858484838382847F7F807F7F7D7D7A7A7A77767576747473727271
6F706E6D6E6B6A676A666664635F5E5E5C595A575856555352504E4C4A4947464444413F
3D3D3A37373533302F2E2C2C2B2A2A292928282828272727272727272726262626262626
2626262626262626
262626262626262627262626262626272726272627262727272727272727272728282828
29282A2A2B2B2C2C2E2F303132343537383A3B3D3F40424446484B4B4D4E4F5152535657
5B5A5E5E6061646667696A6E6F707175767A7B7C818185848888878C908F909395979797
9B9A9B9DA09EA1A1A2A1A4A5A5A6A7A4A5A7A4A4A7A8A8A7A5A6A7A6A5A7A9A5AAA7A9AA
A8A9ACAAA8A9ABABABAAADABAEADAEAFB3B2B4B2B4B5B8B6B5B9B8B9B8B9BABAC0BEC1BF
C0C1C4C3C4C5C7C9C7C8CBCBC7CBCCCECACFD0CFCFD2D1D2D1D6D6D9D9D6DBDDE0E1E1E2
E2E3E9E1E8E8EDECEFEDECF1EFEFEEF3F1EFF0F1F2F0EFEFEEEFEFF3F1F3F0F3EFEFF0F0
EFECEDEDEDEEEDEEF3F2F1EEEEEFEDEDEEECF0EEF2EDEBEFF0EEF1EDF2EEECE9EBEDEAE9
E9E8E7E8E7E5E3E5E3E2DFDEDDD6D6D6CFCDC8C8C5C0C0C0BBB8B3B4B0ADB0A9AAACABA8
A9A6A7A4A19FA09FA09F9F9D9F9D9D9E9D9CA09D9C9E9DA0A29FA2A1A3A3A5A5A5A8A8A8
A9ABACABAFAAABB0ACA8ABA9A9A9AAABAAA8AAABA6A6A3A2A19D9F999897969595939190
8E8F8C8C8C8B8889878686848483838381817F7F7E7D7D7C7B7878787573757474737072
6F6F6E6B6B6C6A6B6866666461615F5D5D5B59585755545352504E4D4C4A49464443413E
3E3C393937343331302E2C2C2B2A2A292929282827272727272727272727262726262626
2626262626262626
262726262626262626262626262626272626262626272727272727272727282727282829
29292A2A2A2B2B2C2D2F2F3133343638383A3B3C3E3F424446474A4A4D4E4F5153555557
595A5D5F5F6263666568696B6E6F727375777A7D7F8081848387878A8B8D909392959798
989C9E9D9EA0A0A0A0A4A5A6A9A7A7A5A7A6A7A6A9A8A9ABAAA8A7A6A9A9A6ABA7A8A9A8
ABAAA8AAABABACADAAACABACAFADADB1B3B2B3B2B3B3B8B7B9B9BAB8BBB9BBBCBDBCC0C1
C2BFC3C1C3C1C4C6C8C8CAC9CACACCCCCFCECED1D0D3D0D0D3D5D7D7D7D4DBDCDEE0E2E1
E2E3E1E8E7E9E9E9EBEAEEEFEFEDF2F0F0EEEEEDF0F1F4F2EDF0EDEFF3EFF1F0F1F0F2F0
EFF2F2F2F0EDF1F2EEEEEFEFEEEBECECECEBEEEFEEF1F0F2F4F3F0F2EFF1F2EBEDEBEEED
EAE7EBEAE7EAE4E7E5E4E2DFDCD9D8D6D1D0CFCAC8C5C1C0BEBDB7B6B4B2B2ACABAAABAA
A8A7A7A5A3A5A1A2A2A39E9EA09DA09E9E9E9B9A9B9EA09E9F9DA19E9FA4A3A3A6A6A6A6
A8AAABABABA9ABABABACA9ABA9AAA7AAACAAA8A6A8A8A5A3A1A09E9B9D9D999697929194
928F8D8D8B8C8987898683848582837F817F7D7F817E7D7C787A7877777674737473716F
706E6D6C6D6B6A6A6865656363605F5F5B5B5A595755545452504E4D4C49474644444140
3E3C3A38363533302F2E2D2B2B2A2A292928282828272827272727272726262727262727
2626262626262626
262626262626262626272626262626262626272627262727272727272728272828282828
292A2A2A2A2B2B2D2D2E303132343537383A3C3D3E4043454748494B4D4F505352535758
5A5B5C5D5E6163626768696B6C6C707172767A797B7E8382828487898C8E8E9192949597
969A9C9E9DA09EA0A1A1A3A3A7A8A9AAA8AAA9A7A6A9AAA8ABA7AAADA9A8A9A9A9AAABAB
ACA8ABADADABABACACA9ABA9AFAEADAFAEAFB2B1B1B2B2B9B7B6B7BBBABABBBBBEBEBEBF
BFBEC1C1C4C4C3C6C7C8C8CBCBCCCCD0CCD3CECCD0CFD2D5D2D4D4D2D8DADADCDEE1E1E2
DFE1E5E3E8E7E8E7E7ECECECF0EDEEEEEDEEEEF1F2EFF0EEEEEEF0EDEEF1F3F4F1F2F1F1
F3F1F0F0EDF1F1F1F1EFF1F8EFEFEFECF0EDF2F0F0F4F0EEF0F1F4F0F2F3F0EEF0EDF0F1
EEEFEBEAEDEAE9E8E9E2E1E1DFDDDAD8D8D6D2D1CFCAC7C4C0BEBAB8B6B6B3B2B1AEA9AB
A8A7A4A6A8A5A3A4A4A1A3A29E9D9EA19D9D9C9A9C9D9A9B9E9B9F9EA1A2A1A2A3A5A9A4
A9A9A8A9AAA6A8A9ABAAA9A9A6A9ABA7A9A9AAA9A6A6A8A4A4A1A09F9D9B9A9797979593
92908F8C8B89898788878485868281827F7F817D7E7C7D7B7A777977777676757471726F
6E6E6E6C6C6B696A6967666465615F5F5D5B59585756565251504F4D4C4948454542413F
3D3C3A3837343331302E2C2C2B2A2A292928292827272727272727272727272726272626
2626262726262626
262626262626262626262627262726272726272726272727272727272727272828282828
292A2A2A2A2B2C2C2D2E303233343537393A3B3D3F41424546474A4B4C4E505253545657
585B5C5B5F6162636666686A6A6C6F72757576777B7C807F838685898B8E8F8F90919796
9B9A9B9AA09D9EA0A1A4A4A5A6A7A8A8A9ABAAABAAA9ACAAABAAADACAAACABABACA9ABA9
AAA8ABAAADACAAADADA9AAAEACADB1AFB1B2AFB2B1B6B6B6B8B6B9B7BABCB9BCBBBDBEBE
BFC3BEC3C3C4C4C5C8C5C6C6C9CAC9CCCCCACECCD0D1D0D2CFD1D1D2D5D2D6DADBDCDCDF
E2E3E6E2E7E5E8E9E9E9EBEBEDEDEEEBECF0EEEDF1F1F4F1EFF0F0F1F4F2EEF0EEF0F1F0
F2F2F0EFF0EFEEEEF1F2F2EFF1EFECEFECF0F1F1F0F0F2F0EEF2F3F2F6F6F5F1EFEFEEF2
F0EEEFEFF0E7EBE8E7E6E6E3E2E0DDDADAD9D6D3D2D1C8C5C7C2C1BCBBB7B7B4B2B0AFAC
A9ABAAA6A6A5A3A5A4A0A1A09DA1A09E9F9C9E9C9D9C9F9B9C9D9C9E9DA09FA1A3A3A2A7
A6A5ABA8AAA9AAA8A9A9AAA9A8ABA6A6A8A9A7A6A8A7A5A6A6A3A29FA09C9A9799979395
95928E8D8E8B898A8685858483858381837F7F7D7F7D7D7B7C7A79787976747574737271
706F6D6D6B6C6A6A68666664636260605D5C59595755555252514F4C4B49474644433F3F
3D3A3A38383533312F2D2D2B2B2A2A2A2928282827272727272727272726262626262626
2726262626262626
262626262626262626262626262626262726272727272627272727272727282828282829
292A2A2B2A2B2B2C2C2F2F323334363839393B3E3E40434446484A4B4D4F515254525557
585B5C5C6060626465676869696C6E7071747375787979817F838486898A8B8E908E9196
96999B9B9E9DA0A2A2A3A5A7A7A8A7A8A9ABA9A9AAABAAABAAAEABACABADACABA9ADACAE
A9AEAEACAEACAAACACADAFABAFB0AFAEB3B0B0B3B2B3B3B5B7B8B6B9BABEBBBCBEBFBEC0
C1C0BDC2BFC3C2C2C3C2C7C4C5CACAC9CAC9CDCBCBCDCACDCFCED3D3D3D4D5D9D9DADAE0
E0E2E1DFE4E4E4E8E6E9ECEBEBEEEDF1E7ECEDF4EFEDF0EEECF0ECF1EFEEEFEDEFEFECF2
EDF2F2EFEFEEF5F3F1F3F0EFEFF2F2F0EFF1F4F0EFF3F3F2F0F0F5F7F5F6F4F2F1F0F2F2
F0F2ECEFEFE9EDEBE7E8E5E2E5E0DFDDDEDADAD7D1CFCFCBCAC5C3C2C0BDBDBBB6B6B4B1
ACAAABAAA8A9AAA5A5A3A29FA19F9E9E9F9D9D9B9C9E9A9B9B9C9E9D9E9E9FA19FA3A5A7
A4A5AAAAA5A7AAA7ACA7A8A9A8A9A7A6A8AAABA4A7A6A7A4A8A3A39FA19F9B999B979896
9291908F8D8D8C8A87868684838384827F80807C7F7C7F7B7C7A78797775757573737372
716E6E6C6B6B6A69686764676362615F5C5E5A595656545251504F4C4A4948454442403E
3C3B3938373433302F2E2D2B2B2A2A292929282828282727272727272627272626262626
2626262626262627
262626272626262626262626262726262726262626272727262727272728272728282828
2829292A2B2B2B2D2E2E303133343537383A3C3E3F40424546474A4D4D4F505353545658
585A5B5E5E5F616365656769696B6D6D7174747576787A7B7E8284868A888D8C8D909293
969A999C9D9E9FA0A2A0A2A3A4A9A8A9AAAEADADADADAEADACAEACADABAEAFAEAEAEADAD
ACABADADACAFACADADB0B0AEAEAFAFB0B0AFB1B3B4B4B3B7B8B9B5B9BAB9BCBBBDBBBEBD
BFBEC0C0C4C2C2C1C1C5C5C5C5C5C6C8C8C9CBCCCBD0CACDCFD0CED1D3D4D6D4D6D9D9D9
DEE0E1E0E3DFE5E6E3E7E9ECECEBEEECEEEEEDECEFEDF1F0EDF2F3EFF0EFF0EDF0EEF4F2
EEEDEEF0F0EFF4F1F1F0F3F3F3F0F1F0F1EEF1EEF0F0F3F3F1F3F9F4F8F5F7F3F4F2EFF3
F5F3EFECECEEF1EDECEBE8E7E5E2E1E0DDDCDCD9D2D3D1CDCCCCCAC9C6C3BFBEBBB5B3B1
AFABACACACACA7A9A6A6A2A0A29FA2A0A09C9E9C9C9B9A9A9A9C9D9C9D9CA09D9DA0A1A0
A2A5A9A8A7A7A8AAA7A6A7A5A9A8A9A9A9A7A8A4A8A3A7A6A5A5A4A2A09D9F9B9B9A9898
979490918E8C8C8B8A86898684848583817F807E7C7B7E7E7B7B78797A78767576747471
716E6D6B6D6B6B686A6867656361625F5D5C5B595756555351514F4D4A4947464442403F
3E3B393736343432302E2C2C2B2A2A292928282828272727272727272726272627262627
2626262626262626
262627262627262626262726262626272627262627272726272727272727272828282829
29292A2A2A2B2B2C2D2F30323234353738393C3D3F4143454547494C4F4F525254535655
585B5B5C5F5F606365676867696A6C6E717175757676797B7D7F82848688888A8D8D9093
939796999B9B9F9FA1A2A3A5A6A7A9ABADACAEADAEAEAEAEAEABB0AFAEAEAEACAEADADAD
B2ADAFACAEADAEACAEAFAEAFB0ACADAFB0AFB3B5B3B7B6B5B8B8B8B9B8B7B9B8BABFBBBD
BEBDBFBFBEBFBEBFC3C2C5C4C6C5C9C7C9C7CBC9CBCBCECECECFD0D1CFD1D1D2D2D5D5D7
DCDDE1E0E3E4E2E6E5EAE9E7ECEAEEEDEDEBEFEFEEF4F1EDEDEEEFECEFEEF0F0F1EDF1EF
EEF1F0EFF1EEEEF1F3F2F1F2F0F3EEECEEF0F3EEF2F2EEEFF4F4F7F4F8F3F4F5F5F4F4F3
F3F1F4EEF1F0EEEDEAE8E7E8E6E2E4E1E1DCD9DBD9D5D5D1D0CBD0C8C9C4C4BDBCBAB8B4
B2AEADAEADACA9A9A7A7A5A3A29E9FA0A09E9D9E9C9E9B9B9C9C9B9D9B9C9A9B9B9D9F9E
9FA0A5A6A8A5A6A6A7A7A5A9A7A9AAA9A6A9AAA8A5A7A7A5A6A3A4A3A1A19D9C9C999A96
97959495918C8E898B88878686868283817F7D7D7E7C7C7D7C7C77797877777675737271
716E6D6C6C6A6A6968686567636161615F5E5A59585653525051504D4A4947464442403F
3D3B3A38363532312F2E2D2C2B2A2B2A2929282828272727272627272726272726262726
2626262626262626
262726262626262626262627262626262727262727272727272727272728282828282828
2929292A2B2B2B2D2D2F303133343738383B3C3D3F40434446484A4D4F50545554545656
565A5A5D5F5D606164656568696A6C6C6E7170737475787A7C7F8082858587898B8E9190
9395979B9C9C9F9EA0A1A0A4A5A7ABAAA8AAADAEADAFACACACB1AFAFB0B0AFADAEACAFAF
B0AFB2ADB1B1AEAEB0B0B0AFB1B1ACB0B1B0AEB2B4B4B3B6B4B6B7B7B8BAB9BBBCBCBCB8
BDBABDBFBDBFC1BEC0C4C4C4C4C5C5C7C6C9C7CAD0D0D0CCCBCDD0CFCDD0D6D4D7D5D8D7
D8DCDEE0E0E1E3E3E4E5ECE9E7E8EAEEECEEEDEFF0EEF0EEF0F0F0F1F2EBECF0F2F1F0F1
F0EDEFEFF0F3F2F0F4F1F1F2F4F2F1F3F1F3F3EFF0EFF2F2F6F7F9F5F4F3F3F1F4F5F4F6
F4F1EEEFEDEDEBEBEEEBEBE9E7E7E6E3DEE3DDD8DAD6D3D5D0D2CFCCC8C8C6C5C1BCBAB6
B2B1AEABACAEADACACA9A5A4A3A5A2A1A19D9E9E9B999A9B9A9A9A9B9D9B9D9B9A9BA09C
9F9EA1A2A5A5A3A5A7A7A9A6A9A8A8A8A8A7A6A5A6A5A6A8A6A6A3A2A4A0A09D9C9B9B97
999794928F928E898A888887868385848281807C7D7D7C7A7C7A79787677757673757572
706E6D6C6A6B6B6A67676664626362605E5B5B585757555251504F4F4B4847444343403E
3D3B3937363532312F2E2D2B2B2A2A292928282828272727272726272726272727272626
2626262626272726
262626262626262626262726262627262626262727262726272727272727272728282829
2929292A2B2B2C2C2D2E3031323436383A3C3D3D4040434447484B4E4F53555655555557
58595A5E5D5E606265666767686B6B6B7071737474747879777E7C8081838586888C8F91
9496979D999B9C9CA09DA3A3A6A7A8A8A8AAABADAFB0B1AFB0B0B1AFB2B0B1B2B3B2B2B1
B0B0AFB0B0AFB0B2AEB1B2B0B0AEAFB0B3B2B2B3B0B7B3B4B7B2B6B7B7B9BAB9B9BDBCBB
C0BCBEBDBFC2C0BEC1C2C4C4C1C2C6C8C7C8C7CDCACCCCCBCCCECFD1D1CDCFD0D2D3D2D3
D8DCDDDBE0DEE0E3E0E4E7E5E5E6ECEBECECECEBEFEFEFF0F1EEF0EEEEEDEFEEF0EFF2F0
EFEDF0F1EEF0F2F1F4F3F1F0F1F2F3F0EFF0F1F4F4F0F4F0F3F4F7F7F5F3F5F6F5F5FAF7
F4F1F1EEEBEFEEF0EDEDE9E9E8E7E4E4DFE0DDDCDFD8D7D4D1D4D1CCCDCBCAC6C3C2BEB9
B7B2B3AFB0ABACACABAAA8A5A6A2A3A1A19E9D9C9C9A9B9B98999A9C9A999B9C9B9A9C9D
9D9FA2A0A1A3A39FA3A5A6A5A7A8AAACA7A9A7A5A7A7A4A4A6A3A7A5A3A2A19DA19E9C9C
9897969594918F8E8D8A8A8688868382827F807F7E7D7C7C7B79797A7A76767675737472
71706B6D6C6B696A68686664626162605F5D5A595755535351504F4D4A4A48464442403E
3D3C3A38373534312F2E2D2C2B2A2A292928282828272727272727272727262626262626
2626272726262626
262626262626262626262626262626262626262627272727272727272727272828282828
2929292A2B2B2C2C2D2F2F3132343537383A3C3E4041434546494A4F5254565757565557
59585C5B5D5E606263646667696A6A6C6D6F6F71757377787A7A7B7E80818388878A8D8E
9391979898989C9F9F9FA1A4A5A4A7A6A8A9ACA9ABADAFAEB2AEB1B0B1B4B6B2AEB0B2B1
B2B4B3B2B0B1B1B1B4AFB0B1B1B2AFAFB2B0B2B1B6B6B4B6B7B6B8B5BAB8B9BCBDBBBDBE
BCBDBBC0C0BDBDC0C1C4C5C4C4C4C6C4C7C6C7C9CCCFCFCDCDCDCED0CECED0D2D1D5D7D1
D5D8DCD9DBD9DFDFDDE3E6E5E9E7E9EAEEEDEBECEDEBEFEDEDEFF0EFEFF0EDEFF2EFF3F2
F3F0F1F0F1F0F1F1F2F4F6F1F2EFF1F2F1F4F7F4F5F3F3F4F6F5F6F8F6F3F6F5F5F8F9F9
F6F3EFEFEFF0EFEFF3EEECE8ECE8E4E4E2E4E1DDDBD8D9D5D4D3D4D2CECACACAC7C3C1BE
B7B8B4B1AFAFAEADACADABA5A5A5A3A3A59FA09E9D9B989B999B9B9A9C9B9A9B9A999B9C
9B9F9F9FA1A0A0A1A4A3A4A6A7A5A7A5A6A8A6A4A6A8A6A6A3A4A5A4A5A1A3A0A09F9C9B
9B9A9A9695938F8F8C8D8889878485848283817F7D7C7C7D7C797B797A7A767474727470
706F6F6E6C6C6B68686665656363615F5E5E5B595756545351514F4D4B4948454441403E
3D3B3A37363533312F2E2D2C2B2B2A292928292828272727272727272626262626262626
2726262627262626
262626262626272626262626262627262626272627272627272727272727272828282829
292A292A2A2B2C2C2D2E303133343637383B3E3D3F40434547484A4E5155555858565657
595A5B5D5D5F60636565676767696A6D6D6C737373737578797A7C7B7E81828485878B8C
8E8F94959599999A9D9EA0A3A2A3A6A6A8A8ABABB0ADADB1B0B1B2B3B3B2B0B3B5B2B4B3
B2B0B4B2B2B1B3B2B2B0B3B1B2B1B1B1B2B4B2B2B1B6B7B4B6B5B7B8B9B6BABAB9BDBEBC
BDBCBCBCBDC0BFC0C2C4C5C5C4C4C3C2C4C6C8C7CDCCCDCDCBCDD0CAD0CFD1D2D4D1D2D0
D6D7D5D5D9D9DCDDDEE1E5E3E4E3E9E9EBEDEDE8EAEDECEDEEEDEEEEEFF1F1ECF1EFEEF2
EFF2EEF5F4ECF3F3F2F4F4F3F5F3EFF1F4F4F3F7F6F1F1F5F4F7FAF4F3F5F9F4F8FAFCFB
F7F5F3EFF1F0EFF1F1EDEDEEEAE3E5E6E6E1E3E0DDE2DCD8D7D5D5D0D4CECCCAC7C5C4C1
C0C0B7B2ADB2B1AFB0AEADAAA9A8A8A4A3A6A29F9D9B9B9B989A999B9C999C9B9A9A9A9B
9D9B9D9E9B9EA0A0A1A3A1A3A5A5A6A8A5A8A6A4A5A4A5A6A3A3A4A4A3A3A3A09E9F9E9F
9D9B989894969190908F8E8988868582858380807E7D7E7C7B7B787A7776777473736F6F
706F6F6E6B6A6A6968676663636260605D5B5B595856555352514F4D4B4947454443403E
3C3B3938373433322E2D2C2C2B2A2A292929282827272727272727262626262726262626
2626262626262626
262626262626262626262626272726262726262727272727272727272727272828272828
2929292A2A2B2B2C2D2E2F3133343636393A3B3F3F40424546484B4F5155565757575757
57595A5A5C5E606062646466676A686D6C6F71747274747779797B7B7D7F80848788878B
8C8F91979498989C9C9E9EA0A2A5A7A9A7A9A8ABAEADB0ADB4B2B2B5B1B5B5B4B2B8B2B4
B5B4B3B5B2B3B1B4B4B5B5B6AEB2B1B2B2B3B2B6B5B5B4B8B7B8B7B8B7B8B9BBB9BCBEBC
BCBDBFBDBCBFC0C0C0C3C6C4C9C5C3C4C1C5C5C9C7C9C9CACBCDCCCFCECFD0D3D0D2D2D3
D5D2D8D3D8DBDADBDEE1E2E4E4E7E4E7E9E8E8ECECE9E9EEEEECEFEFF1EDEFEEEDECEDF1
EEF0F0F2F2F3F2F6F1F3F2F2EFF3F5F5F4F4F3F6F6F1F4F4F8F2F8F6F6F2F4FBFBFBFFFF
FEF7F3F4F3EEEEEFEFEDECE8EAEBE8E6E7E5E2DFDEDFDBDDD7D8D9D6D1D1CFCECBC9C9C5
C3C2BEB9B8B8B4B2B2B1AAACACA7A7A8A2A4A19F9FA19C9A999B999A9B999A9A9A999A9C
9C9D9D9C9E9EA09FA0A2A2A3A1A2A3A4A5A2A6A4A4A6A5A4A5A4A2A2A1A2A2A19FA19E9E
A19B9B9A989693939091908C87878986868483817F7D7C7C7C797A767876747372727071
6F6F706E6D6B6A6969666465626160605D5D5B595858545451504F4D4A4949454542413D
3D3B393936343332302F2D2C2B2A2A2A2929282828272727272727272727262626262626
2626262626262626
262626262626262626262626262626262626262627262726272727272727272828282828
292929292B2B2B2D2D2E2F3132343537393A3B3E4041414446484A4F535657585A575757
585A5B5C5D5D5F616262656767676B6B6E6D706F717175777779797C7C7F818083868588
8E8C8E939596979A9C9B9B9EA4A2A7A8A7A8ABABACAFB0B0B0B1B2B4B2B3B5B0B6B7B7B5
B7B7B7B2B4B3B5B4B2B0B3B5B3B0B1B3B1B3B7B6B6B5B5B6B7B6B9B9BBB6B8B5BABABABB
BAB9C0BFBFBFBEC0C1C1C3C4C7C5C2C4C8C5C5C8C8C7C8CBC7CBD0CCCCCFD3D0CFD2D3D0
D3D3D4D6D4D9DBDDE0DFE1DFDFE4E2E3E8E8E8EBE8EBEEE8EEEEF0F0EFECEEEEEDEDF0EC
F1EFF0F2F3F3F1EEF2EFEFF1F3F5F1F5F9F3F4F6F4F8F1F4F5F5F4F3F4F6F5F6F6FAF8FA
F6F7F6F7F8F1F2F0EDEBE9EAEDE9ECE8E6E2E3E2E3E1DEDCDBDAD8D3D8D4CFCFCBCAC8CB
C7C7C1BBBCB9B9B7B5B0B0ACABAAAAA7A8A6A3A3A2A09DA09E9F9C9B9B9A9B9B9B999B9B
9C9A9D9B9D9D9E9CA2A09F9FA2A3A1A5A7A3A4A6A5A4A4A3A5A3A3A2A3A2A0A09D9EA0A0
9D9E9B9A9695969594908F8E8B878A8787848281817F7D7D7A787A767875767574737170
716E6E6F6D6B6A66676766646362615F5E5C5C5A5755555453514D4D4A4948464442423E
3D3A3939363533312F2D2D2B2B2B2A292929282827282727272727272727262627262626
2626262626262627
262626262626262627262626262627272627262727272726272727272727272727282828
29292A2A2A2B2C2D2D2D2F3132343537383B3B3D3E40424445484A4E5255575757575759
58585B5C5C5F5F5F626464656869676B6E6F6F707072747477787B7C7C7E7F8283848886
898D8C9193979498989B9B9C9DA3A3A4A6A9A8AAACACAEAEB2B5B4B3B5B6B4B4B6B6B8B9
B5B4B4B6B6B5B3B7B6B5B5B4B8B3B6B4B1B2B4B6B4B4B5B6B6B8B8BABBB9B5B8B9BAB7B8
BBBABDBCBFC1C3C1C2C2C2C5C4C2C5C3C5C6C5C6C5C8C7C8C9CCCCCED0CCCECED3D3D3D3
D4D3D3D4D3D6D8D8DBE0DEDFE1E2E2E4E5E2E8E7E6EBE9EEEBEDEDEFEEEDECEBEDEDEDEE
EEF2F0F1F3F0EFF3F1EEEDF2F2F5F5F3F4F7F8F7F5F4F7F9F5F5F6F6F3F7F9FAF9F8F5F9
F2F3F3F4F6F5F1F1F1F1EEEAEAECEAE7E8E4E3E3E4DFDFE1DCDFD8D5D3D3CED3D0CED0CD
CBC8C8C3BEBDBABAB9B6B3B1AFACAAABA7A9A8A3A4A4A0A0A19D9E9D9B999A9D999D9A9C
9C9A9E9C9B9C9B9E9DA09FA1A1A1A2A2A2A5A5A3A3A4A5A6A4A3A2A1A2A4A2A0A0A19FA1
9C9C9C99989896979493928F8D8C8C888886868381817E7D7B7C7979767575747473726F
716F6D6C6D6C6969676667636262615F5F5D5B585957545452504F4C4B4A48454442403E
3D3C383836353431302E2D2C2B2B2A292929282827282727272727272727262727272726
2626262626262626
262626262626262626262626262626272726262626262727272727272727272827272828
2929292A2A2A2B2C2C2E2F313234363739393B3E3F40414346484A4E5154575858595859
585A5B5C5E5D5D6062606264656769696A6E6D6E727273757778797A7C7D7F7F81838488
868C8C908F8F9295999B9A9C9CA0A3A3A4A6A5A6AAABADB0B0AEB1B3B2B7B5B7B5B7B8BC
BBB9B7B7B6B4B5B7B8B9B5B6B3B5B5B6B5B4B5B7B4B5B4B2B7B9BABBB8BBBBB6B9B9BAB8
B7B8BCBCBCC1C0BFC1BFC1C3C1C5C3C3C5C6C6C6C4C6C5C6C9CACDD0CBCECCCDCDD0CFD0
D0D1D0D1D1D5D9D8DADEDEDCDFDFDCE0DFE6E3E7E7E7EBEAEAECE7ECEEEEEFEFEFEDEFED
EFEFEEEFEDF0F1F1F0F0F2EFF2F5F4F7F7F5F6F7F4F6F5F5FBFAF6F4F5F8F9FAF8F6F2F1
EEEDF2F3F7F5F6EEEDF0F2F1ECEAECE6E6E7E8E3E1E1E1DFDEDEDBD9D7D2D5D5D0D3D1D1
CFCCCAC9C4C1BFB9BDB7B6B3B0B0ABAEABA7A7A4A4A7A4A0A3A09DA09D9A9B9A99999B9B
9B9B9B9A9A9B9C9D9F9E9FA1A19DA0A2A1A2A2A2A4A4A5A3A2A2A1A4A1A1A29F9FA0A19E
9C9E9D9A99999895939293908E8E8A8E8A87848482807F7B7E7C7B787676747672727374
726E6F6C6B6B6969656564646261605F5D5C5B595757555452514F4D4B4847454442403F
3D3B393736353332302E2D2C2B2A2A292928282827282727272727272726272626272726
2626262626262626
262726262626262626262626262626272726272726272627272627272727272828282829
282929292A2B2B2C2D2E2F313233353738393B3D3F3F41424547494C5054555857585857
585A595B5D5D5E5F62616363656768686B6A6E6E707173757576787B7B7E7E8180848486
8587888C8D938F92969798999A9EA0A1A5A8A9ABACAAADB0AFB1B1B4B3B3B5B8B8B6B6B7
BBB9B9B9B8B6B6B5B9B8B7B7B9B6B8B7B6B4B7B4B7B7B9B8B8B8B7B9B7B9B6B6B8B9BABA
B6BBBABBBDBEC1BFBFC1C4C4C2C2C4C6C3C6C2C4C1C5C3C7C8C8CCCECDCDCCCDCFCCCBCC
CFD0CFD3D2D1D6D9D7D6D8D8DBDDDEDDDDE1E1E4E1E6E7E5E5E9EDEDEAE7EEEEEDEEE9EA
ECEEEEEEEDEFEFEDF0F2F2EDF5F6F4F4F2F6F5F9F7F3F6F7F9F5F7F6F7F9FAF9F5F3F1F1
EDF0EEF5F4F7F5F1F0EFF0EFECEDE9E9EAEBE3E5E3E3E0E1DCDFDBDED9D7D5D4D6D4D4D3
D0CFD1CAC9C6C4BFBCBCB6B6B3B2B2AEAFABAAA8A7A7A6A4A2A2A09FA19DA09C9B9C999E
9E999B9CA09D9A9A9B9E9C9D9FA19EA0A0A0A2A5A1A1A4A2A2A4A2A2A1A1A0A0A19E9C9E
9B9B9C9D989A9997969294918E918F8C8C8A868483827F7E7F7C7A7A7677757474747371
716E6E6E6B6B69686667646564635E605D5B5B595756565352504F4D4A4A474744423E3D
3C3B393737353332302F2D2D2B2A2A292929282728272727272727272626262626262726
2626262626262626
262626262626262626262626262626272626262627262626272727272727272827282828
292929292A2B2B2C2C2D2F303133353638393C3D3E3F40424546494C4E53555759575857
57595A5B5E5D60605F6261636466686A6A6B6D6E70707073767678797B7B7F7D80828485
8587888A8D8E909293969696999A9E9FA3A4A6A6A9AAAEAEB2B0B0B0B5B5B6B7BAB6B6B7
B7B9BCBDBCBBBBBAB9B9BAB9B9BAB7B6B8B4B8B7B5B8B6B9B9B8BABABAB7B9B8B5BAB9B9
B8B7BDBABCC0BFC0C2C1BFC1C3C4C1C2C4C5C4C3C4C4C5C7C7C8CACBCCCECACDCDCDCECE
CFCDD1D1D2D6D5D4D5D7D9D8DAD8DDDADFDFDFE1E1E3E4E4E6E6E8EBEBEAEAECECEBECEC
ECEDEDEDEEEDEFEFEFF0F3F0F5F2F2F3F5F1F6F6F3F5F6F7F9F7F3F3F4F8F7F6F7F6F4F2
F0F1F2F6F6F5F2F2F2EFEEEDEDEDECE8E6E6E7E2E5E2E0DEE0DEE0DDD9DCD8D7D9D6D6D5
D4D4D0D2CFCBC6C7C2C0BBB9B9B5B4B4B1B0B0ACAAA9A6A5A6A3A2A09F9F9E9E9D9E9A9A
9A9B9B999B9C9B9C9A9E9B9C9C9C9E9D9FA0A0A2A2A1A1A1A2A2A0A09EA19E9DA09E9D9B
9E9B9C9A9898979795959490938F8F918E8B8985858282817F7F7C7A7775757273737273
71706F6C6B686968666664646262605F5D5E5B595656545352524F4E4B4946464441403E
3C3A3A3736343431302E2D2C2C2A2A292929282728272727272727262727262726272727
2626262627262626
262726262626262626272626262627262727272626272727262627272727272728282828
282A292A2A2A2B2C2C2E2E303234353738393B3C3D3F41424446494A4F51535856575656
55575A5C5D5C5F5E6060616465666767696A6C6E7170727272767679797B7C7E80828285
848888898A8D8F9090979697979C9F9FA2A5A5A6ABABAAADAFB0AEB1B3B4B5B8B8BAB6B8
B9BBBBBDBBBDBBBABAB9BBBAB9BBBABAB8BBBABAB9B7B9BAB9BAB8BAB8B9BAB6BAB8BBB9
B9BBB9BBBBBCBEC0BFC1C2C4C4C4C4C1C2C2C4C3C3C5C8C4C7CAC9CBCBC9CACBCFD1CCD2
D0D1CDCDD4D3D5D3D5D5D6D5D9DCDADCDEDCDCE0E0DFE4E3E7E6E7EAE8E9E8E8EBEDEBED
EEEDE6ECEBEDF0EFEFEEF0EEF2EFF3F3F6F5F1F4F5F6F5F6F7F5F6F5F5F6F5F7F8F9F6F0
F1F5F0F0F3F6F2EFEEEFEDEEEFEBE9EFE6E8E5E6E4E3E0DFDFDEE0E0DEDADBDCD6DAD7D8
D7D6D6CFD0CCCDC8C7C4C2BCBCB9B9B7B5B4AFB0ADAFA9A8A4A6A3A3A3A2A09D9C9D9D9B
9B9C9D9D9A9C9A9D9C9C9C9B9D9E9D9F9E9EA0A1A0A09FA1A0A29F9FA09F9C9E9F9D9E9C
9B9A989B9B9B9899959595938F9190908E8B8B878683838182807C7A7976757473727271
706F6C6D6B6A69696667656462615F5E5D5C5B5B5655555352504F4D4A49474544423F3E
3E3B3938363532322F2E2C2C2B2B292A2928282828282727272727272726262726262626
2626262626262626
262626262626262626262626272627262726272627262727272727272728272728282828
2929292A2A2B2B2B2D2E2F303233343638393A3C3E3F41424246484A4D51535658565555
57585A5C5B5D5F5D5F5F62626367676869686C6D7071707273737678787B7B7D7D818182
8384888887898B8C929394929A9B9C9DA1A2A2A5A6A9ADAFADAFB0B0AFB2B5B4B6B8B8B7
B9BBBDBEBCBEBBBBBABCBAB9BBBDBABCB9B7B9BBBBB8B7BAB8BAB7BABCBBB9BBBABBBABA
BABABABFBDBDBCBCC1BDBFC0C4C3C1C1C2C3C1C2C4C2C8C9C5C6C5C7C9CBCACECED0CED2
CCCFCCD0D2D1CFD4D1D5D4D7D9D9DEDAD9DDD8DADCE0DFE0E0E5E6E4E5E6E6E8E8E7E9EF
EEE9EBEBEDEDEDECF0F3EDF0F4EFF0F1F3F1F5F5F6F6F9F6F6F4F2F5F6F7F9F9F9FAF3F4
F1F6F3F4F4EFEFEEEAF1EDEDEBEDECE9E8E6E5E4E6E4DFE0DDE2E0DDDAE0DDDDDBDDDBD9
D9D4D4D3D4D4CCCDCAC6C3C4C2BDBBBCB9B8B5B4B2AFAFACAAA7A8A6A2A2A3A3A09C9C9E
9D9C999B989B9C9C999C9C9D9D9C9D9C9D9D9E9F9FA09EA0A19F9DA09FA1A09F9F9F9B9C
99999A999A9898979594939191918F8C908E89878786858281817D7C7B78767474727172
70706E6E6B6A6968666665656262615E5C5C5B59595655525150504D4B4947454342413F
3C3B3A3836353331312E2C2C2B2A2A292929282827272727272627272727272726262727
2627262626262626
262626262626262626262626262727262627272626272627262727272727272827282829
29282929292B2B2C2C2D2E303134343636393A3C3E3F3F42434445484B4F515455555555
545658595B5C5D5F5E605F62636466696C6A6B6D6E6F717272737478797A787C7C7F8081
81848487878B8A8D9091939495989A9A9E9DA2A2A5A7A9AEACAEAEAFB0B2B3B6B6B9B9B8
B6B9BCBDBFBDBBBBBCBEBEBDBBBCBCBABBBAB8B9BDBBBBB8BCB8BABCBABABBB8BABBBDBC
BCBBB9BBBABABCBDBDC0BFC0C2C1BFBEC0BFC1C1C4C6C6C6C8C7CAC9C7CAC8CBCFCED0D1
D1CFCDCDCFCFD1D0D1D1D3D4D3DAD8D9D8D9DADBD8DDDDE0E0DFE2E6E6E4E4E6E8E9E8EB
E8E8EBE7E8EAEBEEF0EEEFEDEFF0F4F4F2F5F4F1F2F7F6F8F7F5F4F6F6F4F7F7F8F8F6F5
F7F2F5F8F7F2F2EFECEBEEEEECEDEAEBE9E7E6E6E5E2DFE2E3E2E0E3DEDEDDDFDCDFDCD8
D9D7DBD6D2D3D3D2CFCBC9C6C6C4BFBEBEBAB8B7B4B3B3B1AEACA9A9A5A6A3A49FA19F9C
9C9E9D9B9B9B9C9C9D9A999A9A9E9D9D9C9B9E9F9B9E9F9E9F9DA19FA0A09C9F9D9B9C9D
999B979B9A9998959795959592918E8E8D8D8C8B8785828582807E7E7B79777575727171
716F6E6D6C6C6B686666646361625F5E5D5C595857575453514F4F4D4A49474544423F3E
3D3A3A3736353332302F2D2C2B2A2A292928282828282727272727272726262727262626
2626262626262626
262626262626262626262626262626262627262726262726272727272727272727282828
2829292A2A2B2B2B2D2D2F303233343537393A3B3D3E4142434346484A4C4F5353535253
545756595A595D5E5F605E6262656668676A6C6D6F7072727075737577787B7B7D7E8181
8585878888898A8C8D8E9092959698999C9F9FA2A4A9A7AAACADAEAEB2B3B3B4B4B7B9B9
B7BBBBBBBEBBBDBBBEBCBABBBDBBBBBBBCBDBABDBBBBBCBABCB8B9B9BBB6BBBDBBBDBBBB
B7BCB8BAB9BCBCBFBCBDBDBEBFBEC1BDBFC0C2BFC3C4C1C5C7C4C4C9C9CBCFCFCBCECDCD
CBCFCECECFD1D1D2CFD0D3D5D2D6D5D1D7D7DADAD7DBDADADCDFDFE0E2E3E1DFE5E3E9E9
E7EAE6EAE9EEEEEEEDEFECEDEEEFECEEF0F3F3F4F5F3F6F7F5F8F5F6F3F2F6F3F6FBF4F3
F7F6F8F5F6F4F4F1EDF0EFEDEBEAEBEAE9E7E6E3E5E3DFE2E0E3E2E1E1E1DCE2DFDDDEDA
DADAD8DAD9D6D3D4D0CCC9CBC9C6C2C4BEBEBDB9BAB8B6B5B1B2ADADABA7A5A4A0A3A2A2
9D9F9C9B9D9B9D9B989C9B999A9D9E9A9A9D9B9D9C9C9D9D9C9F9EA09E9EA09E9D9D9B9C
9B999A989798969894969395928E9190918D8B8789868583807F81807A7B787674747272
71716F6D6D6D6A67676665645F615F5F5D5B59595755545151504E4C4B4847454341403F
3B3B3A3737353332302E2D2B2A2A2A292928282828272727272726272627272726262726
2626262726262626
262626262626262626262627262626262726272626262727272727272727282728272828
282929292A2A2B2B2C2E2E30313333343637393B3D3E3F42424445474A4B4E4F51535254
54555658595C5D5F5E60616162636668696B6C6A6E6F7070707373737878797B7D7D8080
8282868585888A8A8E8F9292949797989BA09FA1A2A4A7A8ABACAFADB0B2B3B4B7B8B8B7
B6B9BABBBEC0BABCBCBFBEC0BFC0BDBEBDBCBBBCBDBFBEBEBBBCBBBBBDBCBCBBBABDBEBF
BEBDBBBCBBBABEBDBFBEBBBEC0BFBEBEBFBDC1BEC1C1C2C4C2C6C5C8C8CCCBCBC9CCC9CB
CCCFCECDD0D0D0D0D1D2D2D5D2D2D2D5D7D5D7DAD7DBDADADBDDDEE0DFE0E5E3E4E4E5E5
E9E8EAE8E5E9EBE9EEE7EDEBEFEEECF2F0F1F3F2F3F4F5F4F5F2F5F7F4F4F7F3F4F6F6F8
F7F6F5F3F7F2F2F1EFEEECEDEBECEAEDE9E5E5E6E3E2E2E2E1E3E2E2E0DFE1DFE0DDDFDD
DCDCD6D9D7D7D2D2D6CECDD2CBCAC7C4C4C2C0C0BDBBB9B8B6B6B2B2ACA9A8A9A5A4A2A0
A1A19A9B9A9C9C9A999B9A999A9A99979A9B9C9C9C9C9A9D9E9E9C9D9E9C9D9B9E9A9A9C
9B98989C9B9795949594929393908E908E908D8C88888682828280807E7C7A7977757471
6F706F6E6D6C68696764646360615F5E5D5C595957555352524F4D4C4A4947454342403E
3D3B383736343332302E2D2C2B2B292A2928282828282727272727272726272726272626
2626262626262626
262626262626262626272626262626272727262626272727272627272727272827282828
282929292A2A2A2C2C2D2E30313234353738393B3B3D3F4143454448484A4C4E4E505252
51545657595B5C5D5F5F5F616264646869696C6C6D6C6E6F727072727678777A7E7B7E80
838386868686868B8B8E928F92959596989A9B9EA0A3A5A5A8ABABB1AEAEB0B5B6B9B8B9
B7B8B9BCBDBCBBC0BEBFBEC2C0BFC0BEBDBEBFBDC0BDBEBEBDBCBCBABCBBBBBDBEBBBBBD
BBBBBDB9BDBCBDBDBCBFC0BCBEC0BEBCBFC1C0C3C1C3C5C3C4C5C3C6C5CECFCBCBCCC8CB
CCCDCDCFCECED1D3D1D0D2D2D4D3D7D4D7D7D6D8D7DAD8D9DAD9DEDBE0DCDEE0DEE4E5E6
E7E7E6E7EBE9E7EBE6ECEBEDF0EBEDEBF2EFEEF0F0F1F2F4F4F8F2F5F3F5F2F3F5F3F4F7
F2F7F2F6F6F2EEEFECF1ECEFEBEFECECE8E5E4E6E2E5E3E2E2E2E2E2E5E4DFE0E1E0DCE1
DCDDDED7D8D5D7D7D3D2D1D0CECDCBC9C8C5C5C1C0BFBEBCB9B9B8B5B3AFADA8A8A6A6A4
A2A1A09F9C9B9A9B9B9B9B999C9A9A9A9899999A9D9B9B9B9C9B999C9C9D9D9B9C9B9A98
9A98989499969593939292949091918E918C8B8C8B8887838381827F807D7A7A76767472
726E6F6D6C6E6A686865646261615F5E5C5B5959565654524F4E4D4B4A4948474341413E
3C3A3A3837333331302E2D2C2B2B2A2A2929282827272827272727272627262727262626
2626262626262626
262626272626262626262626262626262627262626262627262727272727272728282828
282929292A2A2B2B2C2D2E2F313233353636393A3B3D3E404244444649494C4D4D505152
52545557585A5C5D5F5F616163636466676A6B6B6D6C6D706F727473747678797B7B7C80
80828383838689888A8C8F8F8F9396959899979CA0A0A1A4A6A9ACAEAEB3B3B5B5B3B5B8
B9B8BABABEBDBBBEBDBEBEC0BFC3C1BFBFC0BFC0BEC1BDBCBBBFBDBFBBBEBCBEBCBBBABC
BCBEBBBBBDBDBFBEC2BEBABFBFBBBFC2BEBDBEC0C3C5C6C8C3C3C7C8C9C9CACBCBCCC9CA
C9CECBCACBD0D1CFD2D3D0D2CFD5D3D2D6D2D4D3D8D6D5DBD6D8D7DCDADDDDDEDCDFE2E4
E2E6E4E6E1E6E9E8ECEDEBECECECEAECEBF1EEF0EEF0F0F1F1F7F3F5F7F4F4F5F5F7F4F1
F1F4EEF5F0F0EFEEEFEDEEEDEBEDECECEAE6E5E6E8E3E4E8E5E5E0E3E1DFE1E3DFE0E0E0
DADCDDDEDAD9D6D8D4D7D4D4D1CCCDCCCBCBC5C7C6C2C2C1BDBEBAB6B6B5B0B0ABA8A9A5
A2A1A4A19E9E9D9A9D999D9A999B999A9A989B9B9A9E999A999A9B98999A9C9B9A999B9A
9897989697959595949390939292918F8E8E8E8B88878584858280817F7E7B7A78787673
7071706E6C6D6A6866656363635F5F5D5C5B5857575554524F504D4C4A4A47454443403E
3D3B383836343432312F2D2C2B2A2A292A29272828272727272727272726272626272626
2626262726262626
262626262626272626272626262626262627262727272727272727272727272827272828
282929292A2A2A2C2C2C2E2F313233343536383B3B3C3D404142434648484C4B4C4E5051
5254555656595A5C5D5D6061606263666667686A6B6D6E6E70717373737677767A7A7D7E
7F7F8184818486898A8C8C8F9091929395969A999DA2A0A4A8AAAAAAAEAFB0B3B4B4B4B7
B7B9B8BAB9BCBCBDBEBFC2C1C4C1C2C3BEC0C0C0C1C1BEC2C0C0BEBDBDBFBBBEBEBBBDBF
BBBFBEC0BFC0BFC0BFBFBDBBBEBEBEC2C1C0C2C1C1C4C4C5C6C7C6CAC9CDCAC8C6C9C7C8
C8CFCCCCCDCCCDCDCED0D0D0D3D1D0D1D2D4D3D5D3D4D2D5D7DAD6D8DADFDADDDCDEDFE4
E3E3E0E0E4E6E5E8EAEAEBECE9EDEBEFEDEEEDF0EAF2F1F3F0F2F2F2F5F3F3F0F3F3F1F3
EFEEEEF4F0F4F4F0EDEEEDECEFEFEEEDE5E4E5E5E6E9E3E8E3E4E5E4E1E2E3E5E0E3E2E1
DBDFDCE0DADBDCD6D8D6D3D1CFD1CECDCCCCC9C9C5C7C4C3C4C1BDBEBAB5B5B0B2AEAEAB
A7A7A5A59FA1A0A09C9E9C9E9D9C9899979B9A9A999A98979A989B99989A9A999A989997
999796979795929593919191929192908F8D8C8B8989878484858682807F7D7C7A767575
71706F6E6F6A6A6766666364625F5E5D5D5B5757555453504F504D4C494846454342403E
3D3C3A3836353332302F2D2C2C2A2A2A2929292828272727272727262727262726262726
2627262726262626
252726262626262626262626262726272626262627262727272726272727272728282728
2828292A292A2B2B2C2D2D2E30323234343739393B3C3E3F4142444447484A4A4C4D4E50
5154565657575A5C5D5E5E606463636564666A6B6D6C6C6E7171727373747679787A7B7D
7F7F7F838384848688898B8E8F8E908F919595979BA1A0A1A2A7A9AAAEB1ADB2B1B4B6B4
B9B8B8B7B8BCBCC0C0C2BFC1C0C2C2C0C2C0C1C1C0C2C0C0C1BFBFC1BFBFBDBEBBBEBEBF
BEBDBBBEBCC1BFBEBFC2BDBFBABFC2C1C2C3C3C5BFC3C4C6C6C6C3C8CAC9C7C6C2C5C6C9
C6CACCCCCBCCCECCCDCECFCFCFCDCED0D0CFD0CFD3D1D3D3D5D5D7D7D8D8D9DBDBDEDDDD
DFDFE0DEE1E3E8E5E6E6E8E8E9E8EAE9ECEBEBEBEFF0EEECF0F4F3EFF0F5F2EFF1EFEFF4
EEEDF1EFEFECF1F1F0EEEBEDEEEEEEECE9EBE8E9E7E7E5E5E5E4E2E5E3E0E3E3E6E1E5E2
E3E0E0DFDEDEDCDCD6D8D4D3CDD0D4D2D0D1CDCACAC6C8C6C5C2C2BEBDBBB6B5B2B1B0AF
AFAAA9A5A5A5A0A09D9C9C9D9B9A9A989A98999B9A9A999A999796989997969997999696
9497979594959393959492919191918F8E8D8D8A898A8A8785858481807F7B7D7A7A7876
76716F6E6E6E6A686565646161615E5E5C595855555353514F4D4C4B4A48454443403F3E
3D3B393836353332302F2D2C2B2B29292929282828272727272727272627262726262626
2626262626262626
262626262626262626262626262627272627262626272727272727272727272728282828
282829292A2A2A2B2C2C2D2F313133343537383A3A3B3D3E414343454547494A4B4C4F50
5153535456595A5C5B5C5E6060626363656769696B6B6F6F6F7170717374767778787A7B
807E81808184848586888C8D8F8E8E8F919596989C9D9E9EA0A3A3A7AAABAEB2AFB1B0B6
B6B8B8B8BBBCBCBDC2BFBEC1C4C1C5C4C3C0C0C5C3C3C4C1C3C2C2C2C3C3C0BEC1BEBDBF
C0C0C0BFBFC0C1C1C2BFC0BFBFC0BDC4C5C4C2C1C2C3C4C6C3C3C8C7C9CBC2C6C3C6C5C5
C8CBCCCAC7C6CBCDCDCDCDCECDCECED0D1D0CDCDCDD1CED5D1D4D6D7D6D5DAD8D8DDDADB
DCDCDBDEDEE3E3E3E3E6E5EAE9E9E8EAEBECEDEBEDECEDF1F0F0EEF1F3F0F3F3F0F6F3F3
EEF0F0F1F2EFF1EEECF0ECEFECEDEEEAE8E8EAE9E7E8E5E4E4E4E2E4E4E3E3E4E5E4E8E3
E3E2DFE4E0E2DBDEDCD8D4D5D4D5D2D0D1D1D1D0CCCEC8C8C8C4C3BFBDBCB8B8B6B5B4B3
AFAEACA9A8A5A1A1A09F9E9C9D9B9A999997989897989998979696969796949797959796
9697959693949296919091918F908E8F8E8F8C8D8B89888986858483817F7D7C7B797876
75746D6F6E6C6B696866646162605E5C5B5A5757545352514F4F4D4B494647444341403E
3C3A393836343431302F2D2D2B2A2A292928282827282727272727272627272626272726
2627262627262626
262626262626262626262626262726262726262627272727272627272727272728272728
282829292A2A2A2B2B2D2D2F303133343436383A3A3C3E3F40414343454749494B4E4E50
515253555657595A5B5B5D5F616361636666686A696B6D6F706F70737374747778797A7C
7D7F807F828283878688888B8C8C8E8F91949498979A9A9C9FA3A2A5A8AAADAFAFAFB3B0
B3B7B7B5B9BCBBBBC0BFC0C1C1C1C3C3C3C0C2C2C2C6C4C3C4C2C2C2C0C3C3BDBEBFBDBF
C0BFC1C0BFC2BFC2C0C0BDBCBEBEBDC2C1C1C5BFC3C3C3C2C6C3C4C7C6C5C7C8CACCC8C9
C8C8CACACBCDCDCECCCCCDD0CFD2D0D0D1D3CECACDCFD0D1D3CFD4D3D3D5D4D6D8D7D6D9
DADADCDBDFE1E1E3E5E5E5E8E8EAE9E6EAE9EBECEEECEAEFEDF0EFF1F0F0F3F3EFF3F0F2
F1F0F1EFEFEFF1F0F0EFE8EEE9EAECE8E6EAEAE9E6E7E4E7E4E8E3E5E3E3E2E4E7E8E6E5
E2E2DFE4DFE0DEDEDAD8D9D4D4D4D3D2D2D1CED0D0CFCBCACBC5C4C2C0BDBDBDB9BCB7B2
B5AFADAEAAA9A7A4A3A09E9F9E9C999B9A9A9898979A9797959698969496969695969594
95939495929390919391928F8C908F8E8F8D8B8C8A8B88898587848584817E7E7C7B7876
7573716F6E6D6B686668646360605F5E5B5B585856545251504E4C4B4947464543413F3D
3C3B393736353332302F2D2C2B2A2A292929282828272727272727262727272726262726
2626262626262626
262726262726262626262626262626272627272627272727272727272727272727282828
282828292A2A2A2B2C2D2D2F2F313334353637393B3B3D3F404141444546474A4B4C4D4E
4F515254555557595A5B5D5E6060636464666867696B6C6D6F707071727475767878787B
7B7E7F80818383858486888A8A8C8E8F9196939696999A9C9DA0A1A4A5AAAAABAEADB0B1
B2B3B8B8BAB7BBBDBABEC1C0C1C0BFC1C3C3C5C2C3C4C4C6C5C6C4C3C3C3C3C2C3C2C1C3
BEBEBDBDBEBFC1C0BFBEC0C0BFC0C1C1C3C1C2C4C4C2BFC2C1C3C4C6C6C8CDCACBCECBCA
C8CCCACECBCACED2CDCCCCCCCED0D0D1D2D2D2D0D2CECDCFD0D1D3D2D6D4D0D5D4D8D3D7
D7D7DADBDCDEDFDDE2E2E3E4E3E7E5E8E9E8E8EAEAEEECEDE9EBEDEEF0F1F0EDECF1F1F4
F1EFF3F1F1F0EDECF2EDEAEBEDE9EBE7EBECE7E7E8E7E4EAE4E7E5E4E1E0E2E6E5E8E8E2
DEE2E1E0E0DFDFDFD9D8D9D6D7D4D3D3D1D6D4D3D2D0D1CDC9C7C9C7C3C2BEBFBCBAB9B6
B2B2B0B0AEAAA7A7A3A5A19E9E9D9A989A999B9698979597959595949496949395939595
9394959493929291908F90908E8F8D8D8D8E8C8C8A8C88898687868480827E807E7B7979
767671726F6E6C6B6667636363605E5E5C5B5957545452504E4E4B4B4947464443413F3D
3C3A383836353332302F2D2C2B2A2A292929282828282727272727272727272626262627
2626262626262626
262626262626262626262626262627262626262626272727262727272727272727282728
28292929292A2A2B2B2C2D2F30313234353637383A3C3D3E3F404243444647494A4B4D4F
50515152545758595A5B5B5E6061626365676767696A6B6C6F6E706E717275777677797A
797E7D7E7F818284858587888C8D8C8E919393959598979A999CA2A3A5A6A6AAACADB3B0
B1B0B3B6BABABCBDBDBDBEBEBFC1C0C1C5C3C3C6C1C6C6C6C4C4C4C4C1C4C3C6C4C0C2C1
C1BFBFBFBCC2BEC0C1C3C2C1C1C1C3C2C1C2BFBFC0C1C1C1C3BEC5C2C8C9CACDCBCCC8C9
C8CBCACACCCDCDCDCCCDC9CACECED0D3D0D3CDD1CDCED1CFCDCFD2D1D0D3D4D4CFD6D3D4
D6DBDBDBDCDCDDE0E2DEE3E3E3E6E3E5E8E6E8EAE9EAE9ECF0EAECEFEAEDEEEFF2EEEFEF
EFF1F1EEF0EFEEF0EDEFE9ECECE9E8E9E8E9E8E9E7E6E6E3E2E5E6E4E4E6E4E3E5E6E6E3
DEE1DFE3E0E0E4DDDCDDDAD8D6D5D4D4D3D5D1D1D1D1D0D1CDCCCBC9C5C1BEBEBDBAB9B8
B3B2AFAFAEAEACA9A6A3A5A2A09F9C9C9D9A979796989698969694959295929394949292
939093919293919090908F8C8D8E8E8F8C8E898C8A8C8988898687858383807F7C7C7A79
77747272716E6C6B6967656463625F5D5B5B5857565553504F504C4A4948464340413E3C
3C3A383736353332302E2D2C2C2B2A292928282728272727272727272727262627262627
2726262726262626
262625262626262626262626262626272627262726272626272626272727272727282728
28292929292A2A2A2C2B2D2F2F31323434373838393C3D3F3E3E4042444646474A4C4D4D
5051525355565757585B5B5E61606164636464656A6A6B6A6C6E70707072757474797779
7A7B7F7E7F80808184858688898A8B8C8D91949294969A9A9A9C9F9FA2A4A4A6A9A9ACAD
B1B1B2B6B5B8B9BBB9BDBDC0BCC0C1C3C4C5C4C3C3C2C3C3C4C5C4C4C2C4C2C4C4C1C3C2
C4C2C0BEBFC0C1C1C2BDC2C2C0C1C6C3C2C5C2C5C1C1BFC0C3C6C5C5C8C4C6CDCDCCCCCB
C4C8CBCDCDCCD0CFCECDCCC9CACDCED0CFD3CDD1D0CFCDCDCECDCBCDD0D1D0D3D2D1D3D4
D2D7D4D7D9D8D8DCDEDDDEDFE1E6E4E5E5E8E8E9E8EBE9E9EAEDEEEDEEEFECEDEFEBF1F1
F0EEEDF0EBEEEFEFEFEEEBECECE9E9E8EAE9EBE9EAE7E4E5E2E7E3E4E2E6E5E7E9EBE5E6
E5E5DEE2E2DFE0DEE0DBDBDBD6DAD7D7D4D3D3D2D4D3D2D0CFD0CECCC6C4C2BFBABBBAB8
B8B4B2B3ADAFAFAAAAA7A2A7A5A1A09F9A9A989997979494939494929194929291909292
8F91939190908E8C8F8E8D8F8F8B8D8F8D8C8A898A8A8788878486838381827F7D7D7C78
77767573716E6E6B6868666561615E5D5B595957555352524F4F4C4B4847454442423F3D
3C3A383736353332302E2C2C2B2B2A292928282828282727272727262727262726262626
2626262626262626
262626262626262626262626272626272626262626272626272726272727272727272828
282828292A2A2B2A2B2C2D2E30313233353637383A3B3C3C3E414143434546494A4B4C4E
4E4F52535455575A5B5C5C5D5F5F5E616365676868696B6C6C6D6F707173747576777878
7B7A7A7D7E807E80828384858889898D8F8E8F919392969499999C9EA0A2A4A6A8A7AAAC
AEB1B1B5B3B7B7B8B8BABBBDBDBEC0C2C4C4C4C1C4C4C2C4C3C5C2C4C3C4C1C3C6C5C4C4
C4C2C1C3BFC1C3C2C1C1C0BEC3C3C1C4C6C3C1C2C4C2C4C3C0C6C6C4C7C6CAC9CACDC7C9
C9CAC9C9CECCCBCCCBCCCBCFC8C8C7CECDCDCBCFCFD1CDD1D0CDD0CCCED0D4CFD2D6D3D3
D4D6D6D5D6D8D8D8D8DDDCDBE2E0E4E5E4E6E7E7E4E6EAE8ECEAEBECEBECEBECEAEDEBEC
EDF0EEEDEBECF1ECEAEFEAEBEBEBEBE9EAEBE6E7E9E4E6E1E2E2E5E7E8E4E5E7E9EBE6E6
E6E5E1E2E2E3E2E6E2DEE1DDD8D9D9D4D6D5D6D4D4D3D6D3D1D3D0CDCBC5C3C2BFBFBABB
BAB8B6B3B1B2ACAFACABA9A8A6A4A2A29D9C9E999696989594929591909292918E8F8F8D
918C9090908E8D8F8E8D8C8D8D8A8C8E8A8B898B8989888888868585838280817E7E7B7A
76757572706F6E6C6A67666462615F5D5D595858575451504F4D4C4B48474545423F3E3E
3B3A393635343232302F2C2C2B2B2A292929282828272727272727272727262627262726
2626262626272626
262626272627262626262626262626262626272626272627272727272727272727272828
28282929292A2A2B2B2C2D2E2F313134353637383A3B3C3E3E3E424344444648484B4C4D
4D50515254565658595A5A5C5D5E6161646464676768686B6B6F6E717172747577797979
78777A7A7F7D7F7E808281858686888A8A8D91909091969499999A9C9BA1A3A3A6A3A8AB
ACADAFB1B0B6B3B9B7BABABCBEBEBDC0C2C1C2C3C3C3C3C3C5C6C5C4C4C4C5C3C2C3C5C6
C4C2C3C5C1C1C2C2C4C3C2C1C1C2C0C1C5C4C3C3C6C4C0C0C4C4C1C3C5C9C7C6C4C6C8C9
C8CACACBCDCCD0CBCBC8CCCCC8C9C8C9CBCDCCCBD0D0CFD1CCCCCACDD1D1CED1D2D2D1D1
D3D3D4D6D4D6D7D9D9D8D9DEDFE1E2E3E4E5E7E8E5E8E7E7EAEDE9EAE9EBECEBEBF0EDEB
EBF1E9EFEBEEEBEBEDE8F0ECECE9EBECE7E8E9E8E3E5E0E5E3E6E8EBE7E8E8E9E9E7E9E8
E5E5E5E3E1E3E2E3E0E0DDDCDDD9D9D6D7D9D6D4D5D6D3D7D4D2D0CECAC5C7C4C1BFBCBB
BABDB8B5B6B6B2B1B0ADABAAA9A9A6A0A29F9B99979897969792919090929190918F8E8F
8C8E8C8F8D8E8C8C8D8C8A8D8A8C8B8B8C8A8A898988868784858685838281817D7E7B77
7875737072706E6C6B68666564605D5E5B5B5857565453504F4C4A494947444242403E3C
3B393837363433312F2E2D2C2B2B2A292929282828272727272727272626262627272626
2626262626262626
262626262626262626262626262626272726262626272727272727262727272727282828
2828282929292A2B2C2C2D2D2F303133353537383A3B3D3D3E3E40424344454748494A4D
4D4E505253535657585A5A5B5D5F6060606364656768686B6C6B6E707172737675777877
777A7A797C7E7C7E807F8180848686878B8B8D8C919193939796999A9D9FA09EA3A7A2A6
A8ACADB0B1B5B5B9B6B8B9BBBCBDBDC0C0C2BEC2C6C2C3C6C7C4C7C7C5C7C6C9C6C6C5C4
C3C1C6C6C2C2C4C4C5C0C1C2C2BEC0C2C1C3C2C1C3C4C4C3C2C5C6C4C6C6C5C6C7C7C8CC
C8C9CACCCDCBCCCBCAC9CAC8CAC9C8C9C9CBCACBCBCFCECECBCCCDCCCDCCCECFCFCFD3D1
D3D2D3D1D1D2D2D8D9D6D5DADBE0DDE1E3E0E0E2E4E6E8E9E7E7EAEBE5E7EBEAEBEEEBEC
ECEEECECEDEAECEBEBEBEAEEE6EAEBEDEBEAE7E7E7E4E4E4E7EAE9E9EDEBE9E7EBE9E8E5
E5E9E5E7E1E4E6E2E2E1DDDFDDDBDBD8D6D7D6D8D8D6D3D6D3D2D1D3D0CDC9C6C4BEBFC0
BDBDBBBAB7B6B8B3AFB2ACADAAA9A6A4A2A19F9D9999989992959291918E8F8E8E8E8D8E
8C8C8B8C8A8C8C8B8B8B8B8B8D8B8C8A8889878A8A88858785848385848381817E7D7A7A
757775737270706D6A696664625F5F5D5B595957555352504E4E4C494746454442403E3C
3B39393735343231302D2D2C2B2A29292929282828282727272727272727272627262626
2726272626262626
262626262626262626262626262626262726272726262626262727272727272727282728
2828292929292A2B2B2C2C2E2F2F3233353637383A3B3B3E3E403F414345454647494A4D
4C4F4F515252555657595A5A5C5D5E60616265666667686A6B6D6F6E7072747575777778
7878797B7D7D7E7D7D7F80808082838788888A8D8D8C9295979699989A9D9FA1A2A4A2A4
A4A9ACACADAFB5B5B6B7B9B8BCBEBDC0C0C0C4C2C0C3C5C7CAC9CAC9CAC7C6C8C7C5C5C7
C4C4C5C5C4C5C5C7C6C5C4C1C1C8C0C2C2C5C4C3C4C4C5C1C3C5C5C5C7C3C4C9C1C6C6C7
CBCBC8C9CBCFCBCAC9C8CACBCAC7C6C7C8C9C6CAC9CDCECFCCCECBCDCACCCECCCBD0CED0
D0D4D0CFD0D3D1D7D4D5D8D8D9DCDEDDDEE0DEE4E4E7E7E9E5E8E9EBE8EBE9ECE8E9EAEB
EBE6ECEFEBEBEFEEE9EFEAE9E9ECEDEEECECE7E5E8E4E2E7E6E6E7E8E7E5E7EAE6E7E7EA
E7E4E7E4E7E7E5E3E2E2DEDEDCDBD8DBDCD8D3D3D7D5D7D5D6D4D4D3CCCAC7CBC3C2C1C2
C0BFBEBBBAB8B4B4B6B0ADADABACA8A5A3A4A39F9D9A97989794919392928F918E8B8C8A
8A8B8B8B888A8B88898B878A8B8B898989888886878788878685848282818181817E7C7B
797776757372706C6A6A676663625F605C5B5857535451504F4D4B4948464444423F3D3D
3B3A383635343331302E2C2B2B2A2A292928282827272727272727272727262726262626
2627262626272626
252626262626262626262726262626262626262727262627272726262627272727272828
28282929292A2A2A2B2C2C2D2E2F313234363638393B3C3C3D3F3F414243454748494A4B
4C4D4E505253565558575A5B5C5D5D606164636565666A696B6B6E6E7171747777787979
7B7A7A7B7C7B7D7E7C7D7D7D7F8182848588898B8C8F9194949596999A9A9C9DA09FA4A6
A7A6A7A8ADAEB0B3B2B5B6B7B8BBBCBDBEC1BFBEBFC3C2C7C7C7CACACACAC7C6C7C8C8C5
C6C8C5C4C7C5C5C8C7C5C2C2C2C3C2C4C7C3C4C3C2C4C2C4C3C6C7C9C7C5C6C6C5C4C4C7
CBC7C7CBCCC9CCCAC7C8C8C9CAC9C8C7C5C7C7CAC6CACBCECBCBCBCDCDCFCACECACECECB
CFCECED0D0D1D1D3D3D7D4D5D6DCDDDEDEDCDFE4E3E4E2E4E5EBE9E9EBE6E7E8EAECEAE8
EDECEBEAEBEFEEECE9ECEDE9EAEBEDE8E5E8EAEAE5E6E8E8E7E6E4E4E4E5E5E7E3E5EAE9
EAE9E9E8E7E7E6E4E4E0DFDDDBDED8D7D7D9D7D6D7D6D9D9D7D6D5D3D1CDCBCBC4C5C3C2
C0C0C1BBBCB8B7B8B0B1B1B0ACADABA7A5A3A1A1A0A09D98969594918E8F8F8E8E8E8A8A
8B8B898A898A898785878888888987888587878785898785858384818281807F7F7E7C7B
787877777271706C6B6A68666464605F5C5A5B575553514F4F4D4B4A4846454241403E3D
3B393737353332302F2D2D2C2B2A2A2A2929282828282727272726272727272727262726
2626262626262626
262726262625262626262626272627262626262726262627272727272727272727272728
2828292829292A2A2B2C2C2D2E2F313234353637383A3B3C3D3E3F404242444647464A4A
4B4C4F4F515353555657595B5B5D5E5F60616262656666696B6D6D707072737679797879
787A7B7B7A7B7D7C7A7D7C7B7E7F818083868789888A908F9192959698999C9B9D9FA2A0
A3A6A7A9AAAAACAEB0B5B3B6B7BAB9BDBBC0C0BEBFC1C1C4C6C7C6C9C5C7C8C9C6C7C7C7
C7C5C7C8C5C7C7C4C5C5C4C5C5C6C2C4C5C6C5C2C6C3C3C2C4C7C8C9C6C4C8C5C2C5C5C7
CBCBC7CBC9CBC9CECBCCC8CAC7C6C7C8C8C9C6C5C8CBC6CBC8CCC9CAC9CECDCECBCCCECD
CCCECECFCFD0D1CFD3D4D3D4DBD7D6D8D9DBDCE1E3E1E1E4E2E3E3E6E4E9E8EAE8E9E9E8
E9E9E5EBEDEAEBEBEDECEAE8EAEAE8E9EAE7E6E8E4E9E7E8E7E5E3E4E0E3E0E3E3E5E5E5
E8E9E6E4E6E7E6E5E1E1DFDEDCDCDAD9D9D9D6D9D8D7D7D4D8D2D6D3D0D2CDC9CAC7C0C6
C0C1BFBEBBB9B9B7B4AFB0B1ADB0ADACA6A7A5A2A09E9E9B9896969394928F8D8C8A898A
8A898A8987888986878585868786878685868587868683848483838282807F7E7E7F7D7A
7B7A757674736F706E6A68676662605F5C5C5A57565353524E4D4A494846444240403E3D
3A393936353333312F2D2D2C2C2A2A282928282828272727272727272627272626262626
2626262626262626
252626262626262626262626262726262627262727262627272727272727272727272828
2828282929292A2B2B2B2C2C2E30313334353637393B3B3D3D3E3E40424344454648484B
4C4B4D50505153535456595B5C5C5D5D5F6364636565666A6A6C6E6F71717576797A7A7B
7A78787B7B7B7A7C7D7C7A7A7B7D7D8181848586868A8C8E8F90939796989B9A9C9FA0A2
A2A5A4A7AAAAA9ACB1B0B0B4B7B6BAB9BABEBFC1C0C1C3C4C3C6C6C6C5C5C9CBC9C9CACA
C7C8C9C8C7C6C6C7C8C5C7C7C2C3C5C4C5C4C4C5C3C3C0C2C4C4C6C6C6C4C3C5C6C4C8C9
CDC9C8C7C7CBC9CACCCDCBC9CAC5C7C9C9C8C3CAC9CDC8C7CAC6CACCCCCFC8CDCBCCCACB
CCCECFCED2D1CFCFCFD2D0D3D5D2D6D9DAD9D9DAE0E1DFE2E3E4E3E3E2E3E6E5E4E7E9E8
E5E8E8EAEEE9EAEDEBEDEDEBE6EBEAEAE9E6E3E6EAEAE7E8E8E7E1E4E0E3E3E0E4E5E4E7
E8E8EBE6E3E3E3E0E3E1E0E0DEDEDDDAD9D9D5D7D4D8D5D4D5D5D3D1D1D2CFCCCCC8C6C6
C3C1BDBDB9B9B7B4B3B3B0B0B1ACAAAEAAA8A4A2A19E9D9A9999959591918E8F8C8B8B8A
888889888688868686858484848686868786868483868485828281817E807F807D7E7D7B
787878757372716F6E6B6A66646460605C5C5A58555351504F4D4B4A47454442413F3E3C
3A3A3737343332312F2D2C2C2B2A29292928282828272727272727262627272727262626
2626262626262626
262626272626262626262626262626262626262627272626272627272627272727272728
282828292929292A2B2C2D2D2E2F31313334363738393A3B3D3E3F3F424246464747494A
4A4C4E4F50525156555757595A5B5C5E5E62626365666469686A6C6D6F717175797A7D7B
797C787A797B7A7A7A79787B7C7E7C7E82838386858A898E8F91919496969798999B9C9F
9EA2A3A4A5A9ABAAACADB1B2B4B4B7BABDBDBEC0C1BFBEC3C2C5C5C2C7C6C7CAC8C7C9C7
C8CAC6CCC6C6C5C5C6C5C8C6C4C5C3C5C4C6C2C4C2CCC5C3C1C8C3C6C5C8C7C6C4C9C7CE
C8CAC8C7C9CDCACCCCCBCEC9C7C7C8C9C8C6C4C7C8C7C9C8C4C8C6CBCAC9CBCBCCCBCCCB
CCCDD0CECCCFCFCFD1CFD0D4D4D6D6D6D9D9D9DEDFE0E0DEE0E3E3DEE2DFE7E5E4E7E8E6
E9E6E9E8E9EAEBEAE7E9EBEBECE7E8E7E6E9E8E7E9E6E8EBE6E4E3E5E2E1E2E5E4E5E8E4
E6E1E8E4E4E3E2E3E6E2DEE2DFE1DEDDDDDBD8D6D7D8D7D5D2D4D2D2D2D1CECECAC9C7C6
C4C1BFBABAB7B7B8B6B2B1B0AEAAACA9AAA6A4A1A0A09D9B9B98969492928C8C8F8C8A88
8787878485858384838383828584818183828484838382828182828080807E7E7D7D7A7B
797A7775737373706E6C6967656461605D5E5A59555552514F4E4C4A4846444241403E3D
3A393737353432302F2E2D2C2B2A29292829282728282728272727272627272626262627
2626262626262626
262626262626262627262726272626262626272626262626272727272727272727282828
28282829292A2A2A2B2C2C2D2D2E30323234373738383A3B3C3E3F40414244454647494A
4B4D4D4E5051535455565859595B5B5C5F5E62626463676767696B6D6D70747578797A79
7B7979777A7B7B7B7A797B7A7C7B7D7D808183838487898B8C8E8F949295969B9A9B9C9F
9FA2A1A0A3A6A9AAACAEB0B1B2B2B4B6BCBBBCBEC2BFC1C0C0C2C2C5C4C4C4C7C9C9CCC9
CACCC8CCC9C9C7C7C8C7C4C9C5C6C6C4C6C5C7C8C5C6C4C3C6C5C6C3C7C9C9C9CAC9C8CA
CAC7C9C5C6CAC9C9C9CAC8C5C8C8C9C8C5C6C9C8C8C8C8C5C6C6C7C7CACBCBC8CCCDCDCD
CFC9C9CDCDCED0D1D1D3D3D0D0D3D1D4D5D6D6D9D9DADDDFDFDFE2E0E2E3E1E6E2E5E7E6
E6E6E6E8E8E8E9E9E7E9EAE8E9E8E5E8E7E7E7E9E5E7E6E9E8E5E3E5E5E6E7E2E8E6E6E2
E2E4E6E7E1E4E5E0E3E1E2DFE0E7E0DEDBDCD8D8D6D9D4D5D7D3D6D3CFD1D0D0CCC9C5C3
C5C0BEBBBCBCBCBAB8B7B4B3AFACAFACABA7A6A4A09DA09B9C9A9994959190928D8B8A89
888884848383838484817E8381808281818483808181828181827F7F807F7D7F7C7B7C7A
77787777747372716E6C6C6A66636260605D5A58565452514E4D4B4948454542403F3E3B
3A393737353332312F2D2D2C2C2A2A292928282827272727272727272727272626262626
2626262626262626
262626262626262626262626262626272626262727272627272727272727272727272728
2828292928292A2A2B2B2B2D2D2F31313335353737383A3B3C3D3F40424343474547494A
4A4C4E4E504F5153555657595A5C5B5C5D5F61626264656667676A6B706F6F7276787978
7879797879797B797B7C7A7B7A7D7F7C7F807F8384848788898A8E8F92949797999B999E
9F9E9FA3A4A5A9AAAAACABADB0B1B3B5B7B8BBBCBCBDC3BEC1C0C0C2C4C3C5C6C9C9C8C9
C9CAC9C8CBC8CBC9C8CBC7C8C8C7CAC8C7C9C6C5C6C4C5C4C2C5C3C3C6C6C8C9C7C8CBC7
C4C6C7C6C6C8C7C8CACAC8CACCCACAC9CAC7C9C6C7C4C6C4C7C4CAC8C6C8CACBCACDCDCD
D1CCD0CDD0CFCDCDCFD0D1D2D2D0D3D3D3D8D6D6D9D9DDDCDDDDDFE3E3E0E3E2E3E1E6E3
E5E1E9E5E6E8E7E7E8E8E9EBE7E9E7E4E5E7E5EAE6E7E9E6E5E5E5E5E9E8E6E9E7E7E5E6
E4E5E6E4E2E3E3E4E1DFE2E3E5E3E2DFDED9D8DADAD8D5D4D7D4D4D2D1D0D4CFCBCDC9C7
C7C5C1BEBFBFBEBEBAB3B9B3B1AFAEAFAFAAA6A3A2A29F9D9A979696939291928C8B8B89
878687848383818181827F8180807F807E80818081818282807F7F807F7D7E7C7B7A7A79
79787476757372716F6C6B6866646361605C5C5958555352504E4D4B4746444341403E3B
3A383736343332302F2D2C2C2B2A2A292928282827282827272726272726262627272626
2626262626262627
262626262626262626262626262727262726262626272626262627272727272727282828
2828282829292A2A2B2B2C2C2D2E3032333535373739393B3C3D3F3F414243454649484A
4A4B4C4D4F52515354565557585B5B5D5D5E5F616361646666676A6B6C6C6F7374777776
7677787877797A7979797B797A7B7B7D7D7E80808184868687898F8E9092959398989B9C
9B9F9D9EA2A5A7A8A8AAABACAEAEAFB3B6B9B9BBBCBFC0C0BDC2C3C3C1C5C3C5C7C7C7C6
C8CCC9CBC9CDCACAC8C8CACCCBC9C7C6C4C5C6C8C5C3C5C7C5C3C2C6C7C5C7C5C8CBC9C8
C8C6C5C6C6C7C5C8C5C7CAC7C5C9C7C7C9C8CAC8C5C6C3C6C6C7C7C9C6C5C8C7C8C9CBCA
CCCCCDCECDCCCED1CDCCCED0CFD2D2D1D2D2D2D4D9DAD8DADDDCDDE1DDE0E3DFE2E1E1E5
E1E6E6E6E7E6EAE6E9EAE6EBE8E9E8E9E8E5EAE8E9ECE4E6E4E6E7ECE9E8E8EAE7E6E7E4
E2E4E5E7E1E2E2E5E0E4E5E2E3E2DFE0DEDCDBD8D9D8D9D7D6D2D6D4D2D3D4CED0CDCCC8
CBC6C5C0C2C2BFBEBFBCB8B6B6B1B0ADADAAA8A3A3A2A09F9E9B9897959692908E8D8889
858783848384808282817E807E7E7E7F7F7E7E7F7F81817F81807E7F7D7E7D7C797B7979
79787475747271706C6C6C6C67666360615F5D5B575555514F4E4C4B49464341413F3D3D
3A393735353333312F2E2D2B2A2A29292928282828272727272727272726272626262627
2626262626262626
262726262626262626262626262626262627262726272726272627262627272727272728
2828292929292A2A2B2B2C2C2D2F3031333435363738393A3B3C3F40414243444446484A
494C4E4E4F5151525357555758585A5C5D5E6061626565656668696A6C6E6F7072727273
75767677787778797A7A7B7A7A7B7D7D7E7E7E818281828388898A8C8C8F909197989B99
9C9C9FA19FA2A3A5A7A9A8A9A9AEAFB3B4B4B7BCBAB8BBC1C0C2C2C6C4C5C6C6C9C7C9C7
C7C8C9C8CACACBCAC8CAC9CBCCC8C9C9C7C7C8C7C6C7CAC5C4C4C2C2C4C3C5C4C6C5C8C4
C8C4C5C7C6C4C8C6C7C8CBC7CACACECACCCAC9C9CBC4C4C2C7C8C5C7C8C5C7C7C8C9CCCB
C9C9CDCCCECBCECCCCCDCBCECECED0D2D2D1D7D6D3D4D6D6D5DBDBDCDEDFDFE2E3DDE1DF
E4E1E8E5E5E6E6E5E5E8E7E8E7EBE7E8E8EBE6EBE6E5E8E8E8E5E9E4EAE6EAE7E8E6E4E6
E3E5E4E5E5E2DFE1E3E1E4E2DFE6DDDFDDDBDDDBDCDBD7D8D7D6D5D3D5D4D1D6D3CFCCCC
CAC5C5C3C4C5C4C2C3BEBCB8B5B4B3B4ACACACA8A7A5A09F9C9C999895949391918D8C8A
898785858181817F807F7F807E7D7D7E7E7E7E7F7C7F7C807C7F7D7C7C7E7C7979797979
777674777373726F6E6C6B6867626462605F5D5B58555450504D4C4A4846454241403D3B
3A383736343332302E2E2D2C2A2A2A292928282828272727272727262726262626262627
2626262626262626
252726262626262626262627262626262626262627272727272627262727272727272728
2828282928292A2A2A2B2B2C2D2F3031323435353637383A3B3C3E3F4041424445454949
4B4C4D4D50515353545556565759595B5B5F5F6262636565666768676B6C6E6E71717374
7375757676777A7B7A7B7B7C797B7B7B7D7D7E8081828384848688888B8D8F9294979598
999C9C9C9FA3A2A3A2A5A7A7A9ABADAFB1B6B6B7B5BAB9BFBEC1C2C1C5C3C6C7C5C7C7C8
C8C8CAC9CCC7CBCBCBCACCCBCAC8CAC8CBC9C5C6C7C9C7C7C6C5C5C3C5C4C6C4C9C7C4C7
C5C7C5C6C6C8C6C5C6C9C6C8C9CBC7C6CBCACCCAC8C8C6C6C7C6C6C7C4C4C8C8C7C8C8CB
CAC7CDCDC9CDCDCACCCDCCCBCDCFCFCECFD0D0D2D3D4D1D3D7D5DADADEDEDCE1DFE2DDE3
E1E2E3E4E5E4E3E5E3E7E3E5E7E8EDEBEAEAEBE8E7E6E6E6E9E7E5E5E4EAE8E7E6E4E3E2
E3E3E2E3E4E2E2E2E3E4E0E1E2E1E1E1DEDEDEDDDCDAD8D7D7D6D3D5D2D3D4D5D1D0D2CD
CACACAC6C7C7C6C6C3C3BBBBB9B5B1B2B1ADADABA6A7A3A0A09E9A989B969491918E8D8B
89888586868182817E7E7D7F7C7C7B7C7D7C7D7D7C7C7D7C7D7C7D7F7D7A787C79787877
777674737373706E6D6D6B6966666363615E5D5C58565452504F4C4C48474343413F3E3C
3A383836343331302F2D2C2C2B2A2A292928282827282727272727262727272626262626
2626262626262626
262626262626262626262626262626262626262726262626262727272627272727282728
272828282829292A2B2B2B2B2D2E2F31323434363637383B3B3C3E3F4041424446454749
4A4B4C4D4F5151535654565758595B5C5D5E5F6261616564666567696B6C6C6C6D70716F
727474767876797A7A7B797A7A7C7A7A7C7C7F7F8182828282848089878B8D8E8F909396
93989C9C9EA0A1A2A2A5A7A6A6A9AAABB1AFB1B3B6B9BABCBDBDC2BFC0C4C2C2C4C4C4C4
C9C8C8CBCACBCCC7C7CBCCCBCCCCC9C9C7C9C9C8C6C6C9C9C9CAC6C8C6C2C7C5C6C5C8C4
C5C8C7C6C6C9C6C8C6C9CAC5C6C7C7C6CBCACAC8C7C7C5C5C3C9C7C6C7C8C9C7C6C7CBC8
CAC9C9CACBCACAC9CBCBCECDD0CDCED1D0CFD2D1CDD1D0D0D3D5D6D7D8DADBDBDDDFE1DE
E0E0E3E4E6E2E5E3E3E2E5E6E6EAE9E9E8E5E5E8E7E8EAE7E8E6E6E6E5E8E7E6E3E4E2E1
E4E2E4E2E3E3E0E2DFE3E2E6E4DFE4DFDBDDD9DCDBDBDBDAD8D7D5D2D3D4D3D5D1CED0D1
D0CCC9C6CCCAC8C8C6C3C1C0BDB9B8B6B4B0AFACA8A5A6A4A0A09D9A97979494918E8F8A
8A89878483828281807F7F7E7B7E7B7E7B7C7B7B7A7A7B7B7A7C7B7C7B7B7B7978797777
757674757271706E6F6B6A6869666462615F5E5D5A585553514F4C4C48474542413F3E3C
3A383835343231302F2D2C2B2B2A29292928282827272727272727272627272626272626
2626262726262626
262626262626272626262626262626272626262627262626272727272727272727272728
282828292929292A2A2A2C2C2D2E3031323334363637383A3B3C3C3F4040424344454848
484C4C4D4E5053535453565759595A5A5D5C5D5F5F62646365646668686B6A6A6C6F6E6F
6F747375767977787B7A7C7C7D7B7B7C7C7D7D7E7D818282818384858788888B8E8F9194
959597989B9C9E9FA3A4A6A7A4A7A8AAACB0B3B1B3B4B8BABBBEBCBFC2C1C2C2C3C2C5C6
C8C5C9CDCCC9C8CACCCDCACCCDCDCACCC9C9C7C7C8C9CACACACACAC9C9C9C5C9C7C6C5C8
C7C6C5C7CAC9C9C6C7C7C6C7C5CAC6CACACAC7C9C4C4C8C6C7C8C8C9C9C9CBC9C7C7CBC9
C7C7C9C9CACECACECDCCCBCCCCCECCCDCFCFCECFCFD0D1D0CED5D4D8D7DADDDCDEDBDEE2
E4E1E1E1DFE2E3E3E2E6E2E7E5EEE9E7E7E4E3E5E6E7EBEAEAE9E5E8E4E6E6E8E6E4E7E5
E3E4E4E4E5E4E3E0E3E3E1E3E1E3E3E0DFDDDEDDDADEDCDCD8D5D6D4D5D5D2D2D0CFCAD2
CCD2CDC8C9CCC6C7C6C5C2C3BDBDBBBAB8B3ABADAAABA8A6A59F9A999A979496908F8D8C
8A8A878584828181817D7C7D7C7C797B79797A797B79797979797C7A797A777877777676
7576737371716F6E6C6A69696866646261605F5C5A595753534F4E4B49484544413F3D3B
3A383636343231302E2D2B2C2A2A29292828282827272727272627272726272627262727
2726262626262626
262726262626262626262626262626262626262626262726262727262727272727272828
2728282929292A2A2A2A2B2C2C2E2F3032333536363738393A3B3D3E3F3F424344454747
4A494C4E4D4F51525355555757595A5B5D5C5D5F606062626466676867696C6A6C6B6D6D
6F72717275767577787A797B7C7B7C7D7D7C7E7E7F81818182848484878687898B8B8E90
909598989C9D9C9D9FA3A3A3A4A6A6A8AAAAACADB0B0B4B8B6B9BBBEBEBEC1BFC3C4C5C5
C5C6C8C8C7CBCCCBCDCCCCCCCCCDCAC9C8C9CBCACBC8C9C8C9CDC9C7C8C8C5C7C9C8C6C5
C8C6C7C6C9C6C7C8C8C8C7C7CAC6C6C9C7C9C6C8C6C5CAC8C5C5C9C5CBC6CBC6C9C9C7CA
CBC6C6C7C8C8C8C8CDCACCCCCDCDCECDCCCECDCDCED0D0CBD1D1D7D6D6D5DBD9DCDBDDDC
DCE0DEE0DEDFE1E1E2E1E3E3E3E5E7E5E7E2E3E3E7E9E8EAEAEAE8E4E5E4E3E4E8E4E5E5
E5E3E4E2E4E4E4E6E0E4E2E3E2E3E1E1E1DFDEDADFDFDED8DBDBD8D9D6D6D4D1D2D0CCCE
CFCECFCCCBCBC8C8C7C3C6C3C2BFC0BCBAB5B3AFAEABADA8A5A29E9D9D98979490918D8A
8B8B8886838582807F7F7D7A7B7A7B797A797A7A77797979777877787977777677757473
737273727070706B6C6B696865666363615F5E5C5B57575453514E4C4B474543403F3D3C
3B383635343330302E2D2B2B2A2929292928272728272727272727272727272626262726
2626262626262626
262626262626262626272626262626262726262626262627272727272727272727272727
28282828292929292A2A2B2C2D2E2F3032333436363638383A3B3D3E4040424344444647
474A4C4C4F4E505252525557575A595B5B5C5D5F5E6063636362626566696A6B6A6D6C6B
6E716F71737375787678787A7B7D7F7C7E7F7B7E7C7C7F80818182848585858785888D8E
8F9395969C9A989B9F9D9FA3A4A4A7A8A5A9A9AEB0B1B3B2B5B7B9BABABABBC1C0C1C4C5
C8C7C3C7CDC9CBCBCBCBCACCCDCECACBCACCC9C9C9C9CAC9C8C7CAC8C9C5C6C8C7C7C5C6
C5C8C7C6C6C5C6C6C5C9C6CCC7C8C7C7C6C9CAC9C8C7C7C6C5C8C8CBC6CAC6CAC9C8C9CA
C9CAC9CBC9C8CAC8CCCDCACACDCECCD0CECECFCDCDCDCBD0CED3D0D1D6D8D6D7D9D9DADB
DADCDEDEDFE1DEDFE0E0E1E4E2E5E3E6E5E2E5E2E7E7E4E9E9E8E5E5E4E7EAE9E6E5E8E6
E4E5E5E5E5E0E3E5E1E2E4E5E0E2E2DFDEE2DBE0DFE0DEDEDADAD8D6D7D8D4D5D2CED1D1
D0D0CFCECACCC9CAC7C7C4C4C5C3C1BBBCBCB4B4B0ADACAAA8A3A1A39C9999979191908D
8E8B8987868583827F7F7E7A797B787A7878777777767677777879787877767675747473
7371716F706F6E6C6A6A6A6767656561605F5E5D5A58565452514F4C4B4A4643413F3E3C
3A3836353432312F2F2D2C2B2A2A29292828282827272727272726272726272626272627
2626262626262626
262626262627262626262626262626262626272626272726272727272727272727272827
272828282929292A2A2A2B2C2C2D2E303133343536363939393C3C3E3E40414343444647
49494B4C4E4F4F51525254555759595A5B5C5B5E5F5F63626264646466696B6C6D6D6D6E
6E6E7070717375747577787B7B7D7D7D7E7F7F7F7C807F81808381848485878788888B8B
8E8F939595979A9D9B9CA1A1A1A3A5A3A5A7A8AAACACAEB2B3B5B4B6B9BABDC0C1BFC4C3
C5C6C5C5C8CACBCBCFCCCDCBCCCAD2CCCBCCCACCCACBCCC8C8C8C5CAC7C6C9C5C8C6C8C5
C7C5CAC8C6CAC5C4C7C9CACACAC7C7C5CAC5C8C6C5C7C4C4C6C7C7C5C7C8C9C9C8C9CACA
CBCACACAC5C6C5C4CBCACAC8CCCBCCCBCACBCACBCBCECDCBCECFD4D0D2D1D4D4D5D7D9DA
D9D9DFDBE0DCE2E1E0DFDFE2E4E2E5E4E5E5E4E8E7E4E6E7E8E7E6E6E3E7E5E5E4E8E6E8
E8E5E6E5E2E3E5E0E2E5E0E4E3E3E1E1E4E1E0DFE2DEDEDADCDBD8D9D6D7D8D4D5D1D0D2
CFCED0CCCBC7CAC7C8C6C7C4C4C4C3BEBEBBB8B6B5B3AFABA8AAA4A0A09C9B989795928F
8A8C898787838481807F7E7C7C7A7C777777797575757576777676757674747473737472
717271716F6D6D6B6B6968676664626160605C5B5B58565352524E4E4A494644413F3F3C
393937353332302F2E2D2B2B2A2929292928282827272727272727262627262726262626
2626262726262626
262626262626262626262626262626262626272626272727272627272727272727272728
272828282929292A2A2A2B2C2C2D2E3031333434363737393B3B3B3D3F40404144454748
48494A4B4E4F4F5151525558575B5A595A5A5C5D5D606161626363646669686E6C6D6C6E
716E6F72717272727575747A797C7C7D7E7C7D7D7E7E7E7F818180818283868687898888
8D8C90919596959B999A9CA1A1A0A2A3A4A8A6AAABABAAAEB0B2B3B5B6B9B9BEBEBEC4C2
C6C6C6C7C6C8C9CBC7CBCCCECED0CCCCCECBCECBCCCBCBCDC9CBC9C9CBCCCAC7C8C9C8C9
C6C9C7C6C6C6C5C4C5C6C9C9C9CAC7CBC6C9C6C5C8C6C7C6C8C8C7C9C9C7C9C8CAC8C7C5
CAC9C5C6C6C5C6CACDCDCACBCACDCCCBCCCBCCCAC9CCCBCECECECFD0D1D4D3D2D4D9D8D6
DBDADADCDEDDDCDDDDDCDEE4E0E4E6E7E1E7E6E7E3E5E3E6E5E7E7E8E5E6E8E6E5E7EAE5
E7E9E5E3E3E7E2E6E4E1E5E4E2E4E3E0E1E2E1DEE1E2DFDCD9DED8D9DBD9D6D5D4D4D2D2
CFCFCDCECCC9C9CBC7C7C4C3C8C7C3C0BDBBB8B7B4B6B1AFA9A8A7A39E9D9C999894928F
8E8B8987878783837F80807E7D7979787878757775767576777373747475757275747170
7171706F6E6B6C6A6B67676764636161605D5C5A5957565353514F4D4B49464442413C3B
393836353331302F2E2C2C2A2A2A29292928282827272727272727262627262726262626
2626262726262626
252626262626262626262726262626262626262626262726262627272627262727272827
272728282829292A2A2A2A2B2C2D2E3032333335363637393B3B3B3D3F3E404143444446
474A494D4C4F4F505152535554585758595B5C5C5D5E6062606363666468696B6A6F706F
6F6E6E7071747373747473767A7B7B7E7C7E7E7C807E7F7E81818381818481838685878B
8B8C8B90919596979A9C9D9B9E9EA0A3A3A4A7A7A9ABACADADB0B3B3B4B6BBB9BEBFC1C3
C0C4C5C7C7C7CAC8C7C8C8C9CBCDCFCFCECECCCECCCCCACCC9CDCBCCCACBCBCCCBCBC6CB
C8C7C8C9C7C9C6C8C5C8CAC8C9C8C8C9C8CAC7C7C7C8C4C3C9C8C7C8C6C6C9CAC9C6CAC9
C7C6C6C5C8CAC9CAC7C8CBC9CAC9CBCECDCBCBCDC8D2CBD0CCCFCDCBD0CFD3D2D4D5D4D7
D6D9D8DADCE0DEDEDFE0E3DCE3E4E5E6E7E7E8E5E8E4E7E7E5E4E6E5E9E8E4E4E5E9E6E8
E7E8E6E8E5E3E7E4E5E4E5E1E2E7E2E2E4E2E0DEDBDFDCDEDADDDCDBDAD6D7D7D3D7D2D3
D3D0CFCBCDCDC8C8C7C5CBC9C7C3C3C3C1BDBCBCBAB4B0B0B0ACABA8A3A19F9A9B979492
8F8B8C8A8888838582807F7E7B7B7B797877767677767674747372727271717371717070
6E706F6D6D6C6A6A6867676564636161605D5C5A5856555251504E4D4A4A464542403D3B
3A3737353332302F2E2C2C2A2A2A29292828282727282727272727272626272627262626
2626262626262626
252626262626262626262626272626262726272726262626272727272727272727272727
2828282828282929292A2A2B2B2D2E2E3032333535363839393B3C3D3E3F414043434546
474A4B4A4B4F4E505152535556575758585B5B5D5B5F6062616362646665686A6A6E6D6E
6E6D6F6F727372747474747377797A7A7D7C7E7E7D807F7F817E82818181838486848688
8C8D8C8E8F949497979A9B9D9C9FA0A3A2A3A6A5A8ABAAABB0ADAFB3B2B3B8BCBDBEC1C1
C3C4C2C2C5C4C7C7C5CAC9CAC9CECBD0CDCBCCCDCDCECACACCC9CACDCDCAC9CDC9CAC8C7
C8CAC8CAC8C7C6C5CBCACCC8C9C9C7CBC7C9C8C8C6C6C5C7C5C9C9C7C4C7C6CAC8C7C5C7
C9C6C5C7C8C7C5C7C7C8C8C5CAC9CDCDCDCBCACBCBCCC8CCCCCDCED0CCCDCED0D4D4D5D6
D8D7D9D7D8DBDCDEDEDDDFE0E1E0E1E7E3E8E9E7E7E6E4E4E4E2E4E6E7E5E7E4E2E5EAE8
E6E5E3E6E5E7EAE5E5E4E0E2E2E1E3E3E4E2E3E2DEDDDFDDDCDEDBDCDBD8DAD9D6D6D3D4
D1D0D1D0CBCDCBC8C7C9C8C7C5C4C3C3C3C2BEBBBBB6B4B4B2B2ACA8A5A2A09F9E9C9794
918F8D8A8A86878683817F7F7E7D7B7779757674777774737372717071726F737071706E
6E6D6C6A6B6A6A69686765646463605F5D5D5B595857545352504E4C4C484645423F3E3C
3A3836353333302F2E2C2C2B2A2929292828282827272727272727262627262726262626
2626262626262626
262626262626262726262626262626262626272726262727262727262627262727272727
2728282828282929292A2A2B2C2D2D2F3030333436363738393A3C3C3D3E404142434546
47484B4B4C4D4F515052535555565858585A5C5D5F5E5F6061646264676566676B6A6C6C
6D6D707072737172737474747677797A7C7B7C7D7D7C817F807F7F818181838285858487
898A8C8B8C8F9091939596999C9BA2A1A3A1A5A5A6A6A6ABAAABAEAFB3B5B3B8BBBBBCBE
C0C1C3C2C6C4C8C4C5C7C9C9CBCDCECFCBCED0CDCDCBCBCDCDCDCDCACCCBCBCCC9C9C9CB
C8C9CBCACCC8C6C9C7CAC9CCC9C7C9C8C6C6C6C7C8C9C7C3C6C8C9C3C8C8C8C6C7C3C5C9
C5C7C8C5C5C6C3C2C4C5C8C6C9C8CACDCACBCAC8CDCCCDCDCDCBCCCFCECED0CFD3D0D1D4
D4D5D6D7D9DADBDDDCDAE1E0DFE1E0DDE5E2E7E7E5E5E5E2E4E2E4E5E5E7EAE4E5E5E5E6
E6E5E7EAE9E6E6E5E4E2E5E2E2E1E3E4E4E2E3DFDCDDDDDFDFE0DDDADADBD7D6D9D8D6D4
D3D0D0D2CDCCCDCAC9C9C7C8C8C3C2BFC5C2C1BBBCBAB9B5B3B0AEA9A8A7A49C9C9C9795
93918E8D8A8A8A868482817D7D7A7A7B7976767974747574717371717070716D6F6F6F6C
6F6B6B6C69696A686666646261605F5D5D5A5A5857575453514E4E4C4B47464341403D3B
3A3835353332302F2D2C2B2B2A2A29282828282827272727262727272727262627262626
2626262626262626
262726262626262726262626262626262626262626272726262626272727272727272727
2727282828282929292A2B2B2C2C2E2E3032333435363737393A3C3D3E403F4042424546
4749494A4B4E4E514E52545354545759595B5C5C5D5D5F5E616262626565666E67696B6B
6C6D6F6F71717273727172757677797777797C7B7E817F80817F80807E80828084868687
858788888B8C8F91909696959C9E9E9E9FA2A2A5A4A8A6A8A7ACA9ADAFB0B2B4B9BDBCBF
BDC4C2C2C0C4C6C5C6CAC7CACBCCCCCBCBCECCCDCCCECDCDCACECCCECFCCCBCECDCCCAC7
CEC9C9C9CCC7CACAC8C9CDD4C8C5C5C8C5C5C6C6C6C8C7C6C5C8C4C6CAC5C7C8C5C6C2C6
C4C2C3C4C4C6C7C5C5C6C3C7C9CACBCCCACBCACDCCCDCCCDCECFCCCDCBCBCFCDD0CFCFCF
D0D4D5D8D5DAD9DEDCDDDDDEDFDDE2E1DCE4E3E5E5E2E3E3E1E2E4E6E5EBE6E6E5E7E5E4
E8E6E5E5E8E8E9E7E6E1E3E2E0E3DFE5E3E0E5E0DBDCDCDCDEE1DEDDDCD8D9D9D9DCDCD7
D6D6CFD0CECDCDCBCACBCAC9C5C9C3C3C1C3C0C2BCBEBAB9B3B1B1ABA9A7A4A29E9F9B97
959390908B8A8885848183807D7F7B7A797875767274757070717070706F6D6E706E6C6D
6B6C6A69696867666565636361605F5C5C5A5A585953545451504D4C4B48464342403D3C
3A3836343332302F2D2C2B2A2A2929292928282827272727272726262627262626272626
2626262626262626
262626262626262626262626262627262626262626272727262627272627272727272727
2827282828282929292A2A2B2C2C2D2E2F3032343435373739393A3D3D3F424141434447
4847494A4B4C4D4E50525352565657585A5B5B5B5D5D5D5F60616363656467696769696A
6C6C6D6D7170717271737275787878797A78797B7E7F808180818082817F807F81838283
87858889888B8D8B8E9391979B99999B9BA1A0A4A3A3A5A6A7A7AAA8AEAEB3B4B5B5B8BB
BCBBBBC1C1C3C0C5C4C6CAC7C9CACAC7C9C9CBCECDCECDCBCDCDD0CCCACDCDCBCBCCCDCC
CDCBCBCBCBCBCCC8C8C9CCD1BDC2C7C9C5C7C6C5C7C7C7C7C8C5C5C6C5C5CAC8C9C5C6C4
C3C3C2C4C8C4C6C6C4C6C6C8C6C7C9C7CAC6C9CCC7CBCDCDCCC9CFCDCFCECBCFCECFCCD2
D3D0D6D4D6D5D6D5DADADDDDDFDADCDEDCDDE0E4E4E4E2E2E4E4E4E5E5E6E3E0E5E2E4E6
E5E5E8E4E5E3E6E8E5E1E4E2E2DDE0E0E0E0E2DEDFDDDFDDDEDADCDBD7D7D8D8D7DBD8DA
D6D3D1CFD1D0D0CFCECCCBC8C8CAC6C5C1C4C3BFBFBBBEBBB7B7B3AEAEA7A7A4A2A09D9A
98969392908B8789858E83807F7D7C79787978757673757272706F7170706E6E6C6C6B6A
6B6A6B6868646663646362615F5E5E5C5B5A595756565352504D4E4C49484443413F3D3C
3A38353533312F2F2D2C2A2A2A2929282828282727272627272727272627262626262626
2626262626262726
262626262626262626262626262726262626262626262627262627272727262727272727
27282828282828292A2A2A2B2C2C2D2E2F31323335353638383A3B3C3D3E3F4241434345
464847494C4E4E4E505153535455565859595C5B5C5D5E5E61606362646466676568696A
6B6C6E6E6F6F6E717072757573777979787A7B7B7C7F7F7E81807E8080817F8382808586
8786858789898B8E908E9195969799989B9C9DA2A2A1A4A6A1AAA5A9ABADAEB0B5B2B7B8
B6B9BBBDBDC1C2C1C2C4C6CAC8C9C9C5C8C8CCCECECECBCFCBD0CED0CDCCCDCACCCCCBCA
CBCDCCCACBCACBC9C7C7C7C6C3C5C7C7C8C7C5C5C8C5CBC9C8C6C2C3C1C6C6CAC7C7C4C5
C1C2C2C3C7C4C6C7C3C6C3C4C5C5C4C7C7CAC8CBCACBCDCBC9CBCBCCCBCBCECECFCFCECF
CDCFCFD4D6D5D7D9DDDADBDCDBDCDFDCDADEE0E0E0E2E2E1E3E6E1E5E5E5E3E2E2E4E5E5
E5E6E6E3E2E7E5E3E2E3E4E5E0E2E1E0E0E2E4DFDEDDDEDCDCDADBDADADAD8DBD7DBD7D5
D3D3D7D5D3D0CFD2CCC9CAC6C9C6C7C5C3C2C1BEBEBEBDB8B9B5B3B3AEABA9A8A5A29F9D
999796928E90898B86878383817E807E7B7A7778777373727170706F6E6D6D6C6B6C6A6A
6A686867666664636361605F605E5C5C5B5A5856555354504E4E4C4B48464543413F3D3C
3A3736353231302E2D2C2B2B2A2A29292828282727272627272726272627262627272626
2626262626262626
262626262626262626262626262626272626262626262626272727272727272727272727
2727272828282829292A2A2B2C2D2E2E2E3132333435363739393B3C3D3E3F4141434345
444649494A4C4C4F505151535556575859585C5C5D5C5D5E5F5F60636564636566656868
696B6C6C6F6E6F71727273757577787B7A7B797D7D7D7E7D7D7F7F7D8082848383838181
8587868686888B8D8D8E90919193949798989C9DA2A1A3A5A9A4A5A8AAAEADAEB0B1B5B6
B7B7BBB9BCBFBFC0C2C5C6C5C9C6C5C6CBCACACACCCCCBCCCBCDCECFCDCECDCDCECACACB
CBCCCDCBCBCACBC9C9C7C9C9C9C7CCC7C8CACBC6C7C9C5C7C6C6C3C5C3C3C5C6C7CAC7C4
C4C1C2C3C5C7C5C7C5C4C3C5C4C7C6C5CBC7C7C6C9CACBCBC9C8CCCDCECCCCCBCDCDCDCD
CECFD0CFCFD5D8D5D8D9DAD9DDDCDDD9DEDEDDE1E3E2E1E2E2E2E3E1E1E2E2E2E4E3E4E2
E4E5E2E6E5E2E5E2E5E6E4E4E2E2E0E3E1DEE0E1DFDEDFDEDBDCDCDDDAD8D6D9D9D9D6D6
D6D5D2D2D5D1D0CBCBC9C9C6C9CAC7C7C4C1C4BFBFBCBDBEBBBBB7B7B1AFAAAAA8A4A39C
9A97979390908D8B86878680837F7D7C7C7A7A767675747470716F6F6D6C6B6B696B6968
69676967656464626262605F5E5C5B595C58575555535251504E4B4A49474443403E3E3B
3A39363432312F2D2D2C2B2A2A2929282828272828272627272727272626262727262626
2626262627262626
252626262626262626262626262626262626272727262627262726272627272727272727
2727282828282929292A2B2A2B2C2D2D2F30323435353638383B3A3B3D3E3E4141434245
4447484A4B4C4F4D4F5050525555565857595B5A5C5D5E5F5F6061626564666665676767
6A6B6C6E6E6F707070737575757377777A7A7A7B7E7E7D7E7C7F7F818282838582838284
848685858586888B8C8B8C908F9093929398979D9EA3A2A3A3A3A4A7A6A8AAAEAEB1B0B3
B3B4B9B9BBBEC3C0C1C1C4C5C3C7C5C6C6C8C6C9CACDCECDCACECBCBCFCDCECDD0CDCFC9
CECCCAC8CAC9CCC7C8C7CACBCBC8C9C9C9CAC8C7C7CAC6C8C7C9C6C7C4C5C0C3C4CBC8C6
C5C1C4C6C7C7C3C4C7C7C5C8C8C9C5C5C6CAC7C7C8C7C8CAC8CCCAC9CCC9C8C8C8CBCBCC
C9CDCED1D1CFD3D5D6D7D5D9DADADDDBDCDBDADDE0DDE1E1E1E3DFE2E2E3E1E0E5E3DFE4
E2E4E3E3E5E3E2E4E5E4E3E7E4E2E1E1E2E0DEE2DFDFDDDEDBDCD9DCD6D8D7D9D8D8D9D5
D5D3D6D6D2D1D1D0CECBCBCBC9CAC9C7C4C3C3C1C0BDBCBCBFBAB9B8B3B2ADABA9A8A5A2
A09B99969692918B898887848382817F7D7878757676737272716F6F6D6D6C6A6A6A6867
67676764646362615F605F5F5C5A595A595756555453514F4F4C4B4848454442403F3D3B
3A38353431312F2D2C2C2B2A292929282828282828272726272727262627262627262626
2626262626262626
262626262626262626262626262626262626262627262726262626272627262727272727
272728282828292829292A2A2B2B2C2D2F2F313334353637383A393B3C3D3E3F41424444
45474748494B4D4D4F4F5252545455565859595B5A5B5D5D615F62616363656667676869
6A696C6D6F706F70727373747474737576787A797C7B7B7B7B7E7F7F8180838386838281
82858682858685898A8C8C8F8E9091929497999C9EA0A0A2A2A2A3A3A6A7AAABAEADAFB0
B2B2B6B6B9BCBBBEBFBEC2C3C2C4C6C5C8C9C9CACBC8CDC9CDCCCDCECFCECDCBCDCBCDCD
CFCCCECECBCBC9CBCBCACACCC8CACAC7C9C9C9C7C9C8C5C5C2C6C7C8C7C3C3C6C6C5C8C7
C4C4C2C2C5C7C5C6C4CAC8C5C7C7C9C4C4C3C6C6C8C5C6CBC9C7CEC9C8CCC8C9CACACCC8
CFCFD0CFD0CFD2D0D6D7D9D6D8D8D7DBDADADBDEDADFDEDEE0E0E1E1E0E1E2E0E3E1E1E2
E3E4E4E3E7E2E3E2E5E3E6E5E4E0E2E2E4E2E3E0E2E0DEDFE0DCDBDBDCD9D9D7D7D8D7D6
D3D3D5D5D2D0D2CECCCACDCBCAC9C9C9C9C4C3BFC3BDC0BEBDBBBAB6B5B2B1ADADA8A7A3
A09F9E989894918E8D8A868584827F7E7E7A79777775747371706E6E6C6D6A6969696968
676666646260605E605E5E5D5B5A5A58585655545351504F4E4C4A4848444342403F3D3A
3937353332302F2D2D2B2B2B292929282828282727272727272627262626262726262626
2626262626262626
262626262626262726262626262626262627262627262626262726272727262727272727
2727272828292829292A2A2A2B2B2C2D2E2F32333435353638393A3B3C3E3E3F41414343
45464649494B4B4D4E50505253545657565858595C5C5D5F5E5F62636264646466676869
686B6D6E707071706E7172737475747475787978797B797B7D7E7E7F7C82828387848582
858386868585888888898D8D8E8E8E90919395989C9A9EA0A1A0A3A6A4A7A9A9A8ADADAC
ADB1B1B2B3BCB8BDBDBDBDC0C2C2C3C5C8C8CBCBC7CACCCECBD0CCCDCCCDCBCCCDCDCECF
CECBCFCECDCCCACCCCCFD1CAC8CAC9C9C7CBC5C6C8C9C8C7C3C9C6C4C7C6C4C3C4C5C6C7
C5C5C0C3C1C7C4C6C5C9C8C9C4C6C5C5C6C1C6C3C6C6C6C6C6C6CACDC9CACBCAC9C9CBCC
CAC8CCCCCECFCDD1D3D5D3D2D6D4D8D9DDDBDDDCDCDADBDADDE0DDDDDFDEDFE1E2DFE0E0
E3E6E4E0E1E2E5E6E3E7E4E8E4E4E5E6E2DFE1E2DFE0DEDDDCDBDDDDDBD6D6DBD7DBD8D6
D7D6D4D3D2D5D1D0D0D2CACACEC9C8C7C6C8C4C2C0BFC0C0BCBCBBBBB8B7B2B1AFABAAA4
A4A09B9B999592938D8D8B88858581817E7E79787474747372706F6E6D6C696967686666
6565646461625F5E605D5B5B5B585856565554535151504E4B4A4949464543413F3E3A3B
3937343332302E2E2C2B2B2A292929292828282727272727272727272627262627262626
2627262626262626
252626262626262626262626262626262626262626262727272626272726272727272727
2727272728282929292A2A2B2B2B2B2C2E2E30333535363637393B3B3C3D3F3F40424342
444647484A4A4C4D4E505050525456565756595A5A5B5C5D5E5F60626363646465666769
68696C6B6F71716F6F7072727274757274757878797A797B7E7B7E7D7F80828382818382
86868686878588878B8B8D8E8F8D8E8F8F9494959B9B999A9C9DA1A2A4A4A7A7A8A8A7AB
ACACB0B2B2B5B6B7BBBCBCBDBFC0BEC3C5C5CAC7CBC8C8CBCDCCCBCCCFC8CFCDCDCECCCE
CFCDCFCDCECECDCACDCECDCEC9CACCC8C6C6C8CBC9C5C9C5C4C9C9C7C3C8C7CBC6C6C5C6
C6C8C5C3C4C6C8C7C8C8C7C7C5C2C7C3C4C3C4C4C4C6C1C8C7C7C8C9C8C9C8C9CBCEC9C7
C9C8CACBCBC9D0CDCED0D2D1D2D5D9D6D9DED6E0D9D9DBDADDDADCDBDBE1DDE1DFDDDFE1
E3E3E2E7DFE0E2E7E6E4E2E0E6E2E1E0E3DFE1E0E3DDDFDCDADCDFDDDCD9DADDDAD8D8D4
D8D5D5D2D5D2D2D3CECDCECCCBCACBCBC9C5C8C5C3C0C1BDBDBEC0BAB9B7B8B4B0AFACA7
A5A09E9E9A989694918E8B89878485837F7D7A797775747372706E706C6B6B6967676565
66646561605F5E5E5D5B5C5B5A5857565454535252504E4C4B4B4848454542413F3D3C3A
3837353331302F2E2C2C2B2A292929282828272727272727272627262727262626262627
2626262627262626
252626262626262626262626262626262626262626262726272726262727272727272727
27272728282828282A2A2A2A2A2B2C2D2E2F31323436363738393A3B3C3D3E3F40434445
45454647494B4A4C4D4D515052535356545658585A5C5C5E5D5F61616364646566666669
69696B6B6C6E70706F7171717375757674757679797A7B7C7C7E7F807E80848584838483
86878886878488888A8A8B8C8B8C8E8E8E9192979597969B9A9C9FA2A2A4A4A4A4A9A7A9
ABAAADAFAEB3B5B5B8B9B6B7BCBDBEBFC0C1C5C6C5C2C9CCCBC9CDCAC8CECCCBCECCCDD1
D0CED0D0CFCDCECDCDCDCDCFCBCACBC9C9CAC9CAC9C9C5C7C5C5C7C7C8C8C5C4C5C6C7C7
C7C5C6C4C7C8C7C5C6C6C3C6C6C5C4C8C5C6C5C2C3C4C4C5C6C4C5C5CCC5C7CBC7C9C9C9
C7C9C8C9C9C7CCCDCECDCFD3D3D3D2D5D8D8D8D9D8D8D7DADADDDADDDADDDEDDE1E1E0E2
E0DEE1E2E0E1E1E3E5E3E3E2E3E1E2E0E4E0E1E0DFE0DCDEE2DEDEDBDCDCD9DAD9D8D7D8
D7D6D7D4D5D3D4D0D2D3CDCFCECBCAC9C9C5C5C5C3C0C2BFBEBEBCBDBAB9B7B6B2AFAEAA
A8A6A49F9D9B9792928E8B8986878382827D7C7B7978767471726F6D6F6C6A6868666665
64636262615E5D5D5B5B5B595A585654535352524F4F4D4D4B4A4745464242413F3C3B3A
38363432312F2E2D2C2B2B2A292929282828272727272727272726272726262626262726
2626262626262626
262626262626262626262726262626262626262626262726272626272727262627272727
272728282828282929292A2A2A2B2C2C2D2E2F31333436363739393A3C3D3E3F40424343
46474747494A4A4C4C4F5050525353545657595A595C5B5C5F6060636263656566656769
6A69696D6B6E6E706F6F71727373747675767975797A7A7A7D7E7E7F8080818181838583
84858986888585868888898B8B898B8B8E8F91929395959495999E9DA19EA2A3A4A5A8A8
A8ABACAAB0B0B1B0B4B4B3B5B7B9BDBFC2C0C0C1C2C6C6CACAC7CCC8CBCCCCCACECCCECE
CBD1CFCED0CFD2CFCFCBCECCCCCCCBCBCBC9C8C7C7C7C8C8C6C5C4C6C9C7C4C7C6C5C6C7
C8C7C9C6C3C4C7C6C7C5C6C5C4C8C7C8C5C4C8C4C3C4C5C2C4C5C6C1C4C7C6C5C7C7C8C9
CAC8C9C8CCC9CBCECFCECFCDD1D3D3D3D1D3D8D8D5D5D6D6DBDADCDCDCDAE1DEE0DBE2DB
DFDFE1E0E0E6E3E2E2DFE5E1E2E1DEDDE0DEDEE0DEDDDFDFDADCDEDADBDADBDBDADAD8DA
D5D4D7D4D3D0D4D0CDD2CECCCDCCCCC9C7C7C6C4C3C1C1BFC0BEBFBBBDBABCB7B7B5B4AE
ADA7A5A0A19B9896938F8C8C898A868683817D7C7A7778747371706F6D6B69696B676764
6364625F5E5F5D5C5C5959575756555553515150504E4C4B494847454442413F3E3C3A39
37363432312F2E2D2C2B2A2A292929282828282727272727262726272726272626262626
2726262626262626
262626262626262626262626262626272626262626262726262726272627272727272727
272727282828292829292A2A2B2C2C2C2D2E2F3133343636383A393A3B3D3E3F40414343
44464647484A4B4B4C4D4F505153535555565759595B5D5A5D5E60616363656465646668
6869676A6B6C6D6F6C706E717474757475767776797B787B7B7C7C7E7D7F818081838080
848586868684838785868889888C8C8E8E8D8E8F929294959397989B9B9FA0A2A3A3A4A6
A9A9A9AAACAEAEAFB2B1B4B5B6B8BABCBDBDBFC2C1C2C4C7C5C7C7CBC9CBCACCCECECED0
D0D0D0D1CED2CFD1CECBCFD1CECBCBCCC8C9CBCACBC8C9CAC5C7C9C7C8C5C5C7C7C7C4C6
C5C7C6C6C7C8C8C6C6C5C7C8C7C9C8C7C7C6C1C4C5C2C4C3C4C3C2C2C0C3C2C5C6C6C7C8
C8C9C7CAC8C8C8CECECCCCCFD1CECFD2D2D2D6D5D1D4D8D6D6D7D9DCDCDBDEDCDADDDEDC
DCDCDCE0E1DDE1E1E2DEE3DFDFE1DFDFDFE3E0E2DFDDDCDEE1DDDDDADDDEDBDCDCDCDCDA
D9D8D7D4D2D3D1CFD2D3CFD1CDCDCBCBCAC9C7C5C3C2C0C0BFBCBEBEBCBDB7B7B8B5B2AE
ACABA8A3A19E9C99959391908D8B88868483817E7C7B78777472726F706E6A6967656866
6461605E5E5D5D5B5959575856565553534F504F4E4D4C4A494746454242403F3D3B3A38
36353431302F2E2D2C2B2A2A292929282827282727272727262626272626272726262726
2626262727262626
262626262626262626262626262626272626262726272726262626272627262727282727
2727282828282828292A292A2B2B2C2D2E2D2F313235353637393A3A3B3C3D3F40414243
4446464749494A4B4E4D4E4E5051535656555758595A5C5D5D5E60616161646365666766
686968696B6A6C6D6E6E6E707172747274757577787A777A7B7B7A7B7E7E808083828080
8384878584858484858385878A8B8B8C8D8E8D8F8F91929095959996999C9C9EA0A2A3A5
A7A6A8A8A8ADB0ACB0B2AEB0B3B3B6B9B9BABFBFC2C2C3C5C7C4C4CBCBD0CDCED2CFCECE
CFCDCDCFCCD0CFD0CECFCFCFD0CCCECDCFCCCDC9C8C7C6C8C6C7C9C7C5C7C4C5C6C5CAC6
C6C2C4C4C7C6C6C8C6C6C8C6C6C6C7C3C5C4C3C5C3C2C4C7C2C2C3C0C2C3C4C3C9C7C8C4
C5C5C7C7CBC8CAC8C7CACCCCCFD0D4D2D0D1D0D2D3D3D2D3D4D5D4D8D9D6D9DADCDCD9D9
DDDCE0DFDEDDE1DFE0E1DFDEDCE2DFDFDFDFDDE2DDDDE3DCDFDFDBE1E0DADDDBDCD8DADA
DAD6D8D4D1D0D3D1CECFCFCECCCACDC9C7C7C3C6C1BFC1C3C3BFBCBDBDBAB8BAB6B4B5B1
AFABAAAAA49E9C98989592938F8D8B888685827D7B7B7A77757373716E6F6A6B69676765
6263605D5E5C5B5A595958555454525251514F4D4D4B4949484644444241403F3C3A3939
37353332302F2D2D2B2B2A2A292928282828272727272727272627262627272626262626
2626262626262626
262626262626262626262626262626262626262626272726262727262727272726272727
28272728272828292929292A2A2B2C2C2D2E2F30323434363739393A3B3C3E3F3F404142
4346474848494B4B4B4B4C4E5052515456565757575B5B5C5E5F5F606161616365666667
696869696B6C6B6C6B6D7070707174747473767476787879797A7C7D7D7E7E8081817F7F
8084838484848586868787868786888A8A8C8D8E8B8E8F9293929596969A9A9DA09FA2A1
A0A5A7A9A8AAABAEB0ACACAFB2B2B3B5B5BABBBBBDC3C5C4C1C7C6C7CBCCCECDCFD1D0D0
CFCDCDCBCDCDD1D3D0CFCCD0D0CCCDCDCDCFCDCECBCAC8C6C8C8C5C9CBC7C7C6C7C8C7C7
C6C4C6C6C7C9C5C6C8C9C7C6C6C5C7C6C7C6C3C3C2C4C2C6C3BEC3BEC0C0C3C2C3C6C6C4
C4C6C7C8C6CBC7C9C9C8C9CACECFD1CED0D0CED2D1D1D2D4D1D6D2D5D4D6D6D8D9DBDADF
DADADADCDDDDDEDDDDDCDDE1DFE0E0DEDEDEE0DFDCDEDFDEDDE0DADADEDCDBDCD6D9DDDA
D7D7D3D5D6D3CED1D1CDD0CECCCCCAC9C9C8C8C6C4C0C1C0C0BDBBBBBBBBB9BAB9B9B7B0
B1AEAFADA6A59F9B99999794908F8E8E888684827D7D7A78787773716E6C6C6C68676663
636261605E5B5B58595756555353535150504E4D4C4A48484846444342413E3D3D3A3A38
35353332302E2D2C2B2B2A2A292929282828272727272727272727272727262726262626
2626262626262626
262626262626262626262626262626272626262626272726262726272626262727272727
27272727272828292929292A2B2B2B2C2E2D2E30323335353738393A3B3D3D3E3F414142
444646474648494A4C4D4D4E4F5051545655565959595B5B5C5D5C606060626365646765
6768696B6B6A6B6B6C6C6E707170727374767375787877797879797B7A7C7D7D807E8281
827F83848386858688878587878A87888C8B8D8C908E8E8E9192929595979B999D9E9EA0
A1A3A6A6A7AAABABA9ADACADB2B1B1B4B3B6B9B7BDBEC1C0C2C3C6CACDCECFD0D0D1D3D1
CECECFCCCED0CED2CFD2CFCDCFCDD1CCD0CCCECECBC9CBC8C7C6C6C7C8C9C8C7C6C7C7C7
C7C6C4C6C9C7CAC5C7C6C7C4C7C6C8C6C7C4C4C4C4C4C4C4C1C0C0C1C3C4C2C1C2C2C3C6
C7C3C5C5C7C8C8C6C6C6C8CCCDCACECECDCDCECED0D0D0D4D2D0CFD3D6D4DAD9D7D9D7DB
D8DADED9DADADDE1DFDCDEDCDCDEDEE1DFDEE0DFDCDEDEDDDCDEDCD9DADCDBDAD9D9D6D8
D6DBD6D4D1D1D1D0CECECDCECDCECDCAC8C9C4C4C2C2C1BFC0BCBFBDBEBABAB9BBB7B6B5
B3B1AEABAAA4A5A09D9B969696938F8E8A888785817E7D7B787874726E6E6C6B69666765
6262605F5E5B5B595858565554525150504E4C4B494A48484544444241403E3D3C3A3937
353433312F2E2D2C2B2B2A2A292929282827272727272727272627272626262626262626
2626262626262626
262626262626262626262626262626262626262626262627272627272726262726262726
27272727282728282829292A2A2A2B2C2C2D2E30323435363738383A3B3B3D3E40404141
434444474749494A4A4C4C4E4F5051525556565857595A5B5C5C5C5F6161606363636667
6668686A6B6E6C6C6A6D6E6F6E6D6F7273747374757776777678787A7B7B7E7F7F807F7E
81828184848388888888878988878A86878B8B8D8B8E8E8F908F95959496989B9C9B9BA0
A0A3A1A5A5AAA7A7AAAAAAAEB0B0B3B5B4B6B8BABBB7B9BFC1C5C7C9CACDCACDCED0CDCF
D0D1CDCFCDCFD1D3D0D0D1D1CFD1CFD1CCCECBCCCBCBCBCBC7CBCAC7C6C9C5C7C7C7C7C5
C7C5C5C7C7C7C4C5C6C6C8C5C6C6C7C6C6C5C7C7C6C6C4C3C3C2C1C3C4C1C3C3C3C2C1C6
C2C6C3C5C6C7C6C5C7C6C9CACCCACACECACECECFCFD0CFD1D1CDD1D2D3D6D6D9D4D6DAD9
D8D8D8DADBDCDCDBDEDEDDDBDCE0E0DEDDDEDEDDDDDAE1DEDBDFDEDBDCDCDCDCD8D9D6D7
D6D5D6D4D7D4D3D3D1CECDCECDCCC9CBC7C9C7C5C4C1C0C1C0BFBFBFBBBCBCBBBCB9B4B5
B3B3B1ADACA8A4A5A19F9A9B9895928F8E8B878782817F7D7A7A7573716E6C6B69686866
6462605F5D5C5B5758595554535251504E4D4C4C49494846444343413F3F3E3C3C393836
353332312F2E2D2C2B2B2A29292929282728272727272627262726262726262726262626
2626262626262626
262626262626262626262626262626262726262626262727272626272726272727272727
27272728282828292929292A2A2B2B2C2C2E2E2F3133353537393A393A3B3D3F40414244
444445464848494A4C4C4B4C4E50515353555656585A5A5C5C5C5E5E5F60636163656466
66676A6A696A6B6D6D6C6D6D6F6E6F6F7373747374767676757579787A797C7D7C7F8080
7F838582848584868888878988898988898888898A8C8F8E8E918F93949698989D9A9B9C
9CA0A0A1A5A5A6A6ABA8AAAAAAADADB3B0B3B7BCB7BBBABBBFC2C4C5C8C8C9CACBCDCFCD
CDCACFCCD2CBD0CFD0D1D0D2D3D0CFCDCDCDCCCDD1CCCEC9CACDCCC8C8C8C8C9C7C5C6C6
C4C8C8C6CAC5C9C7C5C4C3C3C5C8C9C8C7C5C6C9C7C4C5C6C3C3C3C1C4C4C3C1C5C3C4C2
C5C0C5C2C6C5C4C6C6C6C6C6C7C7CACAC8CBCCCECFD1CDD0CECFCCD1CED2D5D4D3D7D7D5
DAD7DAD6D9D9DEDBDDDCDFDBDBDBDEDCE0DCDBDADDDFDDDCDDD9DADDDDDDDBD9D8D9D7D7
D9D9D9D7D5D3D2D1CDCCCCCDCACBCDCACBC5C6C5C4C2C1C0BEBDC1BDBABCBCBBB9B7B5B6
B8B1B1AFACADA8A8A4A49F9D9B9695908E8C898484827E7E7C7B78747271706D6A666865
6461605F5D5C5A58575555535250504E4E4D4B4A48464645434242413F3E3D3B3B383737
343232302F2D2D2B2B2A2929292828282727272727272727272727262726262627262626
2626262627262626
262626262626262626262626262626262626262626262626262627272727272727272627
27272727272828282829292A2A2B2B2B2D2D2E2F303335363739393A3A3D3E3F40404143
4245454647494A4B4B4B4B4E4E4F51515354555757595A595B5C5C5D5E60616163666467
6667676A696B6B6D6D6D6E6C6F6D6D70737274767475757675787678787B7D7C7C7E7D7D
7F818181838482868688858687878887888789898A8A8A8F8E9191929494929598999A9A
A0A0A0A2A2A1A4A3A8A8A8AAAAADAAAFB0B3B4B5B6B6B9BCBCC4C2C6C6C7C4C6C9C9C8CC
C9CECCD7D0CECFD4D2D7D2CFCECFD0D3CDCCCCCCCDCECCCBC9CCCACCCACBCAC5C9C8C9C5
C5C3C2C4C5C5C6C9C6C6C6C6C6C9C6C9C6C4C5C6C6C5C5C2C3C2C2C3C2C2C4C1C2C0C0C3
C0C3C4C4C3C2C3C5C3C6C4C3C6C5C6C8C8C8CACAC9CACEC9CDCDCDCECDD0D2D4D6D4D7D9
D6D8D4D7D9DAD9DBD9DCDDDCD9DFDDD8D8DBDBDBDBD9DADDDBDBD9D9DBDBD9D9D7DAD7D6
D5D6D7D5D1D4D2CFCFCFCECDCDCCC9C9C6C4C6C4C6C2BDC1BFBDBEBBBCBCBBBCBAB5B5B8
B4B4B0B1AEACA9AAA8A3A19C9C9A9594918F8A878583827E7D7B79767571716E6C696865
646361605E5C5A595757545252504E4F4D4C4A4949474644454241403F3E3C3B39383735
343332312E2D2C2B2B2A2A29292828282828272827272726272727272626262626262626
2626262626262626
262626262626262626262626262626262626272627262627262727262727262726272727
272727272827282829292A2A292B2B2B2D2D2E2E30313436383A393A3B3C3E3E3F424242
434345464747494A4A4C4A4D4E4E4F515153545556575A5B5A5B5C5C5C5F626163646464
666669686A686B6A6B6D6D6A706E7070717273757576767476767878797B7A7A7A7A7D7D
80818083818384848586888787888789878888888B8A8F8E8F8E8F8F8F9394949396989A
9C9D9E9E9FA0A2A3A3A6A9A9AAA8AEACACB2B3B1B5B5B7B8BEC1C4C3C2C4C3C3C3C5C8C8
CBCECCCFD0D0CDD0D0D2D1CFCFD1D2CED0D0CDCDCDCBD0CDCFCBC9C9CAC7CAC8CAC7C9C9
C8C5C5C6C8C7C7C4C5C4C6C3C8C5C3C3C5C2C2C1C6C6C4C0C0C3C0C0C2C4C1C0C0C5C0BF
BFC0C3C1C2C3C1C4C5C4C4C4C5C6C6C8C6C8C9C8CACBCDCCCBCBCBCDCCCFCFD0D2D3D3D3
D3D3D8D4D8D5D5D7D9D9DBDAD9DAD8D9DDD8D7DAD9DADAD9DCD9D9D9D8DADAD8D7D7D7D8
D6D4D8D4D2D3D1CCCECECECFCEC8C9C6C9C6C4C4C4C4C0C0C0BEBFBDB8BBBDB8B8B8B6B5
B7B5B2B1AFABAEA9A8A5A49FA19B989793908D8A898584817E7D7A777673716E6E6B6868
6562615F5E5C5B58575653535250504D4D4B4A484846464443423F403E3D3B3A3A383735
343130302E2D2C2B2B2A2929282828282727272727262727272727262726272726272626
2626262626262626
262626262626262626262626262626262626262626262626262627262626262727272727
27272728282828282929292A2A2A2B2C2C2E2D2F2F32343637383A3C3A3C3D4040414143
434446464647484A4A4C4C4D4D4E50514F52555454575858595A5B5C5D5E606262626464
6566656867696A6A6A6A6D6E6D6F70727073727472767476757778787978787B797A7B7C
7F8081808180828384848785868588878A8988868A8A898D8E8C8D8E9090929393949597
999A9B9B9C9DA1A2A4A5A7AAA9ABA8ABACADB1B3B3B4B4B8BABFC3C3C0C1C2C1C4C5C9C9
CACDCACBD1CFCECFD0CDD0CCD2D0CFCACFCED0CDCFD0CACECECDCCCBC9C8CAC7C5C7C8C8
C8C5C5C8C5C4C6C8C4C5C5C5C3C3C4C3C4C3C2C2C5C5C6C1C0BEC3C2C0C0BFC2BEBFBEBE
C0BFC0C3BFC1BFC1C5C4C4C2C7C4C7C3C5C4C6C7C6C7CAC8CACACCCECDCECED0CFD1D4D5
D7D5D3D7D5D7D5D8D7D7D9D9D8DAD6DBD8DAD8D9DBDADBD9DADBDBDCD9D9DDDAD7D5D6D7
D7D5D8D3D4D2D3D2D1CECACCCDCAC8CAC4C5C6C3C4C4C3C0BEBFBEBDBEB9BAB8BAB8B7B9
B6B3B4AFB0B0AEABA7A6A4A39F9C9A9A9692918E8B878482817D7B79767474706F706C68
6563625F5E5D5A595756545352514D4E4C4B4948474544434241403E3C3D3B3938373534
3332302F2E2D2C2B2A292929292827282827282727272727272726262627272627262626
2626262626272626
262626262626262626262626262626262626262626262626262627272626262727272727
27272727272727282829292A2A2A2A2B2C2D2E2E30313336383A3A3B3C3C3E3E40414142
43444646474747484A4B4B4C4D4F4F4F50515255565759595A5C5B5B5B5E5E6062636263
6567676768686B6B6B6B6C6C6D6D6F706F717172737376757677757778787B787A797D7C
7E7D7E7D7F808181848583858487858888888887898A8C8C8D8D8D8A8E8E909095929594
979A99989C9D9CA0A1A2A5A6A5A8AAABABAEAFAFB2B2B2B3B8B9BEC0BEC0BDBDC1C5CBCB
CACAC9CBCDCCCCCECFCDCECFCED1D1D4CED0D0D4CFD0CFD0CECECDCBCBC7CACACACAC9C6
C9C6C7C7C6C4C6C5C5C7C2C2C4C7C5C3C6C3BFC3C1C1C4C1C1C2C0C0C0BEC2BFBDBDBEBC
BFBFC0C1C2C0BDC0C1C1C6C4C4C3C5C5C5C5C5C6C7C5C4CBCBCCCDCBCBCCCBCFCECCCFD2
D3D1D1D3D1D5D7D6D8D7D7D6D9D8D8D6D6D9D8D5D8D7DBDADDDDDBD8D9D7D7D8D8D4D8D6
D3D2D2D2D4D2CFCFCECDCDCCC8C9C9CBC6C3C7C4C4C3C3C0BFBDBFBCBCBBBAB8B9B7B6B7
B7B3B2B3B1B1ADABACA9A6A4A1A09D9B9997918E8B898583807E7C7B777572726F6C6A68
66656161605E5B5957565453524F4F4D4B4B49474645444341413F3E3D3B3A3838363534
3331302F2E2C2B2B2A2A2929292828272728272727272727272627262727262626262626
2626262626262626
252626262626262626262626262627262626262626262726262627262626272727272727
272727272827282828282929292A2B2B2C2D2D2E303033363839393B3C3D3E3F3F414142
434344464748484A4A4C4B4D4D4D4F4F50525452555557595B5D5E5C5D5D5F6061626364
6666676769696C6B6A6B6C6B6E6D6E707070717172707375767776777877787A7879787C
7C7E7D7F807F8080838583868585868685878789898B8C8B8A8D8A8B8C8D8F9091939696
95969597989B9A9BA1A3A6A6A6A7A7A9ACADADADB0AEAEB3B7B7BBBDBBBCBABDC2C4C5C7
C7C7C8CBCBCBCBCBCECFCCCFCFD0D1D0CFD1D0D1D2D0CECECED0CCCDCACACACAC9C9C6C7
C7C9C7C5C6C7C2C3C5C3C4C0C2C3C2C2C3C4C3C3C0C0C3C2C0C1C0C1C0BDBDC0C0BBC0BF
BCBFBCBEBEBFC0BDC1C3C2C2C5C4C3C6C6C2C6C6C4C6C5C5C7C7C9C9CECDCCCCCDCED2CF
CFD2D3D1CFD4D5D3D3D6D7D7D6D4D4D7D3D6D7D8D6D9D5D8D8D7D8D8D6DBD6D8D7D4D1D3
D2D2D5D3D3D1CFCED2CDCAC9CACAC9C7C7C5C4C7C2C2C2BFBFBDBDBABAB8B9B7B6B7B6B4
B3B4B2B4B1B1AFABAAA9A3A4A1A29D9D9C9B97958E8B898682817D7B79767372706D6C69
666564615E5E5B5C56565453524F4F4C4C4948464645424242403E3D3C3C393937363433
3331302E2D2C2B2B2B2A2929292828282727272726272727272627272626262627262626
2626262626262626
252626262626262626262626262726262626262627262626272626272626272726272727
272727272728282828292929292B2B2B2C2D2D2E2F30323638393B3C3C3E3E3F3F414143
4345444647474849494A4D4C4C4E4E4F50505253565556585A5B5D5B5C5E616162616264
6466666867696A6B6C6B6D6C6C6D6E6D6F6F707074727374747676767677777577777B7A
7B7D7B7B7F8181818383828583828686888688888A898C8D8C8D8C8C8C8C8B9090919392
93969897989A9A9DA09FA1A4A5A3A4A6A7ACACABABAEB1B0B3B2B7B8BEBEBCBBBEC2C5C4
C4C2C4C7C9C7C5C8C7C9CECECFD0D3D2D1D1D0D2CFCFCECDCCCFCCCECDCCCBCBC8CBCCC8
CAC7C5C9C4C5C9C5C4C4C4C6C6C1C4C5C2C1C5C3C1C3C4C3C2BFBFC2C1C2BFBFBFBCBDBB
BCBDBFBFBEBEBDBCC0BFC3C4C3C1C0C3C3C4C5C3C5C4C2C2C5C7C9CBCACBCCCDCFCBCFCD
CFD0CED0D1D1CFCFD4D4D5D4D4D4D0D5D5D4D1D5D7D5D5D5D8D7D5D8D5D6D6D7D3D3D5D5
D3D6D3D3D2D0CFCBCBCFCACBCBCECAC8C6C4C5C5C2C1BEC0BFBFBCBDB9BAB8B8B8B7B7B5
B6AFB2B1AEADAEADAAAAA8A6A2A59F9E9D9C9997968E888784807F7B79787673716D6C6B
686764635F605C5B5858555452514E4D4B49494644444341413F3D3C3C39393737353433
31302F2E2D2C2B2B2A292928282828282828272727272726272726262627272626262726
2726262626262626
262626262626262626262627262626262626262626262626262727262626262727272727
2727272827272728292929292A2A2A2B2C2C2D2E2F303135383A3A3C3D3D3D3E40414143
4443464647484749494B4C4C4C4F4F4F515153545556575858595A5B5C5E5F5F615F6362
646466676669686B6A6B6B6C6B6F6E6F6E7171717170727372757474777577777779797B
7C7B7B7C7E7F81818182828384868685888587898A888C8B8C8E8A8B8C8E8F8E91929191
9295959696989A9C9EA0A2A2A3A4A5A8A9ABAAAEABACABAEB1B2B2B7B8BBB9BBBDBFBEC2
BEC3C2C6C6C6C5CAC9CCCCD0D0D0D0D0D1D0D0D1D1D0D1D0CFCECBCCCECDCCCBCCCACACD
C7C8C9C6C2C4C7C7C7C3C5C3C3C5C4C1C3C2C2BFC0C1C1C4C2C3C2C3C0C1BEBDBBC0BDBD
BCBBBEBEBFBEBDC1C0BEBDBDBFC0BFC3C1C3C2C1C5C6C3C5C7C6C4C7C8C8CCCACACECECC
CBD0CECFD2CED1D0D2D0D3D0D3D4D3D4D4D3D6D2D3D5D9D4D8D5D4D7D5D8D5D6D7D3D2D2
D2D3D1D3D0D1D0CECFCECECDCAC6C7C8C7C8C6C4C6C3C3C4BFBDBEB9B7B9B6B8B8B7B3B6
B3B4B3B1AEB0B0B0ADACA9A7A7A5A3A19E9C9C98938F8E898584817E7A77777471706E6D
6A666663625F5E5C5A57555451504E4D4C494846454442403E3F3E3D3B3A383736353433
31302F2E2C2B2B2B2A2A2929282828272727272727272727262627272626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262627262726272727
272727272728272828292829292A2B2B2C2D2D2E2E30313437393C3C3E3F3F3F40414343
44454645474748494A4A4B4C4F4D4E50505251535355575758585B5A5C5E5F6061626162
64636666676A68696A6A6D6D6E6D6F6D6D6F717071717174727376747476767876757879
797D7E7D7C807F80828583838383858686838787888A8B8A8B8B8E8A8A8D908F8E908F91
92949493979496989A9C9EA1A0A2A3A2A4A8A9A9A8ABADACB0B3B6B7B9B6B7BABABBBEBD
BDBFC5C4C4C5C6C4C8CBCDCBCDCFCECED0D1D2CFD1D2D0D1D0CECECCCECCCCCCC9CACCCB
CAC8C7C6C6C5C6C4C4C6C1C4C4C2C2C0C4C0C2C0C2C0C0C0C1C3C1BFC1C1C1C0C1BEBDBA
BBBCBFBDC0BFBEC0BBBCC0C1BEBFC1C3C4BFC1C0C4C5C6C3C3C5C2C4C8C7C8C9CCC5C8CB
CACBCBCECFD0D2D0D0CFCFCFD1D2D0D3D2D3CFD1D4D2D2D1D5D2D6D3D4D5D3D4D7D4D5D3
D2D1D4D0D1D1D0CDCECFCFD0C9CAC9CAC5C7C5C2C6C4C2C1BFBCBCBDBBBAB8BAB5B8B7B4
B1B4B2B3AFB0B1AEAEAAA9A9A6A4A4A2A4A09C999694908C898682827E7B76777372716D
6A68676461605F5C5B58565351514F4D4B494846454442413F3C3D3B3B39383735343332
312F2E2D2C2C2B2A2A292929282828282827272727272727262727262626272626262626
2626262626262626
252626262526262626262626262626262626262626262626262626262727262727272627
272727272727272828292929292A2A2B2B2C2D2E2E2F3133373A3C3D3E3F3F3E3F434243
44454545464748494A4B4A4B4D4F4D4E505152535555565657575A5B5B5C5D605F616162
636263656666686A69686B6B6D6D6E6E706E6E706F717170737375737577747676777679
7B797D7D7E7F837D7F8381848584848486848688898B8A8B898B898B8E8E8F8D8E8D908E
909194929596969797979B9EA2A1A0A5A4AAA7A7A8ABACAFADB1B3B3B5B8B5B8B7B8BBB9
BCBFBEC3C4C1C4C7C8CBCCCCCCCECBCDD1CECFD0D1D1D0D0D0CED0D0D1CECFCDCECDCCCC
CAC8C9C8CACACACAC4C3C3C3C2C3C5C5C1C4C0C2C3C1C1C2C0C2C0BFC0C3C3C2BABABABA
BBBCBDBFBBBCBBBCBDBCBCBDBEBFBEC1C0C3BEBFC0C5C2C2C2C2C4C5C3C7C2C7C9CAC8CC
C6CACBCCCDCDCBCFCECECFCECED0CDCFCFD2D1D3D0CFD2D3D0D0D0D1D3D5D1D3D5D3D1D5
D1D2D2D0D0D1CFD0CFD0CBCBCBCEC9C8C9C6C5C5C4C4C3C1C2BFBEBCBCBBB8BAB7B5B4B5
B3B3B3B1B0B1AFAFACADA9A9A7A6A3A2A2A19E9A979691918E8A868382807A7977737270
6C6A686763615F5E5A5955555251514E4B4A48464544413F3F3E3B3C3A3A383735343331
302F2E2D2C2C2A2A29292928282828272728272728272726272726262626262626262626
2726262626262626
262626262626262626262626262626262626262626262726262627272727262726272627
272727272727282828292929292A2A2B2C2C2C2D2E2F303234393B3D3E40414040414343
4445464646474A494A4B4B4D4C4E4F4E4F515151535554555758585A5B5C5C5E5E5F6260
616264656566666868686B6A6E6C6D6F6D706F6F6F6F6F71727274747376767778777779
787B7A7C7C7D807F7E818384828283868785868887898C8B8B8F8E8C8D8E91908F8F8E8E
908F8F91939598949497989B9F9D9EA0A0A6A7A5A8A9ABABADB2B1B2B3B5B5B6B4B8B9B9
B7B9BDBFC1C2C2C6C3CBC9CECBCCCCCCCECFCED2D0D1D1D0D1CFCED1D0CFD0CDCFCFCECE
CCCACAC9C9C7C8C6C5C7C5C4C5C1C2C3C4C1C0BFC1BFC0BFC0C0C1BDBDC2C1C0BDBBBBBC
BBBBBDBEBCBBBFBDBFBDBBBCC0BEBBC0BDBDBFC0C2C1C3C5BFC2C3C1C2C2C5C6C7C8CAC4
C7CACBC9CACCCCCACDCDCACDCECFCECED1CFCFCED0CDD1CECDD0D1CFD0D0D3D3D2D2D1D3
D2D0D1CFD3CDD0CFCFCCCCC9CAC8CBC8C8C7C8C3C4C1C1C0BFC1C2BBBDBCB9B8B4B7B4B3
B2B2B4B2B2AFAFACABABA9A8A6A5A4A2A29E9F9E9A999591908D8B8781817F7A79757371
706E6A676663605D5C5A5856545251514B4848474443423F3E3D3C3B3939373635343231
302F2E2D2C2B2A2A29292928282828272827272727272727272726262626272627262626
2627262626262626
252626262626262626262626262626272626262626262626262626262726272626272727
272727272728282828282829292A2A2A2B2C2C2D2E2F313234373A3D3D40404141424344
45464546464747494B4B4A4B4D4D4D505051515351545456555857595A5B5D5E5C5E6063
636363646467666969696B6B6A6D6A6E6D6E706F70717171737474757676787778777877
7879797C797C7D7E818284838183828282858386888A898B898C8C8C8F8E8E90918D8E8D
8D908E8F9293929892969599989B9C9E9FA4A3A6A8A8ABACAEADB1B1B3B1B4B5B4B3B8B7
B9BCC0C1C1C2C1C3C7C6CACACACBC9CDCBCFD2D0D1CECFCFCDD0D0D0D6D0D2D0CFCFCBCE
CCCBC8C8C8CAC9C8C6C5C3C6C3C3C3C7C1C3C2C0C1C1C2BEBEBCBCBFBEBEBFBEBEB9BCB8
BDBCBABDBEBFBEBEBDBDBCBDBEBBBDBCBFBEBDBFC0C4C1C1C1C4C0C0C5C3C5C4C5C4C5C8
C5C4C8CAC6CDCDCCC9CBCDCECDCDCECCCACFCDCECBD0CECDD0CECFCDD1D1CFD4D2D1D2D5
D1D0CFCED0D1D1CDCECBCACBCAC8C6C9CAC6C5C2BFC4C1C2BEBEBDBEBDBCB8BAB4B8B5B5
B5B0B3B1AFB1ACACACACA9A6A7A5A3A6A0A19F9D979A9794928F8A878684807D79797674
726F6C696766635E5E5C5A5654524E4D4C4A47474342413F3E3D3C3B3837363534333231
2F2F2D2C2C2B2A2929292828282828272727272726262727262626262626262626262626
2626262626272626
262626262626262626262526262626262626262626272627262726272626262627272727
27272728272728272729282929292A2A2B2C2C2D2E2F2F3133363A3C3D3F404141424245
46464746484848494A4A494B4B4D4E4F505051525455535654575657575A5C5C5D5E5F60
616263646565656568686969686A6D6D6D6D6F6E6F707171737376767777777877787777
76777B797A7E7D7E7D80837F8382828385878784888889898B8F8E8C8D8F8E8E8F8F8D8F
8C8D8E8F909094959593989898999A9D9E9DA2A1A3A6A7A9AAAEAFADB1B3B3B4B3B2B4B7
B8B9BEBFBEBEC5C0C4C6C6C9C9CCCBCCC9CBCFCFCFD0CED3CFD1D2D1D3D1CFCFD0D1CDCC
CECCCFCDCCC9CBCAC8C6C5C5C3C5C2C4C4C1C0C0BEBFBDC1BFBBBDBCBDC0BEBEBCBBB7B8
BFBCBBBFBEBCBDBCBBBABCBBBCBBB9BEBEBDBEBBBDBEBFBFC1C0BFBFC0BDC2C0C1C3C2C4
C5C5C8C7C6C9C8C8C9CAC9CCCCCACACACACBCCCECACBCCCECDCED1CFCFD0CFCFCFCECDCA
D0CECFCDCFCDCECECCCDCACBCAC9C6C5C9C4C7C2C4C0C1C0BDBCBEBCBBBBB9B7B7B8B3B2
B3B4B4B2B1AEADABABADA9A9A8A7A6A2A3A0A09F9C97959391908D8C888583817E797975
746F6E6B696563625F5C5A565451514D4C4848454542403F3D3D3B393937363533333230
2F2E2C2C2B2A2A2929292828282727282727272727272627272626262627262726262727
2626262626262626
262626262626262626262626262626262626262626262626262627262627272726272627
2727272727282728282828282929292A2B2B2D2D2E2F303133353A3D3E3E404242424444
4546474747484A494A4A4A4C4C4D4E4E4F5150525253535556575657595A5B5C5D5D5E60
6163646362666667676767696A6B6B6E6C6C6D6E716F707375757576767778787A797677
767779797A7B7A7C7E80808281808181818485878686898889888C8C8E8D8B8F8D8F8E8D
8C8F8E8D8F909395929694969797999D9B9D9EA2A2A6A7A6A9A9ADB0ADAFB2B3B2B3B2B5
B4B9BBBEBCBBC0C1BFC2C6C6C5C8C8CACCCBCECECDCECFCBCDD2CDCED0CFD1D1D0D1CECD
CDCBCCCCCCC9C7CBC7C7C5C4C4C5C6C2C2C4C2C0C0BFC0BDBCC0BCBDBCBCBEB9B7BBB8BB
BBBCBDBEBCBFBEC0BCBBBBB9B7BBBCBBBABDBBBFBBC2BDBFBDBDBEBDC0C0C2BEC2C2C1C4
C2C7C6C7C4C5C6C3C8C5C9C8C6C8CBCACACBC9C8CCCBCACACDCECCCCCECCCBCECBC9CBCD
CFCFD0D0CECFD0CFCDCBC8CAC5C9C8C8C8C7C8C4C2C4C3C1BEBDBEBEBDB9B7BAB9B6B5B6
B5B2B0B1B0AAADAAA8A9ACA9A8A6A5A3A0A3A29E9F9D959693928F8C8B8984827F7D7976
74716D6E696665625F5C5A575552514E4C4A47474442413F3E3C3B3A3837363532323230
2F2E2D2C2B2A2A2A29292828282828272727272727272727272726262626262626262626
2626262626262627
262626262626262626262626262626262626262626262726262726262726272627262726
26272727272727282828282929292A2A2B2C2C2D2D2E2F313134393B3D3F404141444346
47464847484749494A4B4C4D4B4D4E4E51505151545354555657585859595A5A5C5C5C5F
61626364646466666667696868696B6C6C6C6D6E717171717174767779777A7977777677
777778797B787C7C7C7C7E80808182828284858385878887868B8C8B8D8B8C8D8F8D8D8D
8D8E8C918E8D90909194949897999A9899989C9D9DA1A5A5A7AAABA7ADB0AEB1B1B1B2B0
B3B7BBB7BCBEBDBDC0C6C1C7C5C7C9C9C9CACCCCCBCCCDCBCFCCD3CFD2D0CFD2CECECFCE
D0CCCBCCCCCBC9C9CCC7C6C8C6C4C3C4C1C3C3C2C3BCBDC0BFC0BDBCC1BCC0BEB8B9B9B9
BABBBBBEC0BEBFBEBCB9BBBABBB9B9B9BEBEBCBCBEBABEBEC1BBC0BDC0BDBEBCBFC1C2C1
C1C1C0C0C1C5C3C4C6C6C8C4CAC8CBC8C9C6C8C8CACBC9CBC9C7CAC9CDCAC9C9CACBCCCA
CECCD0CDCCCDCCCBCBCAC9C8C9C6C8C6C6C4C7C5C4C1C2BFBEC0BDBCBCBABCB9B8B7B2B4
B1B2B2AEAFACA9AAAAACAAA7AAA7A5A6A4A1A09F9B9D97949392918F8B888783807F7A78
7674706E6B6964635F5C5A575652504D4D4B47464342423F3E3C3B3A3837353433323030
2F2E2C2C2B2A292A29282828282827272727272727272727262727262626262626262726
2626262626262626
252626262626262627262626262627262626262626262626262626262626272727272627
2726272727272728282828282929292A2B2C2C2D2E2E2F303234363A3C3E3F4143434545
4649484947484949494A4B4B4C4D4F4F50515153535454555655565859595A5A5B5D5D5E
5E62626263656567676669676A6A696B6C6D6C6F6D707072727375747778787877777676
7778777A7978787B7B7D7D7F807E7F808281828383858589868A8C8B8B8D8C8F8F8D8C8E
8D8D8C8F8F8E8E8F91949294949797989B9A9A9C9F9FA1A3A7A8A9A9AAAEB1B2B0B0B0B2
B3B4B4BAB6B9BABBBEBEC0BFC4C5C6C8C5CBCECDCACCCACDD0CFCDCFCCD0CFD2CFD0CDD0
D0CFCDCEC9CBC9CAC8C7C6C7C4C5C1C4C2C3C1C1C0C5BFC1BEBCBBBEBEBEBDBCBCBABABB
BCBFBDBFBDBFBCBDBCBDBDBBBBBBBBB7BBBDBAB8B8B9BABABBBFBCBDBDC0BEC0BFBFC0BF
BEC1C0C1C2C1C2C1C5C4C4C5C5CAC7C7C7C5C8C6CBC7CAC6C9C8CACCC8C8C7C8C8C7C9CC
C6C9CBC9C9C6CACACDCBC9C6C8C8C7C8C8C6C5C2C0C1C0BFBEBFBDBFBDBCB9B7B7B4B7B8
B4B3B3B1AFAFABACACABAAA8A8A6A7A2A2A19D9D9C9A97979493908E8C898785817E7C78
797371706D696764615D59585654504E4C4A4946444241403D3C3A393837363533323030
2E2D2C2B2B2A2A2929282828282827282727272727272627262626272626262726262626
2626262626262626
26272626262626262626262626262726262A262626262626262626272627262726272727
272727272727272727282828292929292B2B2C2D2D2E2F30313335393D3E404143434547
474847494A4A4A494A4A4C4D4C4D4E4F4E505152525454565557575858595A5A5B5B5D5E
5F60616463646265676667696A686B6A6B6C6D6B6E6F7070707274737476787779767574
777776777A79797878797B7B7F7E7E808282848184848684878B898B8C8B8C8D8D8B8E8D
8C908F91918D8F8E8F9193919596959696979C98999B9FA2A2A9AAA8AAACAEACB1B0B1B3
B4B4B4B4B3B6B7B8BDBBBEBFC1C2C7C5C6C9CBC9CCCCCBCDCCCECFD0CDCFCDCED1CDCECF
CFD1CDCDCDCBCCCBCBCBC6C8C7C7C7C3C5C1C2C3C0C3C0BFBEC1BDBCBCBFBBBCBCBCBCB9
BCBBBDBEBDBDBCBEBCBDBCBBBBBBBBBABBBDB8B9B9B9B8B8BBB9BCBCBABEBCBFBCBFBEC0
BDC0C1C0BDBDBFC0C3C1C1C2C4C5C5C4C4C7C6C5C6C6C5C5C7C5C9C6C9C6C9C9C5C4C8C7
C9C8CDCCC8CDC9CECBC9CCCBC7CAC8C5C9C7C6C6C4C2C4C2BFC0BEBCBCBABAB6B7B3B4B2
B6B4B2B0ADAEACAFACAAAAA8A6A5A6A19EA09F9D9C9A97959693908E8C8B888682827D7B
767572706E6B6965625F5D5A5652514F4D4C4846444241403E3B3B3A373635333232302F
2E2D2B2B2B2A292929282828282827272727272627262727262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626272626272627262726272727
27272727272727272828282929292A2A2A2B2C2D2D2E2F30313336383A3E404243434445
464948494A4A494C4A4A4C4B4D4D4E4F4E5051515354535455565758585959595A5C5B5D
5E5F605E6264656466666768676868696A6C6B6C6C6E6E6D716E71727475767577767573
7578787A787A787A7679797B7A7F7C7E83848282838384868787898A8A8B8B8C8C8F8D8D
91908F919090908F8E90919394959597989898999B9B9B9D9FA3A6A7AAAAABAEABAEB0B0
B0B3B1B7B4B7B6B9B6B9BCBEBFC1C0C5C5C5C5CACAC9C8C9CBC8CFCECCCECDD2D0D0CFCF
D0CDCDCDCDCACACAC8C9CBC9C5C7C5C3C2C4C1C5C2C0C0C0BEBEBDBEBFBDBABCBABBBCBC
BCBDBDBCBCBEBBBDBCBDBABBBCB8BAB9BDBBB9B8B8B7B9BCBCBDBCBCBBBBBDBCB9BCBEBF
BFBCBDBCBEBFC0BDC0C1C1BFC3C0C3C5C6C6C5C7C5C7C5C5C4C6C7C7C6C7C5C6C3C5C6C7
C8C7C7C9C7C6C6C8C9CAC8C8C6CBC8C8C7C6C7C5C0C0BFBBBDBEBEBFBCBBB8B7B7B3B6B5
B5B2AEAFAEAEAAABACABA9AAA8A4A4A4A1A09CA0999A99969794938E8B8B8987837E7D7B
777574706C6B6A6662605C5A5753514F4E4B4A47464442403E3B3A393736353332312F2F
2E2C2C2C2A2A292928282828272727272727272726262726272626262726262626262626
2626262626262726
262626262626262626262626262626262626262626262626262726262626262627272726
2626272727272727272828282829292A2B2B2C2C2D2D2E2F313234363A3E404144434545
464748494A4A4B4A4A4A4C4C4D4E4D4F4F50515051545455575857575959595A5B5B5B5C
5D5E5E5F6062646566666A676869696A6A6C6E6D6D6E6F6F6F7170727374757476747476
76767679767878797879777A7A7B7D7E8182848282828287838487878689898A8D8E8C8F
8E8D90908F90928F918F908E919194949696989898989C9C9EA1A2A4A7A9AAACADADAAAF
B0B2B0B1B3B7B7B4B5B5B8BBBEBFBEC1C3C4C6C8C7C6C7C8CAC9CFCCCECACFCDD1CED1D2
D0D1D0CDCDCEC8CBC9CAC7C9C7C6C7C6C4C4C6C4C2C0C0BCC0BCBFBCBABCBBBDBCBCBABB
BCB9BDBDBBBDBBBCBCBEBBBBB9BAB8B9B9B8BABAB7B8B5B8B8BABABBBBBABCBDBDBDBDBE
BFBBBCBCC0BBBEBDBEC0BFC3BDBFC0BFC1C1C3C3C3C4C4C3C5C4C4C1C3C2C4C5C6C4C4C6
C4C5C5C0C5C4C7C7CAC8C8CAC8C7C6C5C4C3C1C1C3C2C2BEBFBBBFBAB9BDB8B8B8B6B6B4
B3B4B1B0ADB0ADACADA9A9AAA6A6A4A6A1A19D9C9D9A99969491908D8D888984827F7D7B
797572716D6C696763605D5B5755534F4E4C4848464441403D3B3A38373734323230302F
2E2C2B2B2B2A292929282828272727272727272727272726272627262726262626262726
2627262626262626
262626262626262626262626262626262626262626262626262626272626262727272727
272627272727272727282728282929292A2B2B2C2C2E2E30303233353A3C3F4243444546
46484849494B4C4C4B4B4C4C4D4E4D4E504E4F52525353545554565658585A59595B5C5D
5D5E5E6062626162636466686868696A6C6B6D6B6B6E6D6D6F6E6E707172747372747474
7478797A777678787878797B7A7C7B7D81808184808383858586868584868787888C8C8E
8C8F8F908F928E929191908F909192929496959997989A9B9B9E9EA1A2A5A6A9ABADADB0
B0ADB0AFB1B3B4B6B5B5B6B8B9BBBFC1C2C4C5C4C5C5C7C8C8CBCCCBCCC9CFCECDCFCED0
CDCFCDCFCBCDC9CCC9C8CFC8C6C6C6C5C5C4C4C3C2BFC2BFC0C0BCBDBCBBBCBABBBABBBC
BDBABBBDBABEBBBDBDBABBB8BABBB8B9BBBAB7B7B8B5B7B6B6BAB9B7B9B9BAB8BBBCBDBD
BEB9BBBDBDBDBDBFC0C0BEBFBFBEBEC1C0C1C1C3C1C1C4C1C2C2C4C4C3C2C1C2C4C5C7C3
C6C2C1C1C3C3C5C5C7C8C5C7C8C7C5C2C5C3C1C1C1C2BFBEBABDBEBBB9B8BAB8B5B7B4B0
B2B5B0AFAFADADABADAAAAA7A7A5A4A3A1A19F9C999898969392908E8C89878681817E7B
797873706C6C6A6864615E5A59565251504D4B474644423F3D3C3A38383634333230302F
2D2C2B2A2A2A292928282828272727272727272727262726262627272726262726262626
2626262626272626
262626262626262626262626262626262626262626262626262626262626262627272727
272727272727272728282828282929292A2A2B2B2C2C2E2F30323335383B3F4142444445
4748484A494C4C4B4C4C4C4D4E4E4F504F4F51505252535355565657575859595A5B5C5E
5D5E5F605F6060616363636666686868696A6A6C6D6C6B6E6C6E6E707073727373737474
767576797876777778777A7978797B7D7C7F80807F81838486838686878684858C898B8A
8C8C8E8F918F8F8F9291929191919192949496939896979A9D9B9A9DA2A2A4A6A7AAAEAC
ACADAEAEAFB1B4B3B2B5B4B7B7BBBEBEBEC1BFC1C3C5C7C7C9C7C9C8CBCCCDC8CCCBCECF
D1CDCDCECECCCCCECBCBCACDCBC9C8C3C3C5C5C3C3BFC4C2BFC0BFBDBFC0BEBDB9BBB9BC
B8BCBCB9BEBBBBBABAB7BABDBBBCBABABAB7B8B8B6B4B6B7BAB7B8B8B6B7B9BBB7B9B8B9
B8BDB9BBBEB8BDBDBABBBCBBBDBABCBEBEC2BFC2C1C1C1C0C2C3BFC3C2BEC2C1C5C7C4C2
C1C1C0BFC1C3C2C5C2C2C3C4C7C4C6C2C5C3C2C1C2C1BEBCBDBDBDBBBBBAB7B5B6B3B5B3
B4B0B2AEACADAEADADACAAA6A7A5A4A3A09E9E9B989B97979493918D8B8A878482807D7A
797974716F6C6B6865635F5A58575450504C4B484644433F3D3B3938373634323230302D
2D2B2C2B2A29292929282828282727272727272727262726262627262627262727262626
2626262626262626
252626262626262626262626262626262626262626262626262627262726262726272726
272727272727272728282828282829292A2B2B2C2C2D2E2F30313234373A3D4042444646
474748494A4C4B4D4D4C4D4F4D4D4F4F4F5050515254535555575656585758595A5B5C5C
5C5D605E616060626262626363676567696A696B6C6B6D6F6E706D6F6F71707273737475
75747474767476777779797B797A7B7D7B7E7D7E7F818281858685888583848488898889
8A8B8D8E8F8D8E8F91928F9293939492939394969497989698999B9DA09FA2A7A6A8AAAC
ABACAFADADB0B1B2AFB4B3B6B5B5BABBBCBDBEC2C3C4C1C3C4C5C5C7C8CAC9CCCECCCCCA
CFCECECECACFCECFCECACAC9CACBC7C7C6C9C6C7C2C3C3C0C0C0C0BFBCBFBCBBBAB9B9B7
BCBABBBBBBB7BCBCB8B9B8BBBCB9BDBABAB7B8B7B7B8B6B5B8B7B8B8B7B5B6B6B6B7B7BC
BBB9B9B9BABDBBB9B9BBBDBBBCBEBDBDBDBEBEBEBCBCBCBEBEBFBDBEBCC0BEC1C1C3BEC0
C0C1C0C4C2C4C1C3C2C4C1C4C5C4C3C4C1C4C1C3C1BEBFBDBEBCBABBBAB8B6B8B6B4B2B1
B0B1B0AFADACACADA8AAA6A7A3A5A4A29EA09D9C999A979793928D8D898A868684827E7C
777675726F6D6A686763605C595553524F4C4B484744433F3E3C39393736343331302F2C
2C2C2B2B2A2A2A2928282827272727272727272627262627272626262626272626262626
2626262626262626
252626262626262626262626262626262626262626262626272627262626262626262727
27262727272727272727272828292929292A2B2C2C2D2E2F3030323434393C3F42454546
484948494A4C4C4D4C4D4D4D4F4F4F5050515052535255565555575658585859595B5C5B
5C5E5E5F60606161616262636565686968696669696B6C6C6D6D6D6E706E716F70727473
7473747475767778787B7B797B777979797A7C7E7D7E80838281848787868586888A8A89
898A8B8C8C8F8F8E9091909191949492949592959796949697989A9C9DA09EA4A1A5A5A7
AAA8ACADADB0ADB2B0B0B0B1B3B5B5B6BBBBBCBDC0BEC0C2C3C7C9C6C6C7C8C9CDCCCBCB
CCCBCECFD0CECCCFCECDCCC9CBCBCBC8CBC8C7C3C9C4C2BFC2C0C0BEBEBCBCBBBABAB9B7
B9B6BBB7BAB9B9BABBBBBABABCC1BDBCBBB7B6B6B5B4B6B8B7B7B6B4B6B8B4B8B6B6BAB8
B9BABABCBABABDBAB9B9B9BAB9BABEBBBFBCBDBFBCBCBFBDBCBDBEBEBBBDBCBEC2C0C1C2
C2C2C4C5C7C3C6C4C1C2C2C2C2C5C2C2C3BFC0C0C2BFBFBFBABCBABABBB9B6B6B5B2B2B0
B2B0B0ADABADAAA7A6A7A8A7A4A3A2A0A19E9E9B9A99979494908F8D8B8A888482807E7B
7A767571716F6A6866625F5C5A575453504E4A4A464443403E3C393736363432312F2F2D
2D2C2A2A2A29292929282828282727272727272627262727262726262627262726262626
2626262626262626
262626262626262626262626262626262626262626262626262626262727262726272626
272627272727272827282828282928292A2A2A2C2B2D2E2E2F30313334373B3F42444545
464748494A4B4C4C4E4D4D4E4F4F4F4F50505052535354555555555858575959585B5C5D
5B5F5D5E60626161616261646465656767676A6B69696C6B6D6D6D6E6F6F727070707172
727172727576757879777879797A7A787B787A7B7A7C7D7F80818483848684878887878B
86888B8B8E8D8C8E8F918F918F9192939494949794949594979697999B9C9EA0A2A1A4A6
A9A8AAAEACACAEAFB0B1B0AEB1B2B4B5B6BABCBCBDBEC1BEC2C5C3C5C7C5C7CACACAC9CC
CACECDCECBCFD1CECFCDCDC9CAC9CACDC9CBC8CAC6C6C1C3BFC0BFBEBDBEBABDB9BBBBB8
B8B8BBBBB7B8B8BABBBBBCBDBCC0BCBBBCBAB7B8B5B7B4B4B5B7B7B1B3B3B5B4B6B5B9BD
BCB8B6BCB8B8BAB9B8B7B9B8B9B8BCBBBCBBB8BABABABDBCBABCBBBDBBBBBBBCBBBCBFC0
C2C3C4C4C6C7C5C1C4BFC2C2C4C4C2C3C1BEC1BDBFBFBFBEBABCBAB8B7B7BAB8B6B2B0AF
B0B1ADAFAAA9A9AAA8A6A6A6A5A3A2A0A19F9D9A9898939590908E8B8B86878583837D7B
79787472716E6B676762625E5B585552514D4C49464443403E3C3A3836353332312F2E2D
2C2C2B2A292A292828282828272727272727272727272626272726262627272626262627
2626262626262626
252626262626262626262626262626262626262626262626262726262726262626262727
27272727272726272827272828282929292A2B2B2B2C2D2E302F31323336393E3F424547
4748494A4A4B4C4C4D4E4E504E4E4F50515252515353525355555656575758595C5A5D5D
5D5D5D5E5E60626262626260616568666667676868696B6A6A6D6D6E6E6E6E70706F7172
7172737174767677787876797A7978787B787A787C7C7E7C7E7F81818080838587898887
8888888C8A8B8D8F8E908D8F9091909194959596959898959597999A9A9B9C9FA1A2A2A4
A8A8A9A9ADACAEAEB0ADB3B0B1B1B4B5B6B7B7BEB9BCBEBEBDBEC2C2C5C9C6C8CBCCC8C7
CBCBCAC9CDCED0CDCCCCCCCDCBCEC9CCCAC7C9C7C7C4C7C3C2C3C0C1BFBEBCBFBBBBBAB7
BABBBCBABABCB9BBBABCBDBCBBBABBB8B8B8BABAB7B6B4B5B6B6B7B6B4B4B2B5B4B6B2B5
B7B6BAB7B8B8BAB8B7B6B7B9BAB8B8B7B9BABBBBB8B9B9BAB9B9B8BCBCB9B9BABEBEBFC0
C1C1C3C5C4C4C6C3C2C2C4C3C2C2C1BFC3C0BFBCBEBDBEBBC0B8B8B8B9BABCB6B7B2B4B0
B1B0ADABACABA9A8A7A7A7A5A7A3A19D9F9F9D9B9B979793928F8E8D8C8A8783817D7E79
787576726F6D6A696561605E5B5A5453514E4C4A484442403E3B3A3836343332302F2E2D
2C2B2A2A2929292928272828272727272727272727262627272626272626262626262627
2626262626262626
262626262626262626262625262626262626262626262626262626262626262727272626
2627272627272727272728282828292929292B2A2B2C2D2D2F2F30333335373C40424445
474849494B4A494D4B4F4D4E504F51505051525352545455555555565757585A5B5B5C5C
5D5E5D5E5E6060626161606263656767686768696968696A686C6C6D6C6F6D6F6F6D726F
737273747473757777767977787978767A79797A787B7B7E7D807E7E8182848583868887
888986888A8B8B8C8F8E8E8E9190939091949397989699979593989699999C9E9FA2A7A6
A6A8AAA9ABAAADB1B0B1AFB0B1B2B3B2B3B3B7B8B7B7B9BCBCBEC2C2C0C3C2C6C5C5C7CA
CBC8CACBCACACCCCCECDCACCC9CBCAC9CCC9C9C7C7C9C5C4C6C1C3C1C0C0C0BDBDBCBDBC
BCBAB8B7B6BABABDBEBDBAB9B9B7BABAB8B4BAB9B9B8B6B2AFB3B3B3B2B4B3B1B2B3B5B4
B4B5B4B6B7B6B7B7B9B8B6B9B9B7B7B8B7B8B8B9BAB8BABBB8B9B9B6B6B7B7B9BABCBEBD
BFC0C2C3C2C1C2BFC1C0BFBFC1C2C1C0BEBDC0BEBDBCBBBCBCBCB9B8B4B6B6B5B4B4B0B0
AFAFACADABAAA9A8A7A7A6A4A1A5A09F9B9B9D9998959794918F8B8C89888684827D7C7B
79787572706D6A6866635F5E5C585553514D4B49464442403D3B393835353331302E2D2C
2C2B2A292A29292828282728272727272727272727262726262626272626262626262626
2626272626262626
262626262626262626262626262626262626262626262626262627262626262627272726
262626272727272727272727282828282929292A2B2C2C2D2F2F30323234363A3E414345
464849484A4B4D4C4B4E4D50504F504F5152525252525554565857565758585A5B5B5D5E
5E5D5E5E5F5E606164626261616464676767686769686769696B6B6B6C6D6E6F6E6F6D70
727070737475767575737774797679777A7B79797B7A7C7C7B7D7F807F7F838386858886
8886898489898A8B8C908D8F908F8F9194919695989799989A95949697999A9EA0A2A2A6
A6A5A6A8ABABABABADADB2B0B1AFB1B3B3B3B3B3B5B7B5BABBBDBEBDC2C1C1C3C0C2C6C7
C5C7C7CBCBCBCAC9C8C8C9CBCDC9CBCACAC9C9C6C7C5C8C4C3C0C0BEC0BFC2BDBFBCBCBC
BBBABABBBAB9B8BBBBB9B8B7B8B7B7B6B8B8B8B9B9B9B7B7B4B0B3B0B3B1B2B2B1B3B1B3
B3B4B6B3B4B5B7B8BAB7B7B6B6B6B7B6B7B7B8B4B4B6B8B8B9B6B6B4B6B6B5B5BABEBDBD
BEBFBEC1BEBDBEC1C1BEC1BDBEC2BEC0BEBEBFBDBCBBBCB9BCBCB7B6B6B4B6B4B3B1B2B0
AFADABADA9ABA8A6A8A6A5A4A29FA19E9F9D9D9995979591908D8C898A878483807F7E7B
777575716E6E6A656562605F5C575753514F4B49464642403D3B3937363433312F2F2D2D
2B2B2A292929282828282727272727272726272726262626262627272626262626262626
2627262626262527
252626262626262626262626262626262626262626262626262626262726262626262726
2727272727272727272727272828282829292A2A2B2C2D2D2E2F2F31323435383C414445
464647484A4A4B4C4E4D4F4F4E504F50505252535355555655565657575758595A5C5E5E
5C5F5D5E5E5C61626263626362646468676568676969686969686A6B696C6A6D6D6C706E
716F717172747475747577767777787B79787A787A7B7A7B787D7C7F7F8082828486848A
878787868688878A898F908E8E8F8D9292949496979698989897969799999A9C9E9FA0A2
A3A5A7A8A8A8A6A8A7ACACAEADAEAFB0AEB2B3B2B2B5B5B3B7BBBBBBBEBDBFC1C2C3C6C6
C9C5C7C9C8CBC7C8CDCBCBCCC8CCC9C9CCC9C9C6C3CAC6C5C3C6C2C2C1C2C1C0BFBDBEBD
BDBCBBBCBABDBCBAB9B7B7B3B5B9B4B7B8B4B5B6B6B7B5B7B3B3B1B3B0B3B3B0B1B3B0B1
B2B1B4B4B1B5B5B4B6B5B6B6B4B5B6B6B7B7B6B6B6B5B4B5B8B7B6B8B9B6B8B9B8BBBDBE
B8B8B9BABBBBBFC0BFBEBEBFBFBFBCBFBCBABBBCBDBCB9BCBAB9B7B6B6B3B2B4B2B1AEB2
ABACADA9AAA8A6A6A5A5A1A2A0A09F9C9A9C9C9995959492908E8C8A888683847D7E7D79
767874706E6C6B6765625F5D5B5956534F4F4C484744413F3C3B383736333231302E2D2C
2B2B2A292A29292828282727272727272727272727272626272726262627262626262627
2626262626262626
262726262626262625262626262626262626262626262626262626262626262726262626
272727272627272727272728282828292829292A2B2B2D2D2E2F3030323235373C404244
454648474A4A4C4C4D4D4E4D504F5250505053535454575555565457585758585B5C5F5E
5D5F5F5E5E5F60606263626465646463666767666869666769686A6A6C6B6C6C6C6D6E6F
707271727172727274757475757778787A7979787A79797A7B7A7C7C7D7E7E8084838585
878488858887898B8A8C8C8E8E8F8F919394939698969898989798989899999D9D9D9FA2
A2A5A5A5A9A9A5A5A6A9A9ABAAADAEAEAFAFB3B1B1B1B1B4B4B7B6BCB9BBBDBDBDC0C0C4
C4C9C8C5C6C4C7C7C8C7CCCBCCCACACBCCCCC8CBC7C7C6C6C7C6C4C4C0BFC3C1BEC0BFBB
BDBABCBBBCC0BBBBBBB7B9B6B4B6B5B5B3B4B5B4B5B4B4B4B1B1B4B3B3AFAFAFB3B1B0B2
B2B0B1B4B1B1B4B3B6B7B7B4B8B5B5B8B6B4B5B6B6B7B7B6B8B5B6B7B7B7B8BAB9BABAB8
B8B8B8BAB9BCC1BEBDBABFBEBEBEC0BFBCBDBBBCB9B9BBB9B8B9B5B5B5B6B2B2B1B0AFB0
AEACACA9A9AAA8A7A7A3A5A2A29EA09A9C9B9897959494908D8E8B88868484817F7E7C78
787774726F6B6A666361605C5B595653504D4C484644413F3D3A3837353432302E2E2D2C
2B2A2A2A2929292828282727272727272726262727262726262727262726262626262626
2626262626262626
252626262626262626262626262626262626262726262626262627262726262726262627
2727272626272727272727282728282829292A2A2A2B2C2D2D2F2F30313234363A3E4143
454648474A4A4A4C4B4D4F505051505151535252535458565656575858585858595C5D5E
605F5E5F5E5F5E606061626262636466656564656868686769696A686A6A6C6E6C6D6E70
7070717172717075747478767575757877797A797A797A79797B7A7B7B7E7C8082808384
8386888984878785898B8C8B8F8F90919392949495979596979796969896999B9C9DA09D
9FA1A2A3A7A5A5A7A6A6ACACA8ADACADACADAFB1B1AEB1B1B2B3B5B6BAB9B8BCBBBFBFC1
C4C3C6C6C4C7C7C6C9C9CBCDC9CDCCCDCCCCC9C8C7C6C6C7C7C7C4C5C4C3BFC0C1BEBFBE
BDBFBEBCBABEBEBAB8BAB8B7B9B6B7B8B6B6B5B5B5B3B5B4B2B3B0B2B3B2B2B1B0B1B0B1
B0ADB0B2B1B3B2B4B3B0B5B2B3B2B5B6B6B6B5B5B6B7B2B6B5B6B1B6B4B4B7B7B8B7B7B7
B6B7B6BABABABCBEBABEC1BFB9BDBEBDBEC1BEBCB8BBB7B6B8B7B6B6B5B2B3B1AEB1AEAD
ABABAAA9A8A9A5A6A7A4A0A19F9E9C9A9A9A9896939692918D8B8B87868382807F7D7B7A
787572706D6D696764615E5C5C585554504C49484643423F3B3A3836363332302F2E2C2C
2B2A2A2A2928282828282727272727272727272726272726262626262627262626262626
2626262626262626
262626262626262626262626262626262626262627262726262626262626272626262627
2727262727262727272727272828282828292A2A2A2B2B2D2D2D2F2F31323334373D4043
454647484A4A4A4C4C4D4D4F4F5051505152525455555557575657575558585959595B5B
5D615F605C5F605E60616161626363626564656566676769676869696A69696B6D6D6D6F
70706F70736F73737475747476787778797A7A7779797A7A7C7A7A7A7C7B7C7F807F8282
83888785898689888A888B8A898B8E9090929795959696969795989796979B9C9D9B9D9D
9D9FA1A3A3A2A4A3A7A4A7AAABADABACACAFB2B0B1B0AEB2B2B3B7B4B4B7BAB9BDBABEBE
C0C1C2C2C0C7C5C5C8C9C8CDCAC8C9CCCBCDCBCBC8C8C7C6C7C8C8C4C4C5C2C2C2C0BFBF
BEBBBDBBB9BBBCB8BCB9B6BAB7B8B9B9B5B8B7B6B3B0B2B2B2B0B2B2B2B2B1B1B1AFAFAD
AEAFAFAEAFB1B2B2B0B3B3B4B3B3B2B4B6B4B1B4B2B6B6B3B3B2B3B3B5B4B5B6B7B8B8B5
B7B7B5B8BABABBBEBFC0BEBEBEBEBEBABEBCBCBABAB8B9B7B6B8B5B6B4B1B2B2AEAFB0AE
ACACACA8A8A3A5A4A2A3A1A2A0A09B9A999796959592928F8C8C8A878581837F7F7C7A78
7673746F6D6A6B6764605E5B5A5755524F4D4B474642403E3B3A3836343331302E2E2C2C
2B2A2A292928282828282827272727262727272726272626272726262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726272726
26262626272726272728272828272828282929292A2A2B2C2C2E2F2F31323335363A3F42
43464649484B4B4C4D4E4D4D50504F5253525352525556565556565858575758585A5B5C
5F5E5D5F5F5E5E5D5D5E606062616363616463656466676767686868686A6A6B6D6C6F6E
6E6E7071727172727473747676757877767877797A7A7A797C7B7C7D7B7C7E7F7F7F8182
838286858687878989898B8A8D8B8C8D8F9391929596949595969796959C9A9D9C9C9C9D
9C9EA0A4A1A3A2A0A3A5A6A7A6ABABADACADABACAFB0AEAFB2B3AFB5B3B2B5B9BBB8BBBC
BDBFBDC0C2C1C3C6C5C9C7CACACACDC8CDCACCCAC9C8C9C9C8C7C6C7C3BFC0C2C4C0C0BF
BDC0BDBDBCBCBDB9BABAB8B9B6B7B7B8B5B7B4B3B3B4B3B2B0B2B2B2B0B3AFAEAFADAEAB
AEAEB1ABADB1AFB1B0B1B0B2B3B2B4B3B3B4B2B0B3B3B5B1B2B1B3B0B5B3B4B5B5B5B5B6
B8B9B9BBB8BCBFBDBBB9BBBCBDBBBCBBBCBFBABAB7B5B6B4B4B5B7B4B5B1B0B3AFACACAE
ABAAABAAA6A5A5A4A5A2A19C9D9B9B999995959292908E8F8B8B8A87838582807D7C7976
757271726D6C676464615E5B595655514F4D4A474543403E3C3937353432312F2E2E2C2B
2A2A29292829282827272727272727272727272727262626262626262726272626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262727
27272626272726272727272728282828282928292A2A2A2B2C2E2E2F3032323436383C40
43454648494B4B4B4D4D4E4F50505052515152535355565557555657575958575859595A
5D5F5D5E5E5C5F5F5E5F606162616261626264656665666668696768696869696B6B6D6D
6B6D6D706E6F7172737372747574757576787778797B7A787B7B7A7A7D7A7C7D7D7E7E80
818283858587878588888A88898D8C8B8F8D9091949397969695949597979B9D9A9A9C9C
9C9F9EA2A0A2A2A4A4A2A6A4A7A5AAA9ACAAABAAACAFADAEAFAFB3B2B3B2B4B5B6B9B8B9
BABCBEBBC1C2C3C7C7C5C3C7C8C8CAC9C8C8C9C7CAC6C7C8C5CAC5C8C6C4C6C2C2C0C2C0
C0BFBDBEBDBBBDB9B8B8B9BAB8B7B7B7B7B7B3B0B2B2B1B1B3B3AFB3B3B2ADAEB0AEB0AD
AEACAEAEABACAFAEB2B0AFAEB1B5B1B1B2AFB0B0B2B6B4B1B2B3B2B2B1B0B2B5B3B3B4B6
B4B8B7BBBABCB8BCBCB7BDBBB9BBBABCBBB9B7B6B7B7B5B7B7B1B2B3B5B1AFB0ABAFAFAB
AAABA9A8A8A4A2A2A29FA19E9E989A9897949593908E8E8E8D8887848481817E7D7A7777
7472726F6D686665625F5D5C595755514F4C49464542413F3C3938353433312F2E2D2C2B
2A2A29292928292728282727272727272626272727262727272726262627262627262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
2627262727272727272827272727282828282929292A2B2B2C2D2F2F2F31333335373A3F
424546474949494B4C4D4F5050515052525353525456555455565657595857575858595B
5A5B5C5E5C5D5D5E5E5F606162616262636363646368666667676868686A686A686C6C6B
6D6C6C6C706F706F747172727674737775777779777879797A7A7B7C7A7A7B7B7C7F7E7D
7E8182848484868585868788898A8A8B8A8D8D8F92939292949394959699999B9B9C9C9D
9E9FA1A0A1A0A2A1A0A2A3A6A6A4A7A9AAABA8AAADAFAFADACB2AEB2B2AFB2B3B2B4B7B3
B7B7B7BBBFBEC0C3C2C3C4C5C5C7C5C4C9C9C6C6C7C9C8C8C8C6C5C5C4C6C5C6C3C3BFC3
C0BFBEBFBBBCBCBDBBBCBBB9BCB7B7B7B7B4B3B4B1B1B1B2B2B1B0B3B0AFB1ADAFABABAD
AFAFAFABACAEADB0AEB1B0AFB0AFB1B0AEB2B2B1B3B2B2B1B1B2B2B1AEB1AFAFB1B3B3B5
B6B6B9B9B9B8BBBAB7BAB7B9BBBCB6B7B8B9BAB9B5B5B6B7B4B5B5B5B2B2B1AFB1ADAAAA
AAA9A8A7A4A5A4A3A0A19C9D999C9B98969493928F8C8C8C8A89858682817E7E7C7B7776
73716F6E6B696763625F5C5A585753524D4B474642413E3D3A3936363332302E2D2D2C2B
2B2A29282828282828272727272727272626272726272626262727262626262626262726
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626272626
2727272727272727272727272727282828292929292A2B2B2C2D2E2E2F3131333536383C
41444447494A494C4C4D4E50505051505253525354545556575656575859575959585958
5A5A5B5B5C5C5E5D5D5E5F606060616161646364636466656666666967696867686A6B6B
6D6B6E6D6E707171707174747273747473757677777B79797B7A7C797B7A7A7B7D7D7C7C
807E7F838183838486898889878A898A8B8D8E8F92909091929094959598989A9C9E9D9B
9E9E9EA0A3A0A1A0A3A2A3A6A7A3A6A5A9A8A7A9A9AAABACACAFADB0AFAFAFB1B3B2B4B5
B6B4B8BABABCBFC1C1C4C2C4C9C5C7C4C5C6C4C8C7C8C7C8C5C5C7C7C6C4C4C5C1C2C1C1
C3C3BDBEBFBEBABDBABDBAB7B7B8B9B4B3B2B4B1B3B0B3AFB3B0B1ADAFADAFACADAEAEAB
ABACAAAAADAAABACAEAEAEADAFAFB1AFAEB1B1B0B2B1B4B1B2B4B0ADAEAFB0B1B0B1B3B6
B3B6B6B3B7B8B4B7B7B5B4B7B7B8B9B7BAB7B4B6B3B5B3B0B4B1B2AFB2AEAEAFACAAAEAD
A8AAA7A5A4A2A3A19F9C9E9D9A989598959592908F8F8E8B8886858381817D7B79787975
71716F6C6A676564615E5B5A5755514F4E4B484643403E3D3A3936343331302E2D2C2B2B
2A2929292928282827272727272727272727272626272726262627262626262626262626
2626262626262626
252725262626262625262626262626262626262626262626262626262626262627262627
262726262727272727272727272827282828282929292A2B2B2C2D2E2F30313234353739
3E43454649494B4C4B4F4E50515151515051535354545655565756565658585957585859
59585B5B5B5B5C5E5E5D5F5F5F616160626363636364656466656668666567686868696C
6D6C6D6D6E6E6E7070727273727373757577797877777A7A7A7B7A7B7C797C7E7D7E7C7D
7C7F7F7F7F818185868887888688888B8A888B8E8D908E918F919194959698989A9C9A9C
9E9EA2A1A0A0A1A19FA3A2A2A3A2A3A5A5A6A6A6A6A9ACABABAEACABABADACB0AEB0AFB3
B4B4B6B8BABCBFBAC0C1C1C1C3C4C3C5C5C9C8C6C6CAC9C6C8C7C6C7C6C8C6C6C4C4C3C2
C2C4BFC1C0BBBEBDBDBBBAB9B6B7B8B4B3B3B3B0B1B2B0B3B2B1B1ACADADA9ADABADAEAA
A8ABAAABABAFABADABADAEABACAEAFAFAFB0AFAFB1AFAFB1B0B1B1B1B2AEAEB0B0AEB2B3
B2B3B3B5B1B2B4B5B1B5B1B3B6B6B4B4B7B5B5B3B4B5B2B6B3B0AFB0B1AEAEACACA9A9AB
A7A7A7A6A4A2A1A39F9E9E9C9A9C97979491908F8F8D8A8C8986828482807C7C79787672
736E6E6C686764625F5E5B585653514F4D4A464642413F3D3A37363433302F2E2D2C2C2A
2A2929282828282827272727272727272726272727262627262626262626262726262626
2626262626262626
262626262626262626262626262626262626262526262626262626262626262627262626
272626262727272727262727272727272828282929292A2B2B2C2C2D2F2F313233343638
3C41444748494A4B4C4E4F50505151505152535154555555565657585958575A595B5858
585A5A5A5A5A5C5B5E5E5E605F6060616263636464636564666566676667696868696B6A
6B6D6E6E6D6F6E6F6E707372747474737576777678787C797978797A7E797C7C7C7B7D7E
7C7F80807F8281808484898A8889888A8989898D8C8F8E8E9092929194959998989A989D
9D9E9FA1A29F9F9DA19FA0A2A3A2A0A3A4A4A3A3A4A8A8AAA9ABABA9ABACABADB0ACAFB1
B1B4B6B9BCBABCBBBEBCBEBFC1BFC3C1C3C3C5C6C8C8C7C7C3C3C3C6C7C6C4C7C6C2C5C5
BFC0C1C1BDBFBFBDC0BBBBB6B6B5B4B2B2B2B1B2B1B0B3AFAEADADAFAEAEADA9ADA9ABAD
AAA9A9ACAAACACADAAAAABADACACAEABAEADADA9AEACB0AEB0AEB2B0AFAFAEAEB0B0B3AF
B2B2B2B1AEB0B1B0B2B2B1B2B5B3B5B4B4B4B2B3B3B4B2B1B2ADB1AFADACAAABADA8AAA8
A6A5A6A6A2A2A0A29D9F9C9B9A97979594928F8C8C8B898887868481807E7C7878787472
706E6D69696665615F5D5A585654504F4B49474442403E3B3937363332302F2D2D2C2B2A
2A2928292928282727282727272727272627272627262626262627262627262627262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
26262626272727262727272727272828282828292929292A2B2C2C2D2E2F303132343638
393F434447494A4B4D4F4F515150525352545352545556555557575759585958595A5857
59595A59595A5B5B5C5E5D5E5E606061606264646263636565656769656867696969696A
6C6C6B6D6E6F6D6D706F717171727275737775757676787A78777A7A7A797C7D7C7C7B7C
7D7E7E7F7F8280807F8485878688888789888B898A8C8D8F8E909292959394969697979A
9A9B9F9DA19F9E9F9D9D9FA29F9F9DA0A3A3A3A3A4A6A8A8A8ABA7A9ABACABADACAFABAE
AEAFB4B6B8B7B7B8BCBCBDBDBFBEC1C1C4C2C3C6C3C8C6C5C6C7C3C7C4C5C7C5C5C6C5C4
C3C2C2C2C0BEBEBEBDBCBDB8B5B7B4B5B4B3B4B3B1B0AFAFAEAEAEADACACACAAA9A9ABAA
AAAAA7ABABABABA9ABAAABAAAAACA9ACADADADACB1B0AFAEB0AEAFB0B0AEADAFACB0ADAF
B0AEACAFADADAEAFB2AFABAFB0B3B3B2B0B2B2B2B5B2B2AFB0B1ACACADADADAAA9A8AAA8
A4A7A3A3A3A3A09F9C9B9B99969795959290908F8D898A88878584807E7E7B7977757471
6F6D6D68676662615E5D59565552504D4A484543423F3D3A3837353331302E2C2C2B2A2A
2A2929282828282827272727272727272627272726272726262626272626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262727272726
26272726272727272627272727272727282728282928292A2A2C2C2D2D2F303032343536
383D414646484A4A4D4D4F50505153535354535355555555575957595859595959595859
5859595A5A5B5B5B5C5C5D5E605F5F5F636261616363646365676666656768676869696B
6A6A6C6C6E6D6E6E6F6F6F70727174737575757676777979777978797B797B7B7D7B7B7B
7B7D7D7D807F7F807F8083858685868888898A898B8C8C8C8E8E8F919293969595959798
999A9C9B9E9C9C9E9C9E9D9EA09E9F9FA1A2A2A2A8A6A6A8A9A7A8A9ABAAACADACAEABAE
ADACB1B6B5B8B5B7B9B8BCBCBBBFC0C1BEC0C0C1C3C6C4C7C4C3C6C4C5C8C7C6C3C3C6C5
C5C1C5C0C0BCBEBDBDBDBDB8B6B3B4B5B6B4B4B6B2B2B1AFAFADACAFAAADAAAAA7A8AAA7
A8A8A8A6A8A7A9A8A9A9ABAAABABABACABACACABAEA9ADAEAEAFB0B4B0B0B0ADAEAFAFAF
ABAEADA9AAABACAEAEAAABACADB2B1B0B0B3B3B3B3B3B0AEB4AEABAEACA9A7AAAAA9A8A6
A5A5A1A1A1A2A09C9B9C99999A96939291928C8E8E8A88858483817F7E79797A7674746F
6E6C6A68666361605C5C585453514E4B494846443F3E3C3B37363432302F2E2D2C2B2B2B
292A29282827282727272727272727272727262627262627272726262627262626262626
2626262626262626
262626252626262626262626262626262626262626262626272626262626262626262626
2626262627262727272726272727282728282828282929292B2B2C2D2D2E2F3131333436
373A3F434647484A4B4D4F4F5051505453555555565557565656585857585A59595A5A59
595A595A5A5A5B5C5C5C5D5E5F5E5F616160606262656263636465656666656867686A67
696B6C6B6B6C6C6D6E706F7070727273747575777775767878787A797B7A7A7B7C7C7D7D
7D7C7C7D7E7D7F7E8081808382868585898A8688888A8D8A8F8D91918F95929593939597
989A9B9C9C9A9E9A9D9E9B9A9FA0A0A1A3A39FA09FA7A2A5A5A6A8A8A8AAABABAAABAAAB
ABACB0B1B0B3B4B5B5B4B5BAB8B9B9BDBCBCC1C1C2C2C3C1C1C3C6C6C4C5C7C6C3C5C5C3
C6C4C5C3C0C0BDBEBFBEBABBB9B7B7B6B1B3B4B2B0B1B1B2AEB2ADADAAAAABA9AAA7A8A5
A8A7A8A8A8A7A7A7A8AAABABACA9A9ABAAACABABA8ABADABAFAEADB4B0AEAEAFAEADAFAD
ABACABABA7ACAFAEABABACAEABADAFB1AFB0B0AFB2AFB0ACAEADAAABACAAA7A8A5A6A5A4
A2A3A2A1A09F9C9D9C9A9A989696959192918E8D8C89888484817F807D7B78787674716F
6C6B6A686564605E5C5A5854524F4D4B4A4745423F3D3A3937353332302E2E2C2B2B2A2A
2A2928282828282827272727272727272727262726272727262626272627262627262626
2626262626262626
252626262626262626262626262626252626262626262626262626262626262726262726
2627262726272727262726272727272727272828282929292A2B2B2D2D2E2F3031323335
37393D4245484A4C4B4E4E5151515354545655555657565658575658585758585A595A59
595A5A595B5B5C5B5B5B5C5D5E5E5E605F62616163626265646565666566676668696869
68696B6B6C6D6D6E6E6D6F6F72727372757375777577767776777877797B7B7B7B7A7A7E
7C7D7A7C7B7D7E7E7E7F81828184848484898A8A8A8A8A8B8E8C8C909093929495949595
97999A9A9C989B999C9D9D9E9F9EA19FA1A09F9FA2A1A1A1A4A6A7A6A8ACA7A9AAA7A8AA
ACABAEAEAEAFB1B2B2B3B4B7B8BABCBBBDBDBDBEBEC0C0C3C2C3C3C2C3C1C5C4C4C5C3C6
C5C1C3C1C3C0C1BEC0C0BEB9BBBBB9B6B5B5B3B1B3AFAEB0AFAEABADACABAAA9A9A7A7A6
A8A7A6A8A6A5A6A4AAA7A9A8ABA9A9A8ABA9ABAAABACAAAAACADB0AFAFACADACAEABABA9
A8A9A9A9AAA7ACACABADAAABADADADB0B0B2AEAEADB0AEAFADADABABAAA7A8A7A5A5A5A6
A2A0A3A0A09B9E9B9C9A97969594938F908F8D8B8A878682827F807C7B7C787575736F6E
6E6A696564625E5E5B585855504F4E49494644423F3C3A38363433312F2E2D2D2C2B2B2A
292928282928272727272727272726262726262727262626262726272626272626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
2627262726262727272726272727272727272828282929292A2B2B2C2D2D2E2F30313334
36383B3E444E4B4C4D4D505051525354555457575756555555585757585856585859595B
5959595B5B5B5A5B5C5C5D5E5D5E5F606061606362626163636465666565656965666768
686A6A6B6C6B6C6D6C6E6F6E717172727574747374757476787776777A797B7A797D7D7A
7E7C7C7F7C7E7F807E7E7F7F8081848583888589878A8A8A8B8D8B8C8D8D939390959498
97979B999B9C9C9E9C9D9D9D9D9D9E9DA19EA1A19EA0A3A4A0A3A3A6A7A6A6A6A9A7A5AA
A8ABA9ACAAADADB0B0AFB1B3B3B4B6BBB9BBB8BDBDBFBDC0BEC0C1C1C2C3C2C3C4C5C5C7
C2C4C3C0C1C1BDBFBFC2BEBEBDBDBBBAB8B6B1B2B2B0B2ADB0AFABAAABABAAA8A6A5A3A7
A6A7A4A9A5A6A6A3A4A6A9A9A7A5A8A8AAA9A7A9AAAAAAAAAAADADADACADADACADAAAAAB
AAA7A9A8A7AAADAAACABABA9AAAAABABAEADABACABACABAEABABA8ABA7A8A6A7A2A3A3A2
A19FA19F9A9D9A9D99989796919190908E8B8C888687848180807C7D7B78767274706F6D
6B6A666562605E5B59585552504E4C49464441403D3A393736333230302E2D2C2B2A2A2A
292929292828272827272727272627272727272727272726262626262626262626262625
2626262626262626
252625262626262626262626262626262626262626262626262626262626262627272626
26262726262727272727272727272728272827282728292E292B2B2B2C2D2E2F30313334
3537393C414B49494C4D4F525253535556555656585857575659585857585A5959595859
5A5A595B5A5A5D5A5C5A5C5E5E5C5D5F6060626063636462626164666665676967676867
676869696A6C6E6C6E6F6E6D706F706F7272737474767976787778797777787A7A797B7C
7B7A7C7C7D7C7D7C7E7E80807F8084828584868988868A8C8C8C8D8A8C8C909091969494
9698989B9B9A9B9A9C9B989B9C9D9E9D9D9DA0A39FA0A1A2A3A1A2A4A2A6A8A9A6A6A8A6
ABA9AAA9ACABACAEAFAFAEB0B2B2B3B6B6B7B8BABCBDBDBDC0BFC0C0C2C3C2C0C1C3C4C3
C5C3C4C3C3C2C1BFC1C0BEBEBDBAB9BCB9B8B5B3B2B4B0AFB0B1ACAEABABA8A5A8A7A4A5
A5A3A7A6A7A6A8A6A3A4A7A8A6A9A6AAAAA7A7A7A9AAA8A9A9A7A8AAAEA8ACA8A9A8AAA8
AAACA9A9A9A8A5A8A8A6A7A8A8A9A8A9A8A9A8A8AAA8A8AAA7A9A7A9A8A4A6A2A4A3A2A1
9F9F9E9C9C9A9B98989996949493928E8D8B8B8786868381807E7C7B7A78757473716E6B
6B686563615F5E5A595553524E4E4A494643413E3D3A3837363331302E2E2D2C2B2A2A29
292928282828272727272727272727272726272627262626272626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262627
26262626272726272727272727272727272828292829282929292A2B2C2D2E2E30313134
3436383C3F43484A4C4F5051535354565457575858585857575857585859585959595A5A
595A595B5B5B5C5C5C5D5B5D5D5E5E60605F606061636362626362636565666768666569
676A6969696A6B6B6C6E6C6D6E6D6F72717272737674757774777A77777B7A7B7A7C7A7D
7A7B7D7D7C7C7D7E7B7D7D7F8080808183858487878A8788898A8C8C8D8E8D9393969192
93939598979C9B9A99989A9B9D9C9E9B9E9A9D9C9EA2A1A19E9FA1A0A1A3A4A5A7A4A6A8
A9A9A7A9A7ABABACABAEB0AEAFB3B2B1B2B5B7B9B6BBB9B9C1BEBDC2BFC1C1C3BFC3C1C4
C2C6C5C2C1C1C1BEBDBFBEBCBABCBBB8B8B6B8B5B4B2AFB2B1ADACAAAAAAA7A7A3A4A6A5
A2A4A5A2A4A6A6A7A6A7A5A9A5A6A5AAA9A9A7A7A8AAA8A7AAA8A7A9AAA9A9ABA9A9A8A6
A7A7A7A9A9A6A5A4A5A3A6A6A4A5A7A5A8A9A8A8A7AAA6A7A7A5A7A8A4A5A4A3A2A2A19F
9E9E9D9E9B9A9A979894969491918E8E8D8B86888684807F7E7D7A7877757373706D6E6A
68676461605D5B58565352514D4A4A4745423F3E3B3937363431312F2E2E2D2C2B2A2A29
292828282728282827272727272726262627272726262726262726262626262726262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262727272727262726272728272728282829282829292A2A2A2B2C2D2E2F313233
343636393C42484A4C4F5153545455565657595958575959595957585A585959595A5B5A
5A5A5B5B5A5B5D5B5C5C5D5C5D5E5E5E5F60616162616262626263646465656766686768
68676A6A6B6B6B6B6D6A6D6E6C706F6F6F72717274737474757876787878777979797979
7B7A7B7C7D7B7E7D7C7D7E7E80807F7E82828284858686888A8B8B888B8C8F9092919191
9293959497999A989898999C9C9F9E9D9B9C9C9E9C9C9E9EA19EA09FA1A2A4A4A6A5A2A5
A6A6A7AAA6ABA8A7AAAAADABADADAEB0B1B4B4B5B6B5B7BAB9BDBFBBC1C0C0BEC1BFC3C2
C3C2C4C5C2C1C1C2C0BEBCBEBCB8BCBAB8B9B9B7B8B4B3B2B1B0AEAEABAAABA5A7A5A8A4
A4A09EA4A2A5A4A6A6A6A6A5A5A6A8A4A6A8A8A7A8A7AAA7AAA9AAA6A9A9A7A9A8A7A8A8
AAA5A8A6A6A4A4A3A4A4A4A3A6A3A4A3A8A4A4A7A6A7A6A6A5A7A6A4A6A3A5A0A5A0A0A0
9F9E98999A9999979495929190918F8C8C8789848682827F7E7B7879777573726E6D6A6A
676562605E5C59585552504E4B49494644413E3D3B39373534312F2F2E2D2C2B2A2A2A29
292928282827272727272727272727262627272727262626272626262726262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262727262727
262627262626262727272727272727272727272828282829292A2A2B2B2C2D2D2F303132
343536393D3F464A4D5052535355555656595858595959595959595A585B5A5A5959595B
5A5A595B5C5C5B5B5C5D5C5D5B5C5E5E5F6061606162616361636265646366656667686A
66686B6A6B6A6A696A6C6C6D6F6C6E6F7072707371737474747576787978797977797979
77797A7B7C7B7C7D7C7D7D7E7E807F7F7F81818483848787878888878A8D8C8F8F8D8E90
8E929193939898979798979C9C999D9B999A9E9C9D9D9CA09C9E9EA09E9FA0A0A1A1A5A5
A4A4A7A4A5A4A6A9AAA9A9ABA9ADACACAEB2B0B1AFB2B7B7B9B8BABBBCBABDBDBFBFC3C1
BEC0C3C2C2C3C4C2BEBDBFBFBDBEBBBAB9BAB7B8B5B3B6B4B1B0B0ABAEACA7A6A8A4A5A5
A1A1A0A0A2A3A5A3A5A3A4A4A5A6A8A7A5A6A8A5A7AAAAA8A7A8A7A6A7A8A6A9A9A6A4A7
A6A6A4A5A4A4A3A2A4A3A2A6A2A2A1A3A2A3A4A5A4A5A4A5A5A3A4A3A7A1A2A29F9E9E9E
9B9C9C9B97999794959292918F908D8B8A87858481817F7F7C7A76767475716F6F6C6B67
6664615F5D5B59585453504D4B49474442413D3B3A3836343331302E2D2C2C2B2A2A2929
282828272728282827272727272726262726262626262626262726262726262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262627
2726262727262727272727272727272727272827282828282929292A2B2B2D2D2E303032
343537373B3E43494E51525456585757585A595A59595A5A5B595959595A5B5A59595A59
5A5B59595A5B5C5D5B5C5E5B5E5D5E605E60606161606163636462646464646764676868
6868686869696A6C6A6B6A6C6E6E6D6C6F71707272727275757676767678797778777877
7A797A7B7B7B7C7C7E7D7D7E7D7F807E7F81818284848485878688898A8A8D8C8E8E8B8D
8E8F8F91969796989896979A989B9B9B9C9B9D9A9D9B9D9D9E9D9B9F9E9FA09FA09FA09F
A4A4A4A4A5A6A7A7A8A6A6A9A7A8AAA9ABACAFAFAFB1B2B6B6B6B6B8BBBBBCBDC0C0C3BF
BFC0BFC1C0C1C0C2C2C2C0C1BEBCBCBBBABCB8B6B6B4B5B2B4AFB0B2ACACACA9A7A5A4A3
A49F9FA0A3A2A3A2A1A1A4A5A4A5A8A6A6A5A6A6A4A8A8A6A7A7A5A5A3A7A5A7A6A5A5A6
A5A5A6A4A4A2A2A2A0A2A1A2A1A0A1A0A0A39FA1A1A3A4A3A3A4A3A1A19D9F9D9C9F9C9B
9A989A979696959492938F8E8E8C8B8A8887858481807E7D7E797975747370716D686765
646362605C58575554514F4C49484643403F3E3A3837353432302F2D2D2C2C2B2A292929
292828282827272727272726272727272727262627262626262626262626262626262626
2626262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
26262626262726272726272727272727272727282828282928292A2A2B2C2C2D2E2F3031
33343538393E41484C50535557585858595A5A5D5B5C5A5A5B5A59585A595A59595A5A5A
5B5A5B5A5B5C5C5C5B5D5D5C5D5F5F5E5E5F605F60606262646462636362656565666766
6666686969696A69696D6B6D6C6D6E6E6D6F6F7171727171717274767776767777777879
787A797A797C7B7B7B7D7D7B7E7E7C827E80808281858384848487868689898C8C8B888A
8D8C8D909194949696949695999A9B9799999A9B9B9B9CA09B9D9C9E9D9D9E9E9FA19FA0
A1A0A1A2A4A6A5A7A5A6A7A8A8A8A9A7A7AAA9ADADAEB3B1B3B6B4B8BABABBBDBCBCC2C1
BDBDC1C1C0C2C1C4C2C1C0C1BCBCBCBDBDBCB7BAB8B4B6B5B0B2B0ADABAEACABA6A7A5A4
A1A19E9FA19FA1A1A1A4A4A4A8A6A5A4A4A4A7A4A4A8A7A6A6A6A4A4A6A5A3A5A4A3A5A4
A4A1A3A2A1A09DA1A0A1A2A1A19F9F9F9E9E9F9F9FA19FA2A1A2A1A09BA09F9C9B9B9C99
999898979596919292928E8E8B8E898B87868282827F7D7C7B77767474726F6E6A696666
6461605C5B595654514F4C4A49474442403D3C3A3835343331302F2D2C2C2B2A2A292929
282828282727272727272727272727272727262626262726262727262626262626272626
2626262626262626
262626262626262626262626262626262626262626262626262727262626262626262626
26262626262627262627272727272727272728272828282829292A2A2A2A2C2D2E2F3031
33333636393B3F444B51535558595A5B5A5B5B5D5D5E5B5C5C5C5B5A5C5A595A5B5A5B5C
5C5C5A5B5B5B5D5B5C5D5D5D5D5F5F6062605F5F61606262626262616464666565656567
66666667696869696A6A6B6C6D6D6D6C6E6F6F7270717270727173747675787777777777
77787879797A7A7A7B7E7B7C7B7D7B7D7F7F7F7F81808281838485858988878C88898788
8A888C8E92919491939293959698979799989A999A9D9D9D9D9A9B9C9B9F9C9D9D9A9FA0
9FA2A3A3A1A1A2A4A4A4A5A6A6A8A6A5A7A8ABACACAEADB3AFB3B3B6B7B8BAB7BBBCBFBC
BCBEBEBDBEC0C1C2C2C0C5C1C1BFBDBEBDBCB9B6B8B5B6B5B3B3B1B0B0ADABACACA9A6A2
A1A0A09E9FA0A1A0A4A3A1A3A4A7A4A4A5A5A4A2A4A4A3A6A6A6A8A7A1A6A1A1A4A1A4A3
A2A2A3A1A39FA29D9EA09E9E9E9E9E9C9D9D9F9D9F9F9E9EA09D9E9D9E9CA09C9A9B9998
9A9695979394919190918E8D8C888787868583807D7E7B7A79767673716E6E6B69696662
62615F5D58575553524E4C48474743413F3C3B3A37363332302F2E2D2C2C2B2A292A2929
282828272827282727272727272726272627272626262626262627262626262627262626
2626262626262626
262626262626262626262626262626262626262626262526262626262626262626262626
272626262726262627272627272727272727272827282728282929292A2B2C2D2D2F3031
31333436393A3D42494F5355585B5B5D5C5C5B5D5D5E5E5E5D5D5D5D5B5B5B5B5A5B5C5E
5C5B5B5A5B5B5B5A5E5D5F5E5F5E5F605F60606161626263616363636265646467656767
6767676768666A696B696C6C6D6D6C6E6E6E6F6E70707271727173727677767575777878
777877797B7A797B7A7B7E7C7B7D7D7C7E817E7F80838080807F8284848789898A89878A
8A898B8B8E908E8E8E8F9291959798969794989899999C9C9C999A9A9C9F9B9C9D9D9B9C
A1A1A1A2A1A3A0A3A4A2A2A4A6A5A8A8A4A7A6AAA9AAAAACB1B2B3B6B4B8B4B8B7BCB9BA
BABEBCBFBEBEBFC0BEC2C2BFBFBEBFBCC0BBBCBCB7BBB4B6B4B2B1B2AFAEACADACA8A5A3
A2A2A09F9FA0A1A2A2A2A0A3A5A4A5A4A4A2A4A4A5A4A4A6A4A5A5A3A2A3A1A3A2A2A2A2
9FA0A2A2A0A09B9E9E9D9C9C9D9D9C9E9A9A9B9C9B9E9D9B9D9E9C9B9A9B9B9998999797
98949393919390908F8E8C8A898B86858584817F7F7B7A7776757471716F6C6C6A676562
605F5D5A595652524E4C4A49464542403C3C3A3836343230302E2D2C2C2B2B2A29292929
282827272727272727272727272726272727272626262627262626262626262726262626
2726262626262626
252626252626262626262626262626262626252626262626262626262626262626262626
26272626272627272626272727272727272727272827282829292929292A2B2C2D2E3030
31323335383A3C3F444C52575A5A5C5D5E5D5D5E5F615F61605F5F5D5C5D5C5C5B5A5A5B
5B5D5D5C5B5C5C5D5D5D5D5C5F5F5F5F5E5F616061616262636264626563656566666666
66656867676767676C696A6C6D6B6E6B6D6D6F6F6F707070727073737573737377767777
77797879787B7A787C7A7B7C7C7D7E7E7E807E7E8180817F818282828385858786898989
8888898D8C8D8C8E8F8C8E90919396949697969897979A989C99999A9B9C9C9E9A9D9D9C
9D9B9C9CA1A09FA1A0A1A2A2A5A6A7A6A5A5A8A4A6A7ACADB0AEB2AFB2B6B6B3B7B5BABB
BEBABCBCBDBBBCBEBFBDBEC1C0C0BEC0BDBDBCB9BAB7B5B5B8B3AFAFAFAEAEAEADA9A6A7
A6A2A5A0A09FA3A0A2A1A4A4A2A1A2A2A1A5A6A2A2A0A5A6A3A4A3A3A2A0A4A2A29E9CA0
9F9D9DA09F9D9D9B9E9C9E9D9C9A9B9B9C99989C9B9A9C9A9B98999997959A9697979794
9594939092908D8C8D8C8A88878786848181807E7C797A7676747270706C6B6967656261
5F5D5C58575452504D4C4A464542403F3D3A3937353432302E2E2E2C2C2B2A2929282828
282728282727272727272727272626272727262626262626262726272626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262627262626262626262626
26272626262726272727272727272727272727272727282728282929292B2B2C2C2E2F30
3132333536393B3F42495257595B5D5F615F616061616363616261605E5D5D5E5D5D5C5C
5B5B5D5D5D5C5D5B5C5C5D5D5E5E5F5E5F5F5F6062626162626262636464636466646565
68686669676667686A676969696C6B6C6D6A6E6E6F70706F706F70717273737374767576
7777777779767779787A7B7B7B7B7B7D7C7E7F7E7E7F7F7F808181817F84838685878787
87898B898D8C8D8B8B8D918F9391929491959695989696999B999A99989B9B9C9D9A9A9C
999D9E9D9F9FA19EA19FA0A1A2A3A4A5A6A4A3A5A6A8A7ABADADAFACAFB1B2B1B6B4B9B8
B9BBBCBDBCBBBDBABDBEC0BEC0BDC1BDBFBBBCBCBBBBB9B6B6B4B5B0B1AEADADACAAAAA7
A7A7A5A4A3A0A29FA29FA3A1A2A3A3A4A3A3A7A6A4A4A1A2A4A1A1A4A3A2A3A1A2A1A09D
9E9EA09E9C9C9B9B9A9A9C9B989B96989699999698999696969796979695959795939191
929291908E8F8E8B8D8A89898582848382807F7D7B7879747374716F6C6B6A666664625F
5E5C5A565652514F4C49484644423F3D3B393635343231302F2C2D2B2B2B2A2929292828
282827272727272727272727272727262626262626262626262726262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
26262626272626272727272727272727272727282728272828282829292A2B2B2C2D2F2F
3031333537393C3E40474D545A5D5F61606262616161646565626362615F5E5D5D5D5C5E
5C5D5C5C5B5B5C5E5D5C5E5D5F5F5F5F5F5D60605F616362626363626464646565656565
66656668686668696768696B6A6B6A6C6C6E6D6E6E706D6E6F6F71737372757375747575
76747577777979787A787C787C7A7C7D7B7C7C7D7E7C7E7D838081818182828284848588
868988898988878C8B8B8D8F92939491959593959695979796979A9999969B989A9A9A99
9A999C9D9F9D9EA0A19E9EA0A1A3A5A7A0A3A5A4A6A6AAA9ACAAABABB2ACADAFB2B0B4B5
BABABCBABEBCBCBDBBBABFC0BDBEBCBCBDBCBABAB9BBBBB8B5B5B4B3B2B1AFAFACACAAA8
A4A7A4A5A4A1A1A3A0A3A2A0A2A0A2A0A4A4A4A1A5A6A2A3A2A0A4A2A4A0A3A2A19E9C9C
9F9C9D9C9A9B9C9A9A979A9A9B9696969794969A96969493949496939594959194929191
91908D908B8D8A8B8A8988868383847F807E7C7C7B76777472716D6D6C6967666363615F
5C59585454504F4D4C49474542413E3C3A3837363432312F2E2C2C2C2B2A292929282928
282828272727272727272726262726272627272626262726262627262727262626262626
2626262626262626
252625262626262626262626262626262626262626262626262626262626262626262626
2726262626262627272727272727272727272727272727282828292929292A2B2C2D2E2F
3031333437383A3B40424851595E61616364646363646765656564636361605F5F5F5C5D
5D5E5D5D5C5D5C5E5D5E5E5D5E5F5E5E605F606161636162646364626264666464636463
65666566676968686A69696B6B6B6A6B6C6C6C6C6E6D6E6E6F6E6F716F71737674747576
7576757777787779797A7978797B797B7D7C7C7C7D7C7D7E7E8281818081838184838384
868788878787868988898C8D8F918E8E939294949696949996999797979799999A999B9A
99999D989D9D9D9EA09D9E9FA0A2A49FA3A1A3A4A4A6A3A5A8A9ABAAA8ABAFAEB0B1AFB2
B8B8B9B8BAB8BABBBEBCBFC0C1BEBEBCBEBDBABCBDBAB8B7B8B7B6B6B3B1AEADB1ADACA7
A8A7A8A6A6A4A6A2A2A6A4A4A5A1A2A1A5A5A3A3A5A3A2A1A2A3A7A6A2A3A2A09F9F9D9D
9C9C9E9E9B9B99999C9697979897959594979494959491939392929394949390928F8E8F
8E8D8F8B8E89898B8B878584818280817E7E7A7B7879757371716E6C6B6C69656461605D
5B58565451514F4A49484543413E3C3C3938353333312F2E2D2C2C2B2B2A2A2929292828
282728272727272727272727272727262626262726262627262627262626262626262626
2626262626272626
252626252626262626262626262626262626262626262627262626262626262626262726
26262726272627272626272726272726272727272827282828282929292A2A2B2B2C2E2E
303132343537393B3D42464D565B616466676767666765686868676766666362605F5F5E
5E5D5D5D5F5D5D5D5C5D5C5E5D5F5E5F6160616162616163636264626464646464636365
6565666765666866676866696B696A6B6C6B6C6B6D6E6D6E6E6C6E707070717373737273
72727677797677777778787B7B7A7B7C7E7A7B7E7D7F7F7D7B7E7F7E80817D8182828285
8586878686878886898A89888A8C8E8F8D8F929293969597979598969997989899989A98
9B9B999A9B9B9C9A9D9D9B9C9E9EA0A0A2A1A3A1A2A1A0A3A4A5A6A6A8ACAAABADAEAFB0
B2B6B6B8B7B7B6BCBBBFBEBFBDBEBCBDBFBBBFBDBCBBBBB9B7B7B5B5B3B1B1B2AFADAFAA
A9A8A8A7A7A5A2A5A5A5A2A2A3A2A3A1A3A1A4A2A2A4A3A1A2A4A5A3A1A2A1A1A0A09C9D
9B9C9C9A9A999797989993949595939393939492939494918E8F8D8F91918F8F8F8C8D8E
8E8C8D8A8989888887858484827E837E7B7B797876757372706E6B6B6869666662605F5D
5A575653514F4C4A48454442403D3C3A3837343232312F2D2D2C2B2B2A2A292929292928
282827282828272727272627272727262726272726262627262626262626262626262626
2626262626262626
262626262526262626262626262626262626262626262626262626262626262626262626
2726262626262626262626262726272727272727272827282828282829292A2A2B2C2D2E
2F3132333536383B3D404449525A6164676769696968696A696A6A69676865656261605F
60605E5F5E5C5D5D5D5F5E5D605F616061616160635F6162616364636365666564656564
65666667686666676767686B6A6C6C6A6C6C6B6A6C6D706E706C6D706F71727174707173
73747677767678767877777A7879797B7C7C7B7D7F7C7C7B7C7D7C7C7E7E7F8080828082
838384848586888A8789888A8A8B8A8A8B8E8F9192929493939898959696999699989899
98999C99999997989A999C9D9B9E9FA09F9FA1A0A0A0A0A2A3A3A4A4A7A8A9A9ABACA9AC
AEB1AFB2B4B6B7B9B7B9B9BCBDBBBCBEBCBCBEBEBCB9BABBB9B8B6B3B2B0B1B0B0AFAEAB
ABACA8A7A7A6A7A5A6A4A4A5A5A3A3A1A4A1A2A2A2A1A2A2A6A5A3A3A1A2A19F9FA2A09D
9C9D9C989B969695959695969593939492939091918F908F8F8E8D908D8E8F8B8C8C8D8D
898B8B8A89878785868382827F7F7F7D7B79797677737270716B6A6968656461615F5B5A
58565553514D4B4B464442413E3C3B3937353333312E2E2D2C2B2C2A2A2A292929282828
272727272727272727272727272727272727262727262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262626
26262626262626262626272727272727272726272727272728282828292A292A2B2C2D2E
2F2F31333436383A3C3E43464C545F65686B6A6B6B6C6A696B6B6C6B6B6A68696463625F
5E5F5F5D5E5E5E5C5E60605E5D5F5E605F61636160606162646364636363656462646465
666566686666666868666868686B6B6B6B6B6B6B6D6E6D6E6E6E6E706F706F7171737273
72737374747676787778777679787A7B7C7B7C7A7D7E7E7E7D7C7D7E7C7F81807F818080
8182818386858586878888868889888C8D8E8F8E90909494949394939496969698999597
9797989798989A999A9A9C979C9B9A9B9C9D9FA1A1A0A3A0A1A2A3A3A4A3A8A7ABA9ABAA
AAADADB1B1B2B4B5B5B6B9B9B9BBBBBABCBBBEBABDB9BBB9B6B7B7B6B5B3AFB4B0AFB0B0
AEACACA8A8A8A6A8A5A4A6A3A4A5A6A5A5A3A3A2A4A4A1A4A2A2A1A2A1A0A19FA19E9E9C
9C9B9A999797979893949494949290909091918F8F8D8C8E8C8B8D8D8B8B898A8C898B89
88888A878786858485808080807F7E7A79777776747271706E6C6A6766656260605E5B59
565452504F4D4A484643423F3D3B3A3736353331302F2E2D2C2C2B2B2929292928282828
272728272727272727272727272726272627262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262627262626262626262627
26262726262626262627272627272727262627272727272828282828292929292B2C2C2D
2E303132353537393B3D414449515A61686E6D6E6E6A6C6D6D6B6D6C6D6C6A6868656262
6161615F615E615E5E5F5F5F605F5E605F60616160616161616464636563636464656465
64646664676867656767676A69676B696C6B6B6B6E6E6E6E6E6E6F6E6D6E707072707170
74717273757576777475757678777B78787779797E7E7D7D7E7C7E7D7E7F7C7F81807F7E
7F8282828282848585878885898888898C8D8C8E908F9392919395969596959695969796
9A97969597969697999C9B9C9D9C9C9D9E9BA09D9C9F9D9FA2A0A0A2A1A1A3A3A6A8A9A8
AAABAEACB0AFB1B2B3B5B6B2B6B8B8BABABABAB7B9BAB9BBBAB8B5B5B8B7B2B3B3B0AFB0
AEADABA8A8AAA4A7A6A5A4A4A6A6A6A5A4A4A4A3A4A4A5A3A2A2A1A0A1A0A2A09EA0A09C
9B9A999797969595939392949291918F8F8E8F8D8E8C8F8B8C8A8B8A8B8A888887868787
85858785858484838180807C7E7B7B7A7A75757272716E6D6B6A68666562605F5E595957
5554514F4C4949464543413E3B3A3837353332312F2E2D2C2C2C2B2A2A2A292829282827
282727272727272727272727272626262626262626262627272626262626262626262626
2626262627262626
262626262626262626262526262626262626262626262626262626262626262626262626
262626262627262727262727272627272726272727282727272828282929292A2A2A2B2D
2E2F3032333537383A3D4043474E5760666B7170706E6F716F706F6E6D6E6E6C6B6A6865
6260626162606061605F60605F605F616061615F62616161616363646363666565656465
6463636566686766666967686768696A6A6B6B6C6F6E6D6F6D6C6D6D6E706E706F6E706F
70727372767675747674767877767778797B797A7B7A7B7B7E7B7D7D7D7F7F7E7F80807F
7F8081818283818186878587878789898D8B8C8E8F909090929294939595979596999699
949699969698979698999A9B98999B9A9B9B9E9E9F9D9D9F9FA0A09EA2A0A2A1A4A3A7A5
A6A6AAABAEAEAFB1AEB0B4B4B3B5B6B6B9B8B9BAB7B9BAB9B9B7B6B7B6B4B4B1B2B5B0B0
AFB1ABADABABA9A7A6A5A7A7A6A4A4A4A5A6A6A1A4A3A6A3A3A4A49FA4A09F9E9F9E9D9B
9D9B9A97969593958F9291919090918F8D8D8D8D8D8B8B89888A8A888788868686878785
8383828480818281807D7C7C7D7B79777775747271706D6C6A68676464615F5C5C585954
5352514C4B4A484543403F3D3C3A3836343231312E2E2D2C2B2A2A292928282828282827
282727272727272727272627272726272727272626262626262626272626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
26262726262626272626262627272726272727272727272728282828292829292A2A2C2C
2D2F303233343638393C3E4147485059636C6F7374747172717171717170716F6C6A6967
666263636262626060606161616361606261616363606262626163636365666564656464
646563636467676769676767676969676A6A6D6B6E6C6F6F6C6C6D6F706D706F7070716F
71717273747573737675747577757777787978787B7B7C7B7D7C7B7C7F7F82807E817F81
828182808080828387858686858787888A898B8C8B8E8E8E8F8F91949492949393969497
9594979595959496969796979A9797999A9C9B9B9A9B9B9D9B9B9DA2A0A1A2A0A3A4A4A3
A5A6A6A7A7ACABADADAEB0B0B2B5B4B8B6B7B8BABAB9B9B9B8B7B6B8B5B6B5B0B4B0B1B1
B0B0AFAEABACA8A8A6A6A7A8A6A6A5A6A6A4A5A2A5A5A5A3A5A1A1A1A2A09FA09E9E9C9F
9A9C9A98989495939491908F8E908E8E8D8D8B898A878789898987868586828485828280
83818280837F7D7E7E7A7C7B7B797877767372716E6D6B6B6A676464605F5D5C59585554
524E4D4B4A484644423F3E3D3A3937353331302F2E2D2C2B2B2B2A292929282828282828
272727272727272727272726262726262726262727262626262726262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
2626262627262726262726272726272627272727272728272727282828292929292A2B2B
2D2E303033343537393C3E4144484C5660697175767376757373747270727270706E6D6C
696865666564616262626263616161626161616060616362626263646464656565646466
65656565666765666667686667666968696A6A6A6B6C6C6B6B6C6B6D6D6E6E6D6F6F7070
7071717071757373727374737575747777767977787A7A7B7A7B797D7E807E817F81807E
80818180808082818182838484868887898B8A8C8B8D8B8F8D9192919292919194929592
9596959793949894969594959895969798979A9B999C9A9B9C9EA19E9F9E9FA1A0A0A3A4
A3A5A7A7A9AAA9A8ABADAEAEB0B1B6B6B3B7B5B7B6B6B8B8B9B9B7B7B9B6B4B4B2B2B0B0
AFB0AEADAEAEADAAABA8A8A7A9A8ABA5A6A5A4A6A1A4A4A5A3A3A0A2A2A0A19F9F9E9F9B
9D9A9A9997969593949091908C8A8F8D8A898B8A8A8A8783868884858582828381808281
807E7D7E7F7E7B7B7A797A797876767573726E6E6D6B6B67666364605F5C5C5A58575552
50504E4A49484442403E3D3C3A37363332312F2F2D2C2C2B2B2A2A292928282828282828
272727272727272726272726272726262727262626262626262626262626262626262626
2627262626262626
252626262626262526262626262626262626262626262626262626262626262626262626
26262626272626262726272726262727272727272727272727282828282829292A2A2A2B
2C2D2F3032343536383A3C3F41464A505A656E7577787B7878757676737475747071726F
6D6A68666566666462636463646263646262616162636361626163626564656465646566
6566676666666867676869686867676869696A686A6D6D6C696E6D6C6D6D6D706E707271
706F72737271727374747574737676777576787778797A7B7C7A7C7C7E7E7E817E7E7F7E
817F7D7F7E7E8081818283848482858789878A8A8A8B8C8C908E90908F9090928E929393
95949590939392939494949495959797969899979A9A98999D9B9C9B9D9C9F9DA19FA1A2
A3A2A6A6A6A7A7A7A6ABACACAFB1B3B3B4B3B3B7B5B6B6B6B6B5B6B7B4B8B6B6B4B3B3B3
AFB0ACAFACADABACAAA9AAABA8A9AAA7A6A7A9A6A3A5A8A5A6A1A4A3A3A29FA09C9FA29D
9A9E9A989696949491918F8F8D8C8B8C8B87888787868684848385828181808180807E7E
7E7E7C7E7D7D7A7A7A7879787575757371706F6C6A696868666562605D5D5B5956555351
4F4C4A48464443423F3D3C3B3836353332302F2F2D2C2B2A2A2A29292929292827282728
282728272727272727272726272627262627262626262626272626262626262626262626
2626272626262626
252626262626262626262626262626262626262626262626262626262626262626262626
2626262626262726262727262626262727272727272627272728272828282829292A2A2B
2C2D2E2F31323437383A3B3E4043484D535F6B72767C7B7A777878797675757674727170
6D6C6B696866676664656464636461636063636161626263626364636665646366656465
6466636667666666656867656968676868696A696A6A6A6B6D6B6C6D6D6D6D6C6E6D6E6F
706C707172717274737374717375757575767679787778797B7B7C7B7D7E7E7B7E7E7D7C
7E7D7F807E7E7E7E7F8080848485858586848788878A8A8A8B8B8E8E8F90908F8F908F93
919292919293959295929195959594969699979795989B979A989B9E9A9B9C9C9D9D9EA0
A4A1A2A1A3A4A5A7A5A8A7ACAFAFB3B3B3B2B3B3B5B5B6B5B5B8B7B5B4B7B7B7B4B6B0B3
B1B1B1B1B0ADADAAABACACACA9A8AAAAABA8A7A8A8A6A6AAA9A4A5A5A2A2A3A19FA09D9C
9A9C98989999939492908E8E8B8C898A88898887858685818282827F81807F807E7E7F7C
7D7A7C7979777A7979757375747474706F6D6C68686865666361605F5D5A59585553524F
4D4B4948474241403D3D3B3837353332302F2E2D2C2C2B2A2A2929292828282728272827
272727272727272727272627272626262726262627262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262726262626262626262627272726272726272727272727282727272828282829292A2B
2C2C2D2F3132343537393B3C4043464A4F576570757A7C7F7E7E7A797B78787977757573
72716F6E6C6969676A686865666566626364626262616361656364646563656664636566
65656666676767656765666768676568686767676A6A6C6A6B6A6C6C6C6C6F6C6E6F6C6F
706F6F71717171717073747472747574757679777677777A7A7B7B7B7D7C7C7C7B7C7B7B
7F7E7D7D7E7B7C817F818281818283828384868686878786898A8B8A8E8D8E8E8F90908F
92919093919294949490919493949694959495989696949798999B999A9A989A999A9C9F
9DA09E9FA1A2A3A3A7A4A7A8ADAFAFB3B3B4B4B4B6B3B7B5B7B4B4B5B6B7B6B3B2B2B3B1
B0B1B1AFACB0B0ADACAFADADAAABACABADACA8ABAAA8A8A7A6A6A6A8A6A2A1A2A3A09F9D
9C9D9A97969594959392908D8C8B8A888988858483848483828180807E7E7D7C7C7B7B7B
7A7A7877777776767673747272726E6F6D6B6A686866646361605E5C5A5B56555450504D
4C4A48464542403F3C3C383735343231302F2D2D2C2C2B2A2A2929292928282828282727
272727272727272727272726262726272726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626252626262626262626
262626262627262626262626272626262727272727272727272727282727292829292A2A
2B2C2D2F3031333436373A3B3E4145474B525C6674787C7E807D7E7C7B7B7E7B7C797775
74737072706C6C6A6A6B6968656667656665646362626163626364636564626664626563
656567676565676766666766676766696667696A686B6A6B6A6B6B6B6B6A6D6D6E6D6E6E
6F6E6D706F6F7072717273737172727272757474777779787A787C777A7A7A7B797B7B7C
7D7B7D7C7C7C7D7D7D80817F818183848384858784848586878787888B8A8C8E908E8F8E
90909091939191939391929293939493929394959897969896969A9A9A9A9799999B9B9E
9C9E9E9F9FA2A3A7A3A5A5A8A8AEB1B2B1B3B4B6B4B8B3B4B3B2B4B3B5B5B2B3B1B2B5B5
B3AEADB2B0B0B1ABB2AEB1AEAEACAEACADAFABACACA8AAA8A9A9A7A4A8A3A3A1A3A2A09F
9E9B9B989795949391908E8C8B8987878686858283848181807F7E7E7E7D7C7B7A7A7B7A
797676767774747473737170706E6D6C6D6A686666626460605E5D5A5957555352514D4D
4A49474442413F3E3B3A3836343431302F2F2D2C2C2B2A2A292929282928282727272727
272727272627262727262727262727262626262626262626262626262626262626262625
2626262626262626
252626262626262626262626262526262626262626262626252626262626262626262726
262626262626272626262626272627272626272727272727272728282728282928292A2A
2B2B2D2E2F31323435373A3B3D3F4347484D555E6B767C81818182807D7F807D807D7D7A
787674727172706C6D6B6B696B6868666664656566646363646464656464636363656464
6565666765656567656765676465696769686A69696B696A6C6B6C6C6C6C6D6C6B6E6D6D
6C6D6E6F6F6F7070727071737373737573737275747579797878797B787978797A7D7B7B
7C7B7D7C7D7D7D7D7E7D7E7F7F7E80808483838385848584848587878B8A8C8A8C8C8D8D
8E8F9191929091928F939391919093919394929494949492959698999B9A99979B9A9DA0
9D9D9E9C9F9FA2A0A5A2A4A3AAADAFB0B3B4B4B3B6B5B4B3B4B4B1B1B2B2B2B1B3AFB4B1
B3B0B0B0B0AEB2B1B1B2AFADADB0AEB0ABAEADACAEAAAAA8AAA8A5A7A6A4A5A6A2A0AB9F
9C9A9A9B9B96959491918F8E8D8A898785848283808081807D7C7D7B7C7B7A7B7B787876
757775747273727270706F6E6E6D6B696A6967666663615F5F5B5B59565553524F4E4D4B
49474443413D3D3C393937353431312F2E2E2C2B2B2B2A29292928282828282727272727
272727272726262727272626262726262626262627262626262626262626262626262626
2626262626262626
252626262626252626262626262626262626262626262626262626262626262626262626
26262626262626262627262627272726272727272727272727272727272728282829292A
2A2B2C2D2F3032333535393A3C3E4244494B52596371787F83838584818281848285817E
7E7B7878777473716F6D6D6C6B6A6A696768686665656464646564646263626465636565
6564646465666466666366656567686869686A68696969696B6A6C6C6D6B6A6C6D6D706C
6D6D6D6D6D6E706F6F6F707272717072737375737476757979797677797878777A7B7B7B
7A7B7E7B7C7C7E7C7E7C7D807F7E7F80807F828283858582848586868889888C8A8C8A8D
8C8D8D8E908E908F8F918F8E8E908F9095929292929293959496979997979A97999B9F9F
9D9C9B9D9B9C9F9FA0A2A2A4A6A9ACB0B2B1B3B4B6B2B3B3B3B2B1B4B2B3B3B0B2B1AFAF
B1AFAFAEB0AEB1B0B0B1B1AFB1AEAEADAEAEACAEACACABAAACA7AAA6A8A4A3A5A3A2A19F
9D9B9A9A9A9795939190908C8D8A86858481808182827E7E7D7C7B7A7C787977787A7875
757573717271706E6D6D6D6D6A6A69676666656362605F5D5C5A5A57565451504E4E4B49
47454443413E3C3A3A37363432312F2F2F2E2C2B2B2A2A29292928282828282827272727
272727272727272727272727272626262726272626262626262626272626262626262626
2626262626262626
252626262626262626252626262626262626252626262626262626262626262626262626
262626262626262726262626272727262627272627272727272728272727282929292929
2A2A2C2C2D2F3032343537393B3E4042464A4E545C69747B808586888785858486848783
817D7B7B7778767472716F6F6D6C6D6B6868696968676667646466646463636263636365
64656464636465656766666364656568676868686967696869686A6A6C686B6B6C6E6E6D
6D6D6D6E6D6D6D6F6E6E716F6F7070737274737272747476787877757678787679797A7B
7C797B7D7C7C7B7C7C7C7E7E7D807F7F7C7E80808083838483848587868787868888898A
8B8D8A8D8C8C8E8D8F91919191908E90918C909092939493949297979795979A999A9C9B
9C9A9898989D9FA09FA0A1A0A2A5A8A7ADAFB0B1B0AFB1B0B1AEB0B0B2B0B0B0AFAFB0AD
AEAFADB0ADAFAEB0AEB0ACAFB1AFAFADAFAEACADABACACABA8ACA8A6A6A7A5A6A4A3A39F
9C9A9D9C9B98979492908F8D8C8A8985848182807F7F7C7B7B7979777778777878747573
7272727070716E6E6D6C6C696969676665646161605E5F5C5B5756545452524F4D4A4A49
4644423F3E3C3B3A3937353432302F2E2D2C2C2B2A2A2A29282928282828282827282727
262727272726272726272626262627262626272626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262627272626262727262626272727272727272828292829292929
292B2C2C2C2E2F31343437393A3D404346494B4F58626D78818086898888878788878886
8382807F7D79787774747371706F6C6A6E6A6B6B68676867686565666562646365636464
6563656564626464636665676465656666676868686868696A6A686A6A6A6A6C6D6C6F6E
6F6D6C6B6D6D6C706F706E6F717172727272737273727274757A7776787679787879787B
7B7C7A7B7D7B7B7E7D7E7A7E7C7D7D7C7D7E7B7F807F8282828585848585858687888687
8989888A898B8C8A8D8E908D8F8F8F8F928D90908E928F90929293969596949697989798
9B9A9998989A9B9EA09F9D9EA3A4A6A7AAABAEAFAEB2B0B0B1AEB1AFACADAFAEB0B0AEAE
ACB0ADAEB3B0B1ADB0B0AFAEB1B0B0AFB2B0B1ADABAEADAEACABADA7A6A7A6A3A5A5A3A2
9D9E9E9B9997959492918E8E8D8C88868481807E7E7E7C7A7A7876777675757474747472
717371706F6D6D6C696A6966666565646361625F5F5C5C5A5955555451514F4D4D4A4946
4442413F3D3C3A38373534332F302E2D2D2B2B2B2A292A29292928282828272727272727
272727272727272726272727262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262526262626262626262626
272626272626272626262626262626262726262727272727272727272827282828282929
292A2B2B2D2D2E30323435383A3B3E4043464A4C525A66717B8087898A8D8A8B898B8A89
8A8583817F7E7D7C797675727271726F6C6E6C6A6C6B696A676867686766646464636465
63656465666564656666676464646667666668666868676969686A69696A6B6A6A6A6C6F
6F6E6D6C6A6C6D6D6F716E6E6F6F70727273717373727273737677767876797677797878
787A7A7A7A797C7C7C7B7C7D7C7E7C7B797C7D7C7C7E7F82838181838081868784868784
888887888989888A878B8E8F8D8E8D8E8F8F8F8E918E9190909094939393949196969498
979699979798999B9F9A9D9EA1A1A3A2A7A9AAAEACADAFAEB0ADAFB1AFABAEAFAEADB0AD
AEAFADAEAFAFAFAEAFB0AEB0B1ADAFB2AFB0B2AFAFAFB1ADADACA9AAA7A7A6A7A4A2A3A2
A09F9E9B9A97969592908D8C8B8B888680837F7F7E7C7B7A7B7777777573747271716F70
706F6F6D6E6D6C6A68676865666363626260605E5C5B595756555352504F4E4C49484645
43403E3E3C3B393836343331302E2E2D2C2B2B2B2A2A2928292828282728272727272727
272727262727272727262627272626272626262727262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272726262626262626262626272727262626272727272727272727272728282728282929
292A2A2B2B2D2E2F31323436393A3D3F4244474A4F545C67737D81898B8C8D8A8E8C8D8D
8C8C88858181817F7C7A797677747272726D706E6D6C6B6A676768696665656566636365
65636464646663666467656565646766666768666A68686968696B6969696B6A6B6B6B6E
6C6D6D6C6D6C6D6D6E6F706E6F6F70707071757573727273747574757679767978787878
797878797A7A7A7D7B7C7A7B7D7B7B7D7C7C7B7B7D7B7E7E808180828081818482838285
8886888685868887888A8B8B8D898A8B8C8C8E8D918E8F8E8F9291919491919493959696
9797989696999B9B9C9C9A9C9D9EA1A4A2A5A7A7AAACAFAEADABACAEAAA9ADAAAEACADAF
AEAEAFAEB2AEADADAEAEAFB0B2B3B2B4B2B5B6B2AFB1B2ADAFAEABA8ADAAA9A8A4A3A1A0
A19DA09D9C9995959492918C8C8A89858380807D7D7B7A797875757373717171726F6D6F
6F6D6D6A6C6A696968666665646262625F5E5C5B5A585855555453514E4E4B4A47464543
41403D3D3B393736353331302F2E2D2C2C2B2B2A2A292929282828282828272727272727
272726262726262727272626262626262626262626262726262626262626272626262626
2626262626262626
252626262526262626262526262626262626262626262626262626262626262626262626
262626262626272626272626262726272627262627272727272727272727272828282829
292A2A2A2B2C2D2F30323336373A3C3D404245494D5157606B777F878C8D8D90908F9090
8F908D8B8A8783807F7E7C7B7A797775757171706E6E6B6D6C6C6A6A6867686666666566
66646263636464656563646664656764666767676868666869676969686A6B696A6A6A6B
6A6D6B6C6D6C6C6C6D6D6F706C6C6D6F6E6F727675757272727473757776787575787878
7675777979787B797A7C7D7D7C7B7D7B797A7C7B7D7A7D7F7F7E7D818181828282828383
838486858686878685888A8B8B8A888C8C8D8D8E8F8D8C8F8D90918F92918F8F92949293
9395959597989697999B989C9E9C9F9EA0A3A2A6A8A8AAADACABABABABACABAEAEADACAC
ADACADAEAFAFB0B0B1B0AFB2B3B1B3B4B5B5B8B7B5B6B3B3B1B0B3B1ADADABAAA6A7A5A1
A3A1A09C9B9896959590908D8D89888683817F7B7B7A79777775727271707071706D6F6C
6C6C6B6A696868666664636264605F5E5F5C5C595957555452514F504C4B494846454341
403F3E3B39383735333230302E2D2C2C2C2B2A2A29292929282827272727272727272727
272727262727262727262626262626262626262626262626262626262626262626262626
2626252626262626
252626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262627272727272727272727272727272727272828282828
29292A2B2B2B2D2E2F30333336383A3C3F4144464A4D5359646F7C848A8D8F9092969592
9394918E8B8987858283817E7C7A7A7778767472736F6F6D6C6B6C6A6B69676968656666
6464646464646465636564666766676666666768666866686969686869696A6A6B6B696A
6A6B6A6A6A6C6D6C6B6D706E6D6D6D6C6F6E6F7172757573757172747377747778787776
7778777779787979797A797A7B7B7B7A797B7B7B797D7C7B7D7D7E807F807F817F7F8081
8182848586868488878A8B86898A888B8A898C8C8C8E8D8D8D8E8F8D8F8F8D8E8E919393
9494969596969898969798989C9E9B9D9DA1A2A3A3A7A8AAA9ACA7ABAAA9A8A9AAACA9AA
AEAFAEADADAFAFB0AEB0B4B6B4B5BAB8B7B9BAB8B5B8B7B8B8B6B4B1B3AFADABA7A6A59F
A0A09F9C9A97989694928F8D8B89888584817F7D7A78797574737371716F6F6E6D6D6C6C
6B6968686866666564616161605E5D5D5C5B595756545352514E4E4C4B4A484646424040
3E3C3B393736343432312F2E2D2D2C2B2B2B2A2A29292828282828272827272727272727
272727272626272727262726262626262626262626262626262626262626262626262626
2626262626262626
252626262626262625262626262626262626262626262626262625262626262626262626
272626262626272626262626262626262627272727272726262727272727272728282828
2829292A2A2B2C2E2E3031333537393B3D4143464A4B50535C667580888C918E92969696
9595959293918D8A898481817E7D7C7F7979757275737170706C6B6A6A6A686768656465
6566646464656463646464666663646666656867676869686866686967676A6A6B6A6C6A
6B6A6C6B6A6C6A6A6D6D6F6E6F6C6C6D6C6D6F6D70707272717273717674757576757678
757777787877787779787B7A797E7A7A7A7B7A7A797C7D7C7C7B7C7C7E8081807F7F7F7D
8080847F8282848586868788878887888A8A8B8B888B8C8D8C8D918F8F8D8D8F8F8D8F90
909192949497959495929797999A989A9A9D9EA0A1A1A4A7A8A6A7A9A5ABAAA9A9AAABAA
ADABACAEADACAEB2AFB6B8B6B9BAB8B8B9BABABCBBB8B9B7B9B7B9B8B3B4AFAFAEA9A6A9
A3A19D9C999798959491908D8C8B8684807F7E7B7A797675757371706F6D6E6A6D6A6968
68686566666564636262615E5F5C5C5B5A5757565350514F4F4D4C4B484846454342403F
3D3C3A393637343332312F2F2D2C2B2B2B2A292A29292928282827272727272727272727
272727272726262726262626262626272626262627272626262626262626262626262626
2626262626262626
252626262626252626262626262626262626262626262626262626262626262626262626
262626262726262626262626262626262626262627272727272727272628272727282828
292929292A2A2C2C2E2F30323336383A3C3F4143474A4E51565F697781878C9293949596
97979A9A979292908C8987848482807F7C7B787875757473716E6D6C6C68696968676666
6463656566636465636365656465646765656667676769676869686A68686B6A6969696A
696A6C6A6A6A6C6C6C6D6D6D6D6C6D6F6D6D6E6C6D706F72717372727275747672757474
7778787877797777787779797B79797A7A7A7A7B7A7A797978797B7E7B7E7E7F807D7E7D
7E7D7F8182838283848685868888848A8989898B8A8A8A8A8B8D8F8A8D8C8D8B8D8E8E8E
8F8F909090949693939492969897999A98999C9F9C9FA3A2A5A4A6A6A5A7A7A6A9A7A7A9
ABA7ABACACADB0B0B4B6B9B7BCBABABBBCBBBEB9BBBBBBBCBAB7B9B5B8B3B2B1AFACAAA8
A7A39D9A9B98979695928F8C8C888784827E7D7B78757671747170706C6D6C6C6A696B67
6765656565646361605F5F5B5C5C5959575756545451504E4D4A4B494745444242403F3D
3C39393736343332302F2E2D2C2C2B2B2A29292928292828282728272727272727272727
262626262627272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626252626262625262626262626262526262626262626262626262625262626
262626262626262726262626272626262626262727272727272627272727272727282828
282929292A2B2B2C2C2E2F313335363A3B3D3F4146474B505359606D7B82899091929697
9A9A9B9A9B98999391908C8788868683807C7A797876757372726F6E6C6C696A6A686966
676766646565646565656465646565636567666566666969696A6A6A686B6B696A6A6A6A
6A6A6A6C6B6B6A6A6B6A6B6B6D6C6B6C6D6D6E6C6E707071707072727272747373747575
7577777879777777767678777A7A797B7A7A7A7A7878787978797C7A7B7D7D7D7C7D7D7E
7C7D7E7E817F7F80828280828485858A87868987878789888C888A8B8E8B8B8B8D8D8C8D
8D8F8F928F9191949191929495959697989A99989B9FA09FA4A2A1A3A5A5A5A6A9A4A6A6
A7A9AAA9ACADAFB2B3B4B7B9BCBDBDBCBBBCBCBFBDBDBFBAC0BCBCBAB8B3B3B0B3B1ACAB
A9A3A1A1999B999693938E8E888A8783827F7C7A7876767472716E6C6C6D6A6969696768
6565626363615F60605D5D5C5A5A58585653525252504E4C4B49484745444341403E3D3B
3A39383634333230302E2D2D2C2B2B2A292A292A28282828282728272727272727272727
272727262727272626272626262726262626262726262626262626262626262626262626
2626262626262626
262625262526262625262626262626252626262626262626262626262626262626262626
262626262626262626272626262627262726262726272727272727272727272727282728
282929292A2A2A2C2C2D2E30313335373A3B3E404345484D50555A626F7E869091939699
989C9C9C9D9C9D9C989490908D8C898684827E7C7B7978767574726E6F6C6D6A6A686A69
676666646564636464656666646565646366676665676668696867686969696968696A6A
6B6A6A6B6C6B696A6B6A6C6C6A6B6E6C6C6E6C6C6C6C6C6E6E7070707172737373737274
747676767678757776777877797978787778787A7A797976797979787A7C7E7C7B7B7B79
7C7C7F7E7D7F7E7F7F81808183828485858886858687888889898A8A89898E8B8C8D8E8D
8C8C8D8E8D8F8E90929293959494949594989997999A9F9D9E9DA0A0A1A4A2A3A4A4A6A4
A8A9AAAAADB0B1B3B6B8B9B9BCBCBDBBBDBBBDC0BDBFC0BDBDB9BDBAB9B7B5B1B3B2AEAB
AAA7A2A09B9A9A959491918D8A868681827F7D7B76757371706F6D6C6C6A6A6868676665
6463626361605F5E5E5D5B595857555554525251504F4C4B494746454442403F3E3D3C3B
383836343432302F2F2D2D2C2B2B2A2A2929292928282828272827272727272727272727
262727272726272627262626262626262726262626262626262626262626262626262626
2626262626262626
262626252626252626252626262525262626262626262626262626252626262626262726
262626262626262626262626262626272626262626272727272727272727272727282728
282929292A2A2A2B2C2C2D2F30323435383A3C3E4144474A4E51575A647281898F919597
9A989A9D9E9E9E9D999A969693928F898887837F807C7A7878757471716F6D6C6A6B6969
676965666564636464656466656665656665656565666667696666676869696768696A69
6868696A6D696B6B6B686B696D6A6A6C6C6C6A6E6D6C6E6D6E706F727173737372727571
7376767675757676767778777976777779777679787B777978787A787B797C7C7D7B7B7A
797C7B7B7B7C7B7E7F7E7D808281828483848485878787888A8788878B8A8B8A898D8E8A
8E8D8C8B8D8B8E8D8F8F9292939493959696969797979B9A9D9D9F9E9FA0A4A1A2A2A4A5
A6A6AAA9ABB0B1B5B7B6BABCBABCBEBCC0BCBFBCBEBEBCBCBABBBCBCBAB7B6B4B2B1B1B0
ABA6A3A1A09C9A9794938F8E8B868781807D7D7978757272716D6C6C6B6A676768656462
6361625F5F5E5E5C5B5B5A58585654545352504E4E4D4C49494645434242403E3E3B3A39
383735343230302F2E2D2C2C2B2B2A2A2929292929282828282727272727272726272627
272626262626262727272626262626262626262626262626262626262626262626262626
2626262626262526
252626262626262626262626262526262626252626262626262626262626262626262626
252626262626262626262626262727262626262626262627272727272727272727272827
282829292A292A2A2B2C2C2D2F31323437393A3C3F4345494C4F54575F67747F888F9396
969B9C9F9D9F9EA09E9C9E99999595928E8A8885827F807C797874767172716F6C696B6A
68686665656667656564656464646567686765646566656667676665656867696968696A
69696C6C696B6A6B69696A6C6A6C6B6C6C6B6D6C6B6A6D6B6D6E70707172747174747371
7372767475757475757679777878787876777877797879787A777778787A797B7A7A7B7A
7B7A7B787A7B7A7A7C7D7A7F81828181828481848487878588888786898989888989898A
8A888B8A8A8C8B8F8D908D8F9190939292929694969897999A989A9A9C9F9E9FA1A3A3A2
A3A4A7ACAEAFB2B3B4B5B9BABBBABEB9BEBDBCBFBEBEC0BFBFB9BAB9BAB8B7B3B3B3B1B0
ACAAA8A4A09B9B9794908E8E88898783807F7D77757171706F6B6C6B6867686565666462
62605E605E5C5B5C5A5959575755535352504F4C4D49484747444342413F3E3D3C3A3938
3636333230302F2D2D2C2B2B2B2A2A292929292928282828282727272727272727272727
272727272726262626272626262626262627262626262626262626262626262626262626
2626262626262626
252626262626262525262626262626262526262626252626262626262626262626262626
262626262627262626262626262726262626262627272727272727272727272727272728
2828292829292A2A2A2B2C2D2E2F31333437393B3E404345484C5153585F6A77858C9194
999C9C9F9FA19DA2A0A3A09F9E9B9A9A95918E89888682817F7D7A78767372736F6D6C6C
6A6968686665656665656464656466676767666565666667646666666767686868696868
696A6A68696A696B6A69696A6B6C6A6B6D6A6A6B6C6C6C6B6B6B6D6E7070737073747272
6F727575757276747677767574787575757676777979797879777877777A79797A7A797B
7C7A797979787A7B7A7B7C7B7E7F81817F80828283838485858585858586858485878787
8A888A8987898A878B8C8D8D8F9091919090949291919694949A979798999B9DA09CA0A0
A3A6A8A9ACAEB2B1B5B5BCB9B9BBBCBCBBBCBCBEBBBDBEBABCB9BBB8B8B8B6B6B2B2B0AE
AFABA7A5A39E9A9994938C8E8A8686837F7C7A7675786F6E6E6D6B696866656664616261
605F5D5C5C5B5A5958575755545452514F4D4C4C4A4A4746444342413F3D3C3B39393736
34343232302F2E2D2C2C2A2B2B2929292828282828282727272727272727262727272727
262726272627272626272626262626262626262626262626262626262626262626262626
2626262626262625
252626262525262525262626252626262626262626262626262626262626262626262626
262626262626262626262626262626262726262727272726272727272727272727272728
2828282828292A2A2B2B2C2C2D2E30313436383A3C3F4144474B4E4F5659616D79869194
989B9F9E9FA0A3A1A2A0A2A3A2A19F9D9897938D8F888883817F7B797876747171716F6B
6A6A69666768676766666565646462676568676665676768656566666766656869676969
6969696A686A6A696968696A6B696A6B6A6D6D6C6D6D6D6B6C6B6D6D6F6F6E6E6F737374
74727272747374747375767577757475767474777876767977767676777775777A787978
7B777B7978797B7A7C7B7B7C7C7D7D7F8180828283838383848585858784868486868585
858787878889878A888A8B8B8C8D8E8D8E9193949290929396959394949599989C9D9DA0
9EA2A4AAACAFACB0B2B2B8B7B6BABAB9BABCBABFBBBBBABABABBB7B7B9B4B7B2B7B3B1AE
ADABABA9A2A09F9995918F8C89868582807B79797473706F6C6968676666656363626061
5D5D5E5B5B59595856555454525250504D4B4C4A4847464442423F3F3D3C3C3939383635
343331302F2E2D2C2C2C2B2A2A2A29292929282828272827272727272727272727272726
272726262726262627262627262626262626262626262626262626262626262626262625
2626262626262626
252626262626262626262526252626252626262626262626262626262626262626262626
262626262626262626262626262626262627262627262726272727272727272727272827
272827282928292A2A2A2B2C2D2D2F30313435383A3D3F4145474C4F52565B626E7D8791
95979B9D9E9E9EA1A3A6A4A4A3A29F9E9D9F9B98938F8D8784817E7F797878747172706E
6C6C6B686766666865666465656565666667676565666766686667666665656668686769
6B68696A696769696B68696A6B686A686A6A6B6B6D6D6D6D6C6A6A6B6D6F6E6F71707172
737274707272747473757477757573747675777475747675777674767877777876777777
7777767A7977797679797A797A7C7E7E7D7D7F7E80838282848482858585868483858687
8485868B88868886878A898B8B8C8E8F8D8D8F90908E8E9190949496939598989A9C9B9C
A0A1A2A6ABADAEAFB1B1B3B4B6B7B8B7B8BCBBB9B9B9B7B7B8BAB8B7B7B7B5B4B5B2B0AE
AFABA7A8A4A39D9B96938D8B898785817F7C79777572706F6C69686566656562605F605E
5C5C5B595A59585555535452514E4F4D4C4B48484646444341403F3E3D3C3B3937363634
3432302F2F2D2C2C2C2B2A2A2A2929292828282828272727272727272727272627262627
262626272726262626262626272626262626262626262726262626262626262626262626
2626262626262626
262626252626262626262525262626262626262626262526262626262626262626262626
262626262626262627262627262626262626262627262626262727272727272727272727
2828282728292829292A2A2B2C2D2E2F30333537393A3D3F4245484B4F52585B626D7D88
8F93989C9EA09FA3A4A6A5A4A4A5A7A3A1A19E9C9B968F8D8A84807F7D7B7A797572736F
6D6B6B6A68676966666565656466656664646665646768666A6768676566666865686769
6968676A69696A69696869686A696A6A68696B6C6C6E6C6B6D6B6B6C6E6B6E6D6F6E7271
717472707272717273737473747472757476757673747576747574757776777977777777
777779797877777778777978797B7B7C7C7B7E7E7E808382838484838484858584848484
8586848488868686878986868B898A8D8D8C8A8E8E8C8E91919291919292939698979B9B
9DA1A1A7A6ABACB1AFB1B2B5B4B7B7B6B7B9BAB9B7B6B7B5B4B5B8B7B4B6B4B5B2B1B1AE
ADADA8A7A8A19E989790908D8987857F7E7C797774726E6D6C69676764636362605E5E5B
5D5A595958575653545250504F4E4D4C4B49494644434342403F3E3D3B3A383737353433
32312F2F2D2D2C2C2B2B2B2A292928292828282828272827272727272727272727272627
272627262626262627262627262626262626262626262626262626262626262626262626
2626262626262626
252526262526262626262626262626262626262626262626262626262626262626262626
262626262626262626262626272626262726262627272726272727272727272727272728
272828282829292929292A2B2C2C2D2E3031333537383B3D414346494C5054585D656F7D
8A8F96999D9CA2A3A1A5A3A6A6A4A4A4A4A1A29F9E9A96928D8886827E807B7976757371
726E6D6C6B68686765666666656566636464646666656666676865686667676666676766
6868686A68686968696867696A686A6B6A676B696A6D6C6B6C6D6C6C6D6C6C6A6C6E6E71
6F7070717072717171707272727271747474727471727173727576767778787778777677
767577767576767777767678777678787A797B7C7C7D817E7F8082808484838281848685
85848387858787868787888687878988898C8B8C8B8A8A8E8E8E908F8E908F9393979A99
9C9EA0A3A7A8ADADAEB0B2B3B4B3B3B4B7B9B7B5B6B6B1B7B4B7B6B4B6B3AFB1B1ADB0AC
AFAAA8A6A4A29F999893908A8985837F7B7C767673716E6A69686564616161605F5D5C5B
5A5A5858565454535151504E4F4D4C4B49474745434241413F3D3C3B3A38373636353332
31302F2E2D2C2C2B2B2A2A2A292929282828282727272727272727272627272626272727
262627262627262626262626262727272626262626262626262626262626262626262626
2626262626252626
252626262626262626262626262626262626262626262626252625262626262626262626
262626262626262626262626262626272626262727262626272627272626272727272727
272828282828282929292A2A2B2C2D2E2E30313435373A3C3E4044474A4D51555A5E666F
7D869096999C9DA1A4A5A5A4A6A6A4A9A4A7A2A19F9E9997938E8C8783807F7B7B767675
72716F6F6B6A686868656669676565646563656264646365676667656665666769656567
6867686568676768666969676A686A6869686A696A6C6C6D6C6C6C6B6B6D6C6B6C6D6F6C
706F716F6E6F71717270707170707273727472716F717373747376777777787979797877
75767576777475747575737475777876787778797B7D7E7E7F7F80818282828181818183
8383868386858484868788858687868789898A8A87888A8A8D8E8E8D8E8E909090959698
9A99A0A0A5A5A8AAAFAAAFB1B2B3B7B6B8B4B7B5B5B4B0B3B3B5B3B0B1B3B0AFADAEB0AC
AEAAA7A6A4A09E9C9891918C8887827E7C7B797672706D6A696765646260605F5D5C5B59
5A58575554535251504E4F4E4D4B4948484645434340403F3F3C3B3A3837353534333230
2F2F2E2D2C2B2B2B2A2A2A29292928282828272828272727272727262727272726272726
272726262627262726262726262626262626262626262626262626262626262626262626
2626262626252626
262626262526262626262626262626262626262626262626262626262626262626262626
262626262626262626272626262626262626262626262627272726272726272727272727
2727282728282929292A2A2A2B2B2C2D2D2E2F323336383A3D3E4245474A4D5354595F65
72818B9097999CA0A4A4A5A6A8A8A8A3A8A7A9A0A4A19D9C97958E89878382807C7A7775
767173706F6C696B67676865666565646465646265636564666566656667666566656767
6866676765676768676868696969686967676A6A6A6B6B6C6C6A6B6C6C6B6E6B6D6C6D6C
6D6E6E70716D7071706F6F6F6F70727272717270726F7172737475757779777A79797B78
7777757474747474737373737674757675777678787A7B7B7C7D7C80808281807F808080
8181828583828483858585848386838487878987878987888A8B8A8B8D8A8A8C8E909393
96989DA0A1A4A5A8AAADAFB0B1AFB4B5B4B3B2B5AFAFB1B0B2B1B1B0AEB0ADACADACAEAB
ABA8A6A7A39E9F9A9895918C8784827E7C797773716F6E6A6764636361605F5C5C5A5A59
57565655535251504F4E4D4C4B4A47474645444241403E3D3D3D3A39383735343231302F
2E2E2C2C2C2B2B2A2A292929292828282828282727272727272727272727272727262727
262727262626262626262626272626262726262626262626262626262626262626262626
2626262626262625
252625262526252626252626262625262626262626262626262626262626262626262626
262626262626262626262626262726262626262627262626262727262627272727272727
27282727282828282829292A2A2B2B2C2D2E2F30313437393A3D3F4146484B4F5256595F
6673828A91969A9E9EA0A2A5A8A5AAA6A8A8A6A6A5A2A39F9B9993928C8784827F7D7A79
77747373736F6D6B69686867676767666464636364636464656564656465646467636766
696666676665676768676867686969696969696869696B6969696B6A6B6B6D6D6B6B6D6C
6D6F6F6D6E6F6F6E6E70706F6E6F7070737171706E70707172737675777778787A7A7977
737472737274737272717373747574757375777777777A787A7A7B7B7D7E7E7E81807F7F
80838080818282808483828483818584868583878982878789878A8A8A8A8989898D8F92
939697A09FA0A5A8AAADB1AFAEAFADAFB1AFAFB1AFAFAFAFAEAEAEAEAEABACABA8ABABAB
A9A7A5A4A19D9C9A9692908B8A847F7E7A79757170706969656462615E5D5D5B5A595857
555455535251504F4E4D4D494848474444434241403F3D3D3C3A39383736343332312F2F
2E2D2D2C2B2B2A2A2A292929292828282728272827272727272727272627262627262626
262626262727262626262627262626262626262626262626262625262626262626262626
2626262626262626
252626252625262526262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262627262626262726272626272727272727272727
2728272728272728282829292A2A2A2B2C2D2E2F30323436393B3C414345474C4F53565C
606A76828B95979A9F9FA4A5A5A5A9AAA9A9A6A7A9A5A3A5A09F9993928C8A85827D7E79
7979787473716E6C6B6A6967676868656565656566656664636464646364656564636466
65666565676667676767676867676967686969686867696A69686B696A6C6E6D6C6B6C6D
6D6D6C6D6C6C6B706F7070706D6E6F6E7070706E6E6F6E70717073747376787879767677
7474717370727172757173717671747474747576767775787976797C7B7D7E7E7E807F81
80828183818183818180828281818281838484838384838384868687868687878A898B8E
9092989A9DA0A2A1A6A7A8ACACAEA9AEACAAACB0ACADAFADACADAAABABA9ACAAA9A8AAA7
A5A5A69F9F9F9C989994908C86847F7D7D777573706C6A686763615F5E5C5B5A5A5A5755
5454525351504F4D4C4B4B48474746444343413F3F3D3C3A3939363735353332312F2F2E
2D2C2C2B2B2A2A2929292928282828282727272727272727262727272726272727262627
262726262627262626262626262626262626262627262626262626262626262626262626
2626262626262625
252626262625252626262526262626262526262626262626262626262626262626262626
262626262626262626262626262627262626262626262627262727272726272726272727
2727272727272828282829292A292A2B2B2D2D2E2F313234363A3B3E404245484B505356
5C616A75838A91999C9FA0A5A5A6A6AAA9A8AAA7A4A8A7A4A5A09F9A99908C8A87848280
7B7C77777574726E6B6C6C6A686967656666666866676563656564646364656464666564
6566656566676666676667666868676669676868676A6A6A696A6B6A6B6C6C6E6D6A6C6F
6E6D6A6C6C6E6F6E6F70706F6E6D6E6E6E6F6E6F6E6E6F6F706E72707174747577777575
74717372727170707070717171727173727374757477757877777B7A7B7C7C7C7D7D7E7D
7E7F7F7E81828181808181808281807F828482838383838384848583858785878587898A
8F9093989A9C9E9EA3A2ABAAACAAACAAABACABACADACADAAA8A7ABA8A8A9AAA9A8ABA9A9
A5A4A1A19F9D9C9694918E8A86827F7A79767572706C69666564605E5D5B5A5958565654
535251504F4C4D4B4A4A49484545434342413F3F3D3B39393837363433333230302F2E2D
2C2C2B2B2B2A292A29292928282827282828272727272627272726272727272627272627
262626262726262626262626262626262626262626262626262627262626262626262626
2626262626262626
252626262526252626262625262626262626262626262625262626262626262626262626
262626262626262626262626262626262626262626272626272627272727272727272727
272727272728272828282829292A2A2A2B2B2C2E2F30313435383A3B3F404445494D4F53
555B616975828C939A9B9EA3A4A5A8A9A9ABA9AAA7A6A7A8A4A3A19D9997948F8B898480
827C7D78767672706E6D6C6B6B6A6A676666676567666664636464646464656365646463
65656564656564656766666666666765676768686768696A6A686A6B6A6D6C6D6B6A6A6D
6D6C6D6C6B6A6D6D6E6F716F6E6C6C6D6C6D6E6E6E6E6D6F6F6D706E7070727275737273
72726E7172716F6F6F7170717170717270717172737472767678787576777A7B7C7B7C7C
7F7D7E7F7F7F8081817E80807E7F8080818080818381828181827F838283838386848989
8B8B8F9498999C9F9EA4A6AAA9A7A6A5A7A6A7AAAAA9AAA7A5A6A8A8A8A7A6A7A5A8A4A6
A6A29F9F9F9B999893918E8A857F7E7A797574716F6C68676360605E5C5A585757545454
524F4E4E4D4D4C4A4A484847454442403F3F3E3D3B3A393836363433333231302F2E2D2C
2C2B2A2A2A2A292929282828282728272727272727272727262627272727272626272727
262626262627262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262526262626262526252625262626262626262626262626262626252626262626
262626262626262626262626262626262626262626262626262627272727262727272727
2727272727272827282828292929292A2B2B2B2D2D2F30313336373A3B3E414346484D4F
52575C616975828C90989B9DA0A4A6A7A8A8AAA7A7A6A9A7A5A6A1A49F999895938D8A84
80817E7C7B7976737271706D6D6C69686969676869686664656565636363656564646464
646666636465656464656566656566676766676866696869696A6968686A6A6A6C6B6A6B
6D6C6D6E6A6A6C6C6D6D6D6E6D6C6C6B6C6D6C6D6D6E6E6C6D6D6D6F6F706F7172727071
707071716F706E6F6F6F706F6F72706F6F7071716F73737474757577767877797B7A7B7B
7D7D7D7C7E7D7E7F7F7F7F7E7F817F7D7F7F7F827F7F7F7E817E7E7F807F7F8184838584
878B8D909295979A9D9FA2A5A9A7A5A3A4A6A6A7ABAAAAA4A6A2A4A6A6A7A6A1A3A1A1A1
A29FA19D9B999895938F8A8785807D7A7674726F6D6A686663615E5C5B5A585655535352
524F4D4C4B4B4948484645444241403F3E3D3D3B3B393737363533333231302F2E2D2C2C
2B2B2B2A2A29292928292828282727272728282727272727272727272627272626262626
262627262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262625262626252526262626262626262626262626262626252626262626
262626262626262626262626262626262626262627262626262727262627262727272727
2727272727272727282828282829292A2A2B2B2C2D2E2F30313436383A3B3F404648494C
4F54585B616A75818C9497999F9FA5A4A9A7A7A8A9A7AAA8A7A5A7A6A0A29E9A96948F8A
8781807E7C797A777674726F6E6C6D6B6B69696867666464646566666564646365646362
636364666566646563656464666665656766686768666867686869696A67696B6A6B6A6A
6B6B6B6A6A6A6A6C6C6D6D6A6D6A6B6A6E6D6D6C6C6E6D6D6E6D6E6D6E6C6D706F6F6E6F
6E6E6E6F6F706D6C6F6E6F6E6E6F6F6E6F6F6E706F6F717273757675757476767778797A
7B7C7A7A7C7B7D7E7E7D7E7D7D7C7E7C807E7E7C7C7D7D7D7D7D7E7D7C7D7E7F7F818382
85858B8E8E939498999B9EA1A2A4A39FA1A3A4A3A7A8A4A5A2A2A5A4A2A0A1A29E9F9D9F
A19F9E9A9A9795908F8B8A88817F7B787574736F6C69676562615D5C5957555555525250
4F4E4C4C4B494947454544424240403E3D3C3A3A393837363433323130312F2E2D2C2C2C
2C2B2A292929292929282828282828272727272727272727272727262627262626272626
272626262726262626262626262627262626262626262626262626262626262626262626
2626262626262626
252626262626262525262526262626262525262626262626262626262625262626262626
262626262626262526262626262626262626262627262626262626272727262727272727
272727272727282828282828282929292A2A2B2B2D2D2E303132343538393C3F4244474B
4E5154575B616A75828E94959DA1A3A5A7A7A7A9A9AAA9AAA8A7A6A6A2A4A19E9D979592
8B858380807D7B7A77757470706E6C6B6B6E686969686767656666656764646564626262
63646464636366646466656468656767666565686768666669686A6A6A696A696869686B
6B6C6A696C686A69696A6D6A6B6A6A6B6C6B6B6B6B6C6C6C6C6B6C6C6C6D6F6C6D6D6D6D
6C6E6D6F6D6D6F6D6D6E6E6E6D6E6E706D6D6D6C71717170717274747574757575767979
797A7A787A7B7A7D7C7B7C7A7C7D7C7F7B7C7B7A7A797B7A7C7C7E7D7A7C7B7B7B7D8080
8386878A8D8B919294979B9D9F9E9F9F9EA0A1A2A3A5A3A09EA0A1A2A0A09E9D9E9C9D9B
9B9C9B99969795908E8B8A85827B787675716F6E6C686663615E5D5A5956565553515150
4F4D4C4A4948464744444242403F3E3D3C3B393A383736343432323030302E2D2D2C2C2B
2B2A2A292929282828282827272827272727272727272726272726272726262726262627
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262526262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262627272726272726272727
272727272827282728272828282828292A2A2A2B2B2C2D2E2F30323436383A3C40414446
4A4E4F53595C616876818B939899A0A1A2A2A8A4A8A7A9A9ABA6A6A7A6A4A3A39E9E9893
928C8984837E7D7D7A7A757372706F6F6F6F6D6B6C6A6867646565666564656364646562
636665636364636465646564666667656567666668656667686869676968696867686967
696A68686A68696A6969696B6A6B6B6969696A696B6B6A6B6B6B6D6B6D6D6C6C6A6D6D6D
6D6B6D6C6D6D6D6C6B6D6D6C6F6E6D6D6E6E6F6D6E6D6F70716F70717171737474757776
7778777A7B7A7A7B7A7A7B78797A7C7C7C7A7A7A7B7978797A797A797B79767B7B7C7E7D
7E81828589898B8F9394989B9C999A9B9C9D9EA0A3A4A0A19E9E9E9D9E9B9D9D9B9A999A
989A9A969693918E8C8986827F7A7975736F6E6D69676662605D5C5A57565552524F4F4E
4C4C4A4847464543434140403F3E3D3C3B3A383837363534333230302F2E2D2D2C2B2B2B
2A2A29292929282828282827272827272727272727262727272726272627262726272626
262626262726272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262626262626262626252626262626262626262626262626262626262626
262626262626262626262627262626262626262626262626262626262727272727262727
2727272727272727272828272828282929292A2A2B2B2C2D2E2F31323435373A3D404245
47494D4F54565B626974818992969B9DA3A3A3A7A5A8A8A9ABA7AAA7A4A6A6A4A3A19C98
96928E8B868484807C7B7A777673727370706F6C6D6B696A686765666865656464636364
6264626463646363646465656665646667656565656667676769686A6867696869686767
686869686667686A69696A6A6B6968686A69696A6B69696A6A6C6B6C6A696B6C6C6C6B6B
6B6C6B6B6C6B6C6C6C6C6D6C6D6D6C6D6C6D6B6C6F6D6F70707070727071727273717374
75767576767B79797A797A797A787A7C7A79777977777878787677767877777678797A7B
7C7C7E80848589898B9094979696979C9A9B9C9B9DA09F9C999C9C9B9A9B999A9A9B9897
9797959093918F8D8A8684807F78767472706C6A69686461615F5A585654535250504E4B
4C4A4847464545444240413F3E3D3B3A3938373736353432323030302E2E2D2C2B2B2B2A
2A2929292928282827282727272727272727272727262727272726262626262726262726
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626252526
252626262626262526262626262626262626262626262626262626262626262626252626
262626262626262626262626262627262626262626262726262627272626272627262727
272727272727272727272828282828282829292A2A2B2B2C2E2E3030333436383A3D3F41
44464A4D5153575B6167707F8B9296999D9EA3A3A7AAA9A9ABABA8A8AAA7AAA4A6A6A1A0
9E97928E8D898784817F7C7B787976767372726F6D6D6C6B6B6869696766646463636564
64636463646464626263636665636565656467656667666767686A666767676869686768
6868676767666868696769676767676867676A69696A69696A6B6B6B6A6A6D6B6B6D6B6B
6B6B6B6B6B696A6C6B6B6C6D6C6C6B6B6D6B6C6C6C6E6D6D6E6F6E707170707171737374
757377777877787879787877777877787877787677787777767675767573747576767778
797A7B7D7F8285888B8D8E919395979698979699999B9C97969798969899989898989493
92949492918E8D888784817E7A7872726F6E6B69676562615E5C5957555452514E4C4D4A
4A49464644444242403F3E3D3C3C3A39383736353434323331302F2F2E2D2C2B2B2A2B2A
2A2929292828282827282727272727272727272727272626272627262627262726262726
272626262626262626262726262626262626262626262626262626262626262626262626
2626262626262625
262625262626262626262626252626262625262626262626262625262626262626262626
262626262626262626272626262626262626262627262626262626262627272726272727
2727272627272727272727272827282829292A2A2A2A2B2C2C2E2E3030323536383B3D40
4145464A4D4F53575C6068707E8B93979A9D9DA3A4A6A8A8A9A8A9A9A9A8A6A7A7A4A2A2
9E9B9A94978E8D8A84827E817C797A767975757270706E6B6C6C69686765656464646563
636264646464656364616364636665656665646564656665676666676867666868676869
686568666867686667686767666667676668686867696A696A6969686A6B69696A6C6B6B
6B6B6B6B696A6B6B6A6A6A6A6C6C6B6A6B6B6C6B6B6D6C6D6D6F6F6F6D6F6F7071707070
707373757476777578767777787678787777757675757575747373737172717371717575
7778797C7E7D7F83868B8B8F8E90949294959495989A9895949397979698979694949390
90928E8D8E8C898886807D7B7774746E6E6C69676563625F5E5C5955535352504E4D4B49
4846464544434141403E3C3B3C3A393836373534333231312F2F2E2D2D2C2C2A2A2B2A29
282929282928282828272827272727272727282727262727272726262726262626272727
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626252626262626262626262526262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262626272626272627272727
2626272727272827272727272728282828292929292A2A2B2C2D2E2E2F31333536373A3D
3F4244474A4C4E51565A6065707C888F95979D9FA3A5A5A6A8A7A9ABABA7A8A9A5A6A4A4
A1A49C9E9996938D88858583807E7E79777674737371706D6F6D6C686868656566656563
646363646363636463646262636465646465646565656766656866666669686767686968
6965676666676767676766656666666668676666666667686666696A6969686968696B6A
6A6A6968696A6B6A6B6B6A6B6B6A6B6A6C6A6A6A6A6B6A6B6B6A6C6B6D6B706D6E6F6F71
7170717273737274757675767676757776757775757475767372706F6F6E6F7073717474
75747679797B7E7F828287898B8C8D8E8F92939392939694929294939193949193938F8F
8E8E898B8B878583807D7D767472706E6E6A68666462605E5D5A575754514F4F4C4B4B49
484445454241403F3F3D3C3A3A393736363535333232302F2F2D2D2C2C2B2B2B2B2A292A
292929282828282827272727272727272627272727272726272626262627262626262627
262626272626262627262626272626262626262626262626262626262626262626262626
2626262626262626
252625262526262526262525262625262626262626262626262625262626262625262626
262626262626262626262626262626262626262626262627262626262627272727262726
2627272727272727272727282828272828282829292A2A2A2B2C2D2D2E2F31323536383A
3D404244474A4B4F5257595E666F7B868E94979BA0A3A6A6A9A5AAACA8A9ABA8A8A6A6A5
A4A5A4A09F9997938E8B868686827F7C7C777776757373716F6E6D6A6968676768666765
646363656364616463626263646464646565646364656465656567676867676567676666
686766666766666766656665656563666567676566656866686766676669686668686A68
69666B69686A696869686A686A68686A6A6B6A6A6A6A6B6A6A6C6A6C6C6C6C6C6D6D6D6F
707070717270727073747375747574737373747775747173716F6E6E6D6D6D6E6D6F7173
717574767578787D7E7E808386898B8B8E8C8E8E8F908F91919393919292929091918E8E
8D8A8988888584817E797774736F6E6D6B6A68656461605E5A59565453524E4E4C4A4846
45454442413F3F3E3D3C3B39383836353533333231302F2F2E2D2D2C2C2B2A2A2A292928
282928282828282727272727272727272727272726272626262627262627262626262626
262626262626262626262626262626262626262626262626262526262626262626262627
2626262626262626
262625262626262626252626262626262525262625292626262626262626252626262626
262626262626262626262626262626262626262626262626272626262626262726272727
27272726272726272727272827272828282829292929292A2B2B2C2D2D2E2F3132353738
3A3C3F424447494C4F53565A5F656D7C848E94979B9FA3A3A5A8ABA9AAAAACA9A7ABA7A7
A6A5A79EA29D9A9695908E8D888984817E7C7B787975757471716E6D6968686867666765
646363646363636463626263626565656464656563626564656565666666656767676866
656566676666676566656565646465676567666665656565656867676666676768696768
6868696868686968696A6968696A6A6A6A6969696A6A6B6A696B68696A6C6C6C6C6C6D6E
6E6F6F6F6E6E6E70727371727375717173717476737473706F6D6E6D6B6B6B6C6C6D6E6E
6F716F7274747678797B7B808182858587888A8C8B8D8E908E8D8D8E8E8D8E8F8E8B8A8A
8A8786858382807D7B7874726F6E6B6A6867666461625F5D5A58565652504F4C4A4A4745
464343403F3E3E3D3B3A38383736363534333231312F2E2E2D2C2D2C2B2A2A2929282928
282828282727272727282727272727272727272627262726272627262727272726262627
262626262626262626262626262626262626262626262626262526262626262626262626
2626262626262626
252625262626262626262626262626262626262626282626262626262626262625262626
262626262626262626262626262626262626262626262626262626262627262626272627
27272727272727272727272727272828282828282929292A2A2B2B2B2D2D2E3031323436
383A3C3F414345484B4F5154585E646D77818B8F989A9FA0A5A7A5A7A8A9A9A8ABAAA9A8
A8A5A7A7A09E9E9997989692908C8A86847E7D7F7B7A77777473706E6D6B6A6A69676867
646563646463646364636063636262636363636363646464666665666564666567666765
686666656667656465656364666565656465656665666565666665666667676767686666
666866696966686869696869686968696A69696A6869676A69696A6A696A6B696A686C6B
6D6C6E6D6D6E6E6F6F71737071706F6F707373747271716E706E6C6A6A696A696A6B6A6B
6D6E6F6F71727273757679797C8081818685868789898A8B8B8A8D8C8C8B898888898A88
878582827E7C7B787675716F6C6A696866656460605E5E5C5A585453504E4D4B4A484645
444240403E3E3D3C3A39383836353433333231312F2E2E2D2D2B2C2B2A2A2A292A282829
282828272827282727272727272727272627272627272626262726262626272626262626
262626262626272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262526262626262625262626252626262526262626262626
262626262626262626252626262626262625262626262626272626262626262627262626
27272727262727282727272727272727272828282928292A2A2A2B2B2B2C2E2E30313234
3638393B3E414346484B4E5053585C636B7380899494999D9FA1A4A4A9A9A7A7A9ADA8AB
A9A7A7A6A4A4A19F9D9A999794938F8A878481817E7E797977747271706B6B6968686967
656565646362646363646363626361626363636365646464656565656566666665656565
666465646365676365646364646563636465646666636464646666636666666666666666
676768656767696768676766696667676867696A696868686869696869686A696A6A696A
6D6C6B6C6C6D6C6E6E6D6D6F706E6E6F6E7073727071716F6D6D6C69696868676A676A68
6A6B6B6D6F6F72717072747577797C7C7F80818484838384858787868786868486828482
84827F7B7B79777272706D6B6B6869666463625F5F5C5B59585554524F4E4D4C49474644
4342403E3D3C3B3A3938373635343333323130302E2E2D2C2C2B2B2A2A2A292928282828
282828282827272727272727272727272727272727262626262626262626272626262626
272626272727262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262525252625262625262626262625252526262626262626262526252626262626
262626262626262626262626262626262626262626262626262626272626262626262727
26272727272727272827272727272727282828292828292A2A292A2B2B2C2C2D2E2F3132
343637393B3E404345474A4E4F53585C6168737E878E95999D9DA3A4A7A6AAA9AAA8ACA8
ACA9A7A7A3A4A1A4A3A09E9B9B97968F8E8B8A8382807E7B79777473736F6F6B6B686966
676665646362626365636362606362626161626464646464646464646464646463646565
676365656662636363656664636362636463636362656264646465646565666464666667
666566656866666667676867656568666767686A6768686968676766686767686A696A6A
6A6B6A6C6B6B6E6C6E6D6F6C6B696D6D6E71716F6E6D6D6D6D6D6B696A66676866666766
6B68686A6C6B6E6E6F6F707271747777797C7E7E817E7E7F81838482838381817F7E7E7E
7C7B79787674736F6E6C6C6A686664646461605E5E5C5B59575452514E4D4C4A48464544
42403F3F3C3B3A39373736353433323130302F2F2E2C2D2C2B2B2A2A2A292A2929292828
282728272827272727272727272727262627262727272627272626262626262627262626
262626262626262626262626262626262626262626262626262626262626252625262626
2626262625262626
252625262626262626262525262526262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262627262626262626262726
27272627272726272727282727272728272728282828282929292A2A2A2A2C2C2E2E2F31
32343538393D3D404245474B4D4F54555C5F66717A848E959A9A9DA1A5A7A8ABA9ABAAAB
AAA6ABA8A8A7A6A6A5A2A29F9E9B989992908D8B8886837E7E7A797473736F6D6B6A6767
686665646564646363636262636162606164626464636565646365646465626262626563
656464646563626363636262636165616363626363636264636464646564656564656567
666666666566676567656867676667666767686967666967676767676868676767686769
686967686968696A6B6A6D6C6C6B6C6C6E6D6E6D6B6D6C6C6B6D696A6967676564666665
65666868686A6C6A6C6C6D6E6F7072737472747778797C787B7C7F7F7D7D7E7E7C7B7C77
7778767372736D6C6B6A6A686664646360605E5D5A595958555452504E4B4A4846464241
413F3F3D3B3939383735353434323231302F2E2D2D2C2C2B2A2A2A2A2929292929282828
282827272727272726272726272727272627272727262727262727262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626252625252526262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626272626262627262626262626272626
2626262727272727272727272727282827282728282828282929292A2A2A2B2B2C2E2E30
30323335373A3C3D40434546494C5052555B5F656D79848D94989B9EA0A3A8A9A8A9AAAB
A9ABA8A7A8A9A9A8A4A6A3A0A09F9B99999794928E8B8984837F7A777673706F6E6C6D6A
6A6867666565676565646362626262626163636261646163636462636364636463646463
656461626462626364646262616163626362616261626162636264646563636365636263
646563646464656464666466656567666766666865676766656868686767686566676867
666868686768686968696A686B6A6A6A6C6D6B6A6A6A696869696A6A6967666363636464
65636665666567696B6A6B6A6C6B6E6E6F6D717273727576787878787878797977767675
7373716F706C6C6A6868676564635F5F5F5D5D5B5A5957545452504F4B4A484645444240
3E3D3D3B3A393736363533333231312F2F2E2E2C2C2C2B2B2A2A29292929292928282828
272728282727272727272727272727262626272627262626272627262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625252526252526262626252526262525262626252626262626262626262626262626
262626262626262626262626262626262626262626262627262626262626262626262627
262726272726262727272727272727272727272828282828292929292A2A2B2A2B2D2D2E
303131333538393B3D3F434546484E4F5255595C626A76818B8E95979DA1A7A5A9A8ADAC
ADABAAAAAAA7A9A9A7A4A5A3A29F9E9F9E9C9893928D8D8A86827F7C7977767471716E6B
6B6B68666567656465646362626261626262636263636362636263626064636261626263
656364626464636364626261626062616262616162636062616162616263626362646664
656564646362636064646565666564666665666568666467676666676866656566656765
66686667656868676869686768686A696A6769696866686768696A6A6767656464626262
636464646364666766676869696A696B6B6D6C6D6E6F717272707273757574727272716E
6F6C6D6B6A6969686866646363605F5D5D5D5A5A5856565452514F4D4B4A48474442413F
3E3C3B3A38393736343333323130302F2E2D2D2C2B2B2B2A2A2A29292928292828282828
282727272727272727272626272727262627272726262726262727272726262626262726
262626262626262626262626262626262626262626262626262625262626262626262626
2626262626262626
252626262526252626252526262626262626262526262626252625262526252626262626
262626262626262626262626262626262626262626262626262726262626262626262627
2727272727262727272727272727272727272728282728282928292929292B2B2B2C2D2D
2E2F2F323334363A3C3D3F414446484C4D4F54575B62677680888F93999CA0A1A5A6A7A8
A8ACABA9AAAAAAABA6A9A5A2A5A5A3A2A19E9B999694918E8A86837F7A7B787675747371
6E6C6C686867676466626563626262626262626563606161636263616263626261616063
6263636263646260616060615F616062616261636261625F60615F616163636162616264
626363646464626161626265646565666666666664636566656667666665646465656566
666665646565666668686768676667676868686666686868686869696867656363616161
626263616161616464656566656668686668696A6A6A6A6A6D6D6C6E6E6D6E6B6D6B6B6B
6A6968676867696564626163605D5C5C5A5959575754525250504E4A4A4847454442403E
3C3B3A393837363534323130312F302E2D2C2C2C2B2B2B2A2A2929292928282828282728
272727272727272727272727272726262726272727262627262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
2626262626262626
252625262525262625262626262626262626262625262626262626262626262626262625
262626262626262626262626262626262626262626262626262626262626262627262626
262727262727272727272727272727272727282727282828282829292929292A2A2C2C2C
2E2E2F3031333537393A3D3F424346494B4D4E53565961666F7D878D93949D9FA1A3A5A6
AAA8AAADABA9A9AAA9A5A7A3A4A5A5A49E9F9E9A999793918D8C8783807D7A7878777473
716D6D6B6A6A676865646565656462626361626262626163606162616163636261606363
626162636262626162606161605F60616060626061636160606060636161606163616463
626362616261626361616264626464646464636465656664656565666764646463646463
656563636462666467656867676665676667666566656668686766666565656562626061
5F5E605E5F60606060626366656466656565666564656868696B6C6A696968696A676A66
66666564636463636062605D5E5D5A5A595957555452514F4E4D4C4A4947454442423F3C
3A3A3A3837363433323232302F2F2E2D2C2C2C2B2B2A2A2A2A2929292828282828272727
272827272727272727272727272727272727262726262627262626262726262726262626
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626262625
252626262626262626252626252626262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262727
262726262626262727272727272727272827272727272828282929292829292A2A2A2B2B
2C2D2E2F3031333536383B3C3F404345474A4C4F5256585F646D7B838D93979A9CA2A1A4
A5AAA9ABAEADAAACAAA8A8A6A7A6A7A3A2A19F9C9E9B9A94938F8B878783807F7C777775
7172706F6C6C69676566656665636362636162626261636162625F606061626161636061
6261636263626161626363636261615F606160616161615F605F616062606062615F6161
616161626261636262626161626163646462636463656364656564636264636464646463
636464636263636462656665656465656364646365666664666566666562636363626261
605E5E5F5F5F5E5E5F606264646361636163636363646665656666656364666666666364
646362616161615F615E5D5C5C5A5A57575655545152504F4D4B4A494946444241403D3D
3B3A3737363434343231302F2E2E2D2C2C2B2B2A2A2A2A29292828282828282828272727
272727272627272727272627262726272626272726262626262626262626262626262626
262626262626262626262626262626252626262726262626262626262626262626262626
2626262626252625
252625252626262626262626252526262626252626262625262626262626262625252626
262626262626262626262626262626262626262626262626262626262627272726262626
26272627262627272627272727272727272727272727272828282828292929292A2A2A2B
2C2C2D2E2F303132353538393C3D404344474A4D4F5155595D646B7782868F969C9D9FA3
A3A7A8A8A9ACADAAAAA8ABA8A5A9A7A7A3A3A19F9F9D9C9A9894928F8B8882827F7C7877
7373736F6F6F6B6A67676667656466636262626262616162616161606160626061616062
626161626161616063616363626060605E605F5E5E5E625F5F5E5F606160606260606060
626061616162605E625F6163616262636261636362626263646465626365636365626263
626362636362616363626264656463636464656464636463636464636262636162616160
605E5E5E5D5E5D5E5E5F5F605F6360626161626261626163626261626162616163616161
605F605E5E5E5D5E5B5A5A5A5958575755545352514F4C4C4B4B4A4746454241413F3D3B
3A39363735333332312F2F2E2E2D2C2B2B2B2A2A2A2A2929292828282828272827272727
272727272727272727272727262726272627262627262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252625252626252626252626262626262626252626262626262626262626252626252626
262626262626262526262626262626272626262626262626262626262626272726262626
27262626272627272727272725272727272727272727272827272828282929292A292A2A
2B2B2C2D2E2F303132343637393A3E3F414446484A4E5053565C6166707B888E959B9D9F
A3A3A5A9A7AAABAAAAAAAAA9ABACA8A7A6A6A0A2A3A09F9C9B9694928C8C8786827E7B7A
7875747172726D6C6A6868676666656664636261616163616262616262626161615F6061
616260626160615F5E6061615F6160605F5E5E5E5E6060605F5F5E5F5F5F5F5E5E606160
6161605F61616060606061615F5F61606161606362626162626362636262626162646365
636362616061605F6161606061616363636563626162636462626262626162616162605E
5F5E5E5E5D5D5E5D5E5F5F5F5F5F5F5F60605F5F605F5E5F605F5E5C5E5E5E5D5E5C5D5D
5B5D5C5B5C5B5B595856585856565553525151504F4E4C4A49484746454242403F3C3C3A
3938373634333231302F2F2E2D2D2B2B2B2A2A2A2A292928282828282828282727272827
272727272727272627272626272727262627262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262525262626262625262626252526262626262626262526262626252626262626
262626262626262626262626262626262726262626262626262626262626262626262626
27272626272627272726272726272727272727272728272727282828282829292829292A
2A2B2B2C2D2E2E2F3231343637393A3C3F414345484A4E5154565A5E666B79878C919798
9C9FA1A2A7A7A7A9A9AAABABA8AAA8A7A6A6A5A5A2A4A29F9C9A989394918D8A8584807B
7B7575737372706D6D6B6969676666646664626261626261626161616060606061605F61
5F6062616060626160605F5F5F5F5F5E5F5E5D5D5E5E5F61605F5D5F61605E5E5E605F5E
616160605F5E605F5E60615F5F615F6061615F6161606162626461616161616261626261
616262615F60605F60605F60615F6161626263626163616262636261616060605F5E605F
5F615E5E5D5C5D5E5E5D5E5D5C5D5D5E5C5D5E5E5D5D5D5C5D5C5C5B5D5D5B5A5C5B5C59
5B5A59575858565755545555545452515050504E4C4C4A49484646444342413F3E3B3B38
38363634333331302F2E2E2D2C2C2B2B2B2B2A2929292929282828272728272727272727
272727272727272727272726272626272627272626262626262627262626262626262626
262626262626262626262626262626262626262626252626262626262626262626252626
2626262626262526
252626262626252626262526262526262526262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
262726272726262727272727262627272727272727272728282828282828282829292929
2A2A2B2C2C2D2D2F303032343537393A3D3E424246474A4D5053575A5E626B747F899091
989C9EA1A5A5A6A8A7A8AAABA9A9ADA9A8A6A6A4A5A5A5A2A29D9B9A9995938E8B858480
7F79787474737172706E6D6B6A686967646564636264636161616060605F615F5F605E5F
61626060605F606060605F5F605D5F5D605E605E5F5E62605E605E5D5E5D5D5E5D5E5E60
61605F5F5E5F5F5D5D5E605F605F5F5E5F6060605F606160616061616060616160616161
616061606060605E5E5E5D5D5D5E5D606162606160605F605F5F605F5E615E5E5F5E5E5F
605C5E5D5C5D5B5D5D5C5B5B5B5A5B5B5A5B5C5B5A595B5C5B5B5A5A5B5C5A595A575857
585655565453545452535352515150514F4E4C4D4B494948474544424040403D3B3A3937
363534333231312F2E2E2D2C2C2B2B2A2A2A292929292828282827282728272727272727
272627272727272727272727262626262627262727262626262726262626272626262626
262626262626262626262626262626262626262626262526252626262626262626262626
2626262626262626
252626252625252626262626252626262626262626252626262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262627262727262727262726272727272727272727272727282828272929292929
2A2A2A2B2A2C2C2D2E2F2F32333537393A3C3E3F434546484A4E5154595A5E67707C868B
92979B9CA2A4A4A7A8ABA8A9A9A8A9ABA9A8A7A7A6A4A4A4A3A0A29D9C989592908B8786
827E7B7A787674716F716E6D6B6B696967676464646262626161615F62605F5F60615F5E
5E60605E5E60605E5F5E5E5E5F5F5D5D5C5E5F6060605F5E5F5D5D5D5E5F5F5F5E615E5E
5F5F5F5E5E5E5C5D5D5D5F5F5E5D5E5E5E5E5F5E605F6060615F5F5F5F5F605F5F5F605F
60605F5F5E5E5F5E5F5D5D5E5E5D5E5D5F5E5E5F5E5F5F60605F5F605F5E5E5C5D5D5D5C
5D5C5D5C5C5B5B5A5B5A5C5A59595A59595A595959595759595759595958585757565656
55545554535351515150504E4E4F4E4F4D4B4B4A4948474544424240403F3D3C3B393836
3534333231302F2E2D2D2D2C2B2B2A2A2A29282928282828282828272727272727272727
272627272727272627272726262626262726272626262626262627262626262626262626
262626262626272626262526262626262626262626262626262626262626262626262626
2626262626262626
252625252625262626262526252526262626262526252626252626262526262626262626
262626262626262626262626262526262626262626262626262726262626262626272626
262626272726262627272726272727272727272727272728272727282827282828282929
2A292A2B2B2C2B2C2D2F2E3031333336393A3C3E40424345484B4D5155575A5D666D7880
8B8F96979E9DA0A3A7A6A9A7A7AAACA7AAA9ABA7A9A5A5A3A4A2A09EA09C9997918F8B8B
86827F7B7B7977747372706E6E6B6B6A696868676363636361615F606062615F5F5E605E
5F5F5F5E5F5F5F5E5F5D5E5F5D605E5B5E5E5F5E5E5D5F5F5F605F5E5D5D5D5D5F5E5E5F
5E5C5E5D5E5C5D5C5D5C5E5C5E5E5D5D5E5D5D5E5E5E5E60605E605D605F5E5D5E5D5E5D
5E5E5F5E5D5F5E5E5D5D5E5C5C5C5D5E5D5D5E5C5C5E5E5E5E5D5E5D5D5C5E5C5C5D5D5C
5C5D5D5B5B5B5C5B5A5A5958585957585856565658575656575557575556565454545353
51525251504F4E504F4D4F4D4D4D4C4B4C494847474645434341413E3E3D3B3A39373635
3533323130302E2D2D2C2B2C2B2A2A292929282928282828282827282727272727272727
272727272727262726262726262726262626262626262626262626262627262626262626
262626262626262626262627262626262626262626262626262626262626262626262526
2626262525262626
252625252626262626252625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272726262626
262626272627262627272727262627272727272727272727272727272828272828282829
28292A2A2A2B2B2C2C2D2D2E303132343537393B3D3F414343464A4E4E5255565D626B72
7C868E94959A9FA3A0A3A6A9A8A8A9A8ADACA9AAABA9A6A2A6A3A4A3A19E9E999794908F
8C8784837C7C7777757273716F6F6C6D6A6867666666646363626263615F60615F616060
615E5F5E5E5E605E5D5F5C5D5F5F5D5E605E5D5E5D5D5F5D5D5F5D5D5D5D5E5D5B5D5C5C
5B5F5D5C5C5A5A5C5D5C5C5E5D5C5E5C5D5C5D5B5A5D5E5D5D5E5D605E5F5D5F5F5E5D5D
5F5E5D5C5D5D5C5E5C5D5D5C5C5C5C5C5D5D5D5B5C5B5B5C5E5C5C5D5B5B5C5B5A5B5A5A
5B5B5B5B585A595958595A58585757575756565655565454555353545555535453525151
5050514F4E4E4C4D4D4C4B4B4B4A4949474846464644424141403E3E3D3B3B3837373535
333231302F2E2D2D2C2B2B2A2A2A29292929292929282827282727272827272727272727
272727272727272727262626262626262626272626262626262626262626262626262627
262626262626262626262626262626262626262626262626252626262626262626262626
2626262626262626
252626252625262526252526262626262525252626262526262625262626262625262625
262626262526262626252626262625262626262626262626262626262626262626262626
262626262626262627262727272727272727272727272727272828282728282828282929
29292A292A2A2A2B2C2C2D2E2F2F3032353537393A3C3F41434347494D4E5053575C6267
6F76838A8F95989A9FA1A4A6A7A7A6A9AAAAAAA8AAA8A9A8A5A6A6A4A0A09C9D9B979795
918C8985837F7D7B79767472726F706E6D6B696968656665636462606263605F605F5F61
60605F5E5F5F605F5D5D5D5E5C5E5E5E5E5E5E5E5D5D5E5E5D5D5D5C5E5E5D5B5C5D5C5D
5D5C5D5B5B5B5B5D5B5B5B5B5B5B5C5D5D5C5D5B5D5B5D5C5D5D5E5C5D5C5D5E5D5E5D5E
5D5D5C5C5C5C5C5C5D5B5C5A5C5B5B5A5A5A5A5C5B5B5B5C5D5C5A5B5B5B5A5D5B5B5B58
595A5857585759585758575755565655545455535455545453525252525152515151504E
4F4D4E4F4D4C4B4B49494A494948464745464544434341403F3E3D3C3A3A383736363333
3231302F2E2D2C2C2B2B2A2A2A2A29292928282828282828272727272727272727272726
272627272726262727272627262626262626272626262626272626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262525252626252526262526262626252626252626262626262626262626252625
252626262526262526252626262626262626262626262626262626262626262626262626
272626262726262726272726272726272727272727272727272727272828272828282828
2828292929292A2A2B2B2C2C2D2E2F3032323536383A3C3E40414446484A4E4F5256595E
6067727E888C9195999FA0A2A6A8A6A9A8A7ABA8A9A7A8A8A8A7A7A6A4A1A29F9D9B9B97
96928D8B87837F7E797977777373706F6E6B6A6A696967666565646265636062605E6161
60605F5E5E605E5E5D5F5C5D5D5F5D5E5F5D5E5D5C5B5C5B5D5C5D5B5C5C5C5C5B5C5D5B
5B5B5B5C5A5A5B5B5B5B5A5D5C5A5C5B5D5B5C5B5B5B5B5B5C5B5C5C5D5D5B5C5C5D5D5C
5D5B5B5C595D5C5B5A5A595A5A5A59595859585A5959595A5B5A59595A585A5959585859
5857565757575856575556565556545355535352535253515150515150504F4F4F4D4D4D
4D4C4C4B4A4B4A49484848464545454543424242433F40403D3C3B3A3838373635353332
312F2E2E2D2C2C2B2B2A2A2B292929282929282827282728272727272727262727272727
272627272627272726262627272626262726262626272626262627262626262626262626
262626262626262526262626262626262626262626262626262526262726262626262626
2625262626262626
252625252626262625262526262625262626262626262626252626262626262626252626
262625262626262626262626262626262626262626262626252626272626262626262626
262626262727262727272627262727272727272727272727272727272727282827282828
282929292929292A2A2B2C2C2C2D2E2F303133343537393B3D40404245474A4B4E515559
595F666F7880898F95979C9DA0A1A4A7A5A7A8A8A6A8A8A6A8A9A6A5A2A4A3A1A1A09D9D
9A98958D8C898382817F7C787574737270706B6D6B6A67666565656464636162615E5F5F
5F5E605C5D5F5F5E5E5D5D5D5C5D5E5D5E5E5D5C5C5C5D5C5C5D5E5D5C5B5B5B5B5C5C5A
5A5C5B5A5A5A5C5B5B5B5B5B5C5A5B5A5C5A5B595A5B5C5C5A5A5C5B5C5C5B5B5D5D5C5B
5B5B5B5B5C5A5B5B5B595A5B5A5859595858585756575A57585958595858585857585857
555756565555565456555554535352535153515152515050504F4F4E4E4E4E4C4D4C4C4B
4C4B4A49494848484645444444434342414140403F3D3D3C3C3B3A393737353534333230
2F2E2E2D2D2C2C2B2B2A292A2A2928292829282827282828272727272727272726272627
262727262626272726262626272627262626262626262626262626262626262626262626
262626262626262626262526262626262626262626252626262626262626262626262626
2626262625262626
262625262626262525262526262626262526262626252626262626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272727272626272726272727272727262727272727272728282828282728
28282828292929292A2B2A2B2C2C2E2E2E2F3132333537393A3C3E40424346484C4D5053
55595C6268717D858C9294979C9FA2A4A4A5A9A7A4A7A8A9A6A7A6A7A5A4A5A4A1A1A19E
9D989795908D878683827C7C7A77757373726E6F6D6D6B69686765646562636361605F60
5F5F605E5C5E5E5E5E5E5E5D5D5C5E5E5E5E5E5B5C5C5D5D5D5E5E5E5C5B5D5B5A5A5A5A
5959595A5A5A5A595A5959585A5A595A5A5A59595A5A5A5B595C595A5A595A5B5B5C595B
5C5C5959595A595A595A5758585857575656575457575657575656555655545757575655
5456555455555454545254535253514F4F514D504F4E4E4D4D4D4E4C4B4C4C4B4A4A4A49
49474748474645474543424241424041403E3F3E3D3C3D3B3A3938373635343332313130
2F2E2D2C2D2B2B2A2A2A2929292929282828282828272727272727272727262727272727
272627272727272727272727262627262726262626262626262626262626262626262626
262626262626262626262626262626262626262626262625262626262626262626262626
2626262526262625
252626262526252626262625262626262626262626262626262626262526262626262626
262626262626262626262626262626262626272626262626262626262626262626262626
262626262626262727262727262627272727272727272627272727272727272727272728
282828282929292929292A2B2B2B2D2C2D2F30303233343638393B3E3E424445484A4D50
5054585A60656E7781888D92949A9EA1A1A4A7A5A4A4A6A6A8A7A8A6A8A6A8A6A4A5A2A0
9F9C9C9997918F8D888586817E7C7775777170706F6C6C6A696869676563636161616160
6060605E5E5C5E5D5E5E5E5D5D5E5D5E5F5D5D5B5C5D5E5B5D5E5E5C5D5D5A5C5B5C5B59
5A5B5A5A5959585958585759585958575958595B5A585A5959585858585B59595B5A5959
5959595A5959595856595757585757585655555654555655555552545654545455545454
555454555353525253525150514F504F4F504E4F4F4F4D4E4C4C4C4B4A4A494A49494948
474646454545454444424240403F3F3E3E3E3D3C3C3B3938373736363534333231302F2D
2D2D2D2B2B2B2B2A2B2A2929292828282828272827272827272727272727272726272727
272727272726272626262626262727262626262626262626262626272626262626262626
262626262626262626262626262726262626262526262626262626252626262626262626
2626262626262626
252625262626262626252525252626262626262526262626262626252625262626262626
262526252526262626262626262626262626262626262626262626262626262626262626
262626262627262626262626272727272627272627272727272727272727272727272728
27282828282828282929292B2A2B2C2C2D2E2E2F303132343637393B3C3F414246474949
4C4E52555A5E616A717C858D9293999D9CA19FA3A6A4A6A7A5A8A1A5A8A6A5A7A4A3A0A0
9EA19E9E999995928D8C8784827F7F7A77767372716E6E6C6B6B68666664636563626260
61605F5F5E5E5D5E5D5D5C5C5E5D5E5C5D5C5D5B5C5B5C5E5C5D5C5C5B5A5B595B5B5959
595959595A59595958585758585957585758575857595858595959585858585A58595958
575957585758595858575657575655575756555454535453535253545353545255525353
5353515152505052515151505150504E4F4E4D4D4C4C4B4C4C484A484948474747474745
45454445434342424141413F3E3E3D3C3C3B3B3B3A3939383736363434333231302E2E2E
2D2D2B2B2B2B2A2A29292928282828282828282727282727272727272727272627272627
272626272726262626262626272726272626262726272626272626262626262626262627
262626262626262626262626262626262626262626252626262626262626262626262626
2626262526262626
252526252525252626262626262625262626252625262626262626262626262626262526
262626262626262626252626262626262625262626262626262726262626262627262626
262726272626262626262726262726272726262727272727272627272727272827282728
27282828282829292929292A2A2B2A2B2C2D2D2E2E2F3232343536383A3D3D4042444647
4A4B4E5253555A60656C757F878B93959999A09EA0A1A6A3A6A4A6A7A6A6A6A6A8A6A6A3
A5A4A1A09E9D9896928F8D8B8585807D7D7875727372716E6D6C6B686666656463626260
605E5F5E5D5D5C5D5D5E5C5C5C5C5D5E5C5D5D5C5A5C5D5C5D5C5B5C5B5B595B59595958
5959595A5858595857565756585757595757565656575857585757575758595658585856
585758575758575657555756565656565655555452545455515251515352525152525353
515253505050504F504D4F4F4E4D4F4D4D4B4B4B4C4C4B4B494A48484746464545444545
44424441424143403F403D3E3C3C3D3B3A393A3838373736353434333231312F2F2E2D2D
2C2B2B2B2B2A292A29292928282828272827272728272727272727272727272727272727
262626262626262726262626272627272626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262526252626262626
2626262626262625
252625262526262525252626262526262526262625262626262525262625262626262626
262626262626252626262626262626262626262626262626262626262626262626262626
272626262626262726262626262627272626272726272726272727272727272727272827
2827282828282829292929292A2A2A2B2B2C2C2D2E2E2F323133343637383B3C3E3F4344
47494C4D4E5254575C60666F7881878F9197999B9D9F9EA4A3A4A3A7A3A5A5A6A5A6A8A7
A5A5A7A19F9E9C9C979693908C888482817E7A79747673706E6E6E6A6968676463626262
62625E605E5E5D5D5C5D5C5B5B5B5C5C5C5B5D5C5B5B5B5B5C5C5C5B595A5A595A585858
59595958595B585958585656575757575455565656565656575755575755555657565755
565556575755575755565555535654565554555452535250525151515151515051515052
504F504F4F4F4E4D4E4E4E4D4E4D4C4C4B4C4B4B4A494949484747454445454443434342
4241423F3F40403F3D3D3C3C3C3A3A3939383737363535343533333230302E2E2D2D2D2C
2B2B2B2B2A2A2A2928292928282828282828272727272727272727272727272727262626
272626272626262626262626262626262626272626262626262626262726262626262626
262626262626262626252626262626262626262626262626262626262626262626262626
2626262626252626
252626262526262626262626262626262626262625262626262526262625262626262526
262726262626262626262626262626262626262626262626262626262526262626262626
262626262627272626272626262626272727272727272727262727272727272727272727
282727282828282828292829292A29292B2B2B2C2D2D2E2F303132353537383A3C3E3F42
4446494A4C4D4F5156595C6168707C828A8F96989D9B9E9BA2A3A7A3A5A3A4A5A6A7A6A5
A6A8A5A4A5A19D9E9E9A98969390898A84817E7C7A777573736F6C6C6C69696664646364
616161615F5F5E5E5E5C5C5C5B5B5B5C5C5D5B5A5D5B5B5A5B5C5A5A5959595858585858
595958585959595757565655565754555556535556555555555555555554535555555556
5556565556545453545555545453545353535352525251504F50504F4F4E504E4F504F4F
514F4E4E4D4E4D4E4E4C4B4C4B4A4B4C4A4A4A4948474747464646454344444242424140
40403F3E3E3E3E3C3C3C3C3B3A3939383936373535343433333131302E2E2E2D2D2D2C2B
2B2A2B2A2A29292928292828282828282828272727272727272727272626272626272727
272627262627262626262727262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252625252526252625262626262525252526262626262626262626262626262626262526
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262627272626262626272626262626272727272627272727272727272727
272827282828282828282828282929292A2A2A2B2C2D2D2E2E303132333538383A3B3C3F
404245474A4A4D50515558585E646A757C848B9193989B9B9EA0A2A2A3A2A2A3A5A4A5A5
A5A8A6A6A5A3A19F9F9F9C9B9893928E8A8684817E7A797775726F6D6D6C696867666664
63606261605E5E5E5E5E5C5D5B5D5B5B5A5C5C5C5B5A5B5B5A5B5A595859595958585958
5A5757575758585556565656555655535555555454545454545553535454555455545454
545453535254555354555353535252535251525150515150514F4F4E4D4E4E4C4E4E4C4D
4C4E4D4C4B4C4D4C4C4C4B4B4A4A4A494A49494748464646454444444243414241413F40
3F3F3E3D3C3D3B3A3B3A3A393938373736353534343333323130302F2E2D2D2C2D2C2C2B
2A2A2A2A2929292928282828282827272727272827272727272727262727262626262726
262626262626272626272626262626262627262626262726262626262626262626262626
262626262626262626262626262626262626262626262626262726262626262626262626
2526262626262626
252625262526262626252526262525262626262626262525252625262626262626252626
262626252626262625262626262626262626262626262626262626262726262626262726
262626262626262727262626262627272727272626272627272627272727272727272727
2727272828272728282829282929292A292A2A2A2B2C2C2D2E2F2F303233353637393B3D
3E40424347484A4C4E515354585B5F656C757E868E9296969C9B9FA2A0A2A4A2A2A2A5A4
A3A4A7A6A4A6A4A2A29E9F9C9A9896948E8B888783807B7A7576726F6F6D6D6968666564
65636162605F5D5E5F5D5C5C5C5B5A5A5A5A5B5A5A5A595A5A5A5B5A5A59575757575657
575557575656565656565654545554545554535556535355565554535354545354535252
5252525351535353535352525251515250515050515051504F4E4F4E4D4D4C4D4B4B4A4C
4B4C4C4B4C4A4C4B4B4B4A49484A48484847464846454644444342414240403F3F3F3E3D
3D3B3D3B3C3B3A3939383837373736353435333333323131302F2F2E2D2C2C2C2C2B2B2B
2A2A2A292929282828282827282728272727272727272727272727272726262727272727
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262626262626272626262626262626262626262626262626262626262626
2626262626262626
252626252625262526262626262526262526262525262625262626262625262626262526
252526262526262626262526262626262526262626262626262626262626262626262626
262726262626262626262626262627262727262626272627262727262727272727272727
2727272727282828282828282828292929292A2A2A2A2B2B2D2D2E2F303233343537383A
3A3C3E40424346494B4C4D515355585E61676F7980888D9193999B9B9B9EA1A1A3A3A1A2
A6A6A5A6A5A6A5A3A3A2A19C9B9E9A9893948E8B88847F7F7C78767370706D6C6C686765
6463636262625E605F5D5C5D5C5C5B5B5B595B5A5A5A5A5A595A595A5757585856565556
555656555656555454555654545553545353535454545552535352525251525151525252
52505151505052505250515250514F50505151504E4F50504E4D4D4D4B4C4C4C4B494949
4A4948494B494A4B49494948474746474646464645454343424241413F3F3E3E3D3D3C3C
3C3B3A3A3939383838373736363534343433333231312F2F2E2E2D2E2D2C2C2B2A2A2A2A
2A2A29292828282928282827272727272727272727272727262727272626272626272626
262626262726262626262626262626262626262626262626272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262525
2626262626262626
252626252526252526262526252625262525262626252625262626262626262626252626
262626262626262625262626262626262626252626262626262626262626262626262626
262626272626272626262726262726262627262726272726272727272727272727272727
27272727282727282828282828282828292929292A2A2B2C2C2C2D2E2F30313133353638
383A3C3D404043454748494C4E535256595D6369717B81888E939899999C9EA0A2A1A0A1
A5A3A3A3A5A4A4A3A1A2A29F9F9E9D98959493908B888582817B7A767772716E6C6A6968
66656463626160605F5C5C5C5D5B5B5A5B5A595A5A5A595A5A595A595957585657575556
555655555556555454535354545253525452525351525152535151505051505052515250
50514E504F515051504F4E4F4F4F4F4D4F4E4F4E4C4E4E4C4C4C4B4B4A4A49494A49484A
48484948484748494746474647464546454446444342414141403F403F3E3E3D3D3C3B3B
393B393939373737363636353534333333323030302F2F2E2E2D2D2C2C2C2B2A2B2A2A29
292929292928282827282827272727272727272727272727262727272626272727272626
262626262626272726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262526262626262626262626262526
2626262625262626
252626252525262625252625262625252525262526252626252525262625262626262626
262626262625262626262626262626262626262626262626262626262626262626262626
262626262626262626262626272627262626272627262726272727272727272727272727
2727272727272728272829282828282928292929292A2A2B2A2C2C2D2D2F302F31323436
3738393B3B3D3F41444448494B4D505254595B5F6569737A82898F91959A9B9A9EA1A1A1
A1A3A5A3A4A3A4A2A4A39EA3A09F9D9C9B999593908F87878281807B7B7674716D6E6B6B
68666465636262615F5E5E605D5D5C5C5D5B5A5A5A5A5A5A595A59585757575755555554
555456525353555354525454525353515151515052514F50505151504E4F4F505051504F
504D4F504F504D4F4F4E4F4E4C4D4F4E4D4C4C4C4D4C4C4A4C4B4A4B49494A4847484747
48484647464846464645464644444344434342424242413F3F3F3D3D3D3E3D3B3C3A3A39
3A3838373737363635343434333231313130302F2F2E2E2D2C2C2C2B2B2A2B2A2A292A2A
292929282828282828282727272727262727272627272727272727272627262626262626
272626272626272626262626262626262726262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262526
2626262626262626
252525262626262625252626262625262625262626262625262626252625252625262625
262626262626262626262626252626262626262626262626262626262626262626262626
262626262626262626262626262627262627262626272727272627272727272727272727
272727272727272727272728272828282829282929292A2A2A2B2B2C2C2D2E2E2F303232
33363839393B3D3F41424446484A4C4F505455575A60656B747D858A8E919699999D9EA0
A1A2A5A1A1A2A6A3A4A3A2A1A09D9CA09F9A989896908E8B8683827E7B797674706D6D6B
69686766636262616160605E5D5D5C5B5C5B5B5B5A5B5A59595857565958565657565555
545553545554535254525253525351525251514F50504F4F5050504E4E4F4E4E4F4F4E4E
4F4F4E4E4E4D4D4D4D4D4D4B4C4B4C4C4D4B4C4C4B4A4A4B4A494A494949484848464646
4546464645454545454443444248434242414140403E403E3E3C3C3D3C3C3B3A3A3A3937
38373736363435343333333232313130302F2E2E2D2D2D2C2C2C2B2A2B2A2A2A2A292929
292828282828272728272727272727272727272727272727272726262727262727262726
262727262626272626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
2525262625262626
252625262526252526252626252526252626252625252526262626252526252626252626
262526262625262626262626262625262626262626262626262626262626262626262626
262626272626262626262726262626262626262626262627272727272727272727272727
27272727272727272727282728282828282828282929292A2A2A2B2B2B2D2D2E2F2F3031
3334353638393B3C3D4041444448484A4D4F505356595C61666C747E828B8D9296999B9E
9EA09EA2A1A1A2A3A2A4A1A1A09FA09D9E9D9B999696938E8C878481807C7A7673706F6D
6A6B69676564636160605F5F5E5F5B5C5C5D5B5B5B5A5A5B595759585757565655555555
53545453535353535352525150515151505050504F51504E4E4F4E4F4E4D4D4E4E4D4F4E
4D4E4C4B4D4D4C4C4B4C4B4C4C4B4A4B494A4A4A4A4A4B484A4948494648464646464546
45454444454243434344424342414141403F3F3F3E3D3D3D3C3C3C3A3A3A3A3B38383736
36363535343333333232313131302F2F2F2E2D2D2C2C2C2B2C2B2B2A2A2A2A2A29292929
282828282827282828272827272727272727272727272627262626262627272726262626
262627262626262626262626262626252626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262625252625252626252626262626262626262626262626252626262626
262626262626262526262526262626262625252626262526262626262626262626262626
262626262626262626262626262626262726272627262626272627272726272627272727
272627272727272728272728272728282828282829292929292A2A2B2A2C2C2C2E2D2F2F
31323435353838393A3D3F4041434648484B4D4F4F5356585C62666C747D858A8E919598
9B9A9D9FA3A0A2A3A3A2A2A1A29F9EA09F9D9C9B9A9796948E8C898382827B7A7572716F
6D6C68686866626162615F615F5E5E5E5C5C5A5B5A5B5B5A595757575756555857545654
5354545354535453525253515251515150504E4F4D4D4E4D4F4D4E4E4C4D4C4C4D4C4C4B
4B4C4D4D4C4B4B4C4A4A494B49494A4A4A49494A494A4848474747474646454545464544
4444434443424242434142424040413F3F3E3E3E3E3D3D3D3A3A393A3939383838383636
3535343333323231323030302F2F2E2E2E2D2C2D2C2C2C2B2B2B2A2A2A2A2A2929282928
282828282828272727272727272727262727262727272726272726272626262626262627
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625252526262525252526262625262625262626252626262626262526252626262626
262626262526262626262526262626262626262626262625262626262626262626262626
262626262626262626262626262626262626262626272626262727272727272726272727
27272727282727272827272728272728282828282828282928292A2A2A2B2B2C2D2D2E2E
302F303233343637393A3B3D3F4042434547494B4B4F5153575A5D60676E757D838A8E91
9399999B9B9FA0A1A1A0A1A1A0A19E9F9D9B9D9B98989897918D8B8A85827F7C77797373
72706B696A666663616261605F5E5D5D5D5C5B5A5A595B59585856585756575757545555
56535353545352525151515151515150504F4F4F4F4E4E4D4C4D4D4D4C4A4B4B4B4B4B4B
4C4B4B4A4A4B4A4A4A494948484A49484848484848474746474646464648464443434343
4442424241404140404040403F3D3E3E3D3E3D3C3C3C3A3B3B3B39393838373635363435
33333332323232313030302E2F2F2D2D2C2C2C2C2B2B2B2A2A2A29292929292928282828
282828272728272727272727272727272727272727262627272626272726262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262626262626262626262526262626262526262625252626262626
2626262526262526
262626262526262625252525252526252525262626262526252626262626252626262526
262626262626262526262626252626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262727262627272627272727272627
2727272727272727272727272827282727282828282828292929292A292A2B2B2C2C2D2D
2D2F3030323335363637393B3C3E3E4142444645494C4D4E525357585C62676C737C8389
8D909395969A9B9B9B9D9FA0A09F9F9F9D9C9D9D999A9799969290898886827F7B797A75
72716E6B6967686564636260605E5F5D5E5D5A5B5A5A5A58585857575855565455555554
55555452525353545152505051504F4E4F4D4E4D4D4C4D4D4C4B4B4B4B4C4C4A49494949
4A4949494948494848484847474847474746464646464646464544454345434443444443
4142414040403F40403F3D3E3D3D3E3C3D3C3B3B3A3B3A39393737383636353535343333
33323232313130302F2E2E2E2C2C2C2C2C2B2B2A2B2B2A2A2A29292A2928282828282828
282828282827272727272727272727272727272727262726272626272626262626262626
262627262726262626262626262626262626262626262726262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262525262626262526262626252526262625252526262625262626262626262626
262526252625262626262526262626262626262626262626262626262626262626262626
262626262626262726272626262626262626262626262626262627272726272726272727
2727272728272727272727272727272828282828282828292929292A29292A2A2B2C2C2C
2D2E2E2F2F30333334353638393B3C3E404142454647494B4D4F515357595E61666C737A
82878B8F9297969B9B9A989D9D9C9E9D9D9F9C9F9B9A9996969591908B8886817D7E7A78
75746F6D6B6A696964646362605F5F5E5C5C5A5B5B5B5A59595957565757575556545555
5454555353525252505251504F4F4F4F4D4D4E4D4D4C4B4C4B4B4A4A4A4A484949494949
4A4949474847474847484747464746454645454544454544454344444243424242434341
3F3F3F40403E3D3E3E3C3B3C3C3C3B3B3B3A3A3A39393837373737363635353434333332
3131313031302F2F2E2E2D2D2C2C2C2B2B2B2B2B2A2A2A29292929292928292828282828
282728282727272727272727272727262726272727262626262727262726262626262626
262627262626262626262626272626262626262626262626262626262626262526262626
262626262626262626262626262526262626262525262626262526262626262625262626
2626262525262626
252625262625262626262625262526262525252525252626252526262626262626262626
262626262626252626262626262626252626262626262626262626262626262626262626
262626262626262626262626262626262726262626262626262726272727262726272727
272627272727272727272727272827282728282828282828292928292929292A2A2B2B2B
2C2D2D2E2E2E3031333334363738393C3D3F3F41424446474A4C4E4E4F53565A5C60646B
727983868C8E9394959A9A999A9B9B9B9D9C999A9A9A9998969693908C898884837E7C7A
767471706D6A6A6969666562615F5E5F5D5C5C5C5C5B5958575858575756555654535554
5455545453515151515050504E4E4D4F4E4E4D4D4C4C4C4A4B4A4A494949494749474848
484647464646464647464645454645444444444445454442434343434341414140414040
3F3E3F3E3E3D3D3D3C3C3C3B3A3A3A3A393A393837383637363635343534343333323230
313030302F2E2E2D2D2C2D2C2B2B2B2A2A2A2A2A2A2A2929292928282828292828272727
282827272727272727272726272727272627262726272627262626262727262626262626
262626262726262626262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262526262625262626262626262626262626262626
2626262626262626
252626262626262625252626252625262526252626262526262626262526262626262526
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262627272627262727262627262727272727
27272727272727272727272727272728272727272728282828282929292929292A2A2A2B
2B2C2C2D2E2E2F2F30313234353737383A3B3C3E3F4144444747494B4D4E525455585A5E
626A717980858A8C909494979998979B9A9B9B98989B9897979896938F8D8A8886817D79
797774716F6E6B696865656361616160605E5C5C5B5A5959585858585557575555545454
535453505251515150504F504E504C4D4D4D4D4A4C4B4B4A4A4948494848484846484648
464746454646454645454444444443434343444344434242434242414142413F4040403E
3E3D3D3D3C3D3C3C3B3B3B39383939393839373737353635353434333333323231323030
2F2F2F2E2E2D2D2C2C2C2B2B2B2B2A2A2A2A2A2929292929282828282828282828282728
272727272726272727262627272727272627262726262626262626262626262726262626
262626262626262626262627262626262626262626262626262626262626262626262626
262626262625262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262625252625252626252526262626262625252525252626262626252626262626
262626252626262626252626252626252626262626262626262626262626262726262626
252626262626262626262626272626272626262726262626272626272727262627262727
2627272626272727272727272727272728272727272828282828282829292929292A2A2A
2A2B2B2C2C2D2E2F2E3030313333343638393B3C3D3D404243454647484B4D4E52555559
596062686E767C83888A8F909292949697999898989999989A98969590918F8889838080
7C787574716E6D6A69696665636161605F5E5D5C5B5C5A5A595A56575757555354535352
535151505150515151504F4F4E4F4D4E4C4B4C4C494B4A48494949484747464645464646
464545454344454444444444434343434342414242434141414040413F3F3F3F3F3D3E3D
3D3D3B3B3C3B3B3B3A3A3939393838373737363636353535333332333232313130302F2F
2F2E2D2D2D2C2C2C2B2C2B2B2A2B2A292A29292929292928282828282828282827272727
272727272727272627272727272727272627262627262726262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262526262626262626262626252626262626262526262626262626
2526262625262626
252625262626252626262526262625262625262625252626262625262626252626262526
262626252625262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262726262726272726
272727272727272727272727272827272727272727272827282828282829282929292A2A
2A2A2A2B2C2C2D2D2D2E2F2F30313234353538393B3C3D40404143444648494B4B4F5053
5658595F62666C737A8187888B8D8F92949493959699989697989698968F8E8B89878481
7F7A797774726F6C696868676664626060605D5D5B5C5A59585857575654555554535253
5352525151504F4F50504E4E4D4D4C4C4B4A4B4A4B494949494848474745454646464546
4444444344434242424243424142424140424140404140404040403F3E3F3E3D3D3D3D3D
3D3B3B3A3A3A393938383837373736353535353535353332323332313230302F302E2E2E
2E2D2C2D2C2C2C2B2B2A2A2A2A2A2A292929292928282729282828282727282827272727
272727272726272727272727272726272726272726272727262626272626262626272626
262627262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626252626262626262626262626262626262626262626262626
2625252625252526
252626252626252525252526252526262626252626262625262625252626262625262626
262526262626262626262526262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262627272726
272727272727272727272727272727272727272827272728272828282828282828292929
29292A2B2B2C2B2D2C2D2D2E2F3030313334353637393A3C3D3E404143444447494B4C4E
4F5154565A5C60656A737A7C82848B8D8E8F909193929695959496949293908F8D8A8685
817F7D777775736F6D6B696966666262615F5F5C5C5B5C5A595658575755555554535351
525250515050504F4F4E4F4D4E4D4D4E4B494A4A494A4948474747474644444544444545
4444444443424342424141414041404140403F403F3F3F3E3F3E3D3E3E3C3C3C3C3C3B3B
3B3A3B3A3A393837383637373635353535343434333433323131313130302F2E2E2E2D2D
2C2C2C2B2B2B2B2A2B2A2A2A2A2929292929292929292828272727282727282827272727
272727272727272727272727272627272727262726262626262627272626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
262626262625252526262625262626262626262626262626262625262626262626262626
2626262626252525
252526262626262526262525262626262525262625262625262626262626262626252525
262526262526262526262526262626262626262625262626262626262626262526262626
262626262626262626262626262626262626262626262626262626272626262626262626
272727272726272626272727262727272727282827272727272828282828282828282929
29292A2A2A2B2B2C2B2D2C2D2F2E2F3031333234363638393B3C3D3E3F40434446474849
4C4E4F515456585B5E63696C7478808386898B8B8E908E939291939192918F8F8A8A8A84
85817F7D787873726D6E6B6967656563625F5E5C5E5B5A5B5A5858575555555454535351
51504F515050504F4E4F4F4E4D4C4E4C4B4B4A494A484947464847464545444443434343
43434342434241404240413F4040403F3F3F3F403E3E3D3D3D3D3D3C3D3C3B3C3B393A3A
393939383837373736363635363434343433333231323131303030302F2E2E2D2E2C2C2C
2C2B2B2B2B2A2A2A292A2929292929282928282828282828282828282727272728272727
272727272626262627272627262627262627262627262626262626262626262626272726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262526262626262626262626262626262626262626262526262626
2626262626262626
252625262626252625262625262625252626262526252626262626262626262625262626
262626262526262626262526262626262626252626262626262626262625262626262626
262626262626262626262626262626262626262626262626272726262627272726262726
272626262726272727272726272727272727272728272727272727282728282828282828
29292929292A2A2A2A2C2B2D2C2D2E2E2F30323233353637383A3A3B3E3F3F4142444446
484A4C4D4E505255565A5B5F63686C73787E8083868B8B8E8E928F928F8F8D8E8E8E8B88
8886817E7E7B7674716F6E6E6B68676562605F5F5D5D5D5B595A58575654555453525151
5251505050504F504D4E4C4D4E4C4C4B4A4A484949474846464646454544444344434242
4241404040403F403F3F403F3F3E3E3D3D3E3D3E3E3D3C3B3C3B3B3C3B3A3B3A3A393938
3938383839363735353535343434333332323232313130302F2F2F2E2E2E2D2D2D2C2C2B
2B2B2B2A2A2A2A2A29292929292928282828292828282728282727272727282727272727
272727272727272727272727262727272727262726262626262626262726262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262626262626262626262526262526262626262626262625262626
2626262626262626
252625262626252625252625252626262626262526252526252525262626252625262626
262626262526262626262525262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262726262626262626262626262627
272727272627272727272727272727272727272727272727272728272828282828282829
29282829292A2A2A2A2A2B2C2C2C2C2D2E2F303031323333353639393A3B3D3E40414243
464648494A4B4E50505354565A5D60646B6D72797D81868788898B8C8B8A8E8D8E8C8A8B
888585837F7C7A7574716F6D6D696A666462615E5E5C5C5B5B5959575755565354525252
5050504F4E4F4D4D4E4D4B4C4C4C4B4A4A4A4A4848474747464545444444434244424141
40403F3F3F3F3F3F3E3E3E3D3E3C3C3D3C3D3C3C3B3C3B3B3A3A393A3A3A383838383737
37363736363535343434333333313232323131312F302F2E2E2E2E2D2D2D2C2C2B2B2B2A
2A2A2A2A2A2A292929292829292928282828282828272727272727272727272727272727
272627262627272726272727262726262726272626262727272726262726262626262627
262726262626262626262626262626262626262626272626262625262626262626262626
262626262626252426262626262626262626262625262625262626262625252626252626
2626252626262625
252625252526262525262625252526262525252626262526252526252526252626262626
262526262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262627262626262626
272726262727272727272727272727272727272727272727272727282727282728282828
2828282929292A292A292A2A2B2C2C2C2D2D2E2F2F3031323335353738393B3C3D3E4141
4244444647484A4A4C4E4F525454575A5D5F64686C73787B80838487868A898A89898888
88848583817E7C7976736F6F6E6B69696564605F5E5E5C5C5B5A58575556555353505250
504F504E4F4C4D4D4D4D4C4C4C4B4B4A4A49474747464645464545434244424141414140
403F3E3D3E3E3E3D3E3D3D3D3C3C3D3B3B3B3B3B3B3B3A3A393939383839373737373736
363636353535343433323232313230313130302F2F2E2E2D2D2D2C2C2B2B2B2B2B2B2B2A
2A2A2A292929292929282828282828282828282828272727272827272727272727272727
272727272726272727262726262726262726272627262626262727272626262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262626262626252526262626262626262626262626262626252626262626262526252526
2626262626262526
262525262526252525262625252626252526262526262626252526252625262525262626
252625262626262626262626252626262625262626262626262626262626262626262626
262626262626262626262626262626262627262626262627262626262626262626262626
262727272726272726272727262727272727272727272727272827272727272728282828
282828282929292A292A2A2A2B2A2B2B2C2C2D2D2E2F30303132333435363738393A3D3D
3F41424444454648494A4B4C4E4F52525559595C5F64696C6F767A7C8182868788848583
83848483807D7D7A7A787671706C6B69676462625F5D5F5C5C595B585757555554535252
514F504E4E4D4C4C4C4C4A4A4A4A4A494948474746464545454442444241414140403F3F
3E3E3F3E3D3D3D3C3C3B3B3B3B3A3A3A3B393A393A393938383838383836363636363536
3535353534333333323232313031303030302E2E2E2D2D2C2D2C2C2B2B2C2B2A2A2A2A2A
292A29292928292829282828282828282728282727272727272727272727272727262727
272727262626272627272626262727262727262627262626262626262626262626262626
262626262626262726262626262626262626262626262625262626262626262625262626
262626262625242426262626262626262626262626262626262626262626262626262526
2626262626262626
252625262526252525252625262526252626252626262526262525252526262626262626
262626262626262626262625262626262626262626262626262626252626262626262626
262626262626262626262626262626262626272626262626262626262626262626262626
262626262726272627262727272727272727262727272727272727272727272727282828
2827282828282929292A2A2A2A2A2A2B2A2B2D2D2D2D2E2F30313032343535363739393B
3D3D3E4041434244454648494A4C4C4E5252535558595E5F62686B6F73787C7E80817F7F
7F808180817F7D7C7A7675736E6E6A6967656361615E5B5B5B5B59565855565353505051
50504E4E4E4D4D4B4C4B4A4B4B494A4749484746474645454443434141413F403F3F3F3D
3D3C3D3C3D3D3C3B3C3B3B3A393A39393938393839393738373638373636363535343534
343434343332323231313030302F2F2E2E2D2D2D2C2D2C2B2B2B2B2B2A2B2A2A2A2A2A2A
292929292828282928282828282727282728272728272727272727272727272727262727
262727262726272726272727272626272626262627262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262625
262626262626242426262626262626262626262625262626262626262626262526262626
2626262626262625
252626252526252525252526252626252525262626252625262526262626262625262626
262626262626252626252626262525262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626272626262627262626272626
262627262726262727272627272627272727272727272727272727272727272728272728
28282828282828282929292A292A2A2A2A2A2B2C2B2D2D2E2E2F30313233333535363839
393A3C3D3E3F41414243464647484A4B4A4D4E505053545658595E6265666C717477777B
7C7D7C7E7F7C7C78797673706D6D6C6966646463605F5E5B595959565455555353525150
4E4F4F4E4D4C4B4B4A4949494849484847464645444544444342434140403F3E3E3D3E3D
3D3B3D3C3B3A3B3A3A393A39393838383837373837373636363635353534353434333434
33333231323132313030302F2F2E2E2D2D2D2D2C2C2B2B2B2B2B2A2A2A2A2A2A29292929
292929282928282828282828282827272728272727272727272727272727272727272727
272727272626272627262626262627262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625252526262626262526262526262626262626262626262526252626252625
2526262525262626
252526262626252625252526262526252626252525252625262526262626262625262525
252526262626252526262626262526262626262626262626262526262626262626262526
262626262626262626262626262626262626262626262626262627262626262626262627
262726272726272726272727262727272726272727262727272727272727272728272727
2827282828282828292829292A292A2A2A2A2A2B2B2B2C2D2D2D2E2E3031323333333536
3738393A3B3C3E3D404141434444474748494A4C4E4E505153525657595A5C6163686B6E
71737576787A77777574726F6E6B6C6A69656563615F5E5D595958565655545452505150
504F4E4C4E4C4C4B4B4A484947484846464645454544434341424041403F3E3E3D3D3D3C
3B3C3A3B3A3A3A3739383838383837383736373636363636353535353434343333333332
3132313130303030302F2E2E2D2D2C2C2C2C2B2B2B2B2A2A2A2A2A2A2A29292929292928
282828292828282828282827272727272727272727272727272727272726262726262727
272626272727272626262726272627272626262626272626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242526262626262626262626262625262626262626262626262626262626
2626262625262625
252625252626252525262525262625252525252625262525252626262626252626252626
262626252626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272627272626262627272626272727272727272727272727262727272727282727272827
272727272828282829282829292929292A2A2A2A2A2B2B2C2C2D2D2E2E2F303031333334
3435373838393A3C3D3C3D3F4142424445454847484A4B4B4D4E4F5150515556585A5D61
6167696C6D7170717170716F6E6B6A6966656462625E5D5B5A595855565453535150504F
4F4E4D4D4C4B4B494B4B4A4847474646454543444341424241414040403E3C3D3D3D3C3B
3B3A3A3A3939373838383736363536363637353535353434343434333332323332323131
3131302F302F2F2E2E2E2D2D2C2C2C2B2B2B2A2B2A2A2A2A2A292A292929292929292928
282828282828272828272727272727272727272727272727272626272727272727272727
262726272727262726272626262727262627262626272626262626272626262726262626
262626262626262626262626262626262626262626262625262626262626262526262626
262626262625242426262626262626262525262626262625252625262626262626262626
2626262626262526
252526252526252525252626262626262625262525252626262626262626252626262526
262525262626262625262526262626262626262626262626262626262626262526262626
262626262626262626262626262626262626262626262626262626262626262626262726
262627262626262626272627272627262627272727272727272727272727272727272727
28272728282727282828282829292929292A292A2A2A2B2B2B2B2C2C2D2E2E2E30303132
33333335353838383B3A3C3C3E403F4142424345434847494A4A4B4C4C4D4C4F4F525254
56585B5D5E626567696B6A6B6B6B6968666463615F5D5B5B5A59585655545351514F504F
4D4E4C4C4A4A4B49494A474847474545444543434242424141403F3E3E3E3E3E3B3A3A3B
3A3A38393838383737373634353536343534343434333332343332323132313131313031
2F2F2F2E2E2E2D2D2D2D2C2C2B2B2B2B2B2B2A2A2A2A2A29292928292929292829282828
282828272827282728282827272727272727272727272727272727272626262727272727
272627262627262627272726262626272727262626262626272726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
262626262626252526252626262626262625262626262626262626262626262526262626
2626262626262626
252625252526252626252625252525252625252625252525262525252626252626262625
262526252626262526262626262625252526262626252626262626262626262526262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262627272627262626262627262726272727272727272727262727272727272727
2727272827282728282828282829282929292A292A292A2A2B2A2B2B2B2C2D2D2E2E2F30
303132333435363638393A3B3B3C3D3E3F3F404243424445454647484A474A4A4A4C4C4E
4F4E5052545457595B5D5E61646462646260605D5E5B5B5958585855535252514F4F4F4E
4F4C4C4C4B4A4A49484748484646444543434342424141403F3F3F3F3E3C3C3C3B3A3A39
3838383737373635353535353434343333333433333332333231323230303130302F2F2E
2E2E2E2D2D2D2D2C2B2C2B2B2B2B2B2A2B2A292A292A292A292929292829282828282828
282727272827272827272727272727272727272727272726272726272626262626262726
272626272627272626272626272627262726262626262626262626262626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626252426262626262626262626262526262626262625262626252526262526
2525262626262626
252625252526252526252526252526262525262525252626252525262626262625252626
262626252626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262627262626262626
262626262627262726272626272627272627272727262726272727272727272727272727
2728272728272827282828282828282828292929292A292A2A2A2A2B2B2B2C2C2C2D2E2E
2F2F303131333334353637373839393B3C3D3D3E3F3F4142424243434745454747474747
49494A4C4C4E4F4E505053545658575858585959595A59585756565654535151504F4F4E
4C4D4C4A4A4A49484648474546454544434242424140403F3E3E3E3D3C3C3C3B3A3A3938
383738373636353435353534333333333332323232323131303130302F2F2F2E2E2E2D2D
2C2D2D2D2B2C2C2C2B2B2B2B2A2B2A2A2A2A292929282929292928282828282828282728
282728282727272727272727272727272727272727272627262727272726272727272727
272726262726262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252426262626262626262626262625262626262626262526252626262625
2626262626252626
252625262526252626262625262526252525252625262626262525252526262625252626
262626262625262626262626262625252526262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262726262626262626262626
262726262626262727262726272627262626262727272727272727272727272727282727
272828272728272728282828282828282829292A292829292A292A2A2A2B2B2B2C2C2C2D
2D2E2F2F2F31313133333435363838383A3A3B3C3D3D3E453F4040404242434343444544
454646474747484749494A4B4C4B4C4D4D4F4F52515353545252535351504F51504E4E4D
4C4B494A49474948474745454544434342414041403F3F3E3E3D3C3C3C3B3B3B3A393837
3737363635353434333333333232323231323031312F30302F2F2E2F2E2E2E2E2C2D2C2C
2C2C2B2B2B2B2B2B2B2A2A2A2A292A292929292929292929282828292828282828282727
272727272727272727262727272726272727272627272626272627272727272726272626
272726262626262726272626262626262626262626262626262627262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262526262626242426262526262526262625262625262626252525252626262625262626
2626262626262626
252625262625252625252625252526252626252625262626262525262626262525262625
252625262626252626262626262526262626262626262626262626262626262626262626
262626262626252626262626262626262626262626262626262626262626262626262626
262726262626262627272626262627262726262627272627272726272727272727272727
2727272728272727272728282828272828292828292928292929292A2A2A2A2B2B2B2C2C
2C2C2E2D2D2F2F2F3031313333343436373738393A3A3B3B3D3E3D3E3E403F4041414242
42434444434443444444444547444546474847484A4A4A4949494A4B4C4B4D4C4E4B4D4C
4A4A494847464547454644434242414140413F403F3E3E3D3C3C3B3B3A393A3939393737
35353534343334343332323231313130313030302E2F2E2E2E2E2D2D2C2D2D2D2C2B2C2B
2B2B2B2B2B2B2A2A29292A2A29292A292929282829282828282828282828282727282828
272727272727272727272727272727272727272726272726272726262726272627272627
262726262626262726272626262627262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626242426262625262526252625262626262526262626252625252526262626
2626262625262526
252625262625252525252625262626262526262625262526252626262626262625262626
262526262626252626262526262626262626262626262626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262727262626262626262727272727272627262626272627262727272727272727272727
272726272727272727272828282828282827282928282929292929292929292A2B2A2B2B
2B2B2C2D2C2D2D2E2F2F30313132333334353537373838393B3A3A3B3D3C3E3D3E3E403F
413F42404141404042414141434242414241424243434343434141434343444545454547
46454545434343434443424240403E3E3F3E3D3E3D3C3C3B3A3B3A3A3939383837363634
35343333333331313130313030302F2E2E2E2E2D302E2E2C2C2D2C2C2B2C2B2C2B2B2B2B
2B2A2A2A2A2A2A2A2A2A2929292929292829282828282828282828282828272827272727
272727272727272726272727262726262727272726262627272726262626262727272626
262626272726262626262626262626272626272626262626262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
262626262626242426262626262626262625262525262626262626262526262626262525
2626262526252626
252625262626262626262526262525252625262525252526252625262625262626262625
252625262626252626262526262626252626262626262625262626262626262626252626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262726262626272726262626262726272627272727262727262727272727
272727272727272727272728272A2B282828272828282928282829292929292A2A2A2A2B
2B2B2B2C2C2C2B2D2E2D2E2E2F2F303133333434353536373738393A393B3C3C3C3C3D3C
3D3D3D3D3E3D3E3D3E3E3E3E3E3F3D3D3D3D3E3E3F3D3E3D3E3E3E3D3E3E3D3E3F3F3F3E
3F3F3F3E3E3E3F3E3D3D3E3D3C3B3B3A3A3B3A3A39393938373837363737353534343433
323231303030302F2F2E2D2E2E2E2E2D2D2D2D2D2D2B2C2C2C2C2C2B2B2A2B2A2A2B2B2B
2A2A2A2A292A2A2A292A2929292929292828282828282828282728272727272727272727
272727272727262726272727272727262727262626272627262726272627272626272626
262626262626262626262626262726262626262626262626262626262626262626262626
262626262726262626262626262626262626262626262626262626262626262626262626
262626262626242425262626262626262626262626262526252626262626262526262626
2625262626262526
252625252526262626252525252625252525252625262626252626252626252526262625
262626252626252626262526262626262626252626252626252626262526262626262626
262626262626262626262626262626262626262626262626262626262626262626272626
262626272626262626262626262626262727272726262627272727272627262727272727
2626272727272727272727272828282828272828272828282828292828292929292A292A
2A2A2B2A2B2B2C2C2B2C2E2E2E2F2F2F30303132323334353636363837383938393A3A3A
3A3A3A3B3B3B3C3B3B3C3C3C3C3C3C3C3B3A3B3A3B3B3B3A3C3A3B3B3B3B39393A3A3A3A
3A3939393939393939383837373837373637373736353535353434333433323232323130
312F2F302E2E2E2E2E2E2D2D2D2D2C2C2D2C2B2C2B2C2B2B2B2B2B2B2A2B2A2B2A2A292A
2A2A29292A29292929282928282828282828282828272828272727272727272727272727
272727272727272726272726272627272727262627272626262626262726262626262726
262626262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242426262626262625262625262626262626262625262626262626262626
2626262626262626
252625252525262525252526262526262525252526252626252625262626252626262526
252526262526262626262626262626262626262626262526262625262526262625262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262726262627262626262626262626272727272627272727272727272727272726
272727272727272727272727272727272727272728282828282828282829282829292929
2A2A2A2A2A2B2B2B2C2C2C2C2D2D2D2E2F2E303030313132313233353536363637373838
3938383939393A3A3A3A39393939393939393A3939373838373838383839393837373737
373736373735363536363536353434343434333433333333323232313131303030302F2F
2E2F2F2D2D2D2D2D2D2D2C2D2C2B2C2B2C2B2B2B2B2B2B2B2B2A2A2A2A2B2A2A2A2A2A2A
2A2929292929292828282928282828282827282827282728272727272727262727272727
272727272727272726272627262727262626272727272626262726272726272626262626
262626262727262626272626272626262626262626262626262626262626262626262626
262626262626262726262626262526262625252626262626262626262626262626262626
262626262626242426262626262625252625252626262626262626252626262626262626
2626252525262625
252625262525252525252526252525252626262625262526262525252525262626252625
252626262526262525262526262526262626262626252626262626262626262625262626
262626262626262626262626262626262626262626262625262626262726262626262626
262626262626262626262626262726272627262727272726272726262727272626272727
272727272727272727272727272727272727272727282828282828282828282928282928
29292A2A292A2A2B2A2B2B2B2B2C2D2C2D2D2E2F2F2F3030313132323333333435363535
373837373736373737373738373737373737363737363636373636363636353535353535
3435363534343433333333333332333232323232323131313230302F302F2F2F2F2E2D2D
2E2D2D2D2D2C2D2C2C2C2B2C2B2B2B2B2B2B2B2A2A2A2A2B2A2A2A292A29292929292A29
292929292829282829282828282828282728282828272827272727272727272727262627
272727272727272727272726262727262626262726262626262726262626262626272726
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626252626262626262626
262626262626242426262625262625262626262626262626262626262626262526262626
2525262625262525
252626252525252525262526262626262526252526262525252626262626252626252626
252625262526262625262525252626262526262626262626262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262726262626272626272726272726272727
272727272727272727272727272727272728272727272728282828282828282828282929
2829292929292A2A292A2A2B2B2B2B2C2C2C2D2D2E2E2E2F2E2F31303030323332333434
333435353535363535363536353637363636363636353635353535353434343434333434
3434333334343332323232313131323230303030302F2F302F2F2F2E2F2E2E2E2E2D2D2D
2D2C2C2C2C2C2C2C2C2B2B2B2B2B2B2A2A2A2A2A2A2A2A2A2A2929292929292929292829
292928282929282828282828272828282727272727272727272727272727272727272626
272727272726262626272727272627272626272727262626272726262626262626262726
262626262626262626272626262626262626262626262626262627262626262626262626
262626262626262626262626262526262626262526262626262626262626252626262626
262626262626242426262626262626252626262626262626262626262625252626262526
2625252525262526
252626252626252525252526252525262526262625262526252526252526262626252626
252626262626262626262526262525262626262626262625262526252626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262626272626262726262626262626272626272626272626262727262727272727262727
262727272727272627272727272727272827272727282728272828282827282828282828
282929282829292A292A2A2A2A2A2B2B2B2B2C2C2B2C2C2D2D2E2E2E2F302F3031313131
323232333334333334343334333334343334343334343433333333333433323233323232
32323232323130313130303030303030302F2F2F302F2E2E2F2E2E2E2E2D2D2D2D2D2D2C
2C2B2C2C2B2B2B2B2B2A2A2A2A2A2A2A2A2A29292A2A292A292929292929292928282828
282928282828282828272828282728272727272727272727272727272727262727272726
272626262726262727262726262626262627262627272727262626272626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262626262626262626262626262626262626262526262626262625262626262626
262626262626242426252526262626262626262626262626252626262526262626262526
2626262626262526
252525252526262525262525252525262526252626262626252626262526252625262526
252625262525262526262626252625262626262626262626262626262626262626262625
262626262626262526262626262626262626262626262626262626262626262626262626
26262627262F262626262626262626262627262626262726262627272627272626272727
272727272727272726262727272727272727262727272727272728282828282727282828
2828282928292929292A29292A292A2A2B2B2A2B2B2B2C2C2C2C2D2E2E2E2E2E2E2F2F30
303030303031313231323232323232323132313232323131313231313133313131313130
31313030303030302F2F2F2F2F2F2E2E2E2F2E2E2E2E2E2E2D2D2D2D2C2C2C2C2C2C2C2C
2C2B2B2B2B2B2B2A2A2A2A2A2A2A2A2A292A292929292929292928292828292828282828
282828282728282728272727282727272727272727272627272727272727272726272727
272627262726272726272627262626272726262627272726272626262626272626262626
262626272626262626262626262626262626262626262626262626262626262626262626
262626262626262625262626262626262626262526262626252626262626262626262626
262625262626242426262626262626262625262526262626262526262626262526262626
2625262526262626
252726252526252625262625252525262525252626262526252626262625252525262626
262626262526262526262626262625262626262526262526262626262625262526262626
262626262626252626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262627272726262627262626272727272727272627
272727262627272627272727262727272727272727282727282727272828282727282728
2828282828292928282929292929292A292A2A2B2B2B2A2B2C2B2C2C2D2D2C2D2E2D2E2E
2E2F2F2F2F302F3030303031303031313030313030303031302F30313030303030303030
2F2F302F2F2F302F2E2E2F2E2E2E2F2E2D2D2E2D2D2D2D2D2D2C2C2C2B2C2C2B2B2B2B2B
2B2B2B2A2A2A2A2A2A29292A29292A292929292929282929282828292828282828282828
282828282727282727282827272727272727272727272727272727272727272627272727
272726272727272727272727262626262627262626262626262627262626272626262627
262626272626262627262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262626262626262625262626262626262626
262625262625242526262526262626262526262626262625262626262526252626262626
2625262526252626
252626262525252525252526262525262525262525252625262526252625252625262626
262526252626262626262626262626262626252626262625262526262626262626262626
252626262626262626262626262626262626262626252626262626262626262626262626
262627262626262626262626262626262626262626262626272626272727262626262726
262627272727272727272727272727272727272727272727272727272727282828282828
28282828282828292929292929282929292A29292A2A2B2A2A2B2B2B2B2B2C2C2D2C2C2D
2D2E2D2D2E2E2D2E2E2F2E2E2F302F2F2F2F2F2F2F2F302F2F2F2F2E2F2F2F2E2E2F2E2E
2E2E2E2E2F2E2E2E2E2D2D2D2E2D2D2C2D2C2C2D2C2C2C2C2C2B2B2B2B2C2B2B2B2B2B2B
2B2A2A2A2A2A2A29292A2929292929282929292829292928282828282828282827282728
282828282827272827272727272727272727272727272726272727272727272627272727
272627262726262627262726262626262726272726262627262626272726272626262627
262626262626262626262626262626262626262626262626262626262626262626262526
262526262626262626262626262626262626262626262626262626262626262626252626
262625262625242426262626252625262626262526252526262625262526262625262526
2626262626252625
252626262626252525252525252625252525262625252625252625262626262526262525
262626262525262626262526252626262625252625262625262626262626262626262626
262626262525262526262626262626262626262526262626262626262626262626262626
262626262626262626262626262626272626262727262626272626262626262627262626
262727262726272727272727272727272626272727272727272727282728282728282727
2728282828282828282829282829292929292929292A292A2A2A2A2B2B2B2B2B2B2B2B2C
2C2D2C2C2C2D2D2D2D2D2D2D2E2D2D2D2E2E2E2E2F2E2E2E2E2E2E2D2D2E2E2E2D2E2F2E
2D2D2E2D2C2D2D2D2D2D2D2D2D2C2D2C2C2C2C2C2B2B2B2B2B2B2A2B2B2A2B2A2B2B2A2A
292A2A292929292929292929282828282828282928282828282728282827282728282728
272827272727272727272727272727272726272727272627272726272726272726262626
262626262626262627262626262726262626262626262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242425262626252626252526262626262626262626252526262626252526
2525252526262526
252526262526252525262525262526262626252625262525262625262526252625252626
262626262526252526262626262626262626262626262626262626262525262626262626
262626262626262526262526252626262626262625262626262626262626262626262626
262626262626262626262626262626262626262627272626262626272726262627272726
262627272627262627262726272727272627272726272727272727272727272827272827
2827272728282828282728282828292928292829292929292929292A2A2A2A2A2A2A2B2B
2B2B2B2B2B2C2C2C2C2D2C2C2C2C2D2C2D2D2D2D2D2C2D2E2D2D2D2C2C2C2D2D2D2C2C2C
2C2D2D2C2C2C2C2C2C2C2C2C2B2C2B2C2B2B2B2B2B2B2A2B2B2B2B2A2B292A2A2A292929
292929292929292928292928292828292828282828282828282827272728272827272827
272727282828272727272727272727272726272727262727272727272627272726272626
262627262726262726262626262727262626262627262626262727262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262526262626242425262626262625262626262526262626252626252625262526262625
2626252626262526
252525252526262525252525252626262625252626262526262525252526262625262526
252526252626252526262526262526262626252626262626252626262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262627262626262726262627262626262626
272626272626272727272727272727272726272727272727272727272727272727272727
272727272827282728282828282829282828292829292829292929292A2A2A2A292A2A2A
2B2B2A2B2B2B2B2B2B2C2B2B2C2B2B2B2B2C2C2C2C2C2D2C2C2B2C2C2C2C2C2C2C2B2C2C
2C2C2B2B2B2B2B2B2B2B2B2A2B2B2B2A2B2A2B2A2A2B2A2A2A2A2A2A2A2A2A2929292929
292929282829282828282828282828282828282728272828282727282728272728272727
272727272727272727272727272726262626272726262727272626272627272626272626
262626272726262626262627262626262626262627262626262626262626262626272626
262626262626262626262626262726262626262626262626262626262626262626262626
262626262626262626262625262626262626262626262626262626262626262626262626
262626252626242526262526262626252626262626262625262626262625262626262626
2626262626252626
252525252525262525252625252625262525252625262626262525262525252526252625
262526252526262626262626262625262626262626262625262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262726272726262726262727272727272727262727272727262727272727272727272727
2727272827282728272827282828282828282829282828292829292828292929292A292A
292A2A2A2A2A2B2B2A2B2A2B2A2B2A2B2B2A2B2A2B2B2B2B2B2B2C2B2B2C2B2B2A2B2B2A
2B2B2B2B2B2A2A2B2B2A2B2A2A2A2A2A2A2A292A2A292A2A2A29292A2929292829292829
292929292828282828282828282828282827272827272727272827282727272827272728
272727272727272727262727272726262727272727272727262727262726262727262726
262627262627262626262726262626262626262626262627262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252526
262626252526242426252626262526262626262626252626262526262626252626262626
2626262626252626
252625252525252526252525252525252526252525252526252525262625252626262625
252625262625262626252525252526262626262626252625262626262626262626262626
262626262626262626262626262625262626262626262626262626262526262626262626
262626262626262626262626262626262626262626272626262626262626262626262626
262626262727262726262627262727272727272727272727272727272727272727272727
272727272728272827272727272727282827282828282829282828292829292929292A29
29292A2A2A2A292A292A2A2A2A2A2A2A2A2A2A2A2A2B2B2A2B2A2A2A2A2A2A2A2A2A2A2A
2A2A2A2A2A2A2A2A292A2A2A2A2A2A2A292A2A2929292929292929292929292828282828
292828282828282828272828272727272728272727282727272727272727272727272727
272627272727272727272627262727272626262726272626272627272727262626262626
272626262626262626262626262627262626272626262626262626262626262626262626
262626262626262626262626262626262626272726262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626242426262526262526262626262626262525262625262626252626262525
2625262525262625
252525252525252626262525252526252525252626252526252625262525262526262525
252626262626252626252626252626262625262626252626252626262626262625262626
262626262625262626262526262625262625262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262627
262727272627262626262726272626272727262727272626262727272627272627272727
272727272727272727272727272827272728282827282828282828282828282929282929
2929292929292929292929292929292A2A29292929292A2A2A2A2A2A2A292A292A292A2A
2A2A2929292A2A2929292929292929292929292929292929292928282829282928282828
282828282828272728272728282827272727272727272727272727272727272727272727
272726262727272626272627272627262726262727272726272626262626262626262626
262626262627262627262626262726262626272626272626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626242426252625262626262626262526262625262626262526262625262526
2625262626262626
252626262525262525252625252525252626262525252625262626252525252625262626
262526252626262526262625252625262625262526262626262626262526262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262726262626262626262626262626262626262626262627262626
262626272727262627262627262627272627262727262727272727272626272727272726
272727272727272727272827272727272727272828272828282728282827282828282828
29292928292928292929292929292929292A292829292929292929292929292928292929
2929292A2929292929292929292928292829292828282829282828292828282828282828
282728282728272827272727272827272727272727272727272727272727272626272727
272626272727272727262626262727272627272626272627262626262627272626262626
262627262626262626262626262626262626262626262726262626262626262726262626
272626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262625262626262626262626262626262626262626262625
262626262626242426262626262625262626252625262526262626262625262526262626
2526252626262626
252625252526252525252526252526262625252526252526252525252525262626252525
262526262625262625262626262626262626262625262626262626262626252626262626
262626262525262626262526262626262525262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262627262626262626262626
262626262626272626272727272727262726272727272727272727262726272727272727
272627272727272727272727272727272728272727272827282827282728272828282828
292828282928282829292829292929292828282829282929282829282929292929282929
282828292928282929292828282828282828292828282828282828282828282828272828
282727272727272728272727272727272727272727272727272727272727272727272627
272726272627272726272627272627262626262626272626262626262626262626262626
262726262626262626262626272626262626262626262626262626262626262626262627
262626262626262626262626262626252626262626262626262626262626262626262626
262626262626252626262626262626262626262626252626262626262626262626262626
262626262626252426262626262626262626252525262626252626262625252625262626
2626252526262626
252525252526252525252625252525252625252625262525262625252526252626262526
262526262526252625262625252626252626252625262626252625262626252625262626
252626262626262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262627262626262626262626262626262627
262626262626272727262726262627272726262627272727262626272727272727272727
272727272627272727272727272727282727272827272827282728282728272727282828
282828282828282827282828282828282928282828282928282828282828282828282828
282928282828282828282828282828282828282828282828282827282827282827272827
272827272727272727272727272726272727272727272727272727272727272627262727
272727272726272727262727262726262626272727262627262626262726262626262626
272627272726262626262627262626262626262626262626262626262626262626262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626262625242425262526262526262626262626262626262625262625262525262626
2626252626262526
252625262525262525252625252525262625252626252525262625252626252525252626
252526262526252525262626252626262525262525262625252525262526262626262526
252625262626262626262626262626262626262626262625262626252626262626262626
262626262626262726262626262626262626262626262627262626272626262626262626
262626262626272626262627262727262626262626272726272626272727272627272627
272727272727272727272727272727272727272727272727272727272727282728272828
282728282828282828282828282828282827282828282728282828282828282728282828
282827282728282828282828272828282828282728282827272827282727272727272727
282727272727272727272727272727272727272727272727272726262726272627272627
262626262726262627262626262626262626262726272626262626262627262627262726
262626262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626262625262626262626262626262626262626262626262626252626262626262626
262626262526252426262526262625262625262626252626252626252626252626262526
2625262625262526
252626252525252625252525252626252625262526252626262626262525262525252525
252526252525262626252625252525252626262625252625252626252626262626262525
262626252525262626262526262626262625262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262727262627272626272627272726262726272627272627272627
272727272727262727272727272727272727272727272728272727282727272727272827
272727272727272728282827282828282828282828282828282828272827282828282828
282827272828282728282827282827282728272727282728272727272727272727282727
272727272727272727272727272726272727272726272627272727262726272726262626
262627272726272626262626262626262626262726272626262626262626262626262626
262626262626262626262726272626262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262626262626262626252625
262626262526252426262626252626252626262625262626252625262625262526262526
2526252625262626
252625262525252626262525252625252625252525252526262525252526252626262626
252626252626262525262526262625252526262626262626262625262626262625262626
262625252526262526262626262626262626262626262526262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262627262626262626262627272727272626272627262727262627262727272626
272626272726272727272727272727272727272727272727272727272727272728282727
272827282727272828282727282827282728282728272727282827272727282727282827
272727272827272727272727282727272727282727272627272727272827272727272727
272727272727272727272627262726272627272727272727272626262726272627272626
262727262627262727272627262626262626272626262626262626262626262626262726
262626262626262626262626262626262626262626262627262626262626262626262626
262626262526262626262626262626262626262626262626262625262626262626262626
262626262626262625262626262626262626262626262626262626262626262626252626
262626262626252426262626262626262526262626252526262626252525262626262526
2626252625262626
252625252525252525262526252626252526252625252625262525262525252625262525
262625252625262525262626262526252625252626262526262626262626262625262625
252626262525262626262626262626262626262626262626262626262526262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
262727262626262626262626262626262626272626262726262727272626272626272627
262626272727272727272727272727272727272727272727272727272727272727272727
272727282828272727272728282727272727282727272727282728272727272827272827
272728272727282727272727272727272727272727272727272727272727272727272727
272727272727272727262727262727262727272727262727272726262726272726262626
262828262626262626272727262627262626262626262627262626262726262626272626
262626262627262626262627262626272626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626252626262526262626262626262625262626
262626262626242426252626262625262626262625252626252626252625262526252625
2526262625262526
252626252526252525262625252625252526252626252526262526252525262625262526
262625252525252625262625262526262525262626262625252625262626252626262625
262626262526262626262626262526262626262625262626262626262626262626262626
262626262626262625262626262626262626262626262627262626262626272626262626
262626262626262726262626262626262727262626262626272626272727262627272726
272727262727262727272727272727272627272727272727272727272726272727272727
272727272727272727272727272727282827272727272727272727272727272827272728
272727272727272727272727272727272727272727272727272727272727272727272627
272727272726272727262726262627272727272726262726272627262726262726272627
262726272627262626262627262626262626262626262626272626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262526262626262626262626
262626262626262626262626262626262526262626262626262626252625262626252526
262626262526242525262626262625262626252626262625252526262626262626262526
2625252525262626
252525252525252626252525262525252525252526252526252625252526252625262526
262625252625262526262625262625252625262625252526252526252626262626262626
262626262626262625262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262626262627262726262627262626262626272627272626262726262627262626
262727272627262726272727262727272727262727272726272727272727272727272727
272727272727272727272727272727272827272727272727272727272727272727272727
272727272727272727272727272727262727272727272727272727272727262726262727
262727272727262727272727262727272727262626262727272627262627272726262626
262727262726262626262626262626262626262626262626262626272626262626262626
262626262626262626262626272626262626262626262626262626262626262626262626
262626262626262626262625262726262626262626262626262626262626262626262626
262526262626262626262626262626262626262626262626262626262626262625262626
262626262626242425262626262626252626262625262626252626262526262525252625
2626262526252625
252525252525262525252526252625252625252626262625252625252525262525252526
262626252526262626252525262625252626252626252525262626262526252526262626
262625252625252625262526262626262626262526262626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262627262627262626262726262726272726272726272627272627272726
272626262727272727262727272727272727262626272627262727272727272727272727
272727272727272727272727272727272727272727272727272727272727272727272727
272727272727272727272727272727272727272627272727272726262627272727272727
272727262727262626262727262727272626262727262726262626272627262626272626
272626262726262626262727262726272727262626272626262626262626262626262627
262626262626262627262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626252626262626262626262626262626262626262626
262626252626242525262625252626262625262526262626262625262626262625262526
2626262525262625
252625252526252525262526252525252526252525252525262526262625252526262525
252525252526252626252526262525252525262525262625252625262625262625262626
262625252626252626262626262626262626252626262626262626252626262626262526
252626262626262626262626262626262626262626262626262726262626262626262626
262626262626262626262626262626262627262626262626272626262726262727262726
262727262627272727272727272727262727272727272627262727272727272727262727
272727272727272727272627272727272727272727272727272726272727272727272727
272727272727272727272727272626272727272727262727272727262627272727272727
272627272727272727262627272626262726262626272727272726262726262726262627
262626262626262627262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
262626262726262626262626262626262626262626262626262626262626262626252626
262626262626252626262626262526262626262626262626252626262626262625262626
262626262526242426252626262626262625262626262526262525262525262626262526
2526262626262526
252625252526262525252525252625262525262626262525262525252525252525252625
262525262525252626262625262525262626252525262626262526252626262626262526
252626262626262625262626252526252626262626262625252626262626262625252625
262626262626262626262626262626262626262626262626262626262726262626262626
262626262626262626262626262627262626262626262726272626262626262726262626
262726272626272626262726262627272626272727272727262727272726272727272727
272727272726262727272727272727272727272727272727272727272727272727272727
272627272726272727272727272627272627272626262726272627272726272727272727
272727272727272627262727272727272626272727262626262626262626262627272627
262627262526262626262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262625262626262626262525262626262626252626
262626252626242425262626252626262526262526252526252626262626252626252625
2625252625262625
252625252525252525252525262526262526252525262625252625262526262625262526
252526262625252626262526252626252626252626262626262626252526262626252625
262626262526262526262626262625262626262526262626262626262626262626262526
262626262526262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262726262627262626262726
272627272627262626272627272727262727272726262727262727272727272727272727
272727272727272727272727272727272627272727272727272727272727272727272626
262627272727272727272726272727272727262727262727262726272627272727272727
262627272627272726262726262626262727262626262626272626262627262626272626
262726262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262625262626262626262626262626262626262626
262626262526262626262626262626262626262626262626262626262626262626252626
262626262526242426252526252626262626262625262626262626252526252626262626
2625252525262526
252625252525252626252525262525252526252525252525252626252526252626252625
262625252526262625252626262626252626262526262526262626262526262626252526
252626252526252626262625262626262626262625262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262727262626272626262626262726
262726272627262626272626262727262726272727262627262627272727272627272727
262627272627272727272727272727272727262727272727272727272726272627272727
272727272727272727272726272627262727262626262727262727272727262726272626
262627272627272627262726262627262626262726272626262626262626262626262626
272626262626272627272626262626262626262626262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262726262626262626
262626262626262626262625262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262625262626262626262626262626252626
252626252626242526262626262626252626262626262626262625262626252626262626
2625262625262626
252626252526262525252525252525252525252525252626252625252525252626252626
262525262526262525252525262625262626262626262626262625252625262526262525
262626262626262626252625262626252626262526262526262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262726262626272626272626262626
272626262627262627262626262726262727272727262627262927272727272726272626
272627262627262727272627272626272726272726262727272726272727262627272726
272726262726272626272727272726262626272727272726262626272626262626272627
262627262627262727262626262627262626262726262626262626262626262626262626
262626262726262626262626262626262626262626262626262626262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626262626262626262625252626262626252626262626262626262626262626262626
252625252626242425252625262526262626262625262625262626262526262626262526
2525252625252526
252625262526262526252525252525262525252526262526252525252626252625262525
252626252526262626262526252526262626252626262626262626262626252626262526
262626262625262626262626252626262626252626252626262626262626262626262626
262626262626262626262626262626252626262626262626262526262626262626262626
262626262627262626262626262626262626262626272626262626262727262626262726
262626272626262727262726272626262726262626262627262E27272627262626262726
272626262626272626262726272726272727272727272626262727272727262726272627
272727272627262626272626262626262726272626262627262626262626262626272727
262726262626262626262626262626262626272626262626262626272626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262626262625262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626252626262625262626262626262626252526262625262625262626262526262626
252626262525242526262625252626262625252525262625252526262626262626262625
2525262625262526
252625252525252525262525252525262625252525252526252525252625252625262526
252626262525252525262625262626262626262526252626252626262625262526262626
262625252626262626252626262625262525262626262626262625252526262626262625
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627272626272727272626262626272727262726262726262627
272627272726262626272627262727272727262727262626262627262726262726272627
272727262626262727272726262727272726262726272627272626262726262626262626
272626262727272626272626262726262626262726272626262726262626272727262627
262626262626262626262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262626262526262626262626262626262626
262626262626272626262626262626262626252626262626262626262626262626262626
262626262626262626262625262626262626262525262625252626262626262626262625
252526252625242426262526262626252626252625252526252525262626252525262625
2626252626262626
252625252525252525262625252625262626252525252525262525252525252626252526
252525252526252625262526252525262526262525262626262626252625252626252625
252626252626262626262626262526262626252626262626262526262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262726262626262626262626262626
262627262626262626272626262627262726272627262627262727272626272726272626
272726262627262726262627262626262626262726262727272726272626272627272627
272726272727272626262726262626272627262626272726262726262626262726262626
262626262627262726262626262626262726262726262727262626262726262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262727262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
262626262626262626262626262625262626252626262626262626262626262626262526
262626262626242426262526262626262626262626262526262626262525262626252626
2526252525252625
252625252526252525252525252526252525252525252526262526252625252525252626
252525252626252625252626252626252625252625252525262626262625262626262625
262626262625262626262625262526262626262526262626252626262626262626262626
262526262626262626262626262626262626262626262626262626262625262626262626
262626262626262626272626262726262626262626262726262626262626272626272726
272626262626262626262626262626262726262626262626262626272626272626272726
262627262627262726262726262726262627272627262726272626272626272726262626
262726262627272726272726262627262626272626272626262626262626262726262627
262727262627262726262627262626262626262626262626262626262626262626262627
262626262626272626262626262626262626262626262626262626272627262626262626
262626262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262625262626262626262525262626262626262626262626262626262626262526262526
262626262626252526262525262626262525262626262626252625262625262525252626
2525262626252626
252525252525252525252525252525252625262525262525252525262525252525262525
252625252526252526252625252525262525252626262626252626252525252626252526
252625252526252625262526262626262526262526262625262626262626252526262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262626
262626262726262627272626262626262626262626272626262627262627262626262627
272626262626262626262626272727262626272727262626262726262726272726262726
272627262726262627262726262727262626262726262626262627262626262627262626
262627262626262626262626262627262626262627262626262627272627262626262627
262626272626262626262626262626262626262626262626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626252626262626262626262626262626262626262526262626262626
262626252526262625262626262625262625262626262526262625262626262526262626
252626252626242425262625252525262526252525262525262526262525262625262625
2526252625262625
252625252525252525252525262526252525252526262525252525252525252626252625
252626262625252625262526252525252526252626262625262626252526262626262526
262625262626252626262626252626262626262626262626262626252526262626262626
262626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626262627262626262626262626262626262726262626272626262626
272626262626262626262626262727262626262626262626272627272626262626262726
262726262626262727272626262626262727262726262626262626262626262627262726
262627262626272626262626262626262626262626262626272626262626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626262626252626262626252626262626262625262526252626262625252626262626
252626252526242426262625262625262626262525262625252625262626252526262625
2526252625262526
252626252526252526252525262525252525252625262625252525252626252625252526
252526262525252626252526252626252525252626262626252626262625262625252525
262625252626262526262526262626262625262626262526252626262625262526262626
262626262626262626252626262626262526262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262626262626262626272626272626272626262627262626262626262626262726
262626262626262626262726262626272626262626262727272626272626262626262626
262626262626262727262627262727262626262626262726262627262626262626262626
262626262626262627262626262626262626262627262626262627262626262626262626
262626262626262626262626262626262626262626262626262726262626262627262626
262626262625262626262626262626262627262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262526262626262626262626
262626262526262626262526262626252626262626262626262626252626252626262625
262626262626242426252626262626262525262625252526262626262626252626252626
2525252525262625
252525252526252525252525252525252526252525262525252525252525252525252625
252625252526252626252526262525262626252625262626262626252526262626262626
252625262626252626262626262525252625262626262626262626262526262626262626
262625262526262626262625262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262626262626262627262626
262626262627272626262726262626262626262626262627262626272626262626262626
262726272626262626272626262626262627262626272627262626262626262726262626
262726272626262626272726262626262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262526262626
262626262626262626262626262625262626262625262626262526262626262526262626
262626262626252526252626262526262525262626262526262525262626262626252526
2626252625252525
252625252525252525252525262525252626252525252525252526252626252625262526
262525252525252525252525252625252626252625262526252525252626262525262625
262626262525252626262625262526262625262626262526262626262626252626262626
262626262626252626262626262626262626262626262626262626252626262625262626
262626262626262626262626262626262626262626262626262626272626262626272626
262626262626262626272626262726262626262726262626262626262626262626262626
262627262727262626262726262626262626262626262626262626262626262626272726
262626262626262626262626262627262626262626262626262626262626262726262726
262626262626262626262626272626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626252626252626262626262626262626
262626262626262626262626262626262626262626262626262526262526262625262625
262525262626242426252526262626262626262625262626252526262626262525262625
2625252526262626
252625252525252525252625252525252525252525252625252525252525252626252525
262525262625252625252626252525252625262626262525262626262625262526262626
252626262526252526262625262626262626262626252626252626262625252626262626
262625262626262526262626262829262626262625262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262626262627272626262626262626262626262626272627262627262626262626262726
262626272627262626262726262626262626262626272626262726262626262726262626
262626262726262626262626262626262626262626262626262726262626262626262626
262626272626262626272626262626262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262626262626
262625262626262626262626262626262626262626262626262625262626262626262626
252525262626262526262626262626252626262626262625262625262626262626252625
262626262626242426262526262625262526252526262625262625262626252526262525
2625262625252626
252625252526262525252525252526262525252525262626262525262525252526252625
252625262525252526252625252526262625262625262626252625262525262626262625
252626262526262526252625252526262626262625262626262626262626262626262626
262626262626262626262626262627262626262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262626272626262626262626
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262726262626262626262626272626262626262626262626272627262626
272626262626272626262626262626262626262627262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262626252626
262626262626262626262626262626262626262626262625262626252626262626262525
252626252626242425262526262625262625252626252626262626262626252626252625
2626252525262625
252525252525252525262525252525252625252525252525262525252525252525262526
252626252625262526262526252525252526262526262625262625262525262625262626
252625262625252526262526262626252626262626262526262626262626262626262625
262626262626262626262625262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262627262626262626262627262626262626262626262626
262626262626262626262626262627262626262626262627262626262626272626262626
272626262727262626262726262626262626262627262626262626272626262626262626
262626272626262626262626272626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262625262526262625262625
262526252526242425252626262626262526262625262626262526252626252626252626
2526252526252526
252525252525252525252525252625252525252525252525252526252525252526262526
252625262525262525252525262525252526262526262626262525262525262525262526
262626252525252626262626262626262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262727262626262626262626262626262626262626262626262626262626
262626262626272626262626262727262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262626262626262626262526262625
262626252625262626262626262626262626262526262626262625262626262626262626
262626262526252626262626262626252626262526262626262626262626262625262626
262626252526242425262526262526262526262625262625252526252526262526262625
2526252626252526
252526252526252525262526252526252525252625252525252526252525252625252526
252525252526252525252625262625262626252526252525252626252526262625262626
252525252626262626262625262526262626262626262625262526262626262626262625
262626262626262626262625262626262626262626262525262626262526252626262626
262626262625262626262626262626262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262627262627262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626272726262626272726262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626252626262626262626262526262626
262626262626262626262626262626262526262626262626262626262626262626262626
262526262526262626262625262626262626262626262625252625262626252625262626
262626252625242426262626252525262626252626262526252625252625262525262726
2525252526262625
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=Z@D09BDU0`0V9RH01P0U9BD09RHV02HV9P0V
9RH09BDU02HV9P<09BDU0`0V9RH00`0U9BD09RHV02HV9P0302HV9P0302DU9@0V9RH09BDU00D09RHV
00D09BDU02HV9P0V9RH09RHV02DU9@0J02HV9P0502LW9`0V9RH09RHV02HV9P0W9bL0200V9RH00`0W
9bL09RHV02HV9P0J02HV9P0302DU9@0V9RH09BDU00@09RHV00<09BDU02HV9P0V9RH00`0U9BD00`0V
9RH09BDU02DU9@0402HV9P<09BDU00<09RHV02DU9@0V9RH00P0U9BD00`0V9RH09BDU0=7=Z@030=7=
Z@000`3AcJT402DU9@<09RHV0`0U9BD00`0V9RH09BDU02DU9@0402DU9Ah09RHV00<09bLW02HV9P0V
9RH0100V9RH00`0W9bL09RHV02HV9P0302HV9P0302LW9`0V9RH09RHV00@09RHV00<09bLW02HV9P0W
9bL00P0V9RH202LW9`@09RHV0P0W9bL00`0V9RH09bLW02HV9P0N02HV9P809BDU00<09RHV02DU9@0U
9BD00`0V9RH01P0U9BD09RHV02HV9P0U9BD09RHV02DU9@<09RHV00<09BDU02HV9P0U9BD0100U9BD4
0=7=Z@000`3AcJT00`0V9RH09BDU02DU9@0202HV9P<09BDU0`0V9RH01@0U9BD09RHV02HV9P0V9RH0
9BDU00<09RHV00<09BDU02HV9P0U9BD00P0V9RH00`0U9BD09RHV02HV9P0M02HV9P809bLW0P0V9RH0
0`0W9bL09RHV02LW9`0402HV9P809bLW00<09RHV02LW9`0V9RH01@0V9RH202LW9`P09RHV00<09bLW
02HV9P0V9RH00`0V9RH00`0W9bL09RHV02HV9P0<02HV9P0302DU9@0V9RH09RHV00D09RHV00<09BDU
02HV9P0V9RH00P0U9BD302HV9PD09BDU00<09RHV02DU9@0U9BD00P0U9BD00`0V9RH09BDU02DU9@04
0=7=Z@000`3AcJT202DU9@809RHV00<09BDU02HV9P0U9BD0100V9RH202DU9@@09RHV0P0U9BD00`0V
9RH09BDU02HV9P0?02HV9P0302`/;00V9RH09RHV00D09RHV00D09bLW02HV9P0W9bL09RHV02LW9`03
02HV9P0402LW9`0V9RH09RHV02LW9`<09RHV00<09bLW02HV9P0W9bL00P0W9bL00`0V9RH09bLW02LW
9`0402LW9`809RHV100W9bL0100V9RH09bLW02HV9P0V9RH402LW9`0302HV9P0W9bL09RHV01809RHV
00<09BDU02HV9P0V9RH00P0V9RH00`0U9BD09RHV02HV9P0302HV9P809BDU0P0V9RH01@0U9BD09RHV
02HV9P0V9RH09BDU00809RHV00<09BDU02HV9P0V9RH00`0U9BD202HV9P@0dLfY00030=7=Z@@09BDU
00D09RHV02DU9@0U9BD09RHV02DU9@0402HV9P809BDU1P0V9RH00`0U9BD09RHV02DU9@0A02HV9P03
02LW9`0V9RH09RHV00D09RHV100W9bL0100V9RH09bLW02LW9`0W9bL202HV9P0302LW9`0V9RH09RHV
01009bLW00<09RHV02LW9`0W9bL01@0W9bL00`0V9RH09bLW02LW9`0J02HV9P0302DU9@0V9RH09BDU
00809RHV00<09BDU02HV9P0V9RH0100V9RH00`0U9BD09RHV02HV9P0702DU9@@0dLfY00030=7=Z@80
9RHV0P0U9BD302HV9P0302DU9@0V9RH09RHV00<09RHV00<09BDU02HV9P0V9RH07@0V9RH202LW9`80
9RHV00<09bLW02HV9P0W9bL00`0W9bL202HV9Q809bLW00<0:2PX02LW9`0W9bL02P0W9bL202HV9P80
9bLW00<09RHV02LW9`0V9RH0600V9RH0100U9BD09RHV02HV9P0V9RH302DU9@0302HV9P0U9BD09RHV
00809RHV00<09BDU02HV9P0U9BD00P0U9BD00`0V9RH0dLfY0=7=Z@020=7=Z@000`3AcJT0100V9RH0
9BDU02DU9@0V9RH202DU9@809RHV0P0U9BD402HV9P0302DU9@0V9RH09RHV00@09RHV00<09BDU02HV
9P0V9RH0200V9RH00`0U9BD09RHV02HV9P0>02HV9Ph09bLW0P0X:2P402LW9`0402PX:00W9bL09bLW
02PX:0809bLW1@0X:2P402LW9`0502PX:00W9bL09bLW02LW9`0V9RH00`0W9bLK02HV9P0302DU9@0V
9RH09RHV00<09RHV0P0U9BD01P0V9RH09BDU02DU9@0V9RH09BDU02HV9P@09BDU103AcJT000<0dLfY
0P0U9BD602HV9P0302DU9@0V9RH09BDU00D09RHV00<09BDU02HV9P0V9RH04@0V9RH00`0W9bL09RHV
02LW9`0202HV9P0302LW9`0V9RH09RHV00l09bLW200X:2P0200W9bL0:2PX02PX:00Y:BT0:2PX02TY
:@0X:2P0:BTY1`0X:2P902LW9`809RHV0`0W9bL902HV9P0302DU9@0V9RH09RHV00d09RHV00<09BDU
02HV9P0V9RH00P0V9RH0100U9BD09RHV02HV9P0U9BD402HV9P809BDU00<09RHV0=7=Z@3AcJT00P3A
cJT000<0dLfY0P0V9RH0100U9BD09RHV02HV9P0V9RH202DU9@809RHV00<09BDU02HV9P0V9RH0300V
9RH00`0W9bL09RHV02HV9P0502HV9P0402LW9`0V9RH09RHV02HV9P809bLW00<09RHV02LW9`0V9RH0
2@0W9bL;02PX:0H0:BTY00<0:RXZ02TY:@0Y:BT00`0Y:BT0100Z:RX0:BTY02TY:@0Y:BT202PX:003
02TY:@0X:2P0:2PX0080:2PX00<09bLW02PX:00W9bL01`0W9bL00`0V9RH09bLW02HV9P0D02HV9P03
02DU9@0V9RH09RHV00@09RHV00L09BDU02HV9P0V9RH09BDU02HV9P0U9BD09RHV00809BDU00<09RHV
02DU9@0U9BD0103AcJT000<0dLfY0P0U9BD00`0V9RH09BDU02HV9P0202DU9@809RHV0P0U9BDE02HV
9P809bLW100V9RH00`0W9bL09RHV02LW9`0202LW9`0502HV9P0W9bL09bLW02PX:00W9bL00P0X:2P3
02LW9`@0:2PX100Y:BT302XZ:PD0:b/[1@0/;2`302/[:`80:RXZ00<0:BTY02XZ:P0Y:BT00`0Y:BT4
02PX:0L09bLW00<09RHV02LW9`0V9RH00`0V9RH00`0W9bL09RHV02HV9P0902HV9P0302DU9@0V9RH0
9RHV00@09RHV00<09BDU02HV9P0V9RH0100V9RH01@0U9BD09RHV02HV9P0V9RH09BDU00809RHV0P0U
9BD40=7=Z@000`3AcJT00`0U9BD09RHV02DU9@0302DU9@809RHV00<09BDU02HV9P0V9RH03`0V9RH0
0`0W9bL09RHV02HV9P0202HV9P809bLW00<09RHV02LW9`0V9RH00`0W9bL00`0V9RH09bLW02LW9`03
02LW9`0402PX:00W9bL0:2PX02LW9`<0:2PX0P0Y:BT302XZ:P0702/[:`0Z:RX0:b/[02`/;00];Bd0
;2`/02d];@0202h^;P0302l_;`0`<300<30`0080<30`00<0;bl_030`<00`<3000P0_;bl00`0];Bd0
;Rh^02d];@0202`/;00402/[:`0Z:RX0:RXZ02XZ:P80:BTY0`0X:2P00`0W9bL0:2PX02LW9`0802LW
9`<09RHV00<09bLW02HV9P0V9RH03`0V9RH00`0U9BD09RHV02HV9P0302HV9P809BDU00<09RHV02DU
9@0U9BD00`0V9RH00`0U9BD0dLfY0=7=Z@020=7=Z@000`3AcJT00`0U9BD09RHV02HV9P0D02HV9P03
02DU9@0V9RH09RHV00809RHV00<09bLW02HV9P0W9bL00P0V9RH202LW9`0302HV9P0W9bL09bLW00H0
9bLW1P0X:2P202TY:@0402XZ:P0[:b/0:RXZ02/[:`<0;2`/0P0^;Rh01`0_;bl0<30`030`<00a<C40
<S8b03<c<`0b<S800P0d=3@203De=@<0=3@d00@0<c<c038b<P0b<S80<C4a0P0_;bl0100];Bd0;2`/
02d];@0[:b/202XZ:P0302TY:@0X:2P0:BTY00<0:2PX0P0W9bL0200X:2P09bLW02LW9`0W9bL09RHV
02LW9`0V9RH09bLW6@0V9RH0100U9BD09RHV02DU9@0V9RH202DU9@0302HV9P0U9BD09RHV00@0dLfY
00030=7=Z@0302DU9@0V9RH09RHV00D09RHV00<09BDU02HV9P0V9RH03`0V9RH0100W9bL09RHV02HV
9P0V9RH>02LW9`@0:2PX00<0:BTY02XZ:P0Z:RX00P0[:b/202d];@80;bl_0P0`<3000`0a<C40<c<c
03<c<`0203Hf=P80>CTi00D0>c/k03dm?@0m?Cd0?Cdm03/k>`0303dm?@0303`l?00j>SX0>c/k0080
>CTi00D0=SHf03De=@0c<c<0<C4a030`<00202h^;P0402`/;00[:b/0:b/[02XZ:P80:BTY100X:2P7
02LW9`0302HV9P0W9bL09bLW00T09RHV00@09BDU02HV9P0V9RH09BDU2@0V9RH00`0U9BD09RHV02DU
9@0202DU9@<09RHV00<09BDU0=7=Z@3AcJT00P3AcJT000<0dLfY0P0U9BD00`0V9RH09BDU02DU9@03
02HV9P0302DU9@0V9RH09RHV00`09RHV00<09bLW02HV9P0V9RH00`0V9RH502LW9`0502HV9P0W9bL0
9bLW02PX:00W9bL0100X:2P402TY:@0A02XZ:P0[:b/0;2`/02`/;00^;Rh0;bl_030`<00a<C40<c<c
03De=@0g=cL0>3Ph03`l?00o?cl0@41004A4A019BDT00P1=CDd06@1ADE40E5AD05MGE`1FEUH0FEUI
05QHF01GEeL0De=C051@D01<C4`0Bd];04M7A`14A4@0@41003hn?P0l?3`0>CTi03Hf=P0e=CD0<S8b
030`<00^;Rh0;Bd]02`/;00[:b/00P0Z:RX202TY:@80:2PX1P0W9bL01@0V9RH09bLW02LW9`0V9RH0
9bLW01<09RHV00<09BDU02HV9P0V9RH00P0V9RH202DU9@0302HV9P0U9BD09RHV00@0dLfY00030=7=
Z@T09RHV00@09BDU02HV9P0V9RH09BDU1`0V9RH00`0W9bL09RHV02HV9P0202LW9`@09RHV00<09bLW
02HV9P0W9bL01P0W9bL302PX:080:BTY0P0Z:RX202/[:`0902`/;00];Bd0;bl_02l_;`0b<S80<c<c
03Ph>00k>c/0?Shn0080@D510180A4A404E5A@19BDT0BDU904e=C@1<C4`0Cdm?055AD@1EEED0EeMG
05QHF01KFe/0GemO061PH01WIfL0J6QX06][J`1/K6`206UYJ@0?06EUI@1NGUh0De=C04Y:BP16ATH0
@D5103hn?P0k>c/0>3Ph03De=@0b<S80<C4a02h^;P0];Bd0:b/[0080:RXZ0P0Y:BT302PX:0D09bLW
00<09RHV02LW9`0V9RH05`0V9RH00`0U9BD09RHV02DU9@0302HV9P@0dLfY00030=7=Z@809BDU1`0V
9RH00`0U9BD09RHV02HV9P0B02HV9PH09bLW1@0X:2P0500Y:BT0:RXZ02XZ:P0[:b/0;2`/02d];@0^
;Rh0;bl_038b<P0c<c<0>3Ph03/k>`10@400@D5104=3@`15ADD0ATI604Q8B019BDT0Bd];0P1=CDd0
1`1?Cdl0DE5A05=CD`1FEUH0FEUI05YJFP1LG5`00P1OGel01@1TI6@0JFUY06YZJP1`L700KVi^0080
LG5a0100L71`06e]K@1XJ6P0GUiN055AD@1:BTX0A4A403lo?`0k>c/0>CTi03Hf=P0c<c<0<C4a02h^
;P0/;2`0:b/[0P0Z:RX0100Y:BT0:2PX02LW9`0X:2P402LW9`@09RHV00<09bLW02HV9P0V9RH01`0V
9RH00`0U9BD09RHV02HV9P0602HV9P0302DU9@0V9RH09RHV00809RHV00@09BDU02HV9P0U9BD09BDU
103AcJT000<0dLfY0`0V9RH00`0U9BD09RHV02HV9P0?02HV9P0302LW9`0V9RH09RHV00@09bLW00<0
9RHV02LW9`0W9bL00P0W9bL00`0X:2P09bLW02PX:00302PX:00402TY:@0Z:RX0:RXZ02`/;080;Bd]
00/0;Rh^034a<@0b<S80=SHf03Ti>@0k>c/0?Cdm0492@P16ATH0B4Q804U9B@0204];B`0704i>CP1@
D500D51@059BDP1DE5@0De=C05EEE@0205QHF00N05YJFP1MGEd0H61P061PH01SHf<0IVIV06MWI`1Z
JVX0Kfm_071`L01bLW80M7Ad079bLP1eMGD0Lg=c075aL@1_Kfl0KFe]06=SH`1EEED0Bd];04I6AP10
@400?3`l03Ph>00e=CD0<C4a02h^;P0];Bd0;2`/0P0Z:RX01@0Y:BT0:2PX02PX:00W9bL0:2PX00@0
9bLW00<09RHV02LW9`0V9RH03P0V9RH00`0U9BD09RHV02HV9P0202DU9@809RHV00D09BDU02HV9P0V
9RH09RHV02DU9@040=7=Z@000`3AcJT302HV9P0502DU9@0V9RH09RHV02HV9P0U9BD04`0V9RH402LW
9`0302PX:00W9bL09bLW00<0:2PX0180:BTY02XZ:P0Z:RX0:b/[02d];@0^;Rh0;bl_038b<P0e=CD0
>3Ph03Xj>P0m?Cd0?Shn0451@@14A4@0BDU904a<C01>CTh2051@D006055AD@1EEED0EEEE05EEE@1F
EUH0F5QH0P1GEeL03`1HF5P0Fe]K05aLG01MGEd0GUiN061PH01RHV80Hf=S06MWI`1ZJVX0KFe]06i^
KP1cLg<0MGEe07IfMP0207QhN00C07AdM01fMWH0MgMg07=cL`1bLW80Jf][06ATI01EEED0B4Q80492
@P0m?Cd0>CTi03@d=00b<S80;bl_02d];@0[:b/0:RXZ02TY:@0402PX:0@09bLW500V9RH00`0U9BD0
9RHV02HV9P0302HV9P0302DU9@0V9RH0dLfY00<0dLfY00030=7=Z@809BDU500V9RH00`0W9bL09RHV
02LW9`0802LW9`80:2PX01@0:BTY02XZ:P0[:b/0;2`/02d];@0^;Rh0<30`03<c<`0e=CD0>3Ph03`l
?00n?Sh0@41004=3@`16ATH0B4Q804];B`1>CTh0D51@05=CD`80E5AD00l0EeMG05UIF@1GEeL0F5QH
05YJFP1KFe/0G5aL05eMG@1LG5`0GEeM05YJFP1KFe/0GEeM05mOG`1PH6000P1UIFD01@1VIVH0J6QX
06][J`1]KFd0L71`0080MWIf00H0NGUi07QhN01iNGT0Ng]k07QhN01iNGT207EeM@0=075aL@1[Jf/0
GemO04m?C`14A4@0?clo03Xj>P0f=SH0<C4a02h^;P0/;2`0:b/[02TY:@0302PX:0H09bLW00<09RHV
02LW9`0V9RH02`0V9RH01@0W9bL09BDU02HV9P0V9RH09BDU00<09RHV0P0U9BD00`0V9RH09BDU0=7=
Z@030=7=Z@000`3AcJT00`0V9RH09BDU02HV9P0202HV9P0302DU9@0V9RH09RHV00@09RHV00<09bLW
02HV9P0W9bL0100V9RH00`0W9bL09RHV02HV9P0202HV9P@09bLW00<0:2PX02LW9`0X:2P00P0X:2P0
600Y:BT0:RXZ02XZ:P0[:b/0;2`/02h^;P0`<300<c<c03De=@0i>CT0?3`l03lo?`11@D40ADE504I6
AP1:BTX0CTi>051@D01CDe<0EEEE05IFEP1GEeL0FEUI05YJFP80G5aL00L0GUiN05mOG`1NGUh0GemO
061PH01OGel0HF5Q0080GEeM0180GUiN05eMG@1NGUh0GemO065QH@1PH600Hf=S06EUI@1WIfL0JFUY
06m_K`1aLG40Lg=c07EeM@1iNGT0O7al07QhN01lO7`207]kN`0?07UiN@1gMgL0MGEe07AdM01`L700
I6AT04i>CP17AdL0?clo03Ti>@0e=CD0<C4a02h^;P0/;2`0:RXZ0080:BTY0P0X:2P502LW9``09RHV
00L09BDU02HV9P0V9RH09RHV02DU9@0V9RH09BDU00@09RHV00<09BDU02HV9P3AcJT00`3AcJT000<0
dLfY3P0V9RH00`0W9bL09RHV02HV9P0402HV9P0302LW9`0V9RH09bLW00@09bLW00<0:2PX02LW9`0X
:2P00P0Y:BT04`0Z:RX0:b/[02`/;00];Bd0;Rh^034a<@0d=3@0=SHf03Xj>P0l?3`0?clo04=3@`17
AdL0B4Q804];B`1@D500DU9B05ADE01HF5P00P1JFUX205]KF`0B05mOG`1PH600HF5Q069RHP1SHf<0
HF5Q061PH01SHf<0H61P065QH@1OGel0H61P05eMG@1OGel0H61P05mOG`1QHF40HV9R0P1TI6@206MW
I`0806YZJP1/K6`0Kfm_075aL@1cLg<0N7Qh07]kN`1iNGT307YjNP80NGUi0P1gMgL02`1eMGD0Jf][
05eMG@1>CTh0@D5103`l?00g=cL0<S8b02d];@0/;2`0:b/[0080:BTY0P0X:2P602LW9a009RHV0P0U
9BD502HV9P@0dLfY00030=7=Z@0302DU9@0V9RH09RHV01009RHV0`0W9bL00`0V9RH09bLW02LW9`03
02LW9`<0:2PX0180:BTY02XZ:P0[:b/0;Bd]02h^;P0a<C40=3@d03Hf=P0i>CT0?3`l03lo?`14A4@0
ADE504Y:BP1<C4`0D51@05ADE01FEUH205YJFP0305aLG01PH600HV9R00<0Hf=S0P1VIVH00`1WIfL0
JFUY06IVIP0206MWI`80IFEU00@0I6AT069RHP1SHf<0Hf=S0`1PH6002P1RHV80Hf=S061PH01SHf<0
IFEU06QXJ01ZJVX0Jf][06e]K@1_Kfl207=cL`80MgMg00@0N7Qh07]kN`1jNWX0Ng]k0P1jNWX03P1k
Ng/0MgMg07AdM01^KVh0F5QH04Q8B011@D40>CTi03@d=00_;bl0;Bd]02/[:`0Z:RX0:BTY0`0X:2P3
02LW9`0302HV9P0W9bL09bLW01809RHV0P0U9BD00`0V9RH0dLfY0=7=Z@020=7=Z@000`3AcJTB02HV
9P809bLW00<09RHV02LW9`0W9bL00`0W9bL302PX:080:BTY0180:RXZ02`/;00^;Rh0<30`038b<P0f
=SH0>c/k03dm?@10@400@D5104E5A@19BDT0C4a<04i>CP1ADE40EEEE05QHF01KFe/2061PH00706=S
H`1WIfL0IfMW06MWI`1XJ6P0JVYZ06][J`0206YZJP0406][J`1/K6`0K6a/06e]K@80Jf][00<0JFUY
06QXJ01VIVH00P1VIVH00`1RHV80Hf=S06=SH`0206=SH`0M069RHP1SHf<0IVIV06MWI`1XJ6P0JVYZ
06a/K01^KVh0L71`07=cL`1dM7@0MGEe07IfMP1hN7P0NWYj07alO01jNWX0Ng]k07YjNP1kNg/0MWIf
075aL@1WIfL0EUIF04E5A@0l?3`0=SHf038b<P0^;Rh00P0[:b/0100Y:BT0:2PX02PX:00X:2P502LW
9aD09RHV103AcJT000<0dLfY4P0V9RH702LW9`0302PX:00W9bL0:2PX0080:BTY01L0:b/[02d];@0_
;bl0<C4a03@d=00i>CT0?Cdm0451@@15ADD0AdM704U9B@1<C4`0CTi>059BDP1EEED0F5QH05YJFP1L
G5`0H61P06=SH`1WIfL0JFUY06][J`0206a/K00406e]K@1^KVh0LW9b06m_K`80L71`00@0LG5a071`
L01cLg<0LW9b0P1`L70206a/K00306YZJP1XJ6P0IVIV0080I6AT00H0IVIV06EUI@1SHf<0I6AT06IV
IP1WIfL206IVIP80J6QX00@0JFUY06i^KP1_Kfl0Lg=c0P1gMgL04`1hN7P0NWYj07YjNP1mOGd0Ng]k
07emO@1kNg/0NGUi07AdM01`L700HV9R04a<C00o?cl0>c/k03@d=00_;bl0;Bd]02/[:`0Y:BT00P0X
:2P402LW9a809RHV00@09BDU02HV9P0V9RH09RHV103AcJT000<0dLfY3P0V9RH01@0W9bL09RHV02LW
9`0W9bL09RHV00D09bLW0`0X:2P03`0Y:BT0:RXZ02/[:`0];Bd0;bl_038b<P0g=cL0>SXj03hn?P14
A4@0BDU904e=C@1?Cdl0DE5A05EEE@0205QHF00M05YJFP1NGUh0GemO06=SH`1TI6@0IfMW06UYJ@1]
KFd0LG5a07=cL`1dM7@0MWIf07AdM01fMWH0MGEe07IfMP1iNGT0MGEe07IfMP1dM7@0Lg=c07IfMP1d
M7@0MGEe06m_K`1`L700KVi^06e]K@1/K6`00P1ZJVX0101WIfL0J6QX06IVIP1TI6@206EUI@0306AT
I01XJ6P0J6QX0080JVYZ00<0KFe]06m_K`1`L7000P1dM7@0101gMgL0NWYj07]kN`1jNWX307alO00;
07YjNP1gMgL0M7Ad06][J`1CDe<0AdM703dm?@0f=SH0<S8b02d];@0[:b/00P0Y:BT00`0W9bL0:2PX
02LW9`0302LW9`809RHV00<09bLW02HV9P0V9RH02`0V9RH0100U9BD09RHV02HV9P0U9BD40=7=Z@00
0`3AcJT202HV9P0302DU9@0V9RH09RHV00T09RHV0P0W9bL00`0V9RH09bLW02LW9`0402LW9`80:2PX
0P0Y:BT0:`0Z:RX0:b/[02d];@0^;Rh0<S8b03Hf=P0j>SX0?clo04=3@`19BDT0CTi>059BDP1EEED0
F5QH05]KF`1NGUh0GemO05iNGP1RHV80I6AT06IVIP1WIfL0Jf][06m_K`1aLG40Lg=c07AdM01hN7P0
O7al07]kN`1mOGd0O7al07YjNP1kNg/0N7Qh07UiN@1hN7P0MWIf07QhN01fMWH0MGEe07IfMP1cLg<0
0P1aLG4206i^KP0606e]K@1[Jf/0JVYZ06QXJ01VIVH0IfMW0P1UIFD07P1TI6@0IfMW06QXJ01YJFT0
Jf][06e]K@1_Kfl0LG5a079bLP1eMGD0MWIf07QhN01gMgL0NWYj07alO01kNg/0OGem07alO01iNGT0
M7Ad06][J`1KFe/0B4Q803`l?00h>3P0<C4a02d];@0[:b/0:RXZ02TY:@80:2PX100W9bL202HV9P03
02LW9`0V9RH09RHV00h09RHV103AcJT000<0dLfY0`0V9RH00`0U9BD09RHV02HV9P0502HV9P0302LW
9`0V9RH09bLW00809RHV100W9bL01@0X:2P09bLW02LW9`0X:2P0:BTY0080:RXZ0140:b/[02d];@0`
<300=3@d03Lg=`0j>SX0?clo04I6AP19BDT0Cdm?05ADE01IFET0FUYJ061PH01RHV80IVIV06EUI@02
06MWI`0706UYJ@1ZJVX0KFe]071`L01aLG40MWIf07MgM`0207]kN`0507moO`1nOWh0Ogmo0861P@20
P8000P1oOgl02@1kNg/0OWin07inOP1nOWh0OGem07UiN@1lO7`0NWYj07MgM`0307AdM003075aL@1^
KVh0KVi^00<0Jf][00H0J6QX06UYJ@1WIfL0IVIV06QXJ01YJFT306][J`0306m_K`1`L700LG5a0080
MGEe0P1gMgL0101jNWX0NGUi07]kN`1mOGd207YjNP0:07EeM@1_Kfl0HV9R04];B`11@D40>3Ph038b
<P0^;Rh0:b/[02XZ:P80:2PX100W9bL302HV9P809bLW3P0V9RH40=7=Z@000`3AcJT00`0U9BD09RHV
02HV9P0902HV9P809bLW00<09RHV02LW9`0W9bL00`0W9bL202PX:0<0:BTY01<0:b/[02`/;00^;Rh0
<30`03<c<`0g=cL0?Cdm03lo?`16ATH0C4a<051@D01DE5@0FEUI05eMG@1RHV80IFEU06UYJ@1[Jf/0
K6a/00@0LG5a0P1dM7@01`1gMgL0NGUi07]kN`1mOGd0OWin0820P01oOgl00`24Q8@01@23Ph<0QHF5
0820P022PX80Ogmo0080P82000<0Ogmo07inOP1nOWh00P1jNWX207UiN@80M7Ad00H0Lg=c075aL@1`
L700Kfm_06e]K@1/K6`506YZJP0906][J`1/K6`0KVi^06a/K01]KFd0L71`075aL@1dM7@0MGEe0080
MWIf00l0NGUi07]kN`1kNg/0NWYj07UiN@1fMWH0L71`06QXJ01EEED0@d=303Xj>P0c<c<0;bl_02/[
:`0Z:RX00P0X:2P702LW9`l09RHV103AcJT000<0dLfY3P0V9RH502LW9`@0:2PX01@0:BTY02/[:`0/
;2`0;Rh^034a<@0e=CD0>SXj03dm?@12@T80AdM704a<C01ADE40E5AD05YJFP1LG5`0H61P06IVIP1Y
JFT0KFe]079bLP80Lg=c00<0NWYj07]kN`1hN7P00P1iNGT03`1hN7P0NWYj07emO@20P800PX:208>3
P`25QHD0QXJ608F5Q@27QhL0RHV908N7Q`28R8P0QhN708F5Q@0208B4Q00608>3P`21PH40PH610820
P01oOgl0P8200P1kNg/00`1iNGT0MgMg07QhN00207=cL`03075aL@1_Kfl0KFe]0080Jf][00@0KFe]
06][J`1[Jf/0K6a/0P1]KFd05P1^KVh0KFe]071`L01aLG40Lg=c079bLP1dM7@0MWIf07UiN@1gMgL0
NGUi07alO01iNGT0MWIf079bLP1]KFd0EeMG04E5A@0j>SX0=CDe02l_;`0[:b/202TY:@<0:2PX0`0W
9bL?02HV9P0302DU9@3AcJT0dLfY0080dLfY00030=7=Z@X09RHV00@09bLW02HV9P0V9RH09RHV1@0W
9bL202PX:00R02TY:@0Z:RX0:RXZ02`/;00];Bd0<C4a03De=@0h>3P0?Shn04=3@`18B4P0Bd];04m?
C`1FEUH0EeMG05aLG01PH600IFEU06QXJ01[Jf/0L71`07IfMP1gMgL0N7Qh07alO020P800OWin0820
P01oOgl0OWin0820P021PH40Ph>308B4Q080QhN700d0RHV908J6QP2:RXX0R8R808^;R`29RHT0R8R8
08V9R@28R8P0QXJ608F5Q@26QXH0Ph>30080PX:20P21PH403@20P800OWin07]kN`1iNGT0MgMg07If
MP1cLg<0LG5a06e]K@1^KVh0KFe]06a/K01ZJVX00P1/K6`00`1[Jf/0KFe]06m_K`0306i^KP0D071`
L01bLW80LW9b075aL@1dM7@0MWIf07MgM`1iNGT0NWYj07QhN01fMWH0Lg=c06QXJ01BDU80@D5103Xj
>P0c<c<0;Rh^02XZ:P0Y:BT202PX:0D09bLW3@0V9RH00`0U9BD09RHV0=7=Z@030=7=Z@000`3AcJT;
02HV9P0302LW9`0V9RH09RHV00@09bLW0`0X:2P06P0Z:RX0:b/[02d];@0^;Rh0<S8b03Hf=P0k>c/0
?clo04M7A`1:BTX0Cdm?05=CD`1FEUH0G5aL05iNGP1QHF40I6AT06IVIP1ZJVX0K6a/079bLP1eMGD0
NGUi07inOP22PX80QHF50P26QXH02028R8P0QHF508J6QP25QHD0QhN708J6QP2:RXX0QhN70P29RHT0
202;Rh/0S8b<08^;R`2>SXh0Shn?08j>SP2=SHd0Shn?0P2:RXX01029RHT0QXJ608F5Q@26QXH208B4
Q00608>3P`20P800P82007UiN@1jNWX0MWIf0P1eMGD01P1`L700Kfm_06a/K01/K6`0KFe]06YZJP80
K6a/00H0Jf][06i^KP1/K6`0KFe]06][J`1`L70206m_K`06079bLP1`L700Lg=c07=cL`1gMgL0N7Qh
0P1fMWH02@1aLG40JVYZ05=CD`17AdL0>CTi03<c<`0];Bd0:b/[02TY:@0302PX:00602LW9`0V9RH0
9RHV02LW9`0V9RH09bLW2`0V9RH00`0U9BD0dLfY0=7=Z@020=7=Z@000`3AcJT802HV9P0302LW9`0V
9RH09RHV00L09bLW01/0:2PX02TY:@0Y:BT0:b/[02d];@0_;bl0<C4a03Lg=`0m?Cd0A4A404Q8B01?
Cdl0De=C05QHF01LG5`0GUiN061PH01RHV80IFEU06IVIP1ZJVX0K6a/06i^KP1bLW80MgMg07YjNP21
PH400P25QHD02029RHT0S8b<08f=S@2=SHd0Shn?08Z:RP2;Rh/0RXZ:0P29RHT01@2:RXX0S8b<08^;
R`2:RXX0S8b<0080T92@00@0Shn?08f=S@2@T900T92@0P2<S8`00`2=SHd0S8b<08N7Q`0208N7Q`0;
08J6QP24Q8@0PX:208B4Q01oOgl0OGem07UiN@1eMGD0LW9b071`L01^KVh0101/K6`00`1ZJVX0Jf][
06UYJ@0206a/K080Jf][00<0K6a/06m_K`1_Kfl00P1`L7003`1bLW80Lg=c079bLP1hN7P0NGUi07If
MP1cLg<0JVYZ05UIF@14A4@0>SXj038b<P0^;Rh0:b/[02TY:@0302PX:0<09bLW2@0V9RH00`0U9BD0
9RHV02HV9P0202HV9P@0dLfY00030=7=Z@/09RHV1P0W9bL04P0X:2P0:BTY02TY:@0Z:RX0:b/[02h^
;P0b<S80=SHf03`l?015ADD0C4a<059BDP1HF5P0GUiN06ATI01VIVH0J6QX06UYJ@80JVYZ00d0Jf][
06a/K01]KFd0Kfm_07=cL`1hN7P0Ng]k0820P027QhL0RXZ:08j>SP2<S8`0T92@0080Ti>C0P2BTY80
2@2ATI40Shn?08f=S@2>SXh0T92@08n?S`2ATI40TY:B096AT@0209:BTP80TI6A00@0Ti>C092@T02A
TI40SXj>0P2?Shl0102;Rh/0RHV908R8R026QXH308N7Q`80Ph>300@0OGem07YjNP1iNGT0MGEe0`1^
KVh01@1]KFd0KVi^06][J`1[Jf/0JVYZ0080JFUY0P1ZJVX01`1/K6`0KFe]06i^KP1^KVh0L71`06i^
KP1`L7000P1dM7@0301fMWH0MGEe071`L01ZJVX0Fe]K04=3@`0h>3P0<c<c02h^;P0Z:RX0:BTY02PX
:0<09bLW3`0V9RH40=7=Z@000`3AcJT:02HV9P<09bLW00<0:2PX02LW9`0W9bL00P0X:2P0400Y:BT0
:RXZ02/[:`0^;Rh0<30`03Hf=P0l?3`0ADE504a<C01FEUH0FEUI06ATI01YJFT0KVi^075aL@1bLW82
07=cL`0E07AdM01bLW80Lg=c079bLP1dM7@0MGEe07QhN01nOWh0PX:208R8R02:RXX0Rh^;08n?S`2@
T900UiNG09BDU02IVIT0Vi^K09RHV02IVIT0Ti>C00<0T92@00H0TI6A09BDU02CTi<0UYJF09BDU02C
Ti<409JFUP80U9BD00<0Ti>C09:BTP2ATI400P2=SHd03@28R8P0RHV908V9R@24Q8@0QHF508:2PP1m
OGd0O7al07YjNP1bLW80L71`06i^KP1]KFd00`1[Jf/206UYJ@0406YZJP1YJFT0JVYZ06UYJ@80Jf][
01<0K6a/06e]K@1/K6`0KVi^06m_K`1aLG40MWIf07AdM01`L700Kfm_06YZJP1CDe<0@D5103Ti>@0a
<C40;Bd]02XZ:P0Y:BT0:2PX00@09bLW3@0V9RH40=7=Z@000`3AcJT902HV9PH09bLW0`0X:2P03`0Y
:BT0:RXZ02d];@0_;bl0=3@d03/k>`0o?cl0BTY:059BDP1IFET0GemO06][J`1`L700Lg=c07IfMP03
07YjNP80NGUi0P1hN7P0101eMGD0MWIf07UiN@1mOGd208J6QP0508V9R@2=SHd0TY:B096AT@2CTi<0
0P2HV9P209ZJVP0;09bLW02KVi/0UiNG09RHV02FUYH0U9BD09FEU@2FUYH0UiNG09FEU@2CTi<00P2E
UID01P2HV9P0UiNG09fMW@2HV9P0UiNG09>CT`<0T92@00H0SXj>08^;R`29RHT0R8R808V9R@26QXH2
08:2PP0D07emO@1kNg/0MGEe07=cL`1^KVh0KFe]06a/K01ZJVX0JFUY06YZJP1YJFT0K6a/06YZJP1Y
JFT0J6QX06UYJ@1[Jf/0KFe]06YZJP1[Jf/206e]K@80Kfm_00T0L71`06i^KP1]KFd0IVIV04];B`0n
?Sh0=SHf02l_;`0/;2`00P0Y:BT202PX:0<09bLW300V9RH40=7=Z@000`3AcJT902HV9PH09bLW01<0
:2PX02TY:@0Y:BT0:RXZ02`/;00^;Rh0<S8b03Ph>011@D40ATI6051@D01IFET0HV9R06QXJ01`L700
N7Qh07inOP20P800PX:20080Q8B40P23Ph<20861P@0307moO`20P800Ogmo0080PX:200X0QhN708Z:
RP2;Rh/0RXZ:09>CT`2ATI40UYJF09ZJVP2LW9`0WIfM0P2NWYh0202MWId0W9bL09^KV`2GUiL0UYJF
09NGU`2IVIT0V9RH0P2IVIT02@2HV9P0VYZJ09JFUP2KVi/0WIfM09RHV02GUiL0UYJF09BDU00209:B
TP0B08n?S`2>SXh0SXj>08V9R@2:RXX0RHV908R8R025QHD0P82007alO01gMgL0M7Ad07=cL`1bLW80
Kfm_06a/K01]KFd0Jf][0`1ZJVX00`1[Jf/0J6QX06QXJ00206][J`0306UYJ@1[Jf/0JVYZ00@0KFe]
00T0Jf][06UYJ@1QHF40BTY:03`l?00d=3@0;bl_02/[:`0Y:BT00P0X:2P502LW9`X09RHV103AcJT0
00<0dLfY1`0V9RH00`0W9bL09RHV02HV9P0402LW9`<0:2PX01H0:RXZ02`/;00];Bd0<30`03Hf=P0m
?Cd0ADE504a<C01FEUH0GemO06YZJP1]KFd0MGEe07inOP24Q8@0R8R808^;R`2:RXX0Shn?08f=S@2<
S8`0Rh^;0P2:RXX00`29RHT0QXJ608J6QP0208N7Q`<0R8R800l0RXZ:092@T02DU9@0U9BD09JFUP2K
Vi/0XJ6Q0:2PX02VYZH0XJ6Q0:2PX02NWYh0X:2P09^KV`2HV9P0102KVi/01@2JVYX0Vi^K09VIV@2M
WId0WYjN0080VYZJ00<0V9RH09NGU`2DU9@00P2BTY8208n?S`<0S8b<00X0RHV908F5Q@23Ph<0OGem
07UiN@1gMgL0Lg=c079bLP1cLg<0Jf][0P1/K6`00`1[Jf/0JVYZ06YZJP0206UYJ@0306QXJ01YJFT0
J6QX0080J6QX00d0JVYZ06a/K01]KFd0KFe]06a/K01ZJVX0J6QX05mOG`15ADD0>SXj03@d=00];Bd0
:b/[0080:2PX0`0W9bL00`0V9RH09bLW02HV9P0902HV9P@0dLfY00030=7=Z@<09RHV00<09bLW02HV
9P0V9RH00P0V9RH302LW9`0U02HV9P0X:2P09bLW02LW9`0X:2P0:BTY02XZ:P0];Bd0<30`03@d=00k
>c/0@T9204a<C01CDe<0Fe]K06IVIP1`L700M7Ad07moO`24Q8@0RXZ:08f=S@2BTY80U9BD09JFUP2J
VYX0UiNG09RHV02GUiL0TY:B096AT@2@T900S8b<08V9R@2:RXX0RHV908N7Q`0208R8R00J08f=S@2>
SXh0TY:B09RHV02KVi/0WYjN09nOW`2TY:@0Zj^[0:RXZ02TY:@0YZJV0::RXP2QXJ40W9bL09fMW@2K
Vi/0W9bL09nOW`2MWId0Vi^K09fMW@2KVi/0WinO09ZJVP2KVi/209VIV@0N09NGU`2EUID0U9BD09:B
TP2=SHd0Shn?08^;R`2<S8`0RHV908R8R025QHD0PH6107inOP1iNGT0MgMg07IfMP1aLG40LW9b06e]
K@1^KVh0JVYZ06UYJ@1ZJVX0JFUY06YZJP1YJFT0IfMW06IVIP1UIFD0JFUY0P1XJ6P02`1/K6`0Jf][
06YZJP1VIVH0IFEU05]KF`13@d<0>CTi034a<@0/;2`0:BTY0080:2PX1@0W9bL902HV9P@0dLfY0003
0=7=Z@0302DU9@0V9RH09RHV00@09RHV1@0W9bL202PX:00B02LW9`0Y:BT0:RXZ02/[:`0^;Rh0<S8b
03Ph>010@400B4Q8059BDP1JFUX0I6AT06e]K@1cLg<0NWYj0861P@29RHT0T92@0P2EUID01P2JVYX0
Vi^K0:6QX@2TY:@0XZ:R0:6QX@80WIfM00@0VIVI09JFUP2CTi<0SXj>0P2=SHd0302:RXX0RHV908^;
R`2=SHd0T92@09JFUP2IVIT0WinO0::RXP2TY:@0YjNW0:ZZZP<0Z:RX01@0YjNW0:>SX`2PX:00WinO
09fMW@2KVi/0W9bL0:2PX02MWId0WinO0:2PX02MWId0WinO09jNWP2MWId0VYZJ09bLW02HV9P0Ti>C
09BDU080TI6A00/0S8b<08n?S`29RHT0RXZ:08N7Q`23Ph<0P82007alO01jNWX0MWIf07MgM`02075a
L@0G06i^KP1/K6`0JFUY06YZJP1[Jf/0J6QX06MWI`1SHf<0IVIV06ATI01XJ6P0IfMW06UYJ@1]KFd0
K6a/06UYJ@1XJ6P0Hf=S059BDP10@400=SHf02l_;`0[:b/00P0Y:BT402LW9`X09RHV103AcJT000<0
dLfY1@0V9RH00`0W9bL09RHV02HV9P0202LW9`0302HV9P0W9bL09bLW0080:2PX01T0:BTY02XZ:P0/
;2`0<30`03De=@0k>c/0@d=304e=C@1DE5@0GUiN06QXJ01aLG40NGUi07inOP25QHD0S8b<08n?S`2E
UID0VIVI09nOW`2QXJ40Y:BT0:FUY@2WYjL0ZZZZ0080YJFU00P0Xj>S09fMW@2JVYX0VIVI09JFUP2B
TY80SXj>08^;R`80SXj>00H0SHf=09:BTP2JVYX0WIfM0:2PX02UYJD20:JVYP0D0:ZZZP2[Zj/0ZZZZ
0:^[Z`2ZZZX0YjNW0::RXP2QXJ40WinO0:2PX02MWId0XJ6Q09nOW`2NWYh0Vi^K09fMW@2VYZH0XZ:R
0:2PX02JVYX309NGU`0509BDU02BTY80Ti>C08n?S`2@T9000P2<S8`208J6QP0408>3P`1nOWh0NWYj
07QhN080Lg=c00<0K6a/06i^KP1/K6`00`1[Jf/01P1UIFD0IVIV06IVIP1VIVH0I6AT06MWI`80J6QX
00X0JVYZ06UYJ@1XJ6P0IFEU05eMG@1:BTX0>SXj03<c<`0];Bd0:RXZ0P0X:2P402LW9`T09RHV103A
cJT000<0dLfY200V9RH502LW9`0b02PX:00Y:BT0:RXZ02/[:`0^;Rh0<S8b03Xj>P0o?cl0AdM7055A
D@1LG5`0I6AT06][J`1cLg<0OWin08B4Q02;Rh/0TI6A09BDU02MWId0WinO0:6QX@2VYZH0YjNW0:f]
[@2^[Zh0[jn_0:j^[P2`/;00Zj^[0:ZZZP2SXj<0WinO09fMW@2IVIT0U9BD09FEU@2DU9@0Shn?09>C
T`2ATI40UIFE09RHV02OWil0Xj>S0:BTY02XZ:P0Zj^[0:ZZZP2[Zj/20:j^[P040:b/[02YZJT0YZJV
0:FUY@80XZ:R0P2PX:000`2NWYh0XJ6Q09jNWP020:2PX00:09jNWP2MWId0WIfM09bLW02HV9P0UYJF
09VIV@2GUiL0U9BD096AT@80Shn?00X0RXZ:08R8R029RHT0QXJ60820P01lO7`0NGUi07MgM`1dM7@0
Kfm_0P1]KFd00`1/K6`0JVYZ06MWI`0206EUI@0A06IVIP1TI6@0IFEU06UYJ@1XJ6P0Jf][06UYJ@1W
IfL0IVIV061PH01IFET0@D5103Hf=P0_;bl0;2`/02TY:@0X:2P0100W9bL902HV9P@0dLfY00030=7=
Z@H09RHV00<09bLW02HV9P0V9RH00`0W9bL202PX:00J02TY:@0[:b/0;Bd]030`<00e=CD0?3`l04A4
A01<C4`0EEEE05mOG`1VIVH0LG5a07]kN`24Q8@0R8R8092@T02EUID0Vi^K0:2PX02RXZ80Zj^[0:f]
[@2^[Zh0/K6a0;2`/02c/k<20;Fe]@0:0;>c/`2d];@0[jn_0:b/[02XZ:P0YJFU0:6QX@2MWId0Vi^K
09FEU@80UYJF00<0Ti>C09NGU`2JVYX00P2PX:001@2UYJD0YjNW0:VYZ@2[Zj/0[Zj^0080/;2`00D0
[Zj^0:ZZZP2YZJT0YZJV0:FUY@020::RXP0309fMW@2PX:00WIfM0080XZ:R00D0X:2P0:6QX@2MWId0
WinO0:2PX00209fMW@0?09^KV`2HV9P0UiNG09:BTP2?Shl0TI6A08j>SP29RHT0R8R808F5Q@22PX80
Ogmo07YjNP1gMgL0MGEe0080LW9b00H0Jf][06a/K01XJ6P0IVIV06=SH`1TI6@306IVIP0<06MWI`1V
IVH0J6QX06IVIP1UIFD0Hf=S05iNGP1?Cdl0?3`l03<c<`0^;Rh0:RXZ0P0X:2P302LW9`T09RHV103A
cJT000<0dLfY0P0V9RH01@0W9bL09RHV02HV9P0W9bL09RHV00D09bLW0P0X:2P06@0Y:BT0:b/[02h^
;P0b<S80>3Ph0451@@16ATH0DE5A05UIF@1SHf<0Jf][07=cL`1lO7`0Q8B408Z:RP2CTi<0W9bL09fM
W@2RXZ80ZZZZ0:b/[02^[Zh0/k>c0;Fe]@2f][H00P2g]kL01P2j^[X0^KVi0;Zj^P2k^k/0]kNg0;2`
/080[jn_00@0Y:BT0:2PX02NWYh0VIVI0P2HV9P07P2IVIT0Vi^K09bLW02NWYh0WinO0:BTY02VYZH0
Zj^[0:j^[P2][Jd0[Zj^0;:b/P2f][H0[Jf]0:b/[02ZZZX0YjNW0:>SX`2QXJ40WYjN0::RXP2PX:00
XZ:R09nOW`2QXJ40X:2P0::RXP2MWId0X:2P0::RXP80WIfM01<0W9bL09RHV02EUID0Ti>C092@T02;
Rh/0T92@08^;R`25QHD0PX:207moO`1kNg/0MgMg07AdM01cLg<0LG5a06e]K@1[Jf/0IfMW0080IVIV
0140IFEU06MWI`1TI6@0IVIV06EUI@1VIVH0I6AT06EUI@1TI6@0H61P05YJFP15ADD0=cLg038b<P0/
;2`0:RXZ02PX:00402LW9`0302HV9P0W9bL09RHV00@09RHV00<09BDU0=7=Z@3AcJT00P3AcJT000<0
dLfY1P0V9RH0100W9bL09RHV02LW9`0W9bL402PX:00G02XZ:P0/;2`0<30`03@d=00k>c/0A4A404Y:
BP1CDe<0G5aL06EUI@1[Jf/0M7Ad07inOP27QhL0S8b<09JFUP2MWId0Xj>S0:NWY`2][Jd0[Zj^0;Jf
]P2h^;P00P2l_;`08`2h^;P0^k^k0;bl_02o_kl0_[jn0;^k^`2l_;`0^k^k0;Vi^@2c/k<0[Zj^0:ZZ
ZP2VYZH0XZ:R09nOW`2LW9`0Vi^K09VIV@2KVi/0VYZJ09fMW@2OWil0X:2P0:JVYP2[Zj/0[jn_0;:b
/P2a/K40]KFe0;6a/@2b/[80/;2`0:^[Z`2WYjL0XZ:R00<0XJ6Q00<0WinO0:BTY02OWil00`2RXZ80
5P2TY:@0YJFU0:6QX@2QXJ40Vi^K09VIV@2GUiL0UIFE09BDU02?Shl0T92@08b<S02:RXX0QXJ608:2
PP1nOWh0NWYj07MgM`1eMGD0LW9b071`L01[Jf/206YZJP0306MWI`1SHf<0IVIV00<0I6AT00d0HV9R
06ATI01TI6@0IFEU065QH@1MGEd0D51@03`l?00e=CD0;Rh^02XZ:P0Y:BT0:2PX00809bLW2@0V9RH4
0=7=Z@000`3AcJT402HV9P<09bLW00@09RHV02LW9`0W9bL09bLW0P0X:2P0:`0Y:BT0:RXZ02d];@0b
<S80=SHf03hn?P16ATH0CTi>05ADE01OGel0IfMW071`L01hN7P0Ogmo08V9R@2@T900UIFE09jNWP2T
Y:@0Z:RX0;2`/02e]KD0][Jf0;Vi^@2m_Kd0_[jn0;bl_02k^k/0_kno0<30`02o_kl0`/;20<C4a02n
_[h0_Kfm0;jn_P2j^[X0^KVi0;:b/P2/[:`0Z:RX0:BTY02QXJ400P2KVi/03P2IVIT0V9RH09^KV`2O
Wil0Xj>S0:FUY@2/[:`0[Zj^0;>c/`2b/[80]kNg0;Fe]@2d];@0[jn_0P2[Zj/0402VYZH0YJFU0:JV
YP2QXJ40X:2P0:BTY02RXZ80WinO0:>SX`2TY:@0WinO0:JVYP2SXj<0X:2P09fMW@2JVYX209NGU`0D
09JFUP2DU9@0SXj>08j>SP2:RXX0RHV908>3P`20P800OGem07QhN01fMWH0Lg=c06m_K`1^KVh0K6a/
06MWI`1VIVH0IFEU06=SH`1QHF43069RHP0;06ATI01RHV80HV9R05iNGP1IFET0@d=303Ph>00a<C40
;2`/02TY:@0X:2P00`0W9bL802HV9P@0dLfY00030=7=Z@L09RHV100W9bL202PX:00H02TY:@0[:b/0
;Rh^03<c<`0h>3P0@41004Q8B01@D500FEUI069RHP1/K6`0Lg=c07YjNP25QHD0R8R8092@T02IVIT0
WYjN0:JVYP2ZZZX0/;2`0;Fe]@2l_;`0_[jn0P2m_Kd01031`L40`/;20<71`@31`L420<;2`P80aLG5
01`0a/K60<G5a@36a/H0`/;20<30`02j^[X0][Jf0:n_[`2ZZZX0YJFU0:6QX@2PX:00W9bL09fMW@2N
WYh0X:2P0:6QX@2VYZH0ZJVY0:f][@2`/;00[Zj^0;2`/02a/K40/k>c0;2`/02_[jl0/K6a0P2YZJT0
3`2UYJD0YZJV0::RXP2SXj<0XJ6Q0::RXP2PX:00Xj>S0:BTY02QXJ40Y:BT0:6QX@2KVi/0VYZJ09^K
V`0209BDU00>09:BTP2ATI40SHf=08Z:RP26QXH0QHF508:2PP1nOWh0NGUi07IfMP1cLg<0LW9b071`
L01ZJVX206EUI@0@06=SH`1RHV80HF5Q061PH01QHF40H61P069RHP1PH600GemO05]KF`1@D500?clo
03@d=00^;Rh0:RXZ02TY:@<09bLW200V9RH40=7=Z@000`3AcJT702HV9P@09bLW0P0X:2P0600Z:RX0
;2`/030`<00f=SH0>SXj0451@@1;Bd/0Cdm?05YJFP1SHf<0K6a/07=cL`1mOGd0Ph>308f=S@2ATI40
V9RH09^KV`2VYZH0[:b/0;6a/@2f][H0^k^k0;no_`80`<3001P0`l?30<30`032`/80alO70<;2`P30
`<00bl_;0<[:bP39bLT0b/[:0<_;b`3<c<`0bLW90<K6aP31`L40^[Zj0;Rh^02`/;00ZJVY0:FUY@2S
Xj<0XJ6Q09nOW`2NWYh20:6QX@080:>SX`2XZ:P0Z:RX0:^[Z`2^[Zh0/K6a0;2`/02^[Zh20;Bd]00:
0;Fe]@2/[:`0ZJVY0:NWY`2TY:@0YJFU0::RXP2VYZH0XZ:R0:2PX0<0XZ:R0140XJ6Q09nOW`2MWId0
W9bL09VIV@2FUYH0T92@096AT@2?Shl0RHV908Z:RP27QhL0Ph>30861P@1nOWh0Ng]k07QhN00207Ee
M@0406i^KP1YJFT0IfMW06ATI080Hf=S00h0HV9R05mOG`1PH600GemO05iNGP1OGel0GEeM05IFEP19
BDT0>3Ph034a<@0[:b/0:RXZ02PX:0809bLW00@09RHV02LW9`0V9RH09bLW100V9RH40=7=Z@000`3A
cJT502HV9PH09bLW01d0:2PX02TY:@0Z:RX0;Bd]034a<@0g=cL0?3`l04=3@`1=CDd0De=C05YJFP1S
Hf<0KFe]07AdM01mOGd0Q8B408^;R`2CTi<0VIVI09nOW`2TY:@0[Jf]0:n_[`2e]KD0^k^k0;no_`31
`L40alO70<G5a@020<C4a0050<K6aP3:b/X0bl_;0<[:bP3@d=000P3Bd]804`3AdM40e]KF0=KFeP3I
fMT0cLg=0<_;b`36a/H0_kno0;Ng]`2c/k<0[Jf]0:NWY`2SXj<0XJ6Q09nOW`2SXj<0XJ6Q0:BTY02S
Xj<00P2WYjL02P2YZJT0[Zj^0:j^[P2b/[80/k>c0;Jf]P2e]KD0/[:b0:j^[P2ZZZX20:NWY`030:FU
Y@2TY:@0WinO0080WinO01T0XZ:R0:6QX@2QXJ40X:2P09nOW`2MWId0V9RH09FEU@2DU9@0T92@08f=
S@2;Rh/0R8R808J6QP24Q8@0QHF508J6QP1mOGd0NGUi07IfMP1aLG40KVi^06YZJP1XJ6P0I6AT0080
HV9R1@1OGel02P1NGUh0FEUI055AD@0m?Cd0=3@d02d];@0Z:RX0:BTY02LW9`0V9RH402LW9`@09RHV
103AcJT000<0dLfY1@0V9RH502LW9`80:2PX01`0:RXZ02/[:`0^;Rh0<C4a03Lg=`0m?Cd0@d=304e=
C@1CDe<0GEeM06=SH`1ZJVX0LG5a07QhN024Q8@0QhN708j>SP2FUYH0WinO0:FUY@2ZZZX0/;2`0;Jf
]P2j^[X0^k^k0<?3``36a/H0alO70`38b<P04@3<c<`0c/k>0<k>cP3AdM40eMGE0=;BdP3>c/h0e=CD
0=KFeP3Lg=`0e=CD0=;BdP3=cLd0b/[:0<71`@2k^k/0^;Rh0080[jn_00l0Z:RX0:FUY@2RXZ80WYjN
09nOW`2NWYh0WinO0:6QX@2UYJD0Z:RX0:b/[02^[Zh0]KFe0;Rh^02i^KT00P2d];@00`2^[Zh0[:b/
0:ZZZP020:FUY@0A0:2PX02QXJ40XZ:R0:6QX@2OWil0Xj>S0:6QX@2RXZ80WinO09jNWP2IVIT0UIFE
09:BTP2@T900Shn?08b<S02:RXX00`25QHD0201oOgl0Ng]k07UiN@1dM7@0Kfm_06][J`1ZJVX0IfMW
0P1RHV800`1QHF40GEeM05mOG`0205iNGP80Fe]K00L0EUIF04=3@`0e=CD0;bl_02`/;00Y:BT0:2PX
00<09bLW1P0V9RH40=7=Z@000`3AcJT402HV9PH09bLW01`0:2PX02TY:@0Z:RX0;2`/02l_;`0d=3@0
>SXj03lo?`15ADD0CDe=05EEE@1MGEd0I6AT06e]K@1cLg<0Ng]k08:2PP29RHT0Shn?09JFUP2MWId0
Xj>S0:VYZ@2`/;00][Jf0;bl_02m_Kd0`<300P35aLD06`3>c/h0c<c<0<c<c03>c/h0clo?0=CDe03C
dm<0eMGE0=?Cd`3GemL0f][J0=gMg@3Rh^80hn?S0=cLg03Jf]X0e]KF0=3@d03<c<`0`l?30;jn_P2j
^[X0]KFe0:b/[02VYZH0XJ6Q09nOW`0209bLW00809^KV`2MWId0WIfM0:BTY02XZ:P0[Zj^0;Fe]@2g
]kL20;Vi^@0=0;Jf]P2d];@0[Zj^0:^[Z`2UYJD0Y:BT0:>SX`2OWil0XZ:R0:2PX02SXj<0XZ:R0:>S
X`0209fMW@0I09nOW`2KVi/0UYJF096AT@2>SXh0T92@08^;R`28R8P0QHF508>3P`1oOgl0P82007al
O01iNGT0L71`06e]K@1[Jf/0JVYZ06IVIP1QHF40H61P05eMG@1KFe/0G5aL05]KF`0205YJFP0705IF
EP1<C4`0>SXj034a<@0];Bd0:BTY02PX:00302LW9`H09RHV103AcJT000<0dLfY1P0V9RH402LW9`0G
02PX:00Y:BT0:b/[02d];@0`<300=SHf03/k>`10@400B4Q804m?C`1DE5@0G5aL06IVIP1/K6`0LG5a
07QhN021PH40QHF508b<S02EUID0WIfM0:2PX02UYJD00P2^[Zh02P2c/k<0^k^k0;no_`32`/80alO7
0<c<c03=cLd0d=3@0=CDe03Cdm<20=GEe@0H0=OGe`3Bd]80fMWI0=KFeP3Shn<0i>CT0>;RhP3Ti>@0
gmoO0=gMg@3Jf]X0e]KF0=3@d03<c<`0alO70;bl_02c/k<0ZZZZ0:NWY`2TY:@0WinO09ZJVP2KVi/0
WYjN0P2OWil01@2MWId0YZJV0:^[Z`2a/K40]KFe0080^KVi00D0^k^k0;Vi^@2c/k<0Zj^[0:ZZZP02
0:FUY@0A0:>SX`2QXJ40XJ6Q09nOW`2PX:00XJ6Q09nOW`2KVi/0W9bL09RHV02FUYH0TI6A092@T02?
Shl0S8b<08Z:RP25QHD00P21PH40301nOWh0Ng]k07MgM`1bLW80L71`06YZJP1XJ6P0I6AT061PH01N
GUh0GEeM05aLG080FEUI00P0EeMG05IFEP1>CTh0?Cdm038b<P0^;Rh0:RXZ02PX:0809bLW1`0V9RH4
0=7=Z@000`3AcJT502HV9P0302LW9`0V9RH09bLW00809bLW0200:2PX02TY:@0[:b/0;Rh^038b<P0h
>3P0?Cdm04=3@`1:BTX0D51@05EEE@1JFUX0I6AT06YZJP1aLG40N7Qh07moO`24Q8@0Rh^;092@T02J
VYX0X:2P0:>SX`2WYjL0[jn_0;>c/`2g]kL0_Kfm0<O7a`33`l<0bLW90<k>cP80d];B00P0emOG0=[J
fP3Fe]H0f][J0=WIf@3Kfm/0gMgM0>?Sh`80iNGU0100j>SX0>GUi@3UiND0hN7Q0>3Ph03MgMd0eMGE
0=?Cd`39bLT0_Kfm0;Ng]`2_[jl0ZJVY0:BTY02OWil0WYjN0P2KVi/03P2LW9`0WIfM0:6QX@2VYZH0
ZJVY0;6a/@2f][H0^k^k0;bl_02k^k/0^[Zj0;Bd]02_[jl0Zj^[0P2VYZH00`2TY:@0X:2P09jNWP02
09nOW`0409bLW02OWil0W9bL09RHV0<0U9BD01`0SXj>08b<S02:RXX0QXJ608B4Q022PX80PH6107in
OP1jNWX0N7Qh07=cL`1^KVh0Jf][06QXJ01UIFD0GemO05eMG@1JFUX0FEUI05MGE`1DE5@0EEEE04e=
C@16ATH0=3@d030`<00/;2`0:BTY100W9bL502HV9P@0dLfY00030=7=Z@<09RHV00@09bLW02HV9P0V
9RH09RHV0`0W9bL0:@0Y:BT0:RXZ02d];@0_;bl0<c<c03Xj>P10@400A4A404];B`1ADE40EeMG05aL
G01SHf<0JVYZ06m_K`1gMgL0O7al08>3P`27QhL0SXj>09FEU@2LW9`0WinO0:>SX`2][Jd0[jn_0;Fe
]@2l_;`0`l?30<C4a03<c<`0c/k>0=;BdP3De=@0e]KF0=_Kf`3Lg=`0g]kN0>3Ph03Ogml0h>3P0080
i>CT0140jn_[0>KViP3Vi^H0j>SX0>_[j`3YjNT0hn?S0=[JfP3Hf=P0dM7A0<S8b02n_[h0^[Zj0:n_
[`2ZZZX0Z:RX0:>SX`0209bLW080VYZJ00L0W9bL0::RXP2TY:@0[Jf]0;Jf]P2k^k/0_Kfm0080^k^k
0P2j^[X03@2d];@0/;2`0:VYZ@2WYjL0XZ:R09nOW`2PX:00WinO09jNWP2MWId0WYjN09^KV`2GUiL0
0P2DU9@07@2?Shl0S8b<08Z:RP29RHT0QXJ608F5Q@24Q8@0P82007]kN`1hN7P0MgMg075aL@1]KFd0
JFUY06EUI@1RHV80H61P05eMG@1HF5P0EUIF05=CD`1BDU80C4a<04U9B@0i>CT0<C4a02d];@0Y:BT0
:2PX00809bLW1P0V9RH40=7=Z@000`3AcJT602HV9P<09bLW01l0:2PX02TY:@0Z:RX0;Bd]030`<00g
=cL0?Cdm0492@P17AdL0CTi>05=CD`1HF5P0GUiN06ATI01[Jf/0Kfm_07EeM@1oOgl0Q8B408J6QP2>
SXh0TI6A09RHV02NWYh0Xj>S0:RXZ02YZJT0/K6a0;Vi^@31`L40`l?30080c<c<00<0d=3@0=KFeP3G
emL00P3MgMd02@3Ng]h0gmoO0>?Sh`3Ti>@0i^KV0>GUi@3Zj^X0i>CT0>[ZjP020>WYj@0F0>c/k03V
i^H0hN7Q0=_Kf`3IfMT0bl_;0<C4a032`/80^k^k0;>c/`2[Zj/0YjNW0:BTY02OWil0Vi^K09bLW02J
VYX0XZ:R0:JVYP2XZ:P0/[:b0;Jf]P<0^k^k00H0^[Zj0;fm_@2h^;P0];Bd0;6a/@2][Jd20:FUY@0M
0:2PX02NWYh0WYjN09fMW@2LW9`0VIVI09NGU`2JVYX0UIFE09>CT`2@T900Rh^;08V9R@27QhL0QHF5
08:2PP1oOgl0O7al07YjNP1fMWH0LW9b06e]K@1[Jf/0IVIV069RHP1MGEd0G5aL05QHF01FEUH00P1B
DU801`1>CTh0Bd];03`l?00c<c<0;Rh^02XZ:P0Y:BT00P0W9bL602HV9P@0dLfY00030=7=Z@@09RHV
100W9bL202PX:00`02TY:@0[:b/0;Bd]038b<P0i>CT0@41004M7A`1<C4`0DU9B05QHF01JFUX0GUiN
06EUI@1[Jf/0Kfm_07MgM`1lO7`0PX:208F5Q@2;Rh/0TI6A09BDU02MWId0WinO0:RXZ02YZJT0/;2`
0;Bd]02i^KT0_kno0<O7a`3@d=00d];B0=CDe03Kfm/0emOG0=_Kf`3Ph>00hN7Q0>CTi03QhN40i>CT
0>OWi`3Zj^X0jNWY0>g]k@3[jn/0kNg]0P3^k^h0A@3YjNT0inOW0>3Ph03Cdm<0d=3@0<[:bP33`l<0
`<300;Rh^02d];@0[:b/0:NWY`2QXJ40WinO09fMW@2OWil0X:2P0:NWY`2ZZZX0[jn_0;Fe]@2g]kL0
_;bl0;^k^`2j^[X0_;bl0;^k^`2f][H0/k>c0:b/[02VYZH0Y:BT09jNWP2PX:00WIfM09^KV`2MWId0
UiNG09JFUP2EUID0Ti>C096AT@2?Shl0Rh^;08R8R024Q8@0PX:207moO`1mOGd0NGUi07MgM`1eMGD0
Kfm_06][J`1YJFT0IVIV061PH01NGUh0FEUI05IFEP1EEED0DU9B04e=C@1:BTX0@d=303De=@0_;bl0
:b/[02PX:00402LW9`@09RHV103AcJT000<0dLfY1@0V9RH402LW9`0Z02PX:00Y:BT0:b/[02l_;`0d
=3@0>c/k0492@P1;Bd/0D51@05IFEP1KFe/0GUiN069RHP1WIfL0Jf][075aL@1eMGD0O7al0861P@24
Q8@0R8R808n?S`2DU9@0VYZJ09jNWP2QXJ40YZJV0:b/[02e]KD0][Jf0;bl_031`L40bLW90=3@d03D
e=@0e]KF0=[JfP3Hf=P0gMgM0=kNgP3Ti>@0h>3P0P3Xj>P07P3YjNT0inOW0>SXj03YjNT0j^[Z0?3`
l03_knl0k^k^0>_[j`3Ogml0g=cL0=WIf@3Jf]X0dm?C0<g=c@35aLD0`L710;Rh^02b/[80ZZZZ0:JV
YP2TY:@0XJ6Q0:2PX02UYJD0YjNW0:RXZ02^[Zh0/k>c0;Vi^@80^k^k00P0^KVi0;^k^`2g]kL0][Jf
0;Fe]@2][Jd0Z:RX0:FUY@80WinO0P2MWId209VIV@80U9BD00D0TY:B08j>SP2=SHd0RXZ:08N7Q`02
08:2PP0D07emO@1jNWX0N7Qh07AdM01bLW80KVi^06a/K01VIVH0Hf=S061PH01LG5`0F5QH05ADE01C
De<0Cdm?04U9B@15ADD0=cLg02l_;`0/;2`202PX:0809bLW1@0V9RH40=7=Z@000`3AcJT402HV9P<0
9bLW0P0X:2P0:@0Y:BT0:RXZ02`/;00_;bl0=CDe03dm?@15ADD0CDe=05=CD`1JFUX0HF5Q06ATI01X
J6P0Jf][06i^KP1cLg<0NGUi07alO020P800PX:208N7Q`2<S8`0Ti>C09JFUP2KVi/0WYjN0:>SX`2X
Z:P0/K6a0;Bd]02i^KT0_Kfm0<71`@37alL0bl_;0=7Ad@3Cdm<0fm_K0=WIf@3Lg=`0h^;R00<0iNGU
0P3WinL0103]kNd0i^KV0>[ZjP3/k>`20>o_k`0>0>[ZjP3Xj>P0h^;R0=oOg`3Rh^80gMgM0=SHf03@
d=00c<c<0<71`@2n_[h0/[:b0;2`/02YZJT20:JVYP0h0:6QX@2SXj<0YJFU0:VYZ@2WYjL0/[:b0;6a
/@2f][H0]KFe0;Rh^02i^KT0^[Zj0;Vi^@2d];@0/K6a0:ZZZP2UYJD0X:2P09fMW@2KVi/0V9RH09NG
U`2EUID0TY:B092@T02ATI40SXj>08^;R`29RHT0QhN708:2PP20P800NWYj07UiN@1eMGD0Lg=c06i^
KP1/K6`0JVYZ06IVIP1RHV80GUiN05UIF@1EEED0DE5A059BDP1<C4`0@T9203`l?00`<300;2`/02TY
:@0X:2P09bLW02HV9P0W9bL402HV9P@0dLfY00030=7=Z@<09RHV00<09bLW02HV9P0V9RH00`0W9bL0
5P0Y:BT0:RXZ02`/;00`<300=SHf03dm?@16ATH0CTi>05ADE01NGUh0IFEU06QXJ01]KFd0L71`07Ad
M01gMgL0NGUi07moO`25QHD0QXJ608R8R02?Shl209>CT`0D09ZJVP2NWYh0XZ:R0:RXZ02[Zj/0/;2`
0;Jf]P2k^k/0_kno0<K6aP38b<P0c<c<0<k>cP3AdM40dm?C0=_Kf`3Ph>00hn?S0>CTi03WinL20>KV
iP050>c/k03Xj>P0jNWY0>[ZjP3^k^h00P3]kNd20>WYj@0b0>OWi`3Xj>P0inOW0>;RhP3Hf=P0e=CD
0<k>cP36a/H0_[jn0;Zj^P2b/[80[Jf]0:ZZZP2YZJT0Xj>S0:6QX@2SXj<0Z:RX0:NWY`2[Zj/0[jn_
0;>c/`2e]KD0][Jf0;Rh^02j^[X0]kNg0;Jf]P2a/K40Zj^[0:JVYP2QXJ40WinO09fMW@2HV9P0UIFE
09BDU02CTi<0Shn?08b<S02:RXX0Rh^;08R8R024Q8@0PH6107emO@1nOWh0NGUi079bLP1_Kfl206YZ
JP0>06EUI@1TI6@0H61P05UIF@1EEED0DE5A04e=C@18B4P0@T9203hn?P0a<C40;Bd]02XZ:P0X:2P2
02LW9`D09RHV103AcJT000<0dLfY100V9RH402LW9`80:2PX0340:RXZ02`/;00`<300=SHf03hn?P16
ATH0Cdm?05EEE@1OGel0IVIV06a/K01aLG40MWIf07QhN01kNg/0OWin0820P023Ph<0QXJ608Z:RP2>
SXh0Shn?09>CT`2FUYH0WYjN0::RXP2VYZH0Zj^[0:j^[P2a/K40]kNg0;bl_033`l<0`/;20<S8b03<
c<`0clo?0=?Cd`3Hf=P0gMgM0>7Qh@3Ph>00hn?S0>SXj03YjNT0k^k^0>o_k`3`l?00j^[Z0080k>c/
0P3]kNd0403[jn/0j>SX0>_[j`3/k>`0i>CT0=gMg@3Jf]X0d];B0<_;b`34a<@0_[jn0;Zj^P2b/[80
[Zj^0:b/[02WYjL30:BTY0070:JVYP2WYjL0Z:RX0:f][@2d];@0/k>c0;Bd]0020;Jf]P060;Ng]`2e
]KD0/;2`0:ZZZP2TY:@0X:2P0P2KVi/0102IVIT0U9BD09:BTP2@T90208^;R`0I08Z:RP27QhL0Q8B4
0861P@20P800OWin07QhN01dM7@0LG5a06e]K@1[Jf/0IVIV06=SH`1PH600FUYJ05EEE@1BDU80CDe=
04M7A`12@T80?Shn034a<@0/;2`0:RXZ02PX:00502LW9`809RHV103AcJT000<0dLfY00H09RHV02LW
9`0V9RH09RHV02LW9`0V9RH202LW9`0[02PX:00Y:BT0:RXZ02`/;00a<C40=SHf03dm?@15ADD0Cdm?
05EEE@1NGUh0IfMW06YZJP1bLW80N7Qh07moO`20P800Ph>308F5Q@29RHT0RXZ:08b<S02@T900Ti>C
09BDU02JVYX0WIfM0:6QX@2VYZH0Z:RX0:b/[02`/;00/[:b0;Fe]@2l_;`0_kno0<71`@36a/H0alO7
0=;BdP3De=@0fm_K0=cLg0020>GUi@<0inOW01X0kNg]0>o_k`3_knl0l?3`0>_[j`3^k^h0kNg]0>[Z
jP3[jn/0k>c/0>g]k@3YjNT0inOW0>3Ph03Kfm/0d];B0<g=c@39bLT0`/;20;^k^`2i^KT0/K6a0:j^
[P2ZZZX0YJFU0:BTY080XZ:R0140YjNW0:RXZ02_[jl0/K6a0;:b/P2e]KD0]kNg0;Vi^@2g]kL0]KFe
0;2`/02^[Zh0Z:RX0:2PX02MWId0V9RH09VIV@02096AT@0408n?S`2<S8`0R8R808J6QP80Q8B401H0
P82007inOP1lO7`0MgMg07AdM01aLG40JFUY06IVIP1SHf<0GUiN05YJFP1FEUH0De=C04e=C@17AdL0
@d=303hn?P0c<c<0;Bd]02XZ:P0Y:BT0:2PX0P0W9bL402HV9P@0dLfY00030=7=Z@809RHV0P0W9bL0
5@0V9RH09bLW02LW9`0W9bL0:2PX02TY:@0Z:RX0;Bd]038b<P0e=CD0?3`l04I6AP1=CDd0De=C05]K
F`1VIVH0Jf][07EeM@1hN7P0P82008F5Q@0208Z:RP0608b<S02?Shl0T92@09>CT`2DU9@0UIFE0P2K
Vi/0502LW9`0Y:BT0:NWY`2YZJT0Zj^[0;2`/02g]kL0^;Rh0;bl_02o_kl0a<C40<[:bP31`L40b/[:
0=;BdP3Jf]X0gmoO0>7Qh@3WinL0i^KV0P3YjNT07P3_knl0k^k^0>c/k03`l?00j^[Z0>k^kP3YjNT0
k>c/0>WYj@3^k^h0j^[Z0>CTi03WinL0gmoO0=_Kf`3Fe]H0bl_;0<c<c035aLD0`/;20;Zj^P2h^;P0
[Zj^0:ZZZP2VYZH0YJFU09nOW`2QXJ40X:2P0::RXP80Z:RX0180[jn_0;:b/P2d];@0/[:b0;Bd]02c
/k<0];Bd0:f][@2VYZH0Y:BT09jNWP2JVYX0UIFE096AT@2@T900SHf=08V9R@2;Rh/308>3P`0K0861
P@1lO7`0NGUi07AdM01_Kfl0KFe]06QXJ01SHf<0GUiN05YJFP1HF5P0De=C04e=C@19BDT0@d=303hn
?P0e=CD0;Rh^02XZ:P0Y:BT0:2PX02LW9`0V9RH09bLW02HV9P0W9bL09RHV00@0dLfY00030=7=Z@@0
9RHV00<09bLW02HV9P0W9bL00P0W9bL04`0X:2P0:RXZ02d];@0a<C40=SHf03`l?013@d<0Bd];055A
D@1JFUX0HF5Q06QXJ01aLG40NWYj0861P@24Q8@0RXZ:09BDU02BTY800P2CTi<03@2HV9P0UYJF09NG
U`2HV9P0WYjN09nOW`2PX:00YJFU0:NWY`2[Zj/0/;2`0;6a/@2f][H00P2k^k/03@2o_kl0aLG50<C4
a039bLT0c<c<0=?Cd`3IfMT0g=cL0=oOg`3UiND0i^KV0>WYj@3]kNd00P3/k>`00`3^k^h0l?3`0>_[
j`020>k^kP0C0>g]k@3^k^h0jn_[0>c/k03YjNT0inOW0>?Sh`3QhN40fm_K0=;BdP3AdM40cLg=0<[:
bP2o_kl0]kNg0:n_[`2[Zj/0Z:RX0:JVYP020:6QX@040:2PX02OWil0XZ:R0:FUY@80[Jf]0P2_[jl0
3`2b/[80[Zj^0:j^[P2][Jd0YjNW0::RXP2NWYh0UiNG096AT@2BTY80Shn?08j>SP2=SHd0QXJ608F5
Q@020820P080NWYj0140MgMg07AdM01^KVh0JFUY06MWI`1QHF40Fe]K05QHF01CDe<0CDe=04U9B@12
@T80?Shn03Lg=`0^;Rh0:b/[02TY:@0202LW9`0502HV9P0W9bL09RHV02HV9P0W9bL0103AcJT000<0
dLfY100V9RH502LW9`0L02TY:@0Z:RX0;2`/038b<P0e=CD0?Cdm04=3@`1:BTX0D51@05MGE`1OGel0
IVIV06m_K`1fMWH0P82008F5Q@2;Rh/0Shn?09>CT`2HV9P0W9bL09^KV`2IVIT0Vi^K09bLW02MWId0
X:2P0:6QX@80Y:BT00L0Zj^[0;6a/@2b/[80/k>c0;Jf]P2h^;P0^k^k0080`/;200T0alO70<_;b`3=
cLd0e=CD0=KFeP3MgMd0h>3P0>SXj03[jn/00P3Zj^X04@3[jn/0k^k^0>c/k03`l?00k^k^0?3`l03[
jn/0j^[Z0>o_k`3[jn/0inOW0>_[j`3WinL0i^KV0>7Qh@3Hf=P0e]KF0080emOG00D0d=3@0<;2`P2k
^k/0/K6a0:^[Z`020:VYZ@0;0:>SX`2QXJ40WinO09nOW`2RXZ80YJFU0:VYZ@2/[:`0/K6a0;2`/02a
/K400P2^[Zh03@2YZJT0YJFU0:>SX`2LW9`0UiNG09FEU@2>SXh0SHf=08Z:RP29RHT0QHF50820P01n
OWh00P1iNGT04@1gMgL0MGEe079bLP1ZJVX0J6QX065QH@1MGEd0FEUI05ADE01?Cdl0B4Q804A4A00n
?Sh0=cLg02h^;P0[:b/0:BTY00@09bLW0`0V9RH40=7=Z@000`3AcJT602HV9P<09bLW01D0:BTY02XZ
:P0];Bd0<C4a03Hf=P0k>c/0@d=304];B`1=CDd0EEEE05aLG01SHf<0K6a/07EeM@1kNg/0PX:208N7
Q`2ATI40UIFE09NGU`2KVi/00P2PX:004@2OWil0X:2P0::RXP2NWYh0Xj>S0:FUY@2XZ:P0ZZZZ0:^[
Z`2a/K40/;2`0;Jf]P2n_[h0^[Zj0;bl_033`l<0a/K60080b/[:00P0bl_;0=;BdP3EeMD0f][J0=kN
gP3Ti>@0inOW0>[ZjP80k>c/0P3`l?020>o_k`030>_[j`3`l?00kno_0080k>c/01@0kNg]0>_[j`3]
kNd0j^[Z0>SXj03QhN40h>3P0>?Sh`3Ph>00e=CD0<c<c031`L40]KFe0:f][@2[Zj/0YJFU0:BTY02Q
XJ40WinO09fMW@80WinO0P2WYjL09@2[Zj/0[Zj^0:f][@2^[Zh0[Jf]0:^[Z`2ZZZX0Xj>S09^KV`2H
V9P0Shn?08j>SP2<S8`0RHV908F5Q@27QhL0Ph>307alO01iNGT0MWIf07AdM01cLg<0KVi^06QXJ01T
I6@0GEeM05QHF01DE5@0Cdm?04U9B@14A4@0?Shn03Lg=`0_;bl0:b/[02XZ:P0X:2P00P0W9bL402HV
9P@0dLfY00030=7=Z@D09RHV0`0W9bL202PX:00I02XZ:P0/;2`0<C4a03De=@0k>c/0@T9204];B`1>
CTh0De=C05YJFP1PH600IfMW06m_K`1fMWH0O7al08B4Q02<S8`0Ti>C09NGU`2KVi/0XJ6Q0:BTY02V
YZH0YjNW0:RXZ0020:FUY@030:ZZZP2XZ:P0ZZZZ0080Zj^[00P0[jn_0;Bd]02h^;P0^;Rh0;Zj^P2n
_[h0`L710<G5a@80alO700T0b/[:0<o?c`3Bd]80fMWI0=gMg@3Rh^80jNWY0>g]k@3/k>`00P3_knl0
0`3`l?00kno_0?7al@020>o_k`0P0>g]k@3^k^h0k^k^0>g]k@3^k^h0jn_[0?7al@3/k>`0kNg]0>SX
j03UiND0h^;R0=gMg@3?cll0aLG50;^k^`2d];@0ZJVY0:RXZ02TY:@0X:2P09nOW`2MWId0W9bL09jN
WP2OWil0Xj>S0:FUY@2YZJT0[jn_0:b/[02YZJT20:^[Z`0M0::RXP2OWil0UYJF096AT@2?Shl0Rh^;
08J6QP23Ph<0PH6107inOP1kNg/0MGEe07AdM01bLW80Jf][06YZJP1VIVH0GemO05UIF@1EEED0D51@
04Y:BP13@d<0?Shn03Lg=`0`<300:b/[02TY:@0X:2P00P0W9bL402HV9P@0dLfY00030=7=Z@D09RHV
0`0W9bL06@0X:2P0:BTY02/[:`0/;2`0<S8b03Hf=P0k>c/0@d=304Y:BP1?Cdl0DU9B05]KF`1PH600
IFEU06UYJ@1aLG40MGEe0861P@26QXH0SXj>096AT@2KVi/0X:2P0:FUY@2XZ:P00P2[Zj/0102ZZZX0
Zj^[0:VYZ@2YZJT20:b/[0080:^[Z`2^[Zh0/;2`0;>c/`2f][H0^k^k0;no_`30`<020<?3``0>0<G5
a@3:b/X0bl_;0<g=c@3Cdm<0fMWI0>3Ph03QhN40i>CT0>c/k03^k^h0k>c/0>g]k@3`l?020>o_k`04
0>g]k@3_knl0lo?c0>o_k`80l?3`00h0lo?c0?Gem@3dm?@0l?3`0?;blP3YjNT0j>SX0>GUi@3Ng]h0
dM7A0<[:bP32`/80^k^k0;6a/@80ZZZZ00`0XZ:R09jNWP2MWId0WYjN09bLW02NWYh0WinO0:BTY02U
YJD0[:b/0:VYZ@2VYZH20:BTY0070:>SX`2KVi/0V9RH096AT@2=SHd0QXJ608>3P`0207moO`0C07al
O01gMgL0MGEe079bLP1/K6`0JVYZ06ATI01QHF40FUYJ05IFEP1@D500BDU90492@P0l?3`0=cLg02l_
;`0[:b/0:BTY02PX:00302LW9`<09RHV103AcJT000<0dLfY1@0V9RH302LW9`0J02PX:00Y:BT0:RXZ
02`/;00a<C40=SHf03dm?@13@d<0Bd];05=CD`1EEED0FEUI05eMG@1UIFD0J6QX071`L01dM7@0NGUi
0820P026QXH0Shn?09NGU`2LW9`0Xj>S0:NWY`2ZZZX20;2`/0050;:b/P2c/k<0/;2`0;2`/02b/[80
0P2`/;001`2b/[80/k>c0;Jf]P2j^[X0_Kfm0;bl_032`/800P31`L403037alL0b/[:0<_;b`3AdM40
d=3@0=?Cd`3MgMd0h>3P0>OWi`3Vi^H0k>c/0>o_k`80k^k^00@0l?3`0>o_k`3^k^h0lO7a0P3`l?02
0?Cdm0070?Ogm`3emOD0mOGe0?7al@3_knl0kNg]0>SXj0020=oOg`0:0=7Ad@3<c<`0a/K60;Vi^@2_
[jl0[:b/0:RXZ02SXj<0WYjN09ZJVP80VIVI02@0Vi^K09fMW@2QXJ40Xj>S0:FUY@2/[:`0YJFU0:BT
Y02WYjL0XJ6Q09bLW02GUiL0TI6A08Z:RP26QXH0PX:207inOP1kNg/0NWYj07IfMP1bLW80KFe]06UY
J@1VIVH0HV9R05YJFP1EEED0D51@04Y:BP12@T80?Cdm03Lg=`0_;bl0:b/[02TY:@0X:2P202LW9`80
9RHV00<09bLW02HV9P3AcJT00`3AcJT000<0dLfY0`0V9RH00`0W9bL09RHV02LW9`0202LW9`80:2PX
01`0:RXZ02`/;00a<C40=SHf03/k>`12@T80Bd];05EEE@1GEeL0FEUI05aLG01RHV80IfMW06a/K01d
M7@0MgMg07]kN`24Q8@0QhN7096AT@2HV9P0WYjN0:FUY@2YZJT0[Jf]0;Bd]02a/K40/[:b0P2e]KD0
402d];@0][Jf0;:b/P2b/[80];Bd0;Ng]`2i^KT0_;bl0;fm_@2o_kl0`<300<W9b@31`L40alO70<[:
bP3?cll20=?Cd`0Z0=SHf03Jf]X0h^;R0>OWi`3Xj>P0jNWY0>c/k03alO40kNg]0>k^kP3bl_80m_Kf
0?;blP3emOD0m_Kf0?Cdm03hn?P0m?Cd0?_kn`3gmoL0k^k^0>g]k@3Zj^X0inOW0=kNgP3GemL0e]KF
0<k>cP35aLD0^KVi0;Bd]02ZZZX0YjNW0:BTY02QXJ40Vi^K09VIV@2JVYX0W9bL09jNWP2PX:00Xj>S
0`2TY:@20::RXP0J09jNWP2KVi/0UYJF096AT@27QhL0QXJ607moO`1lO7`0N7Qh07=cL`1aLG40KVi^
06YZJP1TI6@0H61P05]KF`1HF5P0D51@04U9B@12@T80?Cdm03Hf=P0`<300:b/[02XZ:P0X:2P202LW
9`@09RHV103AcJT000<0dLfY1P0V9RH202LW9`0Q02PX:00Y:BT0:BTY02`/;00a<C40=CDe03/k>`11
@D40BDU905ADE01HF5P0FUYJ05eMG@1RHV80IFEU06][J`1^KVh0MGEe07]kN`21PH40Q8B408R8R02?
Shl0V9RH09jNWP2XZ:P0ZZZZ0:n_[`2c/k<0^;Rh0;^k^`2i^KT0]KFe00<0]kNg01P0^KVi0;Ng]`2f
][H0^KVi0;^k^`2n_[h0_kno0<;2`P33`l<0`L710<O7a`3>c/h0cLg=0<c<c03?cll0e]KF0=SHf03M
gMd0hN7Q0>KViP3YjNT0j^[Z0>g]k@3/k>`30>g]k@0O0?Cdm03inOT0m_Kf0?Ogm`3jn_X0lo?c0?3`
l03gmoL0kno_0>c/k03Zj^X0hn?S0=cLg03Ng]h0e=CD0=?Cd`3:b/X0a<C40;Jf]P2b/[80Zj^[0:NW
Y`2RXZ80WIfM09^KV`2NWYh0X:2P09^KV`2MWId0X:2P0:FUY@020::RXP0J0:2PX02LW9`0Vi^K09ZJ
VP2BTY80TI6A08b<S023Ph<0Ogmo07IfMP1dM7@0LG5a06i^KP1YJFT0I6AT05iNGP1KFe/0EUIF051@
D01:BTX0@T9203`l?00g=cL0<30`02/[:`0Y:BT302LW9`0402HV9P0W9bL09RHV02HV9P@0dLfY0003
0=7=Z@<09RHV0P0W9bL202HV9P809bLW0P0Y:BT06P0/;2`0<30`03@d=00j>SX0?clo04E5A@1?Cdl0
EEEE05IFEP1KFe/0GUiN06=SH`1/K6`0KFe]079bLP1hN7P0O7al0820P024Q8@0RXZ:09>CT`2HV9P0
WIfM0:NWY`2/[:`0/;2`0P2f][H01`2m_Kd0^k^k0;fm_@2j^[X0^;Rh0;^k^`2j^[X00`2k^k/04@2j
^[X0_Kfm0<;2`P30`<00a<C40<K6aP39bLT0bl_;0=7Ad@3=cLd0dM7A0=?Cd`3Jf]X0fMWI0=gMg@3O
gml0i^KV00<0j>SX00P0k^k^0>g]k@3dm?@0lO7a0?KfmP3dm?@0moOg0?Shn080l_;b00@0jn_[0>c/
k03YjNT0iNGU0P3Shn<04`3Ogml0f=SH0=KFeP3Cdm<0bLW90;no_`2j^[X0/k>c0:b/[02VYZH0WinO
09bLW02KVi/0WIfM09ZJVP2MWId0WinO09jNWP2QXJ400P2LW9`06@2KVi/0VIVI09FEU@2ATI40SHf=
08N7Q`22PX80Ng]k07EeM@1aLG40KFe]06][J`1TI6@0GemO05UIF@1GEeL0Cdm?04U9B@12@T80?Cdm
03Hf=P0`<300:b/[02TY:@0X:2P00P0W9bL402HV9P@0dLfY00030=7=Z@@09RHV00@09bLW02HV9P0V
9RH09bLW0P0X:2P0800Y:BT0:b/[02l_;`0c<c<0>CTi03hn?P14A4@0BDU9051@D01DE5@0F5QH05mO
G`1SHf<0IfMW06][J`1`L700Lg=c07UiN@1lO7`0Ph>308V9R@2?Shl0Ti>C09VIV@2PX:00YZJV0:j^
[P2e]KD0^KVi0;Zj^P2n_[h0`<300P2o_kl20;fm_@080;bl_02k^k/0_[jn0;fm_@32`/80_kno0;jn
_P33`l<20<S8b00>0<_;b`3:b/X0bl_;0=7Ad@3@d=00eMGE0=;BdP3Fe]H0f=SH0=[JfP3Lg=`0h^;R
0>7Qh@3Xj>P20>c/k080l?3`00X0lo?c0?Cdm03gmoL0m?Cd0?3`l03]kNd0jn_[0>[ZjP3Xj>P0iNGU
0P3Shn<03@3Ph>00g]kN0=KFeP3De=@0cLg=0<_;b`32`/80_[jn0;Fe]@2[Zj/0XZ:R09jNWP2MWId0
0P2JVYX07P2KVi/0VYZJ09^KV`2LW9`0Vi^K09NGU`2EUID0Ti>C09:BTP2>SXh0R8R808F5Q@1oOgl0
NWYj07=cL`1^KVh0JVYZ06=SH`1OGel0F5QH05EEE@1@D500BTY:04=3@`0m?Cd0=SHf034a<@0[:b/0
:BTY02PX:0<09bLW0`0V9RH40=7=Z@000`3AcJT302HV9P0302LW9`0V9RH09bLW00809bLW0P0X:2P0
9@0Y:BT0:b/[02l_;`0c<c<0>3Ph03hn?P13@d<0AdM704i>CP1BDU80EUIF05]KF`1QHF40IVIV06YZ
JP1_Kfl0Lg=c07MgM`1jNWX0P82008>3P`28R8P0S8b<09BDU02JVYX0WinO0:RXZ02_[jl0/k>c0;Fe
]@2k^k/0`L710<?3``32`/80a<C40<;2`P33`l<00P2o_kl02P32`/80`<300;jn_P31`L40`l?30<;2
`P37alL0b<S80<W9b@3:b/X20<g=c@0>0=;BdP3Cdm<0clo?0<o?c`3Cdm<0f=SH0=[JfP3Ogml0hn?S
0>SXj03Vi^H0k>c/0>[ZjP3_knl20??cl`040?3`l03_knl0kno_0>WYj@80i^KV01L0i>CT0>GUi@3T
i>@0iNGU0>CTi03Ng]h0fMWI0=?Cd`3AdM40clo?0<G5a@2m_Kd0^KVi0;Fe]@2ZZZX0Xj>S09nOW`2K
Vi/0V9RH09NGU`2HV9P0UYJF09FEU@0209>CT`0G096AT@2@T900Shn?08Z:RP25QHD0Q8B407inOP1f
MWH0Kfm_06][J`1TI6@0GemO05QHF01DE5@0CTi>04M7A`11@D40?3`l03Hf=P0`<300:b/[02TY:@0X
:2P0100W9bL202HV9P@0dLfY00030=7=Z@0602DU9@0V9RH09RHV02HV9P0W9bL09RHV0`0W9bL0<00X
:2P0:BTY02XZ:P0_;bl0<S8b03Ph>00m?Cd0@41004I6AP1<C4`0DE5A05EEE@1HF5P0HF5Q06=SH`1U
IFD0JVYZ071`L01dM7@0MgMg07moO`20P800QXJ608Z:RP2ATI40UYJF09ZJVP2RXZ80ZJVY0;6a/@2f
][H0^k^k0<30`033`l<0a<C40<?3``34a<@0`/;20<71`@32`/80`<300<;2`P30`<00`/;20<71`@30
`<00aLG50<g=c@80bl_;00L0d=3@0<c<c03=cLd0dm?C0<o?c`3=cLd0d=3@0080d];B00@0fMWI0=cL
g03Ogml0iNGU0P3YjNT00`3^k^h0k>c/0>_[j`030>k^kP0;0>c/k03Zj^X0j^[Z0>;RhP3Ti>@0inOW
0>KViP3Rh^80h>3P0=_Kf`3GemL00P3Cdm<02@3@d=00a<C40;Zj^P2h^;P0[Jf]0:ZZZP2WYjL0WinO
09VIV@0209BDU080TY:B01T0TI6A092@T02>SXh0Rh^;08f=S@2:RXX0QhN708>3P`1oOgl0N7Qh07=c
L`1^KVh0IVIV05iNGP1IFET0De=C04m?C`17AdL0@T9203`l?00f=SH0<30`02/[:`0Y:BT0:2PX0080
9bLW100V9RH40=7=Z@000`3AcJT702HV9P809bLW03X0:2PX02TY:@0[:b/0;Rh^038b<P0g=cL0>c/k
03lo?`15ADD0BDU904m?C`1BDU80EeMG05aLG01QHF40IVIV06YZJP1^KVh0MGEe07MgM`1iNGT0OWin
0820P022PX80R8R808b<S02GUiL0VYZJ0::RXP2TY:@0[:b/0;Fe]@2h^;P0`<300<C4a035aLD0b/[:
0<K6aP35aLD0a<C40<G5a@36a/H0`L710<;2`P34a<@0`L710<G5a@39bLT0alO70<S8b03;bl/0b/[:
0<O7a`39bLT0cLg=0<k>cP3:b/X0bl_;0P3@d=001@3GemL0f=SH0=gMg@3Ti>@0inOW00<0jNWY00P0
i^KV0>_[j`3_knl0jNWY0>c/k03Xj>P0i^KV0>SXj080j^[Z00<0i>CT0>GUi@3Ng]h00P3Hf=P0403E
eMD0e=CD0<[:bP33`l<0`<300;Zj^P2f][H0[Jf]0:FUY@2OWil0V9RH096AT@2?Shl0S8b<08^;R`2:
RXX208^;R`0E08V9R@27QhL0QXJ608:2PP21PH40Ng]k07EeM@1`L700IfMW05mOG`1HF5P0E5AD04e=
C@16ATH0?clo03/k>`0e=CD0<30`02/[:`0Y:BT0:2PX00809bLW0`0V9RH00`0W9bL0dLfY0=7=Z@02
0=7=Z@000`3AcJT502HV9P809bLW02@09RHV02LW9`0X:2P0:BTY02XZ:P0];Bd0<C4a03Hf=P0j>SX0
?clo0492@P17AdL0C4a<051@D01EEED0FUYJ05iNGP1SHf<0JFUY06e]K@1eMGD0OGem07QhN01jNWX0
N7Qh07inOP23Ph<0RXZ:08n?S`2FUYH0VIVI09jNWP2TY:@0ZZZZ0;:b/P2j^[X20;jn_P040<G5a@37
alL0alO70<[:bP80a/K60P34a<@03@32`/80`l?30<K6aP36a/H0c/k>0<S8b03:b/X0c/k>0<O7a`36
a/H0alO70<S8b03:b/X00`3<c<`01P3?cll0e=CD0=KFeP3Ng]h0h>3P0>?Sh`80inOW00L0i^KV0>[Z
jP3YjNT0k>c/0>KViP3YjNT0i^KV0080iNGU0P3Ti>@05P3Rh^80g]kN0=kNgP3Kfm/0f=SH0=CDe03A
dM40b/[:0<C4a02j^[X0][Jf0;2`/02YZJT0XJ6Q09^KV`2FUYH0S8b<08Z:RP27QhL0QHF508>3P`24
Q8@208>3P`0D0861P@20P800OWin07]kN`1eMGD0Lg=c06UYJ@1QHF40FUYJ05EEE@1>CTh0ATI60410
@00j>SX0=CDe02l_;`0[:b/0:BTY02LW9`0X:2P202LW9`<09RHV103AcJT000<0dLfY100V9RH06`0W
9bL09RHV02LW9`0V9RH09bLW02PX:00Y:BT0:RXZ02`/;00`<300=CDe03Ti>@0o?cl0@T9204I6AP1<
C4`0Cdm?05=CD`1HF5P0GEeM065QH@1UIFD0JVYZ071`L01bLW80MWIf07QhN00207]kN`0G07inOP21
PH40R8R808b<S02GUiL0W9bL0:6QX@2UYJD0ZJVY0;>c/`2g]kL0^k^k0<;2`P36a/H0alO70<S8b03:
b/X0b<S80<c<c037alL0a/K60<G5a@32`/800P34a<@00`35aLD0b<S80<_;b`020<[:bP090<C4a038
b<P0b<S80<S8b039bLT0c/k>0<c<c03>c/h0d];B0080e]KF0140fm_K0=oOg`3MgMd0hN7Q0>KViP3X
j>P0inOW0>SXj03Vi^H0j>SX0>CTi03WinL0i^KV0>GUi@3Ogml0i>CT0=gMg@020=_Kf`0B0=KFeP3D
e=@0dm?C0<[:bP34a<@0`l?30;Rh^02d];@0Z:RX09nOW`2IVIT0Ti>C08b<S027QhL0PH6107moO`1m
OGd0OWin0`1lO7`207UiN@0?07MgM`1bLW80Jf][06ATI01MGEd0EEEE04e=C@16ATH0@41003Xj>P0d
=3@0;Rh^02XZ:P0Y:BT0:2PX00809bLW100V9RH40=7=Z@000`3AcJT00`0V9RH09bLW02HV9P0202HV
9P@09bLW01T0:2PX02TY:@0Z:RX0;2`/030`<00d=3@0>3Ph03`l?010@400ADE504a<C01>CTh0E5AD
05UIF@1MGEd0GemO06=SH`1XJ6P0JVYZ06i^KP1cLg<0MgMg07alO01kNg/0OGem0080PH6100X0QhN7
08j>SP2EUID0V9RH09nOW`2WYjL0ZZZZ0;>c/`2h^;P0_;bl0P32`/801`35aLD0bLW90<c<c03=cLd0
bLW90<S8b03:b/X00P39bLT01038b<P0aLG50<W9b@36a/H20<[:bP030<C4a038b<P0bLW90080alO7
0100b/[:0<k>cP3<c<`0cLg=0<o?c`3AdM40e=CD0=gMg@3Kfm/0hN7Q0>;RhP3Vi^H0iNGU0>OWi`3V
i^H0j^[Z0P3Xj>P01`3UiND0i>CT0>?Sh`3QhN40hn?S0=gMg@3Ng]h00P3EeMD04@3@d=00c<c<0<W9
b@36a/H0`l?30;Zj^P2][Jd0YZJV09ZJVP2DU9@0SHf=08Z:RP22PX80OGem07alO01iNGT0Ng]k0080
NGUi0140N7Qh07IfMP1cLg<0Kfm_06UYJ@1TI6@0GemO05UIF@1?Cdl0B4Q803lo?`0j>SX0=3@d02h^
;P0Z:RX0:BTY02PX:00402LW9`809RHV103AcJT000<0dLfY1P0V9RH302LW9`80:2PX01D0:RXZ02`/
;00^;Rh0=3@d03Lg=`0k>c/0@41004E5A@19BDT0CTi>055AD@1GEeL0FUYJ05eMG@1QHF40I6AT06i^
KP1/K6`0Kfm_079bLP1dM7@00P1lO7`04@1nOWh0PH6108:2PP27QhL0SHf=096AT@2KVi/0XJ6Q0:>S
X`2VYZH0ZZZZ0;>c/`2i^KT0_[jn0<K6aP38b<P0alO70080c/k>00d0c<c<0<g=c@39bLT0alO70<W9
b@37alL0aLG50<W9b@3:b/X0bLW90<K6aP38b<P0bLW90080b/[:01L0a/K60<[:bP3;bl/0bl_;0<[:
bP3;bl/0clo?0=?Cd`3IfMT0f][J0=gMg@3Lg=`0h>3P0>7Qh@3Shn<0iNGU0>SXj03Vi^H0iNGU0>?S
h`3Rh^80iNGU0>?Sh`020>;RhP0V0=kNgP3IfMT0e=CD0<o?c`3<c<`0alO70<?3``30`<00]kNg0:n_
[`2WYjL0W9bL09:BTP2;Rh/0QhN70820P01iNGT0N7Qh07EeM@1gMgL0M7Ad079bLP1`L700Kfm_06a/
K01WIfL0HF5Q05aLG01GEeL0DE5A04U9B@11@D40>CTi03<c<`0^;Rh0:RXZ02TY:@0X:2P202LW9`@0
9RHV103AcJT000<0dLfY1`0V9RH302LW9`0D02PX:00Y:BT0:b/[02h^;P0c<c<0=cLg03`l?010@400
@T9204U9B@1;Bd/0CTi>05ADE01IFET0G5aL05iNGP1RHV80KVi^06][J`1_Kfl2079bLP0@07MgM`1i
NGT0PH610861P@1nOWh0Q8B408F5Q@28R8P0TI6A09FEU@2NWYh0XZ:R0:JVYP2YZJT0/[:b0;fm_@80
a<C400D0a/K60<_;b`3;bl/0c<c<0<g=c@020<k>cP040<O7a`39bLT0b/[:0<g=c@80aLG50P38b<P0
203:b/X0aLG50<C4a034a<@0aLG50<O7a`3<c<`0cLg=0P3<c<`20<o?c`070=CDe03Jf]X0gMgM0=oO
g`3Lg=`0iNGU0>7Qh@020>KViP0J0>CTi03UiND0jNWY0>?Sh`3Ogml0h>3P0=cLg03QhN40f=SH0=WI
f@3Fe]H0c/k>0<[:bP39bLT0`l?30<;2`P2i^KT0/K6a0:BTY02KVi/0Ti>C08Z:RP21PH40Ogmo07Ui
N@1bLW82071`L00B06i^KP1]KFd0JFUY06MWI`1SHf<0GemO05YJFP1CDe<0D51@04Q8B010@400>SXj
03<c<`0];Bd0:RXZ02TY:@0X:2P09bLW1@0V9RH40=7=Z@000`3AcJT502HV9P0302LW9`0V9RH09RHV
00809bLW01X0:2PX02TY:@0Z:RX0;Bd]038b<P0f=SH0>SXj03hn?P13@d<0AdM704];B`1?Cdl0EEEE
05MGE`1JFUX0GemO069RHP1VIVH0IfMW06a/K01`L700MGEe07=cL`1jNWX0OWin07alO080PX:201P0
Q8B408F5Q@2;Rh/0T92@09:BTP2GUiL0XZ:R0:BTY02ZZZX0/K6a0;Bd]02n_[h0`L710<?3``36a/H0
b/[:0<g=c@3;bl/0cLg=0<W9b@3:b/X0c<c<0<[:bP38b<P20<[:bP0N0<W9b@34a<@0a<C40<G5a@37
alL0a<C40<S8b035aLD0alO70<S8b03:b/X0b<S80<_;b`3=cLd0clo?0=OGe`3Jf]X0g=cL0>3Ph03Q
hN40h^;R0>3Ph03Ti>@0hn?S0>;RhP3Shn<0hN7Q0>3Ph03Ogml0g=cL0P3Hf=P08@3EeMD0d];B0<k>
cP3;bl/0alO70<71`@2l_;`0^KVi0:f][@2UYJD0Vi^K09:BTP28R8P0PX:207emO@1fMWH0LW9b06e]
K@1ZJVX0IfMW06ATI01RHV80GemO05UIF@1FEUH0De=C04a<C015ADD0?clo03Xj>P0a<C40;2`/02TY
:@0202PX:00302HV9P0W9bL09RHV00<09RHV103AcJT000<0dLfY1P0V9RH402LW9`80:2PX01@0:RXZ
02`/;00a<C40=SHf03Xj>P0m?Cd0@d=304E5A@19BDT0CDe=059BDP1DE5@0F5QH05iNGP1QHF40IFEU
06IVIP1[Jf/0L71`075aL@80MGEe00@0NWYj07alO01nOWh0Q8B40P26QXH05@28R8P0S8b<08j>SP2B
TY80UYJF09nOW`2TY:@0ZJVY0:ZZZP2c/k<0^;Rh0;bl_030`<00aLG50<c<c03:b/X0bl_;0=7Ad@3@
d=00c/k>0<g=c@020<[:bP040<W9b@35aLD0b<S80<G5a@80alO700L0aLG50<K6aP38b<P0`/;20<C4
a035aLD0alO70080bLW900<0alO70<g=c@3Cdm<00P3Hf=P00`3Jf]X0gMgM0=gMg@020>;RhP030>7Q
h@3Shn<0h^;R0080h>3P02D0g]kN0=cLg03IfMT0emOG0=GEe@3Bd]80clo?0<W9b@35aLD0_kno0;bl
_02g]kL0[Zj^0:JVYP2KVi/0SXj>08N7Q`22PX80NGUi075aL@1_Kfl0J6QX06EUI@1RHV80GEeM05]K
F`1FEUH0DU9B04m?C`1:BTX0@T9203`l?00h>3P0<C4a02`/;00Y:BT0:2PX00809bLW0P0V9RH00`0W
9bL09RHV02HV9P040=7=Z@000`3AcJT802HV9P809bLW0P0X:2P06@0Z:RX0;2`/02l_;`0e=CD0>SXj
03`l?011@D40ATI604U9B@1>CTh0D51@05IFEP1HF5P0GEeM065QH@1SHf<0IfMW06QXJ01/K6`0KVi^
079bLP1eMGD0NWYj07]kN`1nOWh00P23Ph<04@25QHD0Q8B408N7Q`2<S8`0SHf=09:BTP2IVIT0W9bL
0::RXP2VYZH0[Jf]0;2`/02c/k<0^KVi0<;2`P35aLD0bl_;0080c/k>00<0cLg=0<o?c`3?cll00P3<
c<`20<O7a`0H0<G5a@36a/H0a/K60<O7a`38b<P0a/K60<?3``35aLD0a<C40<?3``34a<@0alO70<G5
a@38b<P0b/[:0<o?c`3@d=00dm?C0=CDe03Hf=P0f][J0=WIf@3Ogml0hN7Q0`3Ogml01P3MgMd0gmoO
0=[JfP3Lg=`0f][J0=7Ad@80c/k>01h0bLW90<K6aP33`l<0_;bl0;Rh^02e]KD0Zj^[09jNWP2EUID0
SHf=08J6QP1kNg/0MGEe06i^KP1[Jf/0IFEU05eMG@1KFe/0F5QH059BDP1?Cdl0Bd];04I6AP11@D40
>SXj03Lg=`0`<300:b/[02TY:@0X:2P402LW9`<09RHV103AcJT000<0dLfY1P0V9RH402LW9`0P02PX
:00Y:BT0:RXZ02/[:`0^;Rh0=CDe03Xj>P0k>c/0@D5104A4A018B4P0C4a<04i>CP1CDe<0EUIF05aL
G01NGUh0HF5Q06ATI01ZJVX0Jf][06e]K@1^KVh0Lg=c07IfMP1eMGD0NWYj07alO01oOgl0PX:208J6
QP29RHT208R8R080Shn?00d0V9RH09ZJVP2PX:00YJFU0:^[Z`2ZZZX0/;2`0;Ng]`2k^k/0aLG50<[:
bP3=cLd0clo?00<0d=3@00`0cLg=0<c<c03=cLd0b<S80<O7a`34a<@0b/[:0<O7a`33`l<0b<S80<W9
b@35aLD30<?3``0E0<30`035aLD0a/K60<O7a`38b<P0clo?0<k>cP3AdM40e=CD0=GEe@3Fe]H0g]kN
0=oOg`3Ng]h0g=cL0=oOg`3IfMT0gMgM0=SHf03IfMT0eMGE0080cLg=01h0b/[:0<G5a@30`<00`L71
0;bl_02e]KD0/K6a0:f][@2TY:@0UYJF08j>SP24Q8@0O7al079bLP1]KFd0IFEU05mOG`1JFUX0EEEE
051@D01;Bd/0ATI60492@P0n?Sh0>3Ph03@d=00_;bl0:b/[02TY:@0X:2P302LW9`@09RHV103AcJT0
00<0dLfY200V9RH302LW9`0O02PX:00Z:RX0:RXZ02h^;P0c<c<0>SXj03`l?011@D40A4A404M7A`1:
BTX0CDe=051@D01EEED0FEUI05]KF`1PH600HV9R06MWI`1[Jf/0K6a/06e]K@1aLG40Lg=c07IfMP1h
N7P0NWYj07inOP1mOGd0PH6108F5Q@0208R8R00B08b<S02=SHd0T92@09:BTP2JVYX0WIfM0:6QX@2U
YJD0Zj^[0;:b/P2c/k<0`<300;fm_@3;bl/0bLW90<c<c03>c/h0dM7A0P3@d=001`3>c/h0bl_;0<[:
bP39bLT0a/K60<G5a@32`/800P33`l<02P34a<@0`<300<;2`P2m_Kd0_kno0<30`031`L40a<C40<G5
a@37alL20<_;b`030<o?c`3Bd]80dm?C0080emOG02L0f=SH0=WIf@3GemL0gMgM0=OGe`3Hf=P0dm?C
0=CDe03>c/h0c<c<0<_;b`34a<@0`<300;no_`2j^[X0][Jf0;>c/`2a/K40ZJVY0:2PX02IVIT0Rh^;
0820P01gMgL0LW9b06QXJ01QHF40Fe]K05ADE01?Cdl0BDU904E5A@11@D40>c/k03Hf=P0c<c<0;Rh^
02XZ:P0Y:BT0100W9bL402HV9P@0dLfY00030=7=Z@T09RHV0P0W9bL0500X:2P0:BTY02/[:`0];Bd0
<C4a03`l?00o?cl0@D5104E5A@17AdL0BTY:04m?C`1@D500De=C05MGE`1JFUX0H61P065QH@1VIVH0
J6QX0P1]KFd03@1_Kfl0LG5a079bLP1dM7@0MWIf07UiN@1mOGd0P82008>3P`26QXH0QhN708^;R`2>
SXh00P2@T90209BDU00>09ZJVP2PX:00Y:BT0:RXZ02/[:`0]kNg0;Zj^P2m_Kd0aLG50<K6aP3=cLd0
clo?0=7Ad@3Bd]820<k>cP030<W9b@3:b/X0a/K60080a<C40`30`<020<71`@050;jn_P2l_;`0_kno
0;bl_02n_[h00P34a<@02@33`l<0a<C40<W9b@3;bl/0c/k>0=;BdP3?cll0d=3@0=?Cd`020=;BdP0?
0=GEe@3GemL0d];B0=7Ad@3>c/h0d=3@0<[:bP32`/80`L710;bl_02h^;P0]kNg0;Bd]02`/;00ZZZZ
0080Y:BT0140UYJF08V9R@1nOWh0MgMg06e]K@1TI6@0GemO05IFEP1?Cdl0B4Q804A4A00l?3`0>CTi
03@d=00a<C40;2`/02XZ:P0202PX:0@09bLW0`0V9RH40=7=Z@000`3AcJT802HV9P809bLW01X0:2PX
02LW9`0Y:BT0:RXZ02`/;00_;bl0>SXj03lo?`12@T80ATI604Q8B01:BTX0Bd];051@D01BDU80EUIF
05MGE`1LG5`0GemO06=SH`1UIFD0JFUY06YZJP1]KFd0L71`07=cL`80MgMg00L0MWIf07UiN@1nOWh0
Ogmo08>3P`27QhL0RHV90080SXj>01X0Shn?08f=S@2@T900UIFE09RHV02NWYh0Xj>S0:VYZ@2][Jd0
];Bd0;Ng]`2n_[h0aLG50<K6aP3<c<`0bl_;0=3@d03AdM40dm?C0=3@d03>c/h0c<c<0<[:bP35aLD0
a<C40<30`080_Kfm0100_[jn0;^k^`2l_;`0_;bl0;Zj^P2l_;`0_[jn0;fm_@31`L40_kno0<30`034
a<@0alO70<S8b039bLT0b/[:0P3;bl/08`3>c/h0d=3@0<o?c`3@d=00clo?0<c<c03;bl/0aLG50<;2
`P30`<00_[jn0;Vi^@2c/k<0];Bd0:j^[P2][Jd0YjNW0:>SX`2LW9`0TI6A08R8R021PH40MGEe06][
J`1SHf<0FUYJ055AD@18B4P0@T9203dm?@0g=cL0<c<c02l_;`0[:b/0:BTY0080:2PX0P0W9bL202HV
9P0302LW9`0V9RH09RHV00@0dLfY00030=7=Z@P09RHV0`0W9bL202PX:00G02TY:@0/;2`0;bl_03Hf
=P0n?Sh0@d=304U9B@17AdL0BDU904a<C01@D500De=C05EEE@1HF5P0FUYJ05eMG@1RHV80IFEU06UY
J@1ZJVX0KFe]071`L01bLW800`1gMgL01P1jNWX0Ng]k07moO`20P800PX:208F5Q@80S8b<0P2=SHd0
1`2>SXh0TI6A09BDU02KVi/0WinO0:>SX`2YZJT00P2b/[804`2d];@0^[Zj0<30`035aLD0bl_;0<c<
c03?cll0c<c<0<o?c`3@d=00bLW90<[:bP37alL0a<C40<71`@2o_kl0^k^k0;fm_@2j^[X00P2o_kl0
3P2m_Kd0^k^k0;^k^`2h^;P0^k^k0;fm_@30`<00_kno0<71`@32`/80a<C40<O7a`35aLD0alO70`38
b<P08036a/H0bLW90<g=c@36a/H0b<S80<;2`P2o_kl0_Kfm0;Vi^@2g]kL0/k>c0:n_[`2[Zj/0YZJV
0::RXP2LW9`0U9BD08b<S025QHD0N7Qh071`L01WIfL0FEUI051@D019BDT0@T9203`l?00g=cL0<S8b
02h^;P0[:b/0:BTY0P0X:2P202LW9`D09RHV103AcJT000<0dLfY200V9RH402LW9`0]02PX:00Y:BT0
:b/[02h^;P0c<c<0?3`l04A4A018B4P0BDU904];B`1=CDd0D51@059BDP1DE5@0EUIF05UIF@1LG5`0
GUiN065QH@1VIVH0J6QX06][J`1^KVh0Kfm_075aL@1bLW80M7Ad07YjNP1hN7P0Ng]k07emO@21PH40
Ph>308J6QP27QhL0S8b<08n?S`2BTY80TI6A092@T02DU9@0UiNG09^KV`2QXJ40ZJVY0080/;2`00L0
];Bd0;Jf]P2k^k/0a<C40<G5a@3;bl/0c<c<0080cLg=00H0bl_;0<c<c038b<P0aLG50<?3``32`/82
0;bl_080^[Zj00P0_[jn0;Zj^P2j^[X0^k^k0;Rh^02f][H0]kNg0;Rh^0<0_Kfm0P2n_[h20<71`@80
`/;200<0a<C40<K6aP33`l<00P37alL07032`/80`L710;jn_P2n_[h0^[Zj0;Bd]02e]KD0[Jf]0:ZZ
ZP2UYJD0XJ6Q09VIV@2CTi<0S8b<08J6QP1kNg/0L71`06YZJP1NGUh0DU9B04];B`14A4@0?3`l03Hf
=P0`<300;Bd]02XZ:P0X:2P302LW9`0302HV9P0W9bL09RHV00809RHV00<09bLW0=7=Z@3AcJT00P3A
cJT000<0dLfY1`0V9RH0100W9bL09RHV02HV9P0W9bL302PX:00@02XZ:P0^;Rh0<C4a03Lg=`14A4@0
AdM704Y:BP1>CTh0Cdm?051@D01BDU80EEEE05QHF01IFET0G5aL05eMG@80HF5Q00H0IFEU06MWI`1Y
JFT0KFe]06m_K`1`L702079bLP0507QhN01iNGT0N7Qh07YjNP1mOGd00P24Q8@00`27QhL0R8R808f=
S@0208n?S`<0U9BD00/0VIVI0:2PX02VYZH0ZZZZ0:j^[P2`/;00/[:b0;Zj^P2n_[h0aLG50<O7a`02
0<[:bP090<_;b`3>c/h0bLW90<g=c@3:b/X0`L710;no_`2j^[X0^k^k0080^;Rh00<0^k^k0;bl_02l
_;`00P2e]KD02P2a/K40];Bd0;fm_@2l_;`0^[Zj0;Vi^@2l_;`0^k^k0;Zj^P2l_;`20;^k^`070<;2
`P36a/H0a<C40<;2`P33`l<0_Kfm0;jn_P020;Zj^P0G0;2`/02a/K40ZJVY0:JVYP2SXj<0XJ6Q09RH
V02@T900Rh^;08F5Q@1kNg/0LW9b06][J`1RHV80EEEE04a<C014A4@0?3`l03De=@0_;bl0;2`/02TY
:@0X:2P00`0W9bL202HV9P0402LW9`0V9RH09RHV02HV9P@0dLfY00030=7=Z@L09RHV00<09bLW02HV
9P0V9RH00`0W9bL0200X:2P0:RXZ02d];@0_;bl0=3@d0451@@16ATH0BTY:0P1>CTh02`1@D500De=C
05IFEP1GEeL0FEUI05iNGP1MGEd0HF5Q069RHP1TI6@0IFEU00<0JFUY00H0KFe]075aL@1aLG40MGEe
07IfMP1kNg/207YjNP0G07alO022PX80QXJ608N7Q`28R8P0RHV908j>SP2BTY80UiNG09RHV02GUiL0
W9bL0::RXP2WYjL0YZJV0:b/[02^[Zh0/[:b0;Fe]@2k^k/0_[jn0<;2`P39bLT00P38b<P03@3<c<`0
bLW90<K6aP36a/H0`/;20<71`@2m_Kd0_;bl0;fm_@2g]kL0]KFe0;Rh^02f][H00P2c/k<0102`/;00
/K6a0;Bd]02e]KD20;Jf]P040;Ng]`2e]KD0]kNg0;Jf]P80^;Rh00@0^k^k0;no_`2o_kl0_kno0P2l
_;`06@2g]kL0/[:b0:j^[P2/[:`0Z:RX0:FUY@2PX:00VYZJ09FEU@2@T900R8R808B4Q01iNGT0L71`
06][J`1OGel0EUIF04a<C014A4@0>c/k03<c<`0^;Rh0:b/[02XZ:P0X:2P00`0W9bL602HV9P@0dLfY
00030=7=Z@D09RHV00@09bLW02HV9P0V9RH09RHV100W9bL0300X:2P0:RXZ02/[:`0_;bl0<S8b03dm
?@16ATH0BTY:04a<C01?Cdl0DE5A05ADE080EeMG00L0FEUI05]KF`1OGel0H61P065QH@1SHf<0I6AT
0080IfMW00L0JVYZ06e]K@1`L700L71`07=cL`1dM7@0N7Qh00<0NWYj01D0O7al07moO`28R8P0QXJ6
08Z:RP29RHT0T92@09FEU@2FUYH0UiNG09bLW02MWId0XJ6Q0:BTY02WYjL0[Jf]0:n_[`2`/;00/k>c
0;Bd]02m_Kd00P30`<002035aLD0cLg=0<c<c03;bl/0alO70<S8b032`/80`<300P2k^k/0102i^KT0
]kNg0;Fe]@2c/k<20;:b/P0:0;6a/@2][Jd0[Zj^0;:b/P2c/k<0/[:b0;Bd]02f][H0/[:b0;Bd]080
]kNg00<0^[Zj0;no_`2n_[h00P2j^[X01@2g]kL0]KFe0;:b/P2`/;00[:b/0080Xj>S01H0X:2P09VI
V@2EUID0S8b<08F5Q@1oOgl0N7Qh06m_K`1[Jf/0GUiN05EEE@1;Bd/0@T9203Xj>P0c<c<0;Rh^02/[
:`0Y:BT0:2PX02LW9`0V9RH09bLW1P0V9RH40=7=Z@000`3AcJT:02HV9P<09bLW00h0:2PX02TY:@0[
:b/0;Rh^034a<@0f=SH0A4A404U9B@1<C4`0D51@059BDP1CDe<0EUIF05MGE`80FEUI00@0Fe]K05iN
GP1OGel0H61P0P1TI6@00`1VIVH0IfMW06QXJ00206e]K@0D075aL@1dM7@0M7Ad07IfMP1iNGT0O7al
07YjNP1mOGd0OWin08>3P`26QXH0QhN708^;R`2BTY80TI6A09FEU@2JVYX0Vi^K09jNWP2QXJ420:>S
X`080:RXZ02ZZZX0[jn_0:n_[`2c/k<0][Jf0;Zj^P31`L420<C4a0090<S8b037alL0alO70<C4a032
`/80`l?30;jn_P2m_Kd0]kNg00<0/k>c00H0[Jf]0:b/[02[Zj/0ZZZZ0:^[Z`2^[Zh30;6a/@040;Bd
]02_[jl0/;2`0;>c/`@0]kNg00<0][Jf0;2`/02b/[800P2^[Zh05@2ZZZX0XZ:R09bLW02HV9P0UIFE
08n?S`28R8P0PH6107]kN`1eMGD0K6a/06EUI@1KFe/0DE5A04Q8B010@400>CTi034a<@0/;2`0:RXZ
02TY:@0302LW9`809RHV00<09bLW02HV9P0V9RH00P0V9RH40=7=Z@000`3AcJT802HV9P0302LW9`0V
9RH09RHV00<09bLW00T0:2PX02TY:@0/;2`0;bl_03@d=00m?Cd0ATI604e=C@1@D5000P1CDe<02P1E
EED0FEUI05UIF@1HF5P0FEUI05]KF`1MGEd0GemO069RHP1SHf<206EUI@0906QXJ01ZJVX0K6a/06i^
KP1`L700Lg=c07EeM@1iNGT0N7Qh0080Ng]k00X0OGem07moO`1oOgl0QXJ608R8R02;Rh/0S8b<096A
T@2EUID0V9RH0P2LW9`02`2MWId0WYjN0::RXP2VYZH0YjNW0:^[Z`2/[:`0[Jf]0;Fe]@2g]kL0_;bl
0080`L7100L0a<C40<K6aP37alL0`l?30<71`@2l_;`0_Kfm0080][Jf00L0/[:b0:n_[`2_[jl0ZZZZ
0:NWY`2VYZH0ZJVY0080Zj^[02@0[:b/0:VYZ@2_[jl0/;2`0:j^[P2[Zj/0ZZZZ0:j^[P2/[:`0/;2`
0;>c/`2^[Zh0Zj^[0:NWY`2XZ:P0YJFU0::RXP2LW9`0UYJF096AT@2>SXh0Q8B407inOP1jNWX0Kfm_
06QXJ01QHF40F5QH04i>CP16ATH0?Shn03Hf=P0_;bl0:b/[02TY:@0X:2P302LW9`0302HV9P0W9bL0
9RHV00@09RHV103AcJT000<0dLfY00<09BDU02HV9P0V9RH01@0V9RH00`0W9bL09RHV02HV9P0402LW
9`0802TY:@0[:b/0;Bd]034a<@0g=cL0@D5104a<C01BDU8205IFEP0605MGE`1HF5P0FEUI05QHF01I
FET0GEeM0P1LG5`0101PH600Hf=S069RHP1VIVH206MWI`0606UYJ@1/K6`0KFe]06m_K`1cLg<0NGUi
0P1hN7P03P1iNGT0NWYj07alO01nOWh0Ogmo08F5Q@28R8P0S8b<08Z:RP2@T900U9BD09RHV02KVi/0
V9RH0P2MWId03@2PX:00XJ6Q0::RXP2VYZH0Zj^[0:b/[02^[Zh0/;2`0;Jf]P2j^[X0_Kfm0<30`032
`/800P33`l<01`32`/80`<300;fm_@2i^KT0/[:b0;2`/02^[Zh00P2UYJD02`2VYZH0Z:RX0:NWY`2V
YZH0YjNW0:ZZZP2WYjL0Z:RX0:VYZ@2ZZZX0ZJVY0080Z:RX01/0ZJVY0:RXZ02ZZZX0YjNW0:JVYP2R
XZ80WinO09ZJVP2IVIT0Ti>C08f=S@26QXH0P82007YjNP1dM7@0Jf][06=SH`1NGUh0De=C04Y:BP11
@D40>SXj03<c<`0^;Rh0:RXZ02TY:@0X:2P00`0W9bL702HV9P@0dLfY00030=7=Z@T09RHV1@0W9bL2
02PX:00802TY:@0[:b/0<30`03De=@0k>c/0CTi>05IFEP1HF5P205YJFP0705UIF@1JFUX0FUYJ05UI
F@1LG5`0GUiN05eMG@02061PH00306=SH`1TI6@0I6AT0080J6QX0`1/K6`04P1`L700LW9b07IfMP1i
NGT0MgMg07UiN@1kNg/0OWin07emO@1oOgl0Q8B408F5Q@29RHT0S8b<08f=S@2?Shl0UYJF09NGU`<0
Vi^K00H0WIfM09jNWP2PX:00Y:BT0:FUY@2WYjL20:VYZ@040:n_[`2b/[80][Jf0;bl_080`<3000l0
`L710<;2`P2n_[h0^[Zj0;Jf]P2d];@0/[:b0:VYZ@2SXj<0X:2P0:>SX`2TY:@0Z:RX0:FUY@2XZ:P0
0P2WYjL01`2VYZH0YJFU0:BTY02PX:00XZ:R0:2PX02QXJ400P2SXj<0502OWil0W9bL09RHV02FUYH0
Ti>C08b<S028R8P0PH6107inOP1dM7@0LG5a06EUI@1PH600EeMG04m?C`16ATH0?Shn03Lg=`0`<300
;2`/0P0Y:BT0100X:2P09bLW02LW9`0W9bL702HV9P@0dLfY00030=7=Z@`09RHV100W9bL03@0Y:BT0
:b/[02l_;`0c<c<0>CTi04U9B@1HF5P0G5aL05eMG@1NGUh0GEeM05]KF`1LG5`00P1KFe/01P1OGel0
GUiN061PH01RHV80HF5Q069RHP<0IfMW00T0JFUY06a/K01^KVh0Kfm_079bLP1cLg<0MWIf07MgM`1h
N7P00P1jNWX0301kNg/0OWin0820P020P800Q8B408V9R@2:RXX0Rh^;08j>SP2BTY80UiNG09BDU080
VIVI00L0W9bL09fMW@2QXJ40XJ6Q0:>SX`2TY:@0Z:RX0080ZZZZ00<0/k>c0;Bd]02l_;`00P2n_[h0
;`32`/80_kno0<30`02g]kL0];Bd0;:b/P2][Jd0Xj>S09nOW`2QXJ40X:2P0:FUY@2RXZ80Y:BT0:FU
Y@2SXj<0XZ:R09nOW`2PX:00WYjN09bLW02NWYh0W9bL09^KV`2LW9`0Vi^K09NGU`2DU9@0Ti>C08j>
SP2;Rh/0QHF507moO`1fMWH0LG5a06a/K01RHV80FUYJ059BDP1:BTX0@T9203Xj>P0d=3@0;Rh^02/[
:`0Y:BT0:2PX00@09bLW00<09RHV02LW9`0V9RH0100V9RH40=7=Z@000`3AcJT00`0U9BD09RHV02HV
9P0802HV9PD09bLW0P0Y:BT01@0];Bd0<C4a03Lg=`10@400FEUI0080Hf=S00L0IFEU06=SH`1OGel0
G5aL05eMG@1LG5`0GUiN0080GemO00L0Hf=S06ATI01RHV80I6AT06EUI@1VIVH0J6QX0080Jf][00L0
K6a/06i^KP1_Kfl0Lg=c07AdM01fMWH0N7Qh0080NGUi0P1mOGd0401nOWh0PH610861P@24Q8@0R8R8
08J6QP2<S8`0TI6A09:BTP2FUYH0VIVI09NGU`2JVYX0VIVI09fMW@2NWYh209nOW`050:BTY02SXj<0
Zj^[0:n_[`2a/K400P2h^;P0202l_;`0`L710;jn_P2m_Kd0^;Rh0;Jf]P2][Jd0YjNW0P2VYZH00`2T
Y:@0XZ:R0:FUY@030:>SX`0O09nOW`2LW9`0Vi^K09bLW02GUiL0UIFE09BDU02CTi<0TY:B09>CT`2>
SXh0SHf=08V9R@27QhL0PX:207inOP1hN7P0LG5a06][J`1UIFD0GEeM05ADE01?Cdl0ADE503`l?00e
=CD0<C4a02`/;00Z:RX0:BTY02PX:00302LW9`0402HV9P0W9bL09bLW02LW9`<09RHV00<09bLW0=7=
Z@3AcJT00P3AcJT000<0dLfY2@0V9RH0100W9bL09RHV02HV9P0V9RH302LW9`0=02PX:00Y:BT0;2`/
030`<00e=CD0>c/k04U9B@1XJ6P0KVi^06e]K@1/K6`0J6QX069RHP02065QH@80GemO00@0H61P065Q
H@1QHF40IFEU0`1TI6@01P1UIFD0JVYZ06UYJ@1[Jf/0KVi^06m_K`80L71`00<0LG5a07EeM@1dM7@0
0P1hN7P01`1nOWh0OGem07emO@1oOgl0OWin08:2PP24Q8@00P28R8P00`2=SHd0Shn?09>CT`0209FE
U@0409ZJVP2GUiL0UiNG09bLW0<0WIfM00h0X:2P0:>SX`2XZ:P0Zj^[0:n_[`2e]KD0][Jf0;Zj^P2i
^KT0^[Zj0;Fe]@2c/k<0/;2`0:RXZ080Y:BT00`0YZJV0:BTY02TY:@0XZ:R0:2PX02NWYh0Vi^K09NG
U`2CTi<0U9BD08n?S`2=SHd208^;R`0D08R8R027QhL0QHF508B4Q020P800Ng]k07YjNP1bLW80Jf][
06EUI@1OGel0EeMG04m?C`19BDT0@D5103Ph>00b<S80;Rh^02`/;00Z:RX202PX:0<09bLW0P0V9RH0
0`0W9bL09RHV02HV9P0302HV9P@0dLfY00030=7=Z@`09RHV100W9bL202PX:00>02XZ:P0];Bd0<S8b
03Ph>011@D40FUYJ07EeM@1hN7P0MWIf07AdM01bLW80J6QX06IVIP1TI6@2069RHP0306=SH`1RHV80
IFEU0080IFEU00D0IVIV06MWI`1XJ6P0J6QX06YZJP0306e]K@0E071`L01_Kfl0LG5a07AdM01cLg<0
MGEe07QhN01kNg/0O7al0861P@1nOWh0OGem0820P023Ph<0PX:208N7Q`2;Rh/0SXj>08n?S`2>SXh0
UIFE0080Ti>C00D0U9BD09NGU`2GUiL0V9RH09bLW00209nOW`0<0::RXP2WYjL0Zj^[0:n_[`2d];@0
]KFe0;Jf]P2g]kL0][Jf0;>c/`2_[jl0Zj^[0P2ZZZX03P2WYjL0YJFU0:6QX@2RXZ80W9bL09ZJVP2F
UYH0TI6A08n?S`2<S8`0QhN708B4Q025QHD0P8200P1nOWh04@1mOGd0N7Qh07EeM@1aLG40JVYZ06IV
IP1MGEd0FEUI055AD@18B4P0@d=303`l?00e=CD0;bl_02`/;00Z:RX0:BTY0080:2PX0`0W9bL602HV
9P0302LW9`0V9RH0dLfY00<0dLfY00030=7=Z@<09RHV00@09BDU02HV9P0V9RH09BDU1P0V9RH302LW
9`80:2PX00T0:BTY02/[:`0_;bl0=CDe03dm?@18B4P0GUiN0861P@20P8000P1mOGd0101dM7@0L71`
06][J`1XJ6P406ATI00306=SH`1UIFD0IfMW00<0IfMW00P0JVYZ06UYJ@1/K6`0KFe]06i^KP1]KFd0
Kfm_079bLP80Lg=c00D0M7Ad07UiN@1kNg/0NGUi07]kN`0207emO@80OWin00H0Ph>308B4Q025QHD0
Rh^;08b<S02>SXh209:BTP80TI6A0P2DU9@02P2HV9P0VIVI09ZJVP2MWId0WinO0::RXP2ZZZX0/k>c
0;Jf]P2d];@30;6a/@030;2`/02b/[80[jn_0080[Zj^0200ZZZZ0:RXZ02TY:@0XZ:R09bLW02KVi/0
TI6A08j>SP27QhL0Ph>30820P01mOGd0NWYj07QhN01gMgL0Lg=c071`L01]KFd0JVYZ06IVIP1OGel0
EUIF059BDP1;Bd/0@d=303dm?@0g=cL0<C4a02`/;00[:b/0:BTY02PX:0@09bLW2@0V9RH40=7=Z@00
0`3AcJT602HV9P0302DU9@0V9RH09RHV00<09RHV00<09bLW02HV9P0V9RH00P0W9bL04`0X:2P0:BTY
02/[:`0/;2`0=3@d03Xj>P16ATH0Cdm?07QhN029RHT0QhN708R8R020P800N7Qh07=cL`1_Kfl0JVYZ
06MWI`1XJ6P0101UIFD00`1TI6@0IfMW06IVIP0306QXJ00B06YZJP1/K6`0KFe]06e]K@1_Kfl0LG5a
079bLP1cLg<0M7Ad07IfMP1hN7P0Ng]k07YjNP1kNg/0NWYj07emO@1nOWh0Ogmo0P25QHD02`27QhL0
RHV908V9R@2:RXX0SHf=08n?S`2@T900Shn?09>CT`2DU9@0V9RH0080VYZJ00H0WinO0:>SX`2ZZZX0
[Zj^0;6a/@2_[jl30:j^[P0Q0;6a/@2_[jl0/;2`0;2`/02^[Zh0Zj^[0:NWY`2UYJD0WIfM09VIV@2B
TY80SXj>08J6QP1nOWh0NWYj07IfMP1eMGD0M7Ad07=cL`1]KFd0JVYZ06EUI@1SHf<0GemO05UIF@1A
DE40CDe=04I6AP0o?cl0>SXj03@d=00^;Rh0:b/[0080:BTY00@0:2PX02LW9`0W9bL09bLW2P0V9RH4
0=7=Z@000`3AcJT=02HV9PD09bLW01@0:2PX02TY:@0[:b/0;bl_03Hf=P0o?cl0ATI605UIF@24Q8@0
T92@09FEU@2ATI40QhN70861P@1jNWX0MWIf06m_K`1/K6`0Jf][06QXJ080I6AT00L0IFEU06IVIP1V
IVH0IfMW06IVIP1XJ6P0JVYZ0080Jf][00X0K6a/06][J`1]KFd0Kfm_079bLP1cLg<0M7Ad07MgM`1f
MWH0MgMg0P1iNGT207]kN`80OGem0P1oOgl0>021PH40QXJ608R8R026QXH0Rh^;08b<S02=SHd0Shn?
08f=S@2ATI40U9BD09JFUP2GUiL0W9bL09fMW@2SXj<0ZJVY0:^[Z`2YZJT0ZZZZ0:f][@2_[jl0];Bd
0;Zj^P2i^KT0^;Rh0;Jf]P2_[jl0YjNW0:2PX02JVYX0U9BD08f=S@25QHD0OGem07EeM@1cLg<0Kfm_
06a/K01YJFT0IVIV065QH@1NGUh0G5aL05IFEP1ADE40Bd];04I6AP10@400>CTi03@d=00_;bl0;2`/
02XZ:P0Y:BT0:2PX0`0W9bL00`0V9RH09bLW02HV9P0802HV9P@0dLfY00030=7=Z@0302DU9@0V9RH0
9RHV00X09RHV00<09bLW02HV9P0W9bL00P0W9bL05@0X:2P0:BTY02XZ:P0/;2`0<C4a03Xj>P10@400
CDe=069RHP2@T900UYJF09bLW02MWId0T92@08b<S022PX80NGUi07EeM@1_Kfl0JVYZ06MWI`0206AT
I00506IVIP1TI6@0IfMW06IVIP1WIfL00P1YJFT0101ZJVX0Jf][06][J`1ZJVX206a/K00906i^KP1`
L700Lg=c07AdM01fMWH0MGEe07QhN01iNGT0N7Qh0080NGUi00H0NWYj07]kN`1lO7`0OGem07moO`21
PH4208F5Q@0708R8R02:RXX0SXj>08f=S@2<S8`0Shn?09:BTP0209BDU00W09VIV@2NWYh0X:2P0:>S
X`2TY:@0ZZZZ0;6a/@2i^KT0_Kfm0;^k^`2o_kl0^KVi0;Ng]`2c/k<0ZZZZ09^KV`2DU9@0SHf=0861
P@1kNg/0LG5a06e]K@1ZJVX0IVIV06=SH`1PH600GEeM05MGE`1DE5@0D51@04U9B@14A4@0?clo03/k
>`0d=3@0<30`02d];@0Z:RX0:BTY0080:2PX0P0W9bL00`0V9RH09bLW02LW9`0902HV9P@0dLfY0003
0=7=Z@l09RHV100W9bL202PX:00E02/[:`0];Bd0=3@d03Xj>P14A4@0Cdm?06e]K@2ATI40WinO0:>S
X`2RXZ80XJ6Q09NGU`28R8P0PH6107QhN01aLG40JVYZ06IVIP1WIfL0IFEU00<0IfMW0180IVIV06EU
I@1WIfL0JFUY06YZJP1YJFT0Jf][06YZJP1]KFd0Jf][06e]K@1^KVh0M7Ad079bLP1dM7@0MWIf07Ee
M@1dM7@207IfMP0:07MgM`1jNWX0Ng]k07QhN01jNWX0O7al07moO`22PX80Ph>308F5Q@80QXJ600l0
QhN708V9R@2:RXX0S8b<08j>SP2BTY80UYJF09BDU02HV9P0X:2P0:ZZZP2/[:`0^;Rh0;Zj^P2l_;`0
0P2k^k/06`2d];@0]kNg0:f][@2RXZ80UIFE08b<S022PX80NGUi06m_K`1XJ6P0IFEU061PH01MGEd0
FEUI05EEE@1BDU80CDe=04Q8B012@T80?Cdm03Ti>@0e=CD0<30`02d];@0[:b/0:BTY02PX:00702LW
9`T09RHV103AcJT000<0dLfY1P0V9RH00`0U9BD09RHV02HV9P0702HV9P0302LW9`0V9RH09bLW0080
:2PX01/0:BTY02/[:`0^;Rh0=3@d03`l?017AdL0EEEE06IVIP2@T900WIfM0:FUY@2VYZH0YjNW09jN
WP2CTi<0Ph>307]kN`1bLW80Kfm_06QXJ01YJFT0I6AT06EUI@1SHf<0IfMW06IVIP1UIFD00P1WIfL0
1@1VIVH0JVYZ06UYJ@1ZJVX0KFe]0080Jf][00<0K6a/075aL@1aLG400P1`L7001`1dM7@0LG5a07=c
L`1gMgL0NGUi07EeM@1gMgL00P1dM7@0301fMWH0NGUi07inOP20P800PX:20861P@23Ph<0QHF508N7
Q`26QXH0RHV908N7Q`80SHf=00H0T92@09RHV02PX:00Z:RX0:n_[`2g]kL20;Bd]00K0;Fe]@2c/k<0
[Jf]0:j^[P2TY:@0V9RH08b<S01nOWh0MWIf06YZJP1UIFD0H61P05]KF`1HF5P0De=C04i>CP1;Bd/0
B4Q804=3@`0o?cl0>3Ph03De=@0`<300;Bd]02/[:`0Z:RX0:2PX00H09bLW2P0V9RH00`0U9BD0dLfY
0=7=Z@020=7=Z@000`3AcJT?02HV9P0402LW9`0V9RH09bLW02LW9`<0:2PX01@0:RXZ02`/;00_;bl0
=SHf0451@@1<C4`0EUIF07IfMP2GUiL0Y:BT0:FUY@2YZJT0YJFU0:2PX02BTY80PX:207UiN@1dM7@0
K6a/06MWI`80IFEU00@0IVIV06ATI01UIFD0Hf=S0P1VIVH206MWI`80J6QX01/0JVYZ06UYJ@1]KFd0
KFe]06a/K01[Jf/0L71`06i^KP1`L700Kfm_071`L01cLg<0NGUi07AdM01`L700LW9b075aL@1dM7@0
MWIf07EeM@1iNGT0OWin0820P022PX80PH610820P021PH400P23Ph<02@24Q8@0QhN708N7Q`2>SXh0
VYZJ0::RXP2XZ:P0ZJVY0:ZZZP020:f][@80ZJVY01P0YJFU09nOW`2IVIT0S8b<07emO@1cLg<0J6QX
065QH@1KFe/0EeMG05ADE01@D500Bd];04M7A`13@d<0?clo03Ti>@0e=CD0<S8b02h^;P0[:b/0:RXZ
02TY:@0X:2P302LW9`h09RHV103AcJT000<0dLfY0`0V9RH00`0U9BD09RHV02HV9P0:02HV9PD09bLW
0P0X:2P02P0Z:RX0;2`/030`<00h>3P0@41004U9B@1HF5P0MGEe09NGU`2OWil30:NWY`0:0:2PX02F
UYH0QhN707inOP1gMgL0Kfm_06][J`1YJFT0I6AT06IVIP80I6AT01H0Hf=S06IVIP1SHf<0IVIV06MW
I`1XJ6P0IfMW06UYJ@1[Jf/0JVYZ06][J`1ZJVX0KFe]06YZJP1]KFd0KVi^06e]K@1^KVh0Kfm_06i^
KP1_Kfl0K6a/0P1^KVh01`1`L700LG5a07IfMP1fMWH0N7Qh07alO01kNg/00P1mOGd02@20P800O7al
07emO@1mOGd0Ogmo08:2PP2>SXh0U9BD09jNWP020:>SX`0H0:RXZ02RXZ80X:2P09jNWP2QXJ40VYZJ
08n?S`28R8P0N7Qh06m_K`1UIFD0GEeM05EEE@1BDU80CTi>04U9B@15ADD0@41003dm?@0i>CT0=3@d
030`<00^;Rh0;2`/0P0Y:BT202PX:0L09bLW2P0V9RH40=7=Z@000`3AcJT=02HV9P0402LW9`0V9RH0
9bLW02LW9`809RHV0`0W9bL202PX:00G02XZ:P0/;2`0<30`03Ph>00o?cl0BTY:05MGE`1`L700TY:B
09jNWP2ZZZX0Zj^[0:ZZZP2VYZH0WYjN08j>SP24Q8@0Ng]k07IfMP1bLW80K6a/06UYJ@1TI6@00P1S
Hf<01`1TI6@0HV9R06EUI@1UIFD0IVIV06MWI`1VIVH00P1XJ6P00`1WIfL0J6QX06UYJ@0206MWI`03
06YZJP1[Jf/0JVYZ00<0Jf][00L0K6a/06e]K@1[Jf/0K6a/06e]K@1^KVh0L71`0080Lg=c00D0MgMg
07QhN01gMgL0N7Qh07MgM`0207IfMP0507EeM@1hN7P0OGem08F5Q@2>SXh00P2GUiL06P2KVi/0UiNG
09VIV@2HV9P0TY:B096AT@27QhL0OWin079bLP1YJFT0HF5Q05UIF@1BDU80CDe=04U9B@14A4@0?clo
03`l?00h>3P0=3@d034a<@0^;Rh0:b/[02XZ:P0Y:BT0:2PX100W9bL0100V9RH09bLW02HV9P0W9bL;
02HV9P@0dLfY00030=7=Z@0402DU9@0V9RH09BDU02HV9P809BDU300V9RH502LW9`0I02PX:00Y:BT0
:RXZ02d];@0a<C40=cLg03lo?`19BDT0EUIF06EUI@2>SXh0WinO0:FUY@2ZZZX0YjNW0:JVYP2NWYh0
UYJF08f=S@21PH40Ng]k07EeM@1^KVh0J6QX06IVIP0306=SH`06069RHP1TI6@0Hf=S06ATI01VIVH0
IfMW0P1VIVH01`1WIfL0IFEU06ATI01WIfL0IFEU06QXJ01VIVH01@1XJ6P0101ZJVX0JFUY06][J`1X
J6P206a/K00306m_K`1^KVh0Lg=c00<0Lg=c00T0Kfm_06e]K@1/K6`0KVi^079bLP1fMWH0Ng]k08F5
Q@28R8P00`2=SHd0502>SXh0RXZ:08>3P`1kNg/0LW9b06YZJP1TI6@0GEeM05IFEP1?Cdl0AdM704=3
@`0n?Sh0>SXj03Hf=P0d=3@0<C4a02d];@0[:b/0:BTY0P0X:2P402LW9`809RHV00<09bLW02HV9P0V
9RH02`0V9RH40=7=Z@000`3AcJT01@0V9RH09BDU02HV9P0V9RH09BDU00809RHV00<09BDU02HV9P0V
9RH02@0V9RH202LW9`0P02PX:00W9bL0:2PX02TY:@0Z:RX0:b/[02d];@0a<C40=cLg0410@01:BTX0
De=C06QXJ02>SXh0WIfM0:NWY`2ZZZX0[:b/0:NWY`2TY:@0Vi^K08n?S`2:RXX0OWin07AdM01_Kfl0
J6QX06IVIP1RHV80IFEU061PH01QHF4406ATI080IFEU00l0Hf=S06IVIP1SHf<0Hf=S06EUI@1TI6@0
IFEU06ATI01VIVH0J6QX06IVIP1WIfL0IVIV06YZJP1XJ6P00P1WIfL01@1YJFT0Jf][06][J`1]KFd0
Jf][0080KVi^00X0KFe]06UYJ@1XJ6P0IVIV06YZJP1^KVh0L71`07MgM`1lO7`0OWin0P23Ph<05@1o
Ogl0O7al07IfMP1^KVh0JVYZ06ATI01NGUh0FEUI059BDP1<C4`0ADE50410@00k>c/0=cLg03<c<`0`
<300;Rh^02/[:`0Z:RX0:BTY02PX:00402LW9`0302HV9P0W9bL09RHV00X09RHV00@09BDU02HV9P0V
9RH09RHV103AcJT000<0dLfY00<09RHV02DU9@0U9BD00`0V9RH202DU9@/09RHV1@0W9bL202PX:00?
02TY:@0[:b/0;Bd]02l_;`0f=SH0?clo04I6AP1?Cdl0HV9R0820P02IVIT0YJFU0:RXZ02YZJT0Zj^[
0080XZ:R00P0Vi^K096AT@23Ph<0N7Qh07AdM01/K6`0IfMW06IVIP80HV9R00@0Hf=S065QH@1QHF40
HV9R0P1SHf<0101RHV80H61P065QH@1RHV83065QH@80HV9R00<0I6AT065QH@1UIFD00P1VIVH03@1U
IFD0IfMW06ATI01UIFD0IVIV06EUI@1XJ6P0IfMW06QXJ01VIVH0J6QX06UYJ@1SHf<00`1QHF40101U
IFD0J6QX06QXJ01ZJVX306e]K@0B06YZJP1XJ6P0I6AT06=SH`1LG5`0EeMG059BDP1>CTh0AdM70410
@00k>c/0=cLg038b<P0_;bl0;Bd]02/[:`0Z:RX0:BTY0P0X:2P302LW9`0302HV9P0W9bL09RHV00l0
9RHV103AcJT000<0dLfY0`0U9BD802HV9P0302DU9@0V9RH09RHV00H09RHV0P0W9bL00`0U9BD09bLW
02LW9`0202PX:00J02TY:@0Z:RX0;2`/030`<00f=SH0>SXj04A4A01>CTh0EUIF071`L02EUID0Xj>S
0:VYZ@2ZZZX0ZJVY0:NWY`2PX:00WinO09BDU027QhL0OWin07EeM@1bLW80JVYZ06IVIP1TI6@2065Q
H@04069RHP1QHF40HF5Q061PH0<0HF5Q00D0GUiN061PH01OGel0GemO05iNGP02065QH@05061PH01Q
HF40H61P06=SH`1QHF400P1RHV800`1TI6@0Hf=S065QH@02065QH@0506=SH`1QHF40HV9R069RHP1Q
HF400`1NGUh205mOG`03061PH01OGel0GemO0080GUiN0100Fe]K05aLG01HF5P0F5QH05=CD`1@D500
BTY:04M7A`12@T80?3`l03Ph>00c<c<0;bl_02d];@0[:b/0:RXZ0P0X:2P402LW9`0302HV9P0W9bL0
9RHV01009RHV103AcJT000<0dLfY00@09BDU02HV9P0V9RH09BDU0P0V9RH202DU9@X09RHV00<09bLW
02HV9P0W9bL0100W9bL302PX:00=02TY:@0Z:RX0:b/[02h^;P0c<c<0>SXj0492@P18B4P0EEEE06IV
IP2;Rh/0UiNG0:>SX`020:NWY`0:0:^[Z`2UYJD0X:2P09VIV@2?Shl0PX:207UiN@1cLg<0KVi^06UY
J@80Hf=S00<0H61P05mOG`1NGUh00P1OGel01`1NGUh0H61P05iNGP1MGEd0H61P05eMG@1OGel00P1N
GUh205aLG00>05eMG@1NGUh0GUiN061PH01NGUh0GEeM05iNGP1OGel0GEeM05aLG01MGEd0G5aL05iN
GP1MGEd205aLG00H05]KF`1LG5`0FEUI05MGE`1FEUH0EeMG05EEE@1FEUH0E5AD055AD@1@D500Cdm?
04e=C@1;Bd/0AdM704=3@`11@D40>c/k03Hf=P0c<c<0<30`02`/;00Z:RX0:BTY0P0X:2P402LW9`03
02HV9P0W9bL09RHV00<09RHV00<09bLW02HV9P0V9RH0200V9RH00`0U9BD09RHV02HV9P040=7=Z@00
0`3AcJT00`0U9BD09RHV02HV9P0302HV9P0302DU9@0V9RH09RHV00/09RHV0P0W9bL00`0V9RH09bLW
02LW9`0202LW9`80:2PX0P0Y:BT0300/;2`0;Bd]034a<@0g=cL0?Cdm04E5A@1>CTh0FEUI06m_K`2?
Shl0WIfM0:NWY`80Z:RX00l0YZJV0:>SX`2PX:00V9RH08V9R@21PH40MGEe071`L01[Jf/0IVIV06AT
I01RHV80GemO061PH01OGel00P1MGEd01@1NGUh0G5aL05eMG@1LG5`0Fe]K0080FUYJ0P1KFe/0401J
FUX0FEUI05aLG01LG5`0Fe]K05eMG@1KFe/0FUYJ05UIF@1JFUX0F5QH05IFEP1HF5P0FEUI05QHF01G
EeL205IFEP0F05EEE@1BDU80De=C055AD@1?Cdl0CTi>04e=C@1<C4`0BDU904I6AP14A4@0@T920410
@00l?3`0>SXj03De=@0b<S80;Rh^02`/;00Z:RX0:BTY02PX:0D09bLW00@09RHV02LW9`0V9RH09bLW
4@0V9RH40=7=Z@000`3AcJT00`0U9BD09RHV02DU9@0702HV9P0302DU9@0V9RH09RHV00T09RHV00<0
9bLW02HV9P0V9RH0100W9bL202PX:00R02TY:@0[:b/0;Rh^034a<@0f=SH0?3`l04I6AP1<C4`0EEEE
06YZJP2=SHd0WIfM09nOW`2VYZH0XJ6Q0:FUY@2SXj<0XJ6Q09VIV@2=SHd0PX:207MgM`1aLG40K6a/
06IVIP1UIFD0H61P05mOG`1MGEd0G5aL05eMG@1LG5`0Fe]K05eMG@80Fe]K00<0FEUI05YJFP1IFET0
101HF5P01@1IFET0F5QH05UIF@1IFET0F5QH00<0EeMG00/0E5AD05=CD`1DE5@0DU9B05=CD`1ADE40
D51@055AD@1@D500CTi>04a<C00204Q8B00>04M7A`15ADD0@d=30451@@0o?cl0?3`l03/k>`0h>3P0
=SHf038b<P0^;Rh0;Bd]02/[:`0Y:BT202PX:0<09bLW00<09RHV02LW9`0W9bL0100V9RH00`0W9bL0
9RHV02HV9P0=02HV9P@0dLfY00030=7=Z@809BDU00<09RHV02DU9@0V9RH0400V9RH0100W9bL09RHV
02HV9P0V9RH502LW9`80:2PX00d0:BTY02XZ:P0];Bd0;Rh^03<c<`0j>SX0@41004M7A`1@D500F5QH
07EeM@2;Rh/0Vi^K0080XZ:R0180Y:BT0:RXZ02SXj<0WinO09RHV02:RXX0OWin07MgM`1]KFd0J6QX
06ATI01RHV80GUiN05aLG01MGEd0G5aL05YJFP1KFe/205QHF00505YJFP1GEeL0EEEE05IFEP1CDe<0
0P1DE5@00`1CDe<0EEEE05ADE00205ADE00M05EEE@1CDe<0DU9B051@D01ADE40CTi>04a<C01=CDd0
C4a<04e=C@1;Bd/0BTY:04U9B@16ATH0A4A404=3@`11@D40?clo03`l?00k>c/0>CTi03Lg=`0d=3@0
<S8b030`<00];Bd0;2`/02XZ:P0Y:BT00P0X:2P402LW9`<09RHV00<09bLW02HV9P0V9RH04@0V9RH4
0=7=Z@000`3AcJT202HV9P0502DU9@0V9RH09BDU02HV9P0U9BD03`0V9RH0100W9bL09RHV02HV9P0V
9RH502LW9`0302TY:@0X:2P0:BTY0080:RXZ00`0;Bd]034a<@0g=cL0>c/k0451@@19BDT0DU9B05]K
F`1cLg<0Shn?09^KV`2QXJ420:>SX`0=0:BTY02PX:00Vi^K092@T027QhL0Ng]k075aL@1[Jf/0I6AT
069RHP1NGUh0GEeM05]KF`0205YJFP0305MGE`1EEED0EEEE0080De=C00/0E5AD055AD@1@D500Cdm?
055AD@1?Cdl0DE5A04e=C@1@D500CTi>04a<C00204e=C@0304a<C01;Bd/0B4Q80080AdM70P16ATH2
04=3@`0?0492@P0o?cl0?Shn03`l?00j>SX0=cLg03De=@0d=3@0<C4a02l_;`0];Bd0;2`/02/[:`0Z
:RX0:BTY0080:2PX100W9bL302HV9P809bLW400V9RH00`0U9BD09RHV02HV9P040=7=Z@000`3AcJT0
1@0U9BD09RHV02DU9@0V9RH09BDU00809RHV00<09BDU02HV9P0V9RH0400V9RH702LW9`<0:2PX01d0
:RXZ02d];@0`<300<S8b03Lg=`0m?Cd0@d=304U9B@1ADE40GEeM07EeM@2:RXX0VIVI09nOW`2QXJ40
X:2P09fMW@2HV9P0UiNG08Z:RP1lO7`0Lg=c06][J`1VIVH0HF5Q05iNGP1LG5`0FEUI05QHF00205MG
E`0805IFEP1DE5@0DU9B055AD@1@D500Cdm?04i>CP1=CDd404];B`0;04U9B@18B4P0B4Q804Q8B017
AdL0ATI604A4A013@d<0@T920451@@10@4000P0n?Sh02`0l?3`0>c/k03Ph>00e=CD0<c<c038b<P0`
<300;Rh^02d];@0/;2`0:RXZ0080:BTY0`0X:2P602LW9a009RHV00@09BDU02HV9P0V9RH09BDU0`0V
9RH40=7=Z@000`3AcJT202HV9P0302DU9@0V9RH09RHV00809RHV00<09BDU02HV9P0V9RH03`0V9RH0
0`0W9bL09RHV02LW9`0602LW9`80:2PX01d0:BTY02XZ:P0[:b/0;Bd]02l_;`0d=3@0>3Ph03`l?014
A4@0BDU9059BDP1HF5P0JVYZ08F5Q@2@T900VIVI09ZJVP2HV9P0UiNG09>CT`28R8P0NGUi07AdM01[
Jf/0IFEU065QH@1NGUh0FUYJ05QHF00205EEE@0705=CD`1BDU80DE5A051@D01=CDd0BTY:04];B`03
04Q8B00=04M7A`16ATH0ADE504A4A013@d<0A4A404=3@`11@D40?clo03hn?P0m?Cd0?3`l03/k>`02
03Ti>@0903De=@0d=3@0<c<c034a<@0_;bl0;Rh^02`/;00[:b/0:RXZ0080:BTY0P0X:2P202LW9`80
9RHV00<09bLW02HV9P0V9RH00P0V9RH00`0W9bL09RHV02HV9P0D02HV9P@0dLfY00030=7=Z@0402HV
9P0U9BD09BDU02DU9@@09RHV00<09BDU02HV9P0V9RH04@0V9RH802LW9`80:2PX02D0:BTY02/[:`0]
;Bd0;Rh^034a<@0e=CD0>SXj0410@014A4@0Bd];055AD@1LG5`0JVYZ08:2PP2>SXh0Ti>C09FEU@2D
U9@0Shn?08F5Q@1mOGd0Lg=c06UYJ@1VIVH0GemO05]KF`1FEUH0EeMG05ADE01BDU80D51@04m?C`1=
CDd0CTi>04Y:BP19BDT0AdM700<0A4A400@0@T920451@@10@400@4100P0o?cl01`0n?Sh0?3`l03/k
>`0j>SX0>3Ph03Lg=`0e=CD00P0d=3@0100a<C40<30`02h^;P0/;2`202/[:`0602XZ:P0Y:BT0:BTY
02PX:00W9bL0:2PX100W9bL00`0V9RH09bLW02HV9P0D02HV9P0502DU9@0V9RH09RHV02HV9P0U9BD0
103AcJT000<0dLfY00<09BDU02HV9P0V9RH00P0U9BD00`0V9RH09BDU02DU9@0F02HV9PL09bLW0P0X
:2P202TY:@0X02XZ:P0/;2`0;Rh^034a<@0e=CD0>c/k03hn?P14A4@0B4Q804a<C01DE5@0GEeM06a/
K01kNg/0QhN708Z:RP28R8P0QHF507alO01_Kfl0Jf][06ATI01NGUh0FUYJ05EEE@1CDe<0D51@04m?
C`1=CDd0C4a<04Y:BP17AdL0ATI604E5A@12@T80@D5103lo?`0n?Sh0?Cdm03`l?080>c/k00L0>CTi
03Ph>00g=cL0=SHf03De=@0d=3@0<S8b0080<30`00D0;Rh^02d];@0[:b/0:b/[02XZ:P0202TY:@<0
:2PX1@0W9bL202HV9P<09bLW5P0V9RH00`0U9BD09RHV02HV9P040=7=Z@000`3AcJT01P0V9RH09BDU
02DU9@0U9BD09RHV02DU9@809RHV0P0U9BD00`0V9RH09BDU02HV9P0A02HV9P<09bLW0P0V9RH202LW
9`@0:2PX02H0:BTY02XZ:P0Z:RX0;2`/02h^;P0b<S80<c<c03Ph>00l?3`0@41004A4A018B4P0CTi>
055AD@1GEeL0HF5Q06i^KP1eMGD0MgMg079bLP1[Jf/0IFEU05mOG`1IFET0EUIF059BDP1@D500CTi>
04];B`19BDT0ATI604E5A@13@d<0@41003hn?P0m?Cd0?3`l03Xj>P80>3Ph00T0=cLg03Hf=P0e=CD0
=CDe03<c<`0b<S80<C4a030`<00^;Rh00P0/;2`0100[:b/0:RXZ02TY:@0Y:BT302PX:0D09bLW00@0
9RHV02LW9`0V9RH09bLW7@0V9RH40=7=Z@000`3AcJT702DU9@0602HV9P0U9BD09RHV02DU9@0V9RH0
9BDU2`0V9RH00`0U9BD09RHV02HV9P0602HV9P0302LW9`0V9RH09bLW00D09bLW0P0X:2P202TY:@0;
02XZ:P0/;2`0;Bd]02l_;`0c<c<0=CDe03Ph>00l?3`0?clo0492@P13@d<00P17AdL00`1:BTX0Cdm?
05=CD`0205QHF00A05YJFP1FEUH0E5AD051@D01<C4`0BTY:04Q8B015ADD0A4A40492@P10@400?Shn
03`l?00j>SX0=cLg03Hf=P0e=CD00P0c<c<0100b<S80<30`030`<00^;Rh202d];@0602`/;00[:b/0
:RXZ02XZ:P0X:2P0:BTY0`0X:2P:02LW9aX09RHV00@09BDU02HV9P0V9RH09BDU103AcJT000<0dLfY
0`0U9BD202HV9P809BDU00<09RHV02DU9@0V9RH04`0V9RH00`0W9bL09RHV02LW9`0302LW9`0302HV
9P0W9bL09bLW00<09bLW0`0X:2P302TY:@0E02XZ:P0[:b/0;Bd]02l_;`0a<C40=3@d03Lg=`0i>CT0
>c/k03dm?@0o?cl0@T920410@011@D40@T920451@@13@d<0@D5104=3@`15ADD0ATI60080@d=300T0
@T9203hn?P0n?Sh0?3`l03Xj>P0h>3P0=SHf03@d=00c<c<00P0`<3000`0^;Rh0<30`02`/;00202`/
;00302/[:`0Z:RX0:RXZ00<0:BTY0`0X:2P302LW9`0302HV9P0W9bL09RHV00809bLW6`0V9RH01`0U
9BD09RHV02HV9P0V9RH09BDU02HV9P0U9BD0103AcJT000<0dLfY100U9BD0200V9RH09BDU02HV9P0U
9BD09RHV02DU9@0V9RH09BDU3@0V9RH00`0U9BD09RHV02HV9P0402HV9PD09bLW00<09RHV02LW9`0W
9bL0100W9bL402PX:00:02TY:@0Z:RX0:RXZ02/[:`0];Bd0;bl_030`<00b<S80=3@d03De=@D0=cLg
0`0f=SH00`0e=CD0=3@d03@d=00203<c<`80<S8b00D0<C4a030`<00_;bl0;Rh^02d];@0202`/;080
:b/[0P0Z:RX402TY:@@0:2PX1`0W9bL202HV9P0502LW9`0V9RH09RHV02HV9P0W9bL07`0V9RH40=7=
Z@000`3AcJT00`0V9RH09BDU02HV9P0202DU9@0402HV9P0U9BD09RHV02DU9@809RHV00L09BDU02HV
9P0U9BD09RHV02DU9@0V9RH09BDU00l09RHV00<09bLW02HV9P0V9RH00`0W9bL202HV9PD09bLW0`0X
:2P0100Y:BT0:2PX02TY:@0Y:BT202/[:`0302`/;00];Bd0;Rh^0080;bl_100`<3000`0_;bl0<30`
030`<00302l_;`80;Rh^0P0];Bd202`/;080:b/[00<0:RXZ02TY:@0Y:BT00P0Y:BT00`0X:2P0:BTY
02PX:00402PX:0X09bLW0`0V9RH202LW9aX09RHV00<09BDU02HV9P0U9BD00P0V9RH00`0U9BD0dLfY
0=7=Z@020=7=Z@000`3AcJT01@0U9BD09RHV02DU9@0V9RH09BDU00809RHV0P0U9BD00`0V9RH09BDU
02DU9@0202HV9P0302DU9@0V9RH09RHV00@09RHV00<09BDU02HV9P0V9RH03P0V9RH<02LW9`<0:2PX
0`0Y:BT302XZ:P<0:b/[0P0/;2`0100[:b/0;2`/02`/;00/;2`202/[:`H0:RXZ0`0Y:BT602PX:0D0
9bLW100V9RH01P0W9bL09RHV02HV9P0W9bL09RHV02LW9`T09RHV00<09bLW02HV9P0V9RH04@0V9RH0
0`0U9BD09RHV02DU9@0402HV9P0302DU9@3AcJT0dLfY0080dLfY00030=7=Z@809RHV0P0U9BD00`0V
9RH09BDU02HV9P0202DU9@0302HV9P0U9BD09BDU00809BDU4@0V9RH00`0W9bL09RHV02HV9P0302HV
9P0402LW9`0V9RH09bLW02HV9P809bLW00<09RHV02LW9`0W9bL01`0W9bL502PX:00502TY:@0X:2P0
:BTY02TY:@0Z:RX00`0Y:BT00`0X:2P0:BTY02TY:@0302TY:@D0:2PX00<09bLW02PX:00W9bL01@0W
9bL01@0V9RH09bLW02LW9`0W9bL09RHV00<09bLW00<09RHV02LW9`0V9RH05`0V9RH00`0U9BD09RHV
02HV9P0=02HV9P0302DU9@0V9RH0dLfY00<0dLfY00030=7=Z@0302DU9@0V9RH09BDU00809BDU0`0V
9RH0100U9BD09RHV02HV9P0U9BD402HV9P0302DU9@0V9RH09RHV00H09RHV0P0U9BD>02HV9P0502LW
9`0V9RH09RHV02LW9`0V9RH02`0W9bL502PX:00302LW9`0X:2P0:2PX00<0:2PX00H09bLW02PX:00X
:2P0:2PX02LW9`0X:2P:02LW9`809RHV00<09bLW02HV9P0V9RH00`0V9RH0100W9bL09RHV02LW9`0W
9bLN02HV9P0302DU9@0V9RH09RHV00@09RHV0P0U9BD202HV9P@0dLfY00030=7=Z@0302HV9P0U9BD0
9RHV00@09RHV0P0U9BD0100V9RH09BDU02HV9P0U9BD302HV9P0502DU9@0V9RH09RHV02HV9P0U9BD0
4`0V9RH00`0W9bL09RHV02HV9P0402HV9PD09bLW00<09RHV02LW9`0W9bL05`0W9bL302HV9P0402LW
9`0V9RH09bLW02HV9P<09bLW1P0V9RH00`0W9bL09RHV02HV9P0J02HV9P809BDU00<09RHV02DU9@0U
9BD00`0V9RH00`0U9BD09RHV02HV9P0202DU9@0302HV9P3AcJT0dLfY0080dLfY00030=7=Z@0502DU
9@0V9RH09BDU02HV9P0U9BD00P0V9RH302DU9@809RHV0`0U9BD602HV9P809BDU0P0V9RH00`0U9BD0
9RHV02HV9P0802HV9P0302LW9`0V9RH09RHV00D09RHV00D09bLW02HV9P0V9RH09RHV02LW9`0402HV
9PH09bLW00<09RHV02LW9`0W9bL02P0W9bL00`0V9RH09bLW02LW9`0402LW9`0402HV9P0W9bL09RHV
02LW9`<09RHV00<09bLW02HV9P0V9RH08@0V9RH00`0U9BD09RHV02DU9@0202HV9P809BDU00P09RHV
02DU9@0V9RH09RHV02DU9@0V9RH09BDU02HV9P@0dLfY00030=7=Z@0302DU9@0V9RH09BDU00809BDU
00<09RHV02DU9@0V9RH00`0U9BD302HV9P0302DU9@0V9RH09RHV00D09RHV00<09BDU02HV9P0V9RH0
6@0V9RH302LW9`0302HV9P0W9bL09bLW00<09RHV1`0W9bL00`0V9RH09bLW02HV9P0702HV9P809bLW
1P0V9RH00`0W9bL09RHV02HV9P0M02HV9P0502DU9@0V9RH09RHV02HV9P0U9BD0100V9RH202DU9@03
02HV9P0U9BD09RHV00809BDU1@0V9RH40=7=Z@000`3AcJT?02DU9@809RHV0P0U9BD0100V9RH09BDU
02DU9@0V9RH302DU9@0302HV9P0U9BD09RHV01D09RHV00<09bLW02HV9P0V9RH0100V9RH01@0W9bL0
9RHV02HV9P0V9RH09bLW00809RHV0P0W9bL00`0V9RH09bLW02LW9`0302HV9P0302LW9`0V9RH09bLW
00L09RHV00@09bLW02HV9P0W9bL09RHV0P0W9bLD02HV9P0302DU9@0V9RH09RHV00809RHV00@09BDU
02HV9P0V9RH09BDU0P0V9RH00`0U9BD09RHV02HV9P0302HV9P0502DU9@0V9RH09BDU02DU9@0V9RH0
0P0U9BD302HV9P0302DU9@0V9RH0dLfY00<0dLfY00030=7=Z@@09BDU00<09RHV02DU9@0U9BD0100U
9BD202HV9P809BDU3P0V9RH00`0U9BD09RHV02HV9P0A02HV9P0302LW9`0V9RH09RHV00809RHV0P0W
9bL602HV9P809bLW<P0V9RH00`0U9BD09RHV02HV9P0202HV9P0402DU9@0V9RH09RHV02DU9@T09RHV
00<09BDU02HV9P0U9BD00P0U9BD40=7=Z@000`3AcJT202DU9@0502HV9P0U9BD09BDU02DU9@0V9RH0
0P0U9BD01@0V9RH09BDU02DU9@0V9RH09BDU00809RHV0P0U9BDT02HV9P0302LW9`0V9RH09RHV00X0
9RHV0P0W9bL;02HV9P0302LW9`0V9RH09RHV02/09RHV0P0U9BD502HV9P0402DU9@0V9RH09BDU02DU
9@@0dLfY002@0=7=Z@00T03AcJT00900dLfY002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {336.188, 193.188}} -> {-689.508, 713.481, \
3.75948, 3.75948}}]
}, Open  ]],

Cell[TextData[{
  "To apply the restoration, we need an estimate of the support values ",
  Cell[BoxData[
      StyleBox[\(n\_\(x, \ FITS\)\),
        FontWeight->"Bold"]]],
  " and ",
  Cell[BoxData[
      StyleBox[\(n\_\(y, \ FITS\)\),
        FontWeight->"Bold"]]],
  " of ",
  Cell[BoxData[
      StyleBox[\(g\&~\_FITS\),
        FontWeight->"Bold"]]],
  ". We employ the ",
  StyleBox["evaluateSupport", "TB",
    FontFamily->"Courier"],
  " routine, which takes a number ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \ 100]\)\)]],
  " as input, rescales the pixel intensities of ",
  Cell[BoxData[
      StyleBox[\(g\&~\_FITS\),
        FontWeight->"Bold"]]],
  "  to match ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " to the darkest pixel and ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  " to the brightest one, and returns the estimated support window: no pixel \
outside such a window has a rescaled intensity greater or equal than ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\)]],
  ". Increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\)]],
  " makes the support rectangle smaller. A plot of the ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_\(y, \ FITS\)\),
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], "\[Times]", " ", 
        StyleBox[\(n\_\(x, \ FITS\)\),
          FontWeight->"Bold"]}]]],
  " support window superimposed to ",
  Cell[BoxData[
      StyleBox[\(\(g\&~\)\_FITS\),
        FontWeight->"Bold"]]],
  " as a dashed white rectangle may be useful to estimate the most suitable \
value  of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\)]],
  "."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["\[ScriptL]",
            FontWeight->"Plain"], " ", "=", " ", "22"}], ";", 
        " ", \( (*\ turned\ out\ to\ be\ good\ in\ this\ case\ *) \), 
        "\[IndentingNewLine]", 
        RowBox[{\({n\_\(y, \ FITS\), \ n\_\(x, \ FITS\)}\), " ", "=", " ", 
          RowBox[{"evaluateSupport", "[", 
            RowBox[{\(g\&~\_FITS\), ",", " ", 
              StyleBox["\[ScriptL]",
                FontWeight->"Plain"]}], "]"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", \(showSupport[g\&~\_FITS, \ 
        n\_\(y, \ FITS\), \ n\_\(x, \ FITS\)];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0238095 0.00186012 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
252525252526262525252525252526262526252526252626252525262625252625262626
252625262525262525262626252525252526262525262626252526252626262626252626
252626252626262526262626262626262626262626262625262625252526262625252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262726262626262626262626262626262626262626272626
262626262626262626272626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262625262626262626262626262626
262626262626262626262526262626262626262626262626262626262626262626262526
262626262626262626252626262626262526252626262626262626262626262625252626
262526262626262526262626252626252626262626262626252526252625252625262625
252525262626262625252625252526252626252525252525252625252525252525252625
2526252525252525
252626252526252525262625262526252625252525252526252525252525252626262626
262526252626252525252626262625262625252625262526252625252626262626262625
252625262626262626262525262626252626252626262626262625262626262626262526
252626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262626262626262626262626262627262626262626262626262627262626262626272626
262726262626262626262626262626262626262626262626262626262627262726262626
262626262626262626262626262626262626262626262626262626262626252626262526
262626262626262626262626262626262626262626262626252626262626262626262626
262626262525262625262626262626252626252626262626262626262626262626262626
252626262626252525252626262526252625252526262626262626262526252525252525
252525262525262526262526252525252525262525262525252525262526262525252526
2525252625252525
252625252526252625252525252525252525252626252525262526252625252625262626
252526262626252625252625252526252526252626262525262525262526262525262626
262625262526262526262626262626262626262626262626262626252626252626262526
262626262526262626262626262626262626262526252625262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262726262626262726
262626262627262726262626262627262626262626262626262626262726262627262626
262626262727272626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262625262526262626262626262626262626262626262526262626
262626262625252626252526252625252526262526252625262526252526252626262626
262525252625262625262626252625252526262625252525252526252626252625252525
2526262525252525
252525252625252525252526252625252525252626252526262625262526262526252626
262626262526252526262626262626262625262525252625252626262626262626252626
262626262626252626252626252626262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626262726262626262626272626262626
262626262627262726262627262627262726262627272626262627262626272626262626
262626262627262626262726262626262726272727262626262626262626262626262626
262626262626262626272626262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262526262626262626262626262526262626262626
262626262626262626262626252625262626262626262626262626252626262626262626
262625262625262626252525262626252626252626262526252525262625262626262526
262525262626252626262525252626252526252525262625262525252525252525252525
2625252625252525
252625252526252625262626252625252525252625252526252526262625262626262525
262525262525262526262625252525262525252626262526262525262626262526262625
252626252626262626252626262626252626262525262626252625262526262626262626
262625262526252626262626262626262627262626262626262626262626262626262626
262626262626252726262626262626262626262626262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272726262627262626262726262726262626262627
262726272726262626272627262626262626262626262626262626262626262726262726
262627262626262626262627262626272626262626262626262626262626262726262626
262626262626262726262626262626272626262626262626262626262626262626262626
262626262626262626262626262626262626252526262626262626262626262626262526
262626262626252626262526262625262526262525262625262626262526262626262626
252626262626252625252626262626262626252626252526252526262625252625252625
252625252625252526252626252525262526252526252525252525252525262525252625
2525252525252525
252625252526252626252625262525262526262526252625262526262526252625252625
252625262525252526252625262525262525252625262526252525252626252526262626
262626262626262626262626262626262625262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262626262626262626262626262626262626262626262626262626272626
262626262626272626262626262626262626262626262627262626262626262627262626
262626272626262626262727262626262626262627262626262626262626262726262626
272627272626262726262626262626262727262727262727262726262626262726262626
262626262727262626272626262626272726262626262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626252626262526262626262526262526262626
262625252526252626262626262626252626262626252625252626262526262525252626
262626252526262526262625262526262625252525252626252525262525252525252525
2625252525252525
252625252526252626252525252625262525262526262626262625262525252625262526
262625252626262525262525252626262526252525262625262626252525262625252626
262626262626262626262626262626262526252626252626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262526
262626262626262626262626262626262626262626262626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626272626262626272626262626262626262726262626262726262626
262726272727262626262726262727262626262626262626262627272726262626262626
262727262626262727262626262626262627262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626262626262526252526
262626262626262526262626262626252526252525262525252526252626252625262625
252526262625252626252526252525252625252525252625252626262626252526252525
2525262525252526
252625252526252525252525252626252626252525252526262626252625252625262526
252625252626262626252526262525252625262626252626252625252626262626262526
262626262526262626262626262526262625262626262526262626262625262626262626
262626262626262626262626252626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262626262626262626262626262626262626272726262626262626262627272626
262626262626262626262626262626262727272627262627272626262627262626262626
262626262726272626272726262627262627272726272727272626262627272627262626
262626262727262626262626262627272626262626262726262626262626262626262626
262726262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626252626262626262626262626262625
262626262626262626262625262626262626262625262526262626262626252626262626
262626252626262625262526252625252626262526262626262526252626252526262525
252526262626262525252626252625252526252525252526262625262626252526252625
2525252525262526
252625262525262525252525252525252526252526262525262626262625262626252626
262626262526252526262625262526262626262525262626252526252526262626262626
262626262625252626262626262626262626252626262626262626262626262626262626
262626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627262726272626262726262626262626262727262626262726
272626272626262726262626262626262626262626262626262627272626262727262626
262627272626262626272626262727262626272726262626272726262626262726262626
262626272627272726262626272727262626262626262626272626262726262626262627
262626262626262626262626262727262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262625262526262625262625262625252625262625262626262526
262625262626252626262626262526262526262526252625252626262526252625252526
262625252526252526262526252525262526262526252526262525252525252525252525
2526262526262525
252626252525252526252525262625252526252525262626252525262526262626262626
262526262625252526262526252526252525262626252526262626252626262526262626
262525252625252525262625262526262626262526262626262526262626262626262626
262626262626262626262626262626262626252626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262627
262726272627262626262727262626272627262626262626262627272626262626272626
272626262727262626262627262726262727262627272626262726262627262627262726
272727262727272626262627262726262627262626272726262627262626262626262626
262626272626262626262626262626262626262626262626262726262626262626262626
262526262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262626262626262626262526252626252625262526
252526252626262626262626262625262626252526262526262626262526252625252526
252525262525252525262626252625262525262525262625252525252525252626252625
2525252625252525
252626252526262525252526262625252525252625262526262625262626262626262625
252526262626262525262626262625262626252625262625252626252526262626262626
262626262626262626262526262626262626262625262626262626262626252626252625
262626262625262626262526252626262626262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262626262626272626262626
262626262626272726262626272626262627262626262626262626262626262626262627
262626262627272627262726262726262626272627262726262626272627272727272627
272627272727272627262626262627262627262726262726272626262626272727272627
262627262626262627262726262727262726262727262726272727262726262626262627
262626262626262626262626262626272626262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262625262626262626252626252625262625262626262626262625
262626262626262626262526262625252526262526252526252626252625252625262525
262625252626252626252626252625252626262526252625252526252625252626262526
2526252525252526
262525252525252626262525252526262525262525252526252625262625252626262525
262626252626252626252526252625262525262626262625262625252626262525262625
262626262626262626262626262626262526262626262526262626262626262626262626
262626262626262526262626262626262626262625262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272626262726
262626262626272727262626262627262626262626262626262626262627262626262627
272626262726272727272726262726262626272626262726272626272626272627262726
272727262726262727272626272727272627272627272727272627262727272726262727
262626262627272727272726262727262726262627262626262626262626262726262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
262626262626262526262626262625262626262626262626262626262626262626262526
252625262625252626262626262626262525262525262626252626262626262526262525
262626252625252526262526262626262626252525262525252525252525252525252525
2526262525262525
252625252525252625262626252626252526252626262526262626252526252526252525
252625262526252525262626252625262625262625262626252625252625252626262626
262626262626262626262626262626262626252626262626262626262626252526262626
262626262626262626262626262626262626262626262626262626262626262C29262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262627262626262626262626262626262626262626262727262726272626262626
272627272627272626262727262626272626272726272727272627262727262726272627
272727262727262626262727262727262727272727262627272726262627262727272627
272727272626272726262726262727272626272626262626262726262626262626262627
262626272626262726262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262625262626262626262626262626262626262626
262626262526262626262625262626262626262525262525262625252626262626262625
252625262525262526262525252525252625252525252626262526252526262525252526
2526252525252526
252625252525252625262625262625252525252526252525252625262625252626252526
262526262626262526262625262626262625262626262626262526262525262626252526
262626262525252626262626262526262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262F2C262626
262626262626262626262626262626262626262626262626262727262626262626272626
262626262627262626262626262726262626262627262626272726262626262726262626
272626262626262726272727272627272727272627272727262726272627262727272626
272727272726262726272727272727272727272627272627272727272627272726272727
262727262726272727272727262727272626262627262726272726272726272727262626
262626272726262626262626262626262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262626262625262626262626262626252626262626262626262626
252626262626262625262526252625252626262526262625252526262626252525262625
262525252526262526262526262626252526252625262526262625252526252526262525
2525262525262525
252626262625262526262625252525252625262525252526262525252525262525262526
262525262626262625252625252525252625262625252526262526262626262625262625
252626262625262525252626252626262626262626262625262626262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
272626262626262626272626272626272627262726272626262727272627262626262626
262627272726272726272726262726272727272626272726272727272627262627262627
272727272627272627272726272727272727272626272626272727272727272727272727
262727272727272726272626272626272727262726262727272727272726272626262727
262626262726262626262626262726262626262626272627262626262627262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626252626262625262626262626262626262626262626262625262626
262626262625262526262626252526262626262625252625262626252525262625252626
252525252625262526252525262525262525252525252525252625262526252525252625
2526252525262525
252625262526252525252526262526252625262625262525262625252525252626262626
252525262626252525252626262526262626262526262626252625262625262626262625
252626262626262625262625262525262626262626252526262526262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262726262626262626262626
272627262627262627262627262726262626262727272627262727272726272626272627
272726272727272727272727262626272727272727262627272727272726272727272727
272726272627272727272727262727272727272727272627272727272727272727272727
272726272627272727272626262726262627272726272626262727272626262727262626
272726262626262626262627262626262626262626262626262626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252526262626262526262626262526262526262526262626262626
262626262626262625262526262626262626252626262626262526252626252626262626
262526252525252526262525262625252625262525252625252526252625262526252625
2625252625252525
252625252525252525252525252625252526262525252626262526262526252525252526
262525262525262526252526262526262626252626262526262626252626262526252626
262626262626252626262626262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262627262626262626262626262627262626262626262626262626262626272627
262626262627262726262626272627262626262626272626262727262726262626262726
272726272627262627272726262726262627272726272727272727272727272727272727
272726272727272727272727272727272727272827272726272727262727262726272727
272727272727272727272727262727272727272627272727272627272627272627262626
272626262726262726272626262626272626262626262626262727262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262625262626252626252625262526262626262526262526262526
262525262525252626262525252525252625262525252625262525262526262526262625
2525252525262526
252625252525252626252626262525252626262525252526252626262626252625262526
252526262525262626262526252525262626252625262626252626252526262626262626
262625262626252625262626262626262526262626252626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627272626262626262627262626262626272626262626262626
262627272627262727262727272627262726272626262627272627272627272727272726
272726262727272726272627272627272727272727272727272727272727272727272627
272726272727272727262727272727272727272727262726272727272727272727272727
272727272726272727272726272726262727262627272726272727272627262727262626
262626272726272626262627272726262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262625262626262626262525
262626262626252526262626262626262626252626262526262625262626252625262526
262626262625252525252525262525262526262526262625252525252525252526252525
2525252525252526
252525252525252625252626262625252626252526252526252626252526262526252525
252526262525252626262626262625252625262625262526262526262625262626252626
262625252626262626262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262626262626262626262626262626262627
262626262626262626262726272627262626262626272726262626262627262627272726
262626262626272627272626272626272727272727272726272726272627272627272726
272727262627272627272727272727272727272727262727272727272727272727272727
272727272727272727272727272727272728272727272727272727272727272727272727
272727272727272727272727272727272727272727262626272727272627262626262627
272627262626262727262626262626262626262726262626262626262626272626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252625262626262626262626252626262525262526262525262526
262626252626262626262526262625262526252625262525262626262626252525262526
262626262626252526252525252526262525252625252626262525252525252625252526
2525262525252626
252625252526262525262626262625252626252626262625252625252626262526262625
252525262626262626262526262525262626262625262525252626262626262626262626
262626252626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
262626262726272626262626262626262627262726262626262626272626262627272627
262727262727272626272726272726272726262727272726272627272727272727272727
272726272727272726272727272727272727262727272727272727272727272727272827
272727272727272727272827272727272727272727272727272727272727272727272727
272727272727272727262727272727272727272627262727262727272727272727272627
262726262727272626262626272626262726262626272626262626262626262626272626
262626262626262626262626262626262627262626262626262626262626262626262626
252626262526262626262626262626262626262626262626262626262626262626262526
252626262626262526252625252526262626262625262626262626262626262625262625
262625252626262526252626262626252625262526252626262526262525252525252626
2525252625262525
252625252526262525252625262625262626262526262626262526262626262626262626
262626252525262625262625262626252626262526262626252625252626252626262626
262626262625262626262626262626262626262626262526262626262626262626262626
262626262626262626262626262626262626262626262626262626272626262626262626
262627262626272627262626262626262727262626262626262626272627262726262626
262626262627262727262727262727272627272626272627272727262727272727272627
272727272727272727272727272727272727272727272727272727272727272727272727
272727272828272727272727272727272727272727272827272727272727272727272727
272727272727272727272726272627272727272727272727272726272627272727272727
272727262726272727262726272626262726262626272626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262625
262626262626262625262626262626262626262626262626252525262526262625262626
262525262526252526252626262525252525252525252525262626262626252626262625
2525252525252525
252626262626262525252526252525262526252626262626262525252526262626262526
262626262626262626262626262625262626262526262625262526252526252626262626
262625262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262627262727272726262626
262627272627262626262727272727272727272627272727272727262727272627272727
272727262727272727272727272727272727272727272727282727272727272727282727
272727272728282727272727272727272727272727272727272727272727282727272727
262727272727272727272728272727272727272727272727272727272727272727272727
272727272627262726262626262627272627262726262627262726262726262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262526262626262626262526262626262626262626262626262626
262625262626262526262626262625262526262625262626262626262625262526252626
252626252626262625252626262626262526262625252525252526252626252626262525
2526252625262525
252625252525252525262626262525262626262525262525252525252525262626252626
262526262525262526262525262526262525262626262526262625262526262626262625
262626252626262626262626262626262626262626252626262626262626252625262626
262626262626262626262626262626272626262626262626262626262626262626262626
262726262626262626262626262626272727262726262726262626262626272726262627
272726272727272626262726272727262726272727272727272727262627272727272727
272727272627272727272727272727272727272727272727272727272727272727272728
272827272727272727282727272728272727272727272728272827272727272727282727
272727272727272727272727272727272727272727272727262727272727262727262727
272627262726272726262727262627272727262626262727262626262626262627262626
260026262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626262626262626262625262625262526262626262626252626
252626262626262626262525262626252626262626252626262625262626262526262525
262625262526252526262526262525262525252625262525262626262525252525252525
2525252625262626
252626262626262525262625252526262625252626262626262626262526252626252626
252626262526262626262626262626262625252626252626262626262626252626262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272626262626
262626262726262626262626262626262626272727272627272627272626262627272727
272726272626262727272627272627272726272727272727272726262727272727272727
272727272727272727272727272727272727272727272728272727272727272827272828
282728272828282728272728272727282827272828272827282728272828272827272827
272727272728272727272728272828272827272727262727272727272727272726272627
262727272727262727262626272626262726262626262626262626262626262626262626
262426262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
252626262626262626262626262626262626252626262625262626262626252625252625
262625252526262626262625262625262526252525262526252626252626262626262525
2526262626252625
252526262525252526252625262625252525262625262525262625262626252625252525
262525262525262626262626262626262626252626262626262626262626262626262626
262625262626262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626272627272626262626
262626262626272626262626262726262627262727262626262626272726262626262626
262626272727272627272727272727272727272727272727272627272727272727272727
272727272727272727282727272727272727272827282727272828272727272727272727
272728272727272828282827282727272827282828282728272827272728282728282727
282827272828272727282727272727272727272727282727272727282727272727272627
272627272727262626262726272627262627272627262627262627262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252626262526252626262626262626262626262626262626262626262526
262626262625262526262626262625262526262625262625262625262526252625262526
252626262526262626262526252626252525262625252625262526252625252526262525
2625252526252525
252626262526252526252525262525252626262626252526252625262626252525262525
252526262625262625262626262626262526262626262626262626252625262626262626
262626262626262626262626262626262526262626262626262626262626262626262626
262526262625262626262626262626262626262626262627262626262626262627262727
262626262626262726272627272626272727262726262626262726262627272727272726
272627272627262727272727272727272727272727272726272727272727272727272727
282727272727272727272728272727272727272828282727282727282827272727282828
272728282827282728272828282728282828282828282828282728282828282727272827
282828282827272828282827272727272728272727272727272727272727272727272727
272727272627272627272726272727272626272727272727262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262626262625252625262626252626262626252625252526252625
262526262625252525252625262625252525262525252525262525252525252525252526
2526262526252526
252625262526262626252525262525252526252626252526262526262626252625252625
262626252525252626262626262625252526262626262626262526262626262626262626
262626262626262626262626262626252626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262727262626262726272726
262626262627262626272626272726272626272726272727272627272626262726272727
272726272727272627262727272727272727272727272727272727272727272727272727
272727272727272827282727272827282728272828282727272828282728282828282828
282827282828282827282828282827282828282828282828282728282828282828282827
282827282827272828272827272727282727282728272827272728272727272727272728
272727272727272727272727262627272727272726262626262626262727272727262726
262626262626262626272626262626262626262626262626262626262626262626262626
262626262626262626262625262625262626262626262626262626262626262626262626
262626252526262626262626252625262626252626262525252626262626262626262526
252525252626252526252626262526262625262625252626262525262625262625252526
2526252625252626
252525262525252525252525262526252525252626252625262626252525252626262526
262625262525252626262625262626262626252626262526252626262626262626262626
252626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262626262626262626262626262626272627
262727262726262626262626262627262726262626262727262626272727272626272827
272626272627272726272727272727272827272727272727272727272727272727272727
272727272727272827272828282828282728282728282828282828282828282828282828
282828282828282828282828282828282828282828282828282928282828282828282828
282828282727282728282727272727272827272727272827272727272727272727272727
272727272727262727272727272727262726272726272727262626272726262726262627
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626252626262626262626262625262626262625252625252626252626262626262526
252626252626252525252525252526262626252625262526262525252526252625252625
2525252526252626
252625262526252626262625262626252626252526252625262526252626262625262626
262526252626262626262626262526262626262625262626262625252626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626262726262626262727
272726262627272627262627262627262627262627272726272727262627272727272726
272727272727272727272727272727272727272727272727272727272727272727272827
272827272827282728272827282828282828282728282828282828282828282828282827
272828282828282827282829282828282829282928282828292829282828282828282828
282827282828282828282828282827272827282727282728272728272827272727272727
272727272727272727272727272727272726272726262627262726262727262727262626
262626262626262626262626262626262626262626272626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262626252626252626262626262626252525252626262626262626262526
262626262526262626252625262525252625262626262526252526262526262525252526
2626252525262625
252625252625252526252625252525252525262526262625252626262525262526252626
262525262525262626262626252626262626262625262626262626262626262626262526
262626262625262626262526262626262626262626262626262626262626262626262726
252626262626262626272626262626262626262626262626262726262626262626262626
262626272626272627272727262627272727272726272727272626272727272727272627
272727272627272727272727272727272727272727272727272727272727272728272727
282828282728282827282828282828282828282828282828282829282828282829292828
282828282928282829282829292829282929282929292829282828292828282828282828
282828282828282828282728282827282827272828272728282727272727272727272727
272727272727272727272727272727272727272726262727272627272626262626262626
272626262626262726262726262626262626262627262626262626262626262626262626
262626262626262626262625262626262626252626262626262626262626262626262626
252626262526262626262626262526262626262626262626252525262625262626262525
262626252626262525252626262626252626262525262625252625262525252526262625
2525252525262525
252625252626262625252526262525262526252626262626262626262626252626262626
262526262626262626262625252625262625262525252526262626262526262626262526
262626262626262625262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262726272626262626272626262626262726
272727272726262727262627262726272726272727272727272626272727272727272727
272727272727272727272727272727272727272728272727272728282727272728282827
272828282828282828282828282828282828282928282828282828292828292828292829
282929292928292929292929292929292929292929292929292828282928282928292829
282828282828282828282828282728282828282828282827282827282728272827272727
272727272727272727272727272627272727272627272727272626272627272626262626
272626262627262627262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625252626262526262626262626262626252625262626262625262626252526262526
262526252626252525262625262625262525262625252525262525262525262625262626
2625252625252526
252625262526252626262626252525262625262526252626252625252525252626262526
252626262526262526262625252626262626252626262626262626262626262626252626
262626262626262626262625252626262626262626262626262626262526262626252626
262626262626262726262626262626272626262626262727262626262726272626262726
262627262726272727272727262627262727272627262727262626272727272727282727
272727272727272727272727272727272728272728272728272728272728272828272728
282828282828282828282828282828282828282829282828292929282828292929292929
2929292929292929292A292929292A2A2929292929292929292929292929292929292929
292928282828282828282828282828282828282828272828272827282727272728282727
272728272727272727272727272726272727272727272727272727272627272726262727
272627272726262626262626262627272626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262625252626262626262626262626262625262625262625262626262626262625
262525262626252625252625262626252626262526252625262625252526252525262626
2625262526262625
252626262626262526252626252626262526252626252626252526262525262526262626
252626252526262626262626262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262627272626262626262626262626
262626262626262626262626262627272627262626262626262727262626272727262726
272626262727272726272726262627272726272727272727262727272727272727272727
272727272727272727272827282727272827272728282828282727282828282828282828
282828282828282728282828282829282929292829292929292929292929292829292929
292A29292A292A292A292A2929292A29292929292929292929292A292929292929292829
292929292928282828282829292928282828282828282828282827282827272728272728
272728272727272727272727272727272727272727272727272727272627262726272726
272627262626262626272626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262526262626262625262626262626262626
262626262626262626262526262626262626262626262526252625262626262526262626
252625262625262626262625252625262525252526262526262525252625252526252626
2625252526252525
262625262626252625262626262626252525262625262626252526262625262626262625
262626252526262626262626262626262626262626262626262526262626262626262626
262626262626262626252626262626262526262626262626262726262626262626262627
262626262626262626262626262626272626272626262627262626262726262626262626
262626262627272726272726272726272626272727272727272727272727272727272727
272727272727272727272827282727272727272827272727282828282828282828282828
282828282828292928292828282929292929292929292929292929292A292929292A2A2A
2A2A292A2A2A2A2A292A2A2A2A2A2A2A2A29292A2A2A2A2A292A2A2A2A292A2929292929
292929292929292929292829292928292928282828282828282828282828272827272728
272727272727272727272727272727272727272727272727272727272727272626262727
262627262726262626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626252626262526262526262626262626262526262626262626262525262626262626
262626262626262625262626252625252626252526252625252525252525252626262526
2626252625252526
262626252526262526262626252625252626262526262626252626262625252626252626
262525262625252625262525262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626262626262626272626262726262626262627272627272627262626
262627272726272627272627272726262727262727272727272727272727272727272727
272727272728272727282828282828282827272828272828282828282828282828282828
2928282828292828282928292829282929292929292A292A29292A2A2A2A2A2A2A2A2A2A
2A2A2A2A2A2B2A2A2A2A2A2A2A2B2A2A2A2B2A2A2B2A2A2A2A2A2A2A2A2A292A2A2A2A29
29292A2929292A2929292928292929292928292828282828282828282828282828282828
282827272828272727272727272828272727272727272726272627272727272727272626
262727272626272726272726262627262626262626262626262626262626272626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626252626262626262626252626262626262626262526262626252625262626262625
252526252526262525262625262525262626252625252526262526262625252625262525
2525262626252525
252626252526262525262626252626252626252525262626262525262625252525262626
252625252626262526252526262526262626262625262626262626262626262626262626
262626262626262626262626262625262626262626262626262626262626262627262626
262726272626262626262626262626262726262627262726272626272727272626262726
272627262626262727272726272727272727262627272727272727272727272727272727
272727272727272727272728282828282828282727272828282828282828282828282828
282929292829292929292A29292929292A292A2A2A292A2A2A2A2B2A2A2A2A2B2A2A2B2A
2B2B2B2B2B2B2B2A2B2B2B2A2B2B2B2B2C2B2B2A2B2B2C2B2B2B2B2A2A2A2B2A2A2A292A
2A2A2A292A292A2929292929292929292829292929292828282829282829292827282828
282828272827272728272727282827272727272727272627272727272727272727272727
262726262626272726262626272627262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262526262625252626262526262526262625262525252625252525
252526252625252625262626262626262525262626252626252625262625252626252525
2526252625262626
252625252526252526262526262526262626262625252626252525252626252626252625
252525252626262626262626252626262626262626262626262626262626262626262626
262626262626252626262526262626262626262626262626262626262626262626262626
262626262626262626262626262726262627262627262726262627262626262626262626
272727262627272727272627272727272727262727272727272727272727282727272728
272827272728282827272828272828282728282828282828282828282828282828292929
2929292A29292929292A292A2A2A292A2A2A2A2A2A2A2B2B2B2B2A2B2B2B2C2B2B2C2B2B
2B2B2C2B2B2B2C2C2B2C2C2C2B2C2B2C2B2B2B2C2C2B2C2B2C2C2B2B2B2B2B2B2B2B2A2A
2A2A2A2A2A2A2A2A29292A292A2A29292929292929292928292829292928282828282828
282828282828282827272727272727272727272727272827272727272727272727262727
262627272726272626272626262626262627272626262627272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262526262625262626262626262526262626252625252625262626262626262626
262526262626262526262525252526262526262625252626252625262626262626252625
2526252526252625
252526262626252625262525252526262625252626262626262626262526252626262626
252626262626262525262626262626252626262526262626252626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272626262626262726262626262726262627272727272626272626272627
272727272727262727272726272727272727272727272727272727272727272728272727
272727272727272828282828282828282828282828282829292928282829292929292829
292928292A2A2A2A2A2A2A2A2A2A292A2A2B2A2B2B2B2C2B2B2B2C2B2C2C2C2C2C2C2C2C
2C2C2D2C2C2C2C2C2C2C2C2C2C2D2C2C2C2D2C2C2D2C2C2C2C2C2C2C2C2C2C2C2B2C2C2C
2B2B2A2B2B2B2A2A2A2A292A2A29292A292A292929292929292929282828292828282828
282828282827272728282827272827272727272727272727272727272627272727272727
272627262727272726272726272727262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262625262526262626262626262626252626252626252526262626
262625262626262525262626262625262626252525252625252625252526262525252625
2526252526262525
252626252525252525262526252626262626262526252526262625262626252525262626
252625262626262626262626262626262625262626262626262626262626262626262626
252626262626262625262626262626262626262626262626262626262626272626262626
262626272626262626262626262627262627272626262627262627262726272627262727
272727262727272727272727272727272727272727272727272727272727272727272728
272728282828282828282828282828282828282929282928292929292929292929292A29
2A2A292A2A2A2A2A2B2A2A2B2B2B2A2C2B2B2C2C2B2C2C2C2C2C2C2D2C2D2D2D2D2D2D2D
2D2D2D2D2D2D2E2D2E2E2D2D2E2E2E2E2E2D2D2E2D2D2D2D2D2D2E2C2C2D2D2C2C2C2C2C
2C2B2B2C2B2B2B2B2B2B2A2A2A2A2A2A292929292A2A2929292929292929282928282828
282828282828282828282828282827272727272727272727272727272627262727272727
272727272726262727272627262627262626262627262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626252626262626262626262526262626252626262626262526262626262525262626
262526262626252626262626262626262626252625262526252626262526262626252626
2526262526252525
252626262626262626262526262625252626262626252626262626262526262626262626
262626262626262626262526262626262526262626262626262626262625262626262626
262627262626262626272626262626262626262626262626262726262626262626262626
262626262626262626262626262626272626262626272627262627272627272727262727
262727272727272727272727272727272727272727272727272727272827272727272827
272828282727272828282828282828282929282829292A292929292929292A292A2A2A2A
2A2A2A2B2A2B2A2B2A2B2B2B2A2B2C2C2B2C2C2C2D2D2D2D2D2D2D2D2D2D2D2E2E2F2F2E
2E2E2E2E2E2E2E2E2F2E2F2F2E2F2F2F2F2F2F2F2E2E2F2F2E2E2E2E2E2E2E2E2D2D2D2D
2D2D2C2C2C2C2B2B2C2B2B2B2B2A2A2B292A2A2A2A2A2A2A292A29292A29292829282928
282828292828282828282828272828272728282728272827272727272727272727272727
272727272727272727272727262627272626262726262626262627262626262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626252626262626262626262626262625262625262526
262626262526262625262626262525262625262626252626262525262525252625262526
2525252526262626
252625262625262625252626252526262525262625262625262526262625252625252626
262626262626262626252626262626262526262526262626262626252626262626262626
262626262626262626262726262626262626262626262626262626272626262626262626
262626262626262626262726262726262626262727272627262726272727272727272727
272627262727272726272727272827272727272727272727272728272727272727282727
2727282827282828282828282828292929292929292A292A2A292A2A292A2A2A2A2A2A2B
2A2A2A2B2A2B2B2C2C2B2C2C2C2D2C2C2C2C2D2D2D2D2D2E2D2E2E2E2E2F2F2F2F2F302F
30303030302F3030303030303030302F3130303030303030302F2F2F302F2F2F2E2D2D2E
2E2E2D2D2D2D2C2C2C2C2B2C2C2C2B2B2B2A2B2B2A2B2B2A2A2A2A2A292A292929292929
292928282828282828282828282827282728272728272727272727272727272627272727
272727272727272727272627272627272627272626262626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262526262626262626262626
262526262625252626252526252626252626252626252625252525252525262525252625
2626262525252625
252626252626262625262526262625262625262525252626262526262626252625262626
262626262626262626262625262626262626252626262626262626262626262626262626
262626262626262626272626262626262626262626262626262626262626262626262626
262726272627272726262626262626262727262727262726272627272627272727272627
272726272727272727272727272727272727272727272727272727272728272828282728
2728282828292828282828292829292929292A29292929292A2A2A2A2A2A2A2B2B2B2B2B
2B2B2B2B2B2B2C2C2B2C2C2D2D2D2E2D2D2E2E2E2E2F2E2F2F2F2F303030303031313030
31313031303131313231313131323132313232323131313131303130303131303030302F
2F2F2F2E2F2D2F2D2D2C2C2C2C2C2C2C2B2C2B2B2B2B2B2B2B2A2A2A2A29292929292929
292929292828282828282828282828282828282727282727272727282727272727272727
262727272727272727272627272626272727272627262626272626262726262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262526262626262625262626262626262626262626
262625252526262626262626252626262525262626252626262525252526252525262626
2525262525252526
252626252626252625252526252525252626262626252626262626262626262626262626
262626262526262625262526262626262625262626262626252626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262726262626262726262627272626262626262626272627262727272627272626272727
272727272727272727272727272727272727272728272727272728272727272828282828
282828282828282829282929292929292A292A2A2A292A2A2B2B2B2B2A2B2B2B2C2C2C2B
2C2C2C2C2D2D2C2D2D2D2D2E2E2E2F2E2E2F2F302F2F2F30303031303131313132313232
323232323332333232333333333233333333333433333332323232323231313231313130
303030302F302E2E2E2F2E2D2D2E2D2D2D2C2C2C2B2C2C2C2B2A2B2B2B2B2A2A2A29292A
292929292829282928282928282828282828282827282828272727272727282727272727
272727272727272726272727262627272626262627272727272626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626252625262626262626252626262626262626252526252526
262526262626262626262526262625252626252625252626262626262526262526262526
2626252525252525
252625252526262526262626252626262626262526262625262626262626262626252626
252526262626262625262626262526262626262626262626252626262626262626262626
262626262626262626262626262626262526262626262626252626262626262627262726
262626262626272626272626262627272627262627272727262627272726272727272727
272727272727272727272727272727272727272727282828272728272828282728282828
282828282828292829292929292A2A2A2A292A2A2B2B2B2A2B2B2B2B2B2C2C2C2B2B2C2C
2D2D2C2D2D2E2E2D2E2F2E2E2F2F2F2F3030302F2F303130313132323232333233333333
323333343434333435343335353534353434353434343434353334343432333333323232
3232303030313030302F2F2E2F2F2E2D2D2D2D2D2C2C2C2C2D2C2C2B2B2B2A2A2A2A292A
292929292929282928292929282828282828282828282827272728282727272728272727
272727272727272727272726262727272727262626272627262626262627262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626252626262626
262625262626262626262625252526262626262525262626252525252525252625252625
2525252626262525
262626252626252625262526252526252525262625262626262625252625262626262526
262626252626262626262626262626262526262626262626262626262626262626262626
272626252626262626262626272626262626262626262626262626262626262726262626
272626262627262626262726262727262726272727272626272626272727262727272727
272727272726272727272727272727272827282827272827282827282828282828282829
282928282829282929292A29292A2A2A2B2A2B2B2B2A2B2B2B2B2C2C2D2C2C2C2D2C2C2D
2D2D2D2D2E2E2E2F2F2F2F30302F30303030303131313132323332323333343334343434
343535353535363635363636363736353636363636373636363535353636353635353434
343333333232313131313030312F302E2E2E2E2E2E2D2D2C2C2D2C2C2B2B2B2B2B2A2B2A
2A2A2A2A2929292929282828282828282828282828282728282827272727272727272727
272727272727272727272727272726262727262627262727272627262627272627262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252625252626262626262626262626252625262626262626252626262526
262525262626262526262526262626262626252625252526252625252626252526262525
2526252625262626
252626262626252625252526252525262626262626262626262626262625262625252626
262626262626252626262626262625262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262626262626262627262626
262626262626262626272626272727262727272627262627272727272727272727272727
262727272727272727272727272728272727272728272728282728282828282828292828
28282829292A2A292A2A2A2A2A2B2A2B2B2B2B2C2B2B2C2C2D2C2C2C2C2D2D2D2D2E2D2E
2E2E2E2F2E2F2E2F30303030313030313132323232323234343335343435363535363637
353737373738383737373938393837373838383937383838383938373838383737363737
3635353434343333333332323130313030302F2F2F2E2E2E2D2D2D2D2C2C2C2C2C2C2B2B
2A2B2A2A2A29292929292929292828282829282828282828272827272727282827272728
272727272727272727272727272727262727272727272627262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262626262626262626252526262626262525262626
262626262626262626262526262626262625262525252626262526262526252625252626
2625252525252626
252625252625252525252526262525262625262626262626262625262626262626262626
252626262526262526262525262626262626262626262526252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627272726262727272726272727262727272727262727272727272727272727
272727272727272727272727272727272728282827272827282828282828282828282929
29292929292A2A2A2A2A2A2B2B2A2B2B2C2B2B2C2C2C2C2D2E2D2D2D2D2D2E2D2E2E2E2F
2F2F2F2F3030303031303131323232323334343434353535353535373636373839383838
3A3A3839393A3B3B3A3A3A3A3A3A3A3A3A3B3A3A3B39393B3B3A3939393A393939383938
3738373636363535353334343333323130313030302F2F2F2E2E2E2D2D2D2D2C2C2C2B2B
2B2B2B2B2B2A2A2A2A2A2929292929292828292828282828282827282828272727272827
272727272727272727272727272727272727272726262727262726272626262627262626
262626272626262626262626262626262626262626262626262626262626262626262626
262526262626262626262626262526252626262626262526262626262626262626262626
262626252626262626262525262525252526262525252626262626252625252526262625
2525262626252626
252625262626262625262526252625262626252626262526262626252626262625252626
262626262626262625262626262626252626262626252626262626262626262626262526
262626262626262626262626262626262626262626262626262726272626262626262626
262626262626272726262727272726272727272727272727272626272727272727272727
272727272827272727272727272727272727272728282828282828282829282928282929
29292A29292A2A2A2A2A2B2B2B2C2B2C2B2C2D2D2D2D2D2D2E2E2F2F2E2F2E2F2F2F3030
30303030313131323232333333333534353635363636373739393939393B393B3B3B3C3D
3D3D3C3C3D3D3D3D3E3C3D3B3D3D3E3D3E3D3E3D3D3D3D3E3C3D3C3C3B3B3A3B3B3B3A39
393939393839373837363635353434343332323131303030302E2F2E2F2E2E2E2D2C2D2C
2B2B2B2B2B2B2B2A2A292A29292929292929292928282828282828282828272828282827
272727272727272727272727272727272727272727272727272726272726272626262726
262626272726262626262626262626262626262626262626262626262626262626262625
262626262626262626262526262626262626262626262626262626262626262526262626
262525252626252526262625252626262625262525252625262525252526262525252626
2626262626252626
262626262526252626252526262526262626262626262625262526262626262626252625
262626262626262625262626262525262626262626262626262626272626262626262626
262626262526262626262626262626262626262626262626262626262626262626262627
272726272626272626262726272726272727262726272727262727272727262727272727
272727272727272727272728272727282728282828282828282828282828282929292929
292A2A2A2A2A2A2A2B2B2C2C2C2C2D2D2D2D2D2D2E2D2E2D2E2E2F2F2F2F303030313131
313232323333323434343435363637373737373839393A3A3B3C3C3C3C3D3E3D3F3F413F
3F41403F414141414241414140414241414041424040403F403F3F3F3F3E3E3E3D3C3C3D
3C3C3D3B3C3A3A39383738373736363534343333333332313231312F2F2F2F2F2E2E2D2E
2C2D2D2C2B2B2B2B2B2A2A2A2A292A292929292929292929282828282828282827282827
272828272727272727272727272727272727272727272627272627262726272726262627
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262625262626262625252626262626
262626262626262626262526262626262626252626252526262625262626262626252625
2626252626252525
252625262626262626262526262626262526262625262525262626262626252626262626
262626262526262626262626252626262626262626262626262626262626262626262626
262625262626262626262626262626262626262726262626262626262626272626262626
262626272627272626272727262727272727272727272727272727272727272727272726
272727272727272727272728272727282828272828282828282829292828292929292A2A
2A292A2A2A2B2B2B2B2C2C2B2C2D2D2D2D2E2E2E2E2E2E2F2F302F2F2F30313132323332
3333333435353536353636383839383A3A3B3B3C3D3D3E3E403F41424242434345454546
47464646474547484747464646464647464646444545454445444444434140414141413F
3F3F3F3E3E3D3D3B3C3B3B3939393838373735353634333332323131313030302E2F2F2D
2D2D2D2C2D2C2C2C2C2B2B2B2A2A2A292A29292929292928292828282828282828282828
272727282827272727272727272727272727272627272727272727262726272626262626
272626262626272726262626262626262626262626262626262626262626262626262626
262626262626262625262626262626252626262626262626262626262626262526262626
262626262626262626262625252525262525262526252526262525252625262626252626
2525262526252526
252625262526252626262625262626252626252626262626262525262626262626262626
262626262626262626262626262526262626262526262626262626262626262626262626
262626262626262626262626262626252626272626262626262626262626262626262626
272627262726272727272627272626272727272727272727272727272727272727272727
27272727272727272728282827282828282828282828282828292829292929292A29292A
2A2B2A2A2B2C2C2B2C2C2D2D2D2E2E2E2E2F2F2E2E2F2F30313131323132333334343435
353436363738383739393A3B3B3C3C3D3E3F3F404242444548464848484A4B4C4D4D4D4E
4D4F50504E4F514F504E4E4E4D4E4E4D4E4E4D4D4D4B4C4A4A4949494847464645444443
4343424241403F3F3D3E3D3D3C3B3A393938383836363636353433333231323130312F2F
2F2E2D2D2D2D2C2C2C2B2B2C2B2A2A2A2929292A29292929292928282828282828282828
282828272828272728272727272727272727272727272727262627262726272627262626
262626272726262626262626262626262626262626262626262626262626262626262626
262626252626252626262625262626262626262626262626262626262626262626262626
262625252526252625262626262626252626262525262626262626262625262526252625
2625262526262626
252625252625252525262625262526262625262626262626262626252626252625262626
262625262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262726262626262626262626262627262626262626
262727262726272726272727262727272727272727262727272727272727272728282728
2727272827282728282828282828282828282928292929282929292A2929292A2A2A2A2A
2A2B2B2A2B2C2C2D2C2D2C2E2E2E2F2E2F302F3030303231323233333233343534363637
363738373A3A3C3B3C3D3F3E3F40414344444545474948494B4D4C4C4D4E4F5051525453
545354555757575656565759585558585758595757575355545450514E4E4C4E4C4B494A
48474645444442424040403F3E3E3D3C3C3B3A3A39383837363736353333333232323130
30302E2E2E2D2D2D2D2C2C2B2B2B2B2A2A2A2A2A2A2A2929292929292829282828282828
282828272728282727272727272727272727272727272727272626272726272727262727
262627262627262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626262626262626252626262626262626
262626252626262625262625262626262626262625252626262625262626252525252626
2626252525262525
252625262626262626252626262626262526262626262626262626262626262625252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626272626262726262626262626262626262626262726
262626262727262727272727272726272727272727272727272727272727282727272727
2727272727272828282828282828282828292828292929292A2929292A2A2A2A2A2B2B2B
2A2B2C2C2C2C2C2C2E2D2E2D2E2E2F30303030323232323333333434343536363839393A
3A3B3C3C3D3F3F404242434344444547464949494A4B4A4D4D4F4E4F5051525252545456
56575757585A5A5A5B5C5C5C5D5E5E5D5E5F5F605F5E605F605D5D5B5A57565456545250
4F4C4D4B4A4947464544434142403F3F3D3D3D3B3B3B3A3A393937363735353433333232
313030302F2F2F2E2D2D2E2D2C2C2C2C2B2B2A2A2B2A2A292A2929292929292828282828
282828282728282727272727282727272727272727272627262727262626262726262627
262726262727262627262627262626262726262626262626262626262626262626262626
262625262626262626262626252626262625262626262626262626262525262625262626
262626262526262626252526252526252626262526252626262626262625262625252625
2526262626252525
252625262626262626262626262625252626262626262526262626262626252626262626
252626262626262626262625262626262626262626262626262626262626262626262626
252627262626262626262626262626262626262626262626262626262626262627272627
262726272726262627272727262727272727272827262727272727272727272727272727
272827272727282828282828282828282828292829292929292A2A292A2A2A2A2B2B2B2B
2B2C2C2C2C2D2D2D2E2E2F2F303030303132333233333434363636373839393A3B3C3C3D
3E3E414141414342444446474647484747484A484B4A4A4F4C4F50515252525254555557
56575758595A595B5D5E5D5F6061606362626365636564646563646364606160605E5D5B
5A585453504E4D4F4C4A4847464443424141403F3E3E3D3C3C3B39383837373735353434
333232313130302F2F2E2E2D2D2D2C2B2B2B2B2B2A2A2A292A2929292929292928282828
292828282828282828272827282727272727272727272727272727272727262627272726
272627262726262627272626262726262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262526
262626262626262526252526262626252626252625262625262526262626252626262526
2525252625252525
252625262626262626262525262625262525252525252525262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262626262726262626262726262627262626262726262726262626262627262626
262626262727262626272727272727272727272727272727272727272727272727272727
2827282827272828282827282829292928292929292929292A2A2A2A2A2B2B2B2B2B2C2C
2C2C2D2D2D2E2E2E2F2F303030313131323333343535363738393B3A3B3D3D3D3F3F3F41
41424242434343454547474847484849494A4B4B4C4B4D4C4F5050515252535556545456
5756575859585A5B5D5E5E5F61606162646366646668676665686867696B696766686665
6462615D5C5958575452504C4A4A48474545434242403F3E3D3C3C3B3B3B393838383536
35343433323131302F302F2F2E2E2E2D2D2C2B2C2B2B2A2B2A2A2A29292A292929282929
282828282828272827282827282727272727272727272727272727272727272727272726
272727262726262626262627272626272626262626262626262626262626262626262626
262626262626262625262626262626262626262626252626262626262626262626262626
262526262626252626262526262626262525252626262526262526262626252526262625
2626262526262526
252626262526262626262626262626252626262626262626262626252626262626262625
262626262626262626262625262626262626262626262626262626262626272626262626
262626262726262526262626262626262726272726262626262627262627272626262627
272727272627262727272727272727272727272727272727272727272727272827272827
2827282828282828282829292829282929292A2A292A2A2A2A2A2B2B2B2B2B2B2C2C2C2C
2C2D2D2E2F2F2E2F2F30313132333232333635363839393B3C3D3E3E403F404142424241
4345444445444545474849494A494A494A4D4B4B4B4C4D4C4F4F50515152545455565555
57565959585A5A5B5D5D5E5F606162606163646765686868696B6B6C6C6B6C6C6C696A6B
6A696967656563615F5E5A5553504E4E4A4A48474645444241413F3E3D3C3B3B3B393938
3736363534333232323131302F2F2E2E2D2D2D2C2B2B2B2B2A2A2A2A292A292929292928
292928282828282828282828282728272727272727272727272727272726272727262626
262727272626262727262627262626262626262626262626262726262626262626262626
262626262626262626262626262626262626262626262626262626262526262626262526
262626262626262626252526262625262626262626252625262626262625252626252626
2626262626262526
262625262626262626252626262626262626262626262626262526262626252626262626
262626262626262626262626262626262626262626262626272626262626262626262626
262626262626262626262626262626272626272626262626262626272726262727262627
272726272627272727272727272727272727272727272727272727272727272827282827
282828272828282828292929292929292A2A292A2A2A2A2B2A2B2B2B2B2C2C2B2C2C2D2C
2E2E2E2E2F2F302F3032323333333535363839393B3A3B3E3E3F40414142424242434445
44454546454645464948494B4C4C4B4C4C4C4C4C4C4C4D4D4E4F50535453535355575757
56575858595B5C5C5B5E5C5E5F60606061626563666869696B6C6B6D6E6F6D6A6C6E6E6D
6C6D6F6E6C6B6B6A686866645F5C585553504E4C4D4A4847464444423F3F3F3D3B3B3B39
39383737363534343332323130302F2E2F2E2D2D2C2D2B2C2C2B2A2A2B2A2A2A2A292928
292929292928282828282828282827282727282727272727272727272627272727272727
272727272626262626272726262626262727262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262625262526262626252625262625262625252626252525252625252625
2525252626252625
252626252526262626262526252626262626252626262625262626262626262625262626
262626262626262625262526262625262626262626262626262626262626262626262626
262626262626262626272626262626262626262626262626262626272626262627272726
272626272727272727272727272627272727272727272727272727272727272728272828
28282828282828282828292828292A2A2A2A292A2A2A2B2B2B2B2B2B2C2C2D2C2D2D2D2E
2E2F2F303031313232333334353637393A3B3B3B3D3F3F41404242434242444444444545
4647484747484849494A494B4C4C4C4B4D4C4C4E4E4D4F4E4F5051525254565556555857
5A585A5B5B595B5C5E5C5D5D5F5E606161626366656769696B6B6C6C6D6F70706F6E706E
6F6E72726F72706E6D6F6C6B676664605E5C595554504E4E4A48474645444240403E3D3D
3C3B3A3A393737373534343331313031302F2E2E2E2D2D2C2C2B2C2B2A2A2A2A2A292929
292929292929282828282828282827272827272727272727272727272627272727272727
272627272726272627272627262626262626272627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262525
262626262626262626252626262626262626262625252626262526262625262526252526
2626262525262526
252625262526252526262625252626262526262526262626262626262626262626262625
262626262626262626262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626272626272726262626262626262627272626
262726272727272727272726262727272827272727272728272728272827282828272827
28282828282828282929282929292A2A2B2A2A2B2B2B2B2B2B2C2C2C2C2D2D2E2E2E2E2F
2F2F303132323233333635373839383B3B3C3D3F40424141434343434445434546454546
4748484948474949494C4B4C4C4D4E4D4D4D4E4E4E4F4E50505152545354565656575957
5958595A5A5D5B5C5B5D5E5F5F60605F626363646567696A6C6B6A6C6D6F706F706E716F
7071727370716F717170706E6D6D6A6B686463615E5A585551504D4A494847444243403F
3E3E3D3B3A3B393838353634343333323131302F2E2E2E2D2D2C2C2C2B2B2B2A2A2A2A29
2A2A29292929292828282827282827282828272728272727272727272727272627272627
272627272726262627262626262726262627262626262626262626262626262626262626
262626262626262626262626262625262626262626262526262626262626252625262626
262626262626262626262626252526262626262626262626252626262626252526262626
2626252625252525
252625252526262625262626262626262626262526252525262626262626262526252626
262626262626262626262626262626262626262626262626262626262626262626262727
262726262626262626262626272626272626262626272726262626262627272626262727
272727262627272727262727272727272727272727272728272828272727282828282828
29282929292829292929292929292A2A2A2B2B2B2B2B2C2C2C2C2C2D2E2E2D2E2E2F3030
303131323334353536373739393B3B3C3D3D3F4043434243434545464745474747484849
484A4A4A4A4A4B4B4B4C4D4D4E4D4D4D4E4F4F50504F5150535255545556565657575859
595A595A5B5C5D5C5D5E5C5D605F616262626564636567696A6A6B6C6D706E7072707272
70727272727072727274717072706F6E6E6C6D696763645E5A5856524F4D4B4847464443
42413F3E3D3D3B3A39393737363534343231323030302F2E2E2D2C2D2C2B2C2B2B2A2B2A
292929292929282828282828282727282827282727272727272727272727272727272727
272727272727272627262627262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626252625262626
262626262626252626262626252526262626262625262626252625252625262625262525
2625262526252625
252626262626252526262625262526262625262626262626252626262626262626262626
262625262626262626262626262626262626262626262526262626262626262626262626
252726262626262626272626262626262626262726262627272627272627262727272626
272726272726282727272727272727272727272827272728282727282728282828282828
282828292929292929292A292A2A2B2B2B2C2B2C2C2C2C2D2D2D2E2E2F2E2F3030303032
3132343535353737383839393A3C3D3D3E3E40414343454544454547484749484948494A
4B4C4B4A4C4C4D4C4D4D4D4F4F505050505050515252525252545653555757575757595A
595B5B5C5B5D5C5E5E5E5E5F5F6061606465646463666769696A6B6B6D6D6D6F71717072
747574737272747375737473737272727271706E6B6B69686561615D595554504E4B4A47
46454242413F3E3D3B3B393A39373636343333323131302F2E2E2E2E2C2D2B2B2B2B2B2B
2A2A2A2A2929292929282828282928282728282728272727272727272727272727272727
272726272727272626262626272726262726262626272626272626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
252626262626252626262626262626262526262526262526262625252625252526262626
2625252525252525
252625262526252626262525262626262626262626262626262526262626252626262626
252526262626262626262626262626262626262626262626262626262627262627262626
262726262626262726262626262626262626272626272726262727272626272727272727
272727272626272726272727272727272727272827272828282827282827282828282829
292928292929292A2A2A2A2A2A2B2A2B2B2C2C2C2D2D2D2D2E2E2E2E2F30303131323233
34353537383738383A3B3B3B3C3D3D3E3F414142454546464746484949494A4A48494B4A
4C4C4C4B4C4C4E4F4E4E504F515051525151515354525354555554555656585559575958
5A5B5C5C5B5C5C5E5E5E5F6062626163636365656668686A6A6A6B6B6D6E6F7170717271
74747474747474767474747375747572757373716E6E6E6C6B6B686665625D5B5754504F
4B494745434241403F3D3C3C3A3A38373635343433323130302F2F2D2D2D2D2C2C2C2C2B
2B2A2A2A2A2A292929292829292828282828282828282828272728272727272727272727
272727272726272727262627262726262626272626272626262626262626262626262626
262626262626262626262626262626262626262526262526262625262626262626262626
262626262626262625262626262626252626262626262626262626262625252526252525
2625262626262526
252626262626262626262626262526262626262626262626262625262626252626262626
252526262626262626262626262526262626262626262626262626262626262626262627
252626262626262627272626262726262626262726272627262726272627262726272627
272727272727272727272727272727272728282827272827282828272828282828282929
28292929292A292A2A2A2B2A2B2B2B2C2C2C2D2C2D2D2D2E2E2F2E2F3030313132323436
363638383839393A3B3C3C3D3D3F403F424245464647464848484949494A4B4B4C4A4B4B
4C4C4E4E4E4E50514F505051515251505354535255535555565555555858565858575759
5A5B5C5C5D5F5C605E5F60606160616362636566676767676B696A6B6F6F6F706F707371
7372747473747675757274757574747373737372717071706F706D6D6B69686362605C55
524F4D4B4A4646434241403D3D3D3C3939383736353533323131302F2F2E2E2D2D2D2C2C
2C2B2B2A2A2A2A2A2A292929282929282828282828282827272728272727272727272727
272727272727272727262626262726272627272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626252626252525252626262626262626262625262525262526262625
2626262625252625
252626252625262626262626262626252526252625262626262526262526262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262726262626262627262726262627262627262627262626272727262726262627
272727272727262727272727272727272828272728282827282828282828292828292828
292A292A29292A2A2A2A2A2A2B2C2C2C2C2C2D2E2D2E2E2F2F3030313132333435353637
373939393A3B3B3C3C3D3E3F404042424445464847474948494A494C4B494C4A4B4B4D4D
4C4E4D4F505050515052515252525253525352535454555555575756565658575858585A
5B5B5D5A5D5B5F5D61605F61626061616463666465686869696C6A6D6E6E6C707070706F
72747373727476747476757575727576747776737474737372727370716E6D6B6A67635F
5C5A5552504C4A4746444442403D3C3C3C3A393837363534333131302F2F2F2E2E2E2D2C
2C2C2B2B2B2A2A2A292A2929292928282828282828272728282728282827282727272727
272726272727262727262627272626272627262626262626262626262627262626262626
262626262626262626262626262626262626262626262626262626262626252626262626
262625252626252525262626252626262626262626252526262626252526262625262526
2625262526252526
262625262626262526252626262626252626252526262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262626262626262726
262626262626262626262727272726272726272626272626262726272627262727272727
262727272727272727272727272728272728272728272828282828282828292929282929
29292A2A2A2A2A2B2B2A2B2B2C2C2C2D2C2D2D2D2E2F2F30303131323335353636363838
39393A3B3C3C3E3D3F3F404141424345454649484A4A4B4A4B4C4C4C4C4D4C4D4C4D4D4D
4E4F515052525353525355535253535454555455545656565656575658575857595A585A
5A5A5B5C5C5E5F5E5F5F6160616263646364656466646767696A6A6C6E6A6C6D6F707071
717271747676787877757678767575777576767576777574757573737270706E6E6C6A68
6464615B59534F4F4D4948444441403F3E3C3D3A3A393837363433323131302F2E2E2D2D
2D2C2C2B2B2B2A2A2A2A2A292A2929282828282828282828282828272727272727272727
272727272727262727272726272727262726262727262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262526262625252626262626262626262626262625262526252626262526262626
2625262625262526
252625252626262625252526252526262626262626262626262626262626252626262526
262626262626262626262526262626262626262626262626262626262626262626262626
262626262627262626262726262626262626262627262626272727272627262727272626
27272727272727272728272827272727272728282827282828282828292929282929292A
292A2A2A2B2B2B2B2C2B2C2C2C2C2C2D2D2E2E2F2F303030313233343436363838393939
3B3C3B3C3D3E3E3F404043434444454849484A4B4B4D4B4D4E4E4E4E4D4E4D4E4D4F4E50
51515252525253535354545556565656555656575556575857595A585A585A5958595A5A
5A5C5B5B5B5D5D5F6161606061616262636163646365676769676A6A6B6C6C6D6D6F706E
70727373747575777875777576757576767777767676777975767775757373747070706E
6B6A686663615C5854514E4B48444443413F3F3D3B3C3A3839373534333331312F2F2E2E
2D2D2D2C2C2B2B2A2A2A2A2A292929292929292928282828282828272827272727282727
272727272727272727272626272727262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626252626262626252625262625262625252526262526262526
2526262625262626
262526252526262625262525262526262626262626262526262626262526252626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262626262626272626262726262627272626272726272627262726272727272727
282727272727272727272827272728272727282828282828282828292829282829292929
2A2A2A2A2A2B2B2B2B2B2C2D2D2D2D2E2F2F2F303031323334343535373738383A3A3B3B
3C3D3E3E3E3E41414142444444454749494B4B4C4C4C4E4E4E4F4E504F4E4F504F505151
54535554555455535656555656565657575857565857575758575858585A5A595B595A5A
5C5B5A5C5D5C5C5E5D5F606060616262626363636465676768696A6A6B6D6D6D6D6E6F70
717371747375757477767777787876767876767674767675767576777674747373727272
72706E6B696664615F5955514D4C4847454242413F3D3C3B3A393836363433323231302F
2F2E2E2D2D2C2C2B2B2A2B2A2A2929292928292828282828282828282728282727272727
272727272727272726272726272627262626262626272726262726262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625262626262525262625252626262626262626252526252626262526262626
2626252526262625
262626262526262625252625262626252626262626262626262526262626262626252626
262526262626262626262626262626262626262626262625262626262626262626272626
262726272627262626262727262727262626272726262626272626272727272727272727
2627272727272728272727272727272728282728282828282828282829282829292A2A2A
2A292A2A2B2C2B2C2C2D2C2E2E2E2E2F2F31303232333334363737373938393A3C3B3D3D
3E3E3F4041414243454344454647494A4A4C4C4C4E4F4E50504F50504F51515253525353
5354555554535557545757585858595A59595859575857595A59585859595C5A5B595C5A
5A5B5A5A5C5D5C5E5E5E60606262626264656465646566656667686A6B6B6D6E6F6F6F6F
71707271737476747675767977757A777777787678767978767877767574777573747274
727271726E6C6A6A66635F5B5852504D4A4845444240403E3D3A3A393837363434333130
302F2E2E2D2D2C2C2B2B2B2B2A2A29292928292828282828282828282828282827272827
272727272727272727272726272727272726262727262726262626262626262626262626
262626262627262626262626262626262626262526262626262626262626262626262626
262626262626262626262526262626262626262626262626262626252626262625262625
2625262626262525
252626252626252526262625262626262626262626262626262526262626252625262626
252626262626262626262626262626262626262626262626262626262626262627262626
262726272626262626262627262726262727262627272726272627262727272727262727
2727272727272727272727282727272828282828282829282829292929292A2A292A2A2A
2A2B2B2B2B2B2C2C2C2E2D2E2F2F2F30313133333434363537383838383A3B3B3D3D3D3E
3E41404041434545454548474849494C4C4D4D4E4F4F5051505052505151525454535455
555555555656575658585857575758595A5959595A595A5A5A595A5B5B5B5A5A5C5A5A5B
5B5B5D5B5D5D5E5D605B5E5E616160616164636665656565666665666A6B6C6F6D6E6F70
7170706F7173757576757777797A77797976777776787779777979777979777777777777
74747272747270706C696765635E5956514D4A48464343413F3F3D3D3B39383734343333
3231302F2E2E2E2C2D2C2B2B2A2A2A2A292A282828292828282828282828282827282727
272827272727272727272727272727272627262626262627272626262626262626262626
262626272626262726262626262626262626262626262626262526262626262625262626
262626262626262626262526262626262526262626262526262625262526262626252625
2526262526262526
252626262626262526262626262626262626262626262625262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262627262626262626272626272626262626272726272726272726272727272727262727
27272627272727272827272828282828282828282829282829292929292A292A2A2A2A2B
2B2B2C2C2C2D2C2D2E2E2E2F2F313131333333353536373737383A3A3B3C3C3C3F3E3F41
40424343434544464747474A4A4B4B4B4B4E4F4E50515152535252535252545453555654
5556565657575859575859595958595B595B5B5B5B5A5B595A5A5B5A5A5B5B5C5B5B5A5B
5B5B5C5B5C5C5D5C5B5E5E5E5F606060626264636464646465666666696A6B6C6C6E6F6D
6F6E706E727172747575777676767B797A7C7878777778787A7B797A7979787679777876
7575747373737473706F6F6C6967635F5C55524D4C49454542423F3E3D3D3A3937373535
343231302F2F2E2E2D2D2C2C2B2B2B2A2A2A2A2929292829282928282827282828282728
272827282727272727272727272727272726272726262726262626262726262626262626
262626262626262626262626262626262626262626262626262626262626262626252625
262625262626262526262626262526252526262626252625262626252626262625252626
2626252525262526
252625252526252626262625252625262626262626262626262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262626262626262627272627262626272727272727272726272727272727272727
2727272727272727272727272827282828282828292828292929292A2A2A2A2B2B2B2B2B
2C2C2C2D2C2D2D2E2E2F30303131323334353536363738383A3A3C3B3C3D3E3D3F404042
424344444546464848494A4A4B4B4D4D4E4F4E5050525353555454545555555455575557
545859595A5957585958585A5A5A5A5B5C5B5C5C5C5C5D5B5A5D5E5C5C5B5D5C5D5B5E5C
5A5B5B5E5B5D5C5D5C5D605F606060606161626562646563656566686768686A6B6B6D6D
6E6D6E6E707073737476777676797677797E777A7877797979797A7B787A7A78787A7879
79777775747575747472716F6E6C6B66635F5B58524F4A4946444242403F3E3B3A393837
3634333231302F2E2E2E2C2C2C2C2B2B2B2A2A2929292928292928282828282828272728
272727272727272727272727272726272726272726262727272627272627272626262626
262627262626262626262626262626262626262626262626262626262626262626262626
272626252526262626262626262626252626252626262626262626252626252626262525
2626262525252626
252626252525252626262626262626262626262526262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626272626262626262727272627272726272727272726272727272727272727272727
272727272728272727272728282828282828282829292829292A292A2A2A2A2B2B2B2B2C
2C2C2D2D2D2D2D2F3030303133323334353636383939393A3C3C3D3D3D3E3F4142424243
4445454647484A494A4A4B4D4C4D504E4F4F515152535454535556565556565858575658
58585958595A5A5B5A5B5B5B5B5E5C5B5E5D5E5E5E5F5E5D5D5E5E5C5D5C5C5C5E5C5C5B
5C5C5B5C5C5C5C5C5C5D5F5F5E5F60606060616163636363646365666665666A6B696C6C
6C6D6E6C707071727073757576777577777677777676797A78777A78797A7B797A797978
7B7877787776757574757272726F6E6C6C6A65635D5554504C4A4645434341403D3B3939
3836353433313030302E2D2D2C2C2C2B2B2A2B2A29292929292829292928282828282827
282727282727272727272727272727272727262626272726262726272727262626262626
262626262626272626262626262626262626262626262626262626262626262626262626
262826262626252626262626262626262626262626262626262625262626252626262526
2626262526262626
252625262625262526262626252626262625262625262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262726262626262627262727272727272726272726272727272727272727272728
27272727272728272728282828282828282928292929292A29292A2A2A2B2B2C2B2B2C2C
2D2D2E2E2E2E2F2F303132333435353637373838383A3B3C3D3E3E403E40414243444545
46464649474A4A4A4C4C4C4D4F4E4F51515252545454555557565556585858595858595A
5A59595A5A5B5A5B5B5C5C5D5C5E5D5D5D5D5D605F5F605F5E5D5C5E5D5D5D5B5D5D5D5D
5B5D5D5D5D5B5C5A5B5B5E5F5D5E5F5F615F6161626364636465646466646767666A6B6A
6B6C6D6E6E6F727070727474757675767776767777797A7C7A7778797A7A7B7B7B7A797A
79797A7A787877777776747574727171706E6B6966625E59554F4C4A46464442403F3E3C
3A38373636333331302F2E2E2E2D2C2C2B2B2A2A2A2A292A292828292928282828282728
282827272727272727282727272727272727272627272626272727262626272626262726
262626262626262626262626262626262625262626262626262626262626262626262627
262626262626262626262626262625262526252526262625252626262625262526252626
2525262626262526
252626262625252626262526262626262626262626262625262626262626262626272626
262626262626262626262626262626272626262626262626262627262626262626262626
262627272627262627262726262626262627272727272627262727262727272727272727
27282727272727282828282828292828282829292929292A2A292B2A2B2B2B2C2C2C2D2D
2D2E2E2E2F313031313333343636363738393B393A3C3C3E3D4040414242434344454646
4748484A4A4B4B4E4D4E4E4F5051525252555452555657575758585758595A595A5A5B5A
5C5C5B5C5C5C5D5D5D5D5E5D5C5F5F5E605F6160606162605E605D5F5E5F5D5D5D5D5D5D
5E5D5D5D5C5C5B5D5D5C5E605F605E606060606161646364626364646465676667686969
6B6C6C6C6D6E70707172727675767576777576767778797A7A7A7A7A7A7B787C7B7A7B79
787A797979797A7875777877777475727272716E6E6A68655D5855514D4846464343403E
3C3A3B39373635343231302F2F2D2E2D2C2C2B2B2A2A2A29292929282828282828292828
282827272727282727272727272727272727272726262726272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262526262626252626262626262626252626262525262626262626252626
2626262526262626
252626252626252625262526262626262626262625262626262626262626262626262626
262626262626262626262627262626262626272626262626262626272626262626262626
262727262626262626272727262726262627272727272727272727272727272727272827
2727272728272828282828282828282929292929292A292A2A2A2B2B2B2C2C2C2C2D2D2E
2E2F2E3030313233343435353637383939393C3B3D3E3F3E404041424244454446464849
4B4A4B4D4E4E4F4E504F4F5153545253555655565657565757595A59595A5A5A595B5C5C
5C5B5C5D5D5D5E5E5E5D5F5F5F5E6060605F61605F60615F625F615F615F5F5E5D5E5D5D
5D5C5E5B5E5C5D5D5D5D5F5E5F5E605F615E616162616064636463636564656467676868
6A696A6B6B6F6F6E6E7170727375747575767875797979777C7B7878787B7A7C7C7A7B7B
7A797B7B787A797878787776767675747474737070706D6A69645E5A534E4E4947464441
3F3D3D3B3938373635333231302F2F2E2C2C2C2C2B2B2B2A2A2929292929292828282828
282828282827282727272727272727272727272727272627262626272627262626272626
272626262626262626262626262626262626262626262626262626262626262626252626
262626262626252626262626252626262626262526262526262526252626262625262626
2626252525262525
262626262626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262626252626262626262626
262626262627262626272727262627262727272727272627272726272727272727272728
27272828282828282828282828282929292829292A292A2B2B2A2B2B2B2C2C2C2D2E2E2E
2E2F303132323434343537363838393A3A3C3D3D3F3D40404041434444444747484A494B
4B4D4C4D4F4F4E50505152525253555656575659575A59595A5B5A5B5C5A5D5B5C5C5D5D
5E5D5E5E5D605F5F605E5F616060616060615F61625F6261605F615F61606060605E5D5F
5F5D5F5D5D5D5D5D5E5D605E5D5E5F5E605F5F5F60616262636564656465656566686668
6968696A6C6C6C6C6F6F70707372737374737377777978797A7A797B787A787A7A7C797C
7B7B7A7A79797A787A797B7978787776767875747571716F6E6C68645F5853504C494746
42413F3F3B3B3A383735343232302F2E2E2D2D2C2B2C2A2A2A2A2A2A2929292929292928
282828282828282727282727272727272726272727272726262726262626262626262626
262626262626262727262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262525252626262525262626262525252526262626
2626252525252526
262626252526262526262626262626262625262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262726272626262626262626272627272727272727272727272727272727272727272828
2727272728282828282828282828292929292929292A2B2A2B2B2C2C2C2C2D2E2D2E2E2F
30303032333434353737383939393B3D3C3E3D3E3F4042434344444546474749494A4B4D
4D4E504F504F5153535454545556565758595A5A595A59595B5B5B5A5C5B5D5D5F5C5E5E
5E5E5E5F615F6160616061626061616261606262626160606160616161605F60605F605E
605E5E5E5E605D5F5F5F5F5E5F5F5F605F60605F62616261626264636364646566656767
69686969696B6B6A6E706F7071717273747275747474767779787A7A7A7C7C7A7A797B79
7A797B7A7B7A7B7A7A7C7B7A797979777777797675757472706E6E6B68625D5853504C47
45444340403C3B3B39373635333231302E2F2D2C2C2C2B2B2B2A2A2A2929292928282828
292828282828282728272727272727272727272727272626272727262626272726262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262526262626262626262626252626262626262526262626262625262626
2626252526262626
252626262626262626262626262626262626262626262625262625262626262626262626
262626262626262626262626262626262626272626262626262626262626262626262726
262626262627262627272627262726272727272727272727272727272727272727272827
272727282728282829282928292929292A2A292B2A2B2B2B2C2C2C2C2D2D2E2E2E303031
31313334343436363838383A3B3C3D3C3D3F3F404041434445454746484948494B4B4D4F
4F50525052525353545556565857585A5A5A595A5A5C5C5B5D5D5D5B5D5D5F5F5E5E6060
6060615F5F6262626263636362616262636060636263616263606361616360605F606060
605F5D5F5D605E5F5E5F5F605F615F5F5F5F606160606263626364646464646564676569
676768686A6A6A6A6D6C6D6C6F6F70727172727373737577787A797B7B797B79797A7A7A
7A7A777A797A7A787B7C79777A7A79797677777777777575737572726D6B67635D57524E
4E48464341403E3C3C3A393735343232312F2F2D2D2C2C2C2B2B2B2A2A29292929292929
292828282828282727272727272727272727272727272727272727272726262627262626
262626262626262626262626262726262626262626262626262626262626262626262625
262626262626262526262526262626262626262526262525262626262626262626252626
2526262526262625
252626252626252626262626262526252626252626262626262626262626262626262626
262626262626252627262626262626262626262626262726262626262626262726262626
262727262727262727272627272726262727272727272727272727272727272727272728
28282728282828282828292929292929292A2A2A2A2B2C2B2C2D2E2D2E2F2E2F30303033
3333343536363838383B3B3B3B3D3D3E3F40404042434545474647484A4B4C4C4C4F4E4F
4F5152525354545557555758595A5C5A595A5C5B5C5C5D5E5D5D5E5E5D605F60605E6162
626163636263626363646667656463636462636364626362616262636362626160636161
616161605F5F60605F5E615F615F5F5F6060606061606363636364646564646264656666
68686767686B6A6B696B6B6C6E6E6F6F707072727373747577777979787B7C7C7C7A7A7A
787979787A7A78787A7C7C7C797A7A7A7A797879777978757675737472716D6B67635D57
524D4A484544413F3E3C3A39373635343131302F2F2E2D2C2C2B2B2B2A2A2A2929292929
282928282828282828272728272727272727272727272726272726262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262526262626262526262626262626262626262626262626262626252626
2526262625262625
252625262625262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
272726272726272626262727272727272727272727272727272727272728272728282827
28282828282828282829292929292A2A2B2A2A2B2B2B2C2C2C2D2D2E2F2E2F3031323233
343436363638383A3A3B3B3C3E3F3F40414242434545454647484A4A4B4B4D4E4D505151
53515355545656545758595A5B5B5B5C5D5C5D5E5D5E5D5F605F5F616160616260636262
626262636564656465666566666465646764656565636463656363646364636061616261
6262616161605F6061615E5F605E5E60606161625F606262626464636363636365646466
666465656968696968686B6A6E6E6E6F70707071727372747475777878777979797B7C7A
7A787979797A7B7A7C7A7D797A7C797C7B787A7A7A787777767978757475746E6D6A6663
5C57514D49484443403F3D3B39383735333231312F2F2E2D2D2C2C2B2B2A2A292A292929
282828282828282828282828272727272727272727272727262627272627262726262626
262726262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262526262626262625262625262625252625262626262626252626
2526262525252526
262626262626262626262626262626262625262626262526262626252626262626262626
262626262626262626262626262626262626262726262626262626262626272626272626
262726262627262727272727272727272727272727272727272727272727272728282827
2828282828282828292929292A2A2B2A2A2A2B2C2C2B2C2E2D2E2E303030303133343335
3536363837393B3B3B3C3E3E3F414041434243444547484849494B4A4D4F4E5051505253
5454565757575758595A5C5A5C5E5D5D5E5D5F605F606162626062626462636262636463
636365646666666766686965666666666667676664656463646764646463626262626263
62616261626061626160605F5F60616060605F5F61606162646264636362626462646564
6567686766676768686969696A6B6D6D6C6E717172727173757574777677777A79797A7B
7978787A797A7A797A797B7B7A7B7B7B7A797A797A7C7A7B7B77777777757475716F6F69
65615A54514B494743413F3D3C3A3A383635343331312F2F2E2D2C2C2B2A2A2A2A292929
292929282828282828282828282827272727282727272727272726272726262726272627
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262625262525262626262626252625252526262626262625262626
2626252626262626
252625262626262525262626262625262626262626262526262625262626262626262526
262626262626262626262626262726262626262626262626262626262626272626262726
262727262727262727272727262727272727272727272727272827272727272728272828
2828282828282828292929292A2A2A2A2B2B2B2C2C2D2D2D2E2E30303131313334343535
363738393A3A3B3C3E3D3E3F414043444344454647474A4A4A4B4C4C4F4E505152545552
55565657585A595C5A5C5B5C5C5E5E5F605F616162616263616362636363626364676466
666566676566676767676968686665676967676869676668666565656564656564646363
626362636362626361616260636061606260626062606263656363636262606262636363
6565666767686869696A696A6B6C6C6C6D6D6F6F6F707071737574737576777778777B77
777A7978797A7B7B7B797A7A7B7B7B7D797A7D7D7B7A7A797A7B7779787776747472736E
6E6A646058544F4B484643413F3E3C39383736343331302F2F2E2D2C2C2B2B2B2A2A2A29
292929282828282828282727282827272727272727272727272727272627272726262727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626252626262626262525262526
2626252526262625
252625262626252626252626262626262625262626262626262626262626262625262626
262626262626262626262626262626262626262626272626262627262626262727262727
272726272726262727272727272727272727272727272727282727272728282828282828
282928282828292929292A292A2A2B2B2C2B2B2C2C2D2E2E2E2F30303132333335363638
38393A3A3B3C3C3D3F4040414242444445464848484B4A4B4B4C4E4F4E51515252545555
575857585A5A5A5A5D5D5D5E606060606260626263626364636565666664666464656666
6867666668686768666968696967686A686A686B69696968696868666866666564646665
646363636264636362626161626162616062646362636262646463636261616262616463
6464656567666567676768676B6A6B6A6C6E6D70706E7171727374747575767477777879
7778797A7A7A7B7A7979797C78797A7B797B7D7B7C7B7B7B7C7B79797A78797775767472
716D6C68645C57514E4B474442413F3C3B39373635343231302F2E2E2D2C2C2B2B2A2A2A
2A2A29292829282928282828282827272727282727272727272727272727272726262627
262627262627272626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262526262526252625252526
2625252625262526
252625262626262626262626262626262526262626262626262625262626262626262626
262626262626262627262626262626262627262726262626262726272627262626272627
272727272726262727272727262727272727272627272727272727272728282827282828
282828282929292A2A2A2A2B2A2B2A2B2D2C2C2D2D2E2E2F2F3031323434353536383739
3A3C3B3B3C3E3F404040424243444545464848494A4B4A4C4E4D50515151535355545759
5A595B5B5B5C5D5C5D5E5E5F626162616265626364666563666566666866666668676667
686867696967696969696A6A69696B6A6A6B6A6A696A6868686868696766686867656565
666665666564646463646263646162616262626263636262656363626363636362616363
6364666465656767666669686B6A6A6A6B6C6C6F6E707070717172737272737476777677
78797678787A7A787A79787A7B797A787B7C7D7D7B7D7C7B7B7B7C787C78787A78767674
7372716E6A65605954514D484442423F3D3C3B3836363432312F302F2E2D2C2C2B2B2A2A
292A2A282929282828282828282728272728272727272727272727272627272727262727
262627262726262626262726262626262626262626262626262626262626262626262626
262626262625262626262626262526262625262626252626262626262525262626252625
2525262626252525
252526262526262626262626262625262626262626262626252626262626262626262626
262626262626262626262626262626262726262726262626272726262626262626272727
262626272727272727272627272727272727272727272727272727272828282827272829
28282929292929292A2A2A2A2B2B2C2C2C2C2D2E2F2F2F3031323433353537363839393A
3B3C3C3D3F3F4040424242434445474649494A4C4B4C4D4E4E5051515253535455565758
5A5A5A5D5E5D5E5E5E5F6061616165646465656466666565666767696665696769676968
6868696769686A686B6A6B6C6B6C6B6C6C6B6C6A6B6C6B686B6A6B686969696867676767
666565676564666566636664656463636262626462636364626362636363626362626262
646363656464636666666866686A6A6A6C6C6B6E6D6F6F6F706E6E6F7372717371757575
76787779797A77787A787A7B79797A7A7C7B7A7C7D7E7C7D7D7C7C7C7B7A7C7B79787676
75757371706C69655E56534E49464542403E3C3B393736353332312F2E2D2D2C2B2B2B2A
2A2A29292929292828282828282828282728272727272727272727272727272727272727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262626262626262526262626252626262526262626262626262626
2626252626262625
252626262626262626262626262625262626252626262626262626262625262626262626
262626262626262626262626272626262626262626262626262626272626262726272627
272726272627272627262727272727272727272727272727272828282727282828282828
282829292929292A2A2A2A2B2B2C2C2C2C2E2E2F2E303032323334353637383A3B3A3B3B
3D3D3E404041424143434345454748494A4A4C4D4D4F4E50525251525355555556585959
5A5B5C5D5E605F5F606162616365676567666666676667676767666868686B6A696A6C6B
6B696A6B6B6B6A6B6C6B6B6C6D6C6C6C6D6C6C6C6D6D6C6C6C6B6A6C6B696B69696A6869
686867696667656665666866666564626461636362626363636363626362636162626362
616363656566666665676868686969696A6A6B6B6C6C6C6D6E6E70706F71737373747374
7678777577767678787A787879797A7A797C7C7B7E7A7F7C7E7B7C7C7C7A7C7A7B7A7978
76757575716F6E6A67625A56514C484544413F3C3C3A383635343231302F2E2E2D2C2B2B
2B2B2A2A2A29292828282828282828282828272727272727272727272727272727262727
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262526262626
2626262526262626
252626262526262625262526262626262626272626262626262626262626262626262626
262626262626262627262626262626262626262626262626272726262627272627272627
272727272727272627272627272627272727272727272827282828272728282828292828
292929292A292A2A2A2A2C2B2C2D2D2D2E2E2E303031323334343537393939393B3C3D3E
3E3F404142414243464646474848494A4B4C4D4D4D50515052505455555656565759595A
5A5C5D5F6060606263646564656666666667676867676869696A6A686B6A6B6A6B696C6B
6C6C6B6B6C6C6C6D6D6C6C6D6D6D6E6D6F6E6D6E6D6B6C6C6E6C6C6C6C6C6B6B686A6A6C
696969686966676766686667666666646563636364646463626362626365636262626362
646363656463666565656567676767696869696C6B6A6C6C6C6D70706E70727072717474
75767677787677787879797A797A79797A7A7B7A7A7C7B7C7D7D7D7D7D7C7B7A7B7A7978
797778767574736E6D6A656059544F4A484543403F3C3A3A373635323130302E2E2D2D2B
2B2A2A2A2929292929282828282828282828282827272727272727272727272727272727
262726262727262626262726262626262626262726262626262626262626262626262626
262626262626262626262626252626262625252626262626262626262626262626262626
2526262626262626
252625252626262626262526262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262726262727272727262727262627
262727262627272627272727272727272827272727272728282827282928282828282929
2829292A292A2A2A2A2B2B2C2C2D2D2E2F2F2F303132333536373738393A3C3C3D3E3F3F
414142424444444546464849494A4C4C4C4F4F504F5251525454535558585759595A5B5B
5E5C5E5E5F6262616566656665676767686869696A6A6969696B6D6B6D6A6C6B6C6D6E6E
6E6C6F6E6F6D6D6E6F6D6E6F6F6D6E6F6F71706E6E6E6E6E6E6C6C6E6D6E6C6A6B6A6C6B
6B6B69696A67686968686767676566646465646364646562626363646363656462636262
6263626263656365666567666668676869696A6869686A6A6C6E6B6C6D6F6F7071737372
757575757577787779787979787B797A7C7C7B7C7B797B7B7D7D7D7C7D7C7B7C7D7A797A
7A79787776757573716F6C68645C56504D49464341403E3B3A373635343230302F2E2D2C
2C2B2B2A2B2A2A2929292928292828282828282727272727272727272727272727272627
272626272626272626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626252625262626262526262626
2626252626252625
252626262626252626252625262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262727272626262726272626272727
272726262627272727272727272727272728272827282728282728282828282828292929
292929292A2A2A2B2C2B2C2C2D2D2E2E2F303133333335363638393A3B3B3C3E3F404141
43434645444746474748494A4C4B4D4D4E504F515153525355565757595A5B5B5B5C5E5E
5F5E606061646263656567666868686A6B6B6B6C6C6C6D6C6C6C6D6D6D6D6D6F6F6E6F6E
6F6F6F706F6F6F6F6E6E706F6F6E70706F6F6F6F7071706F6E6F6D6F6D6D6E6D6B6D6C6A
6B6A6C6A696A6A6868696969686767666665666564646566646464646665646563636162
62646362656665646464666665646567686767686A6769686B6A6B6D6C6C6C6E706F7072
717473737473777676797A7779787A7A7B7A7C7C79797C7A7B7B7C7E7B7C7B7D7C7C7D79
77797879797774747571706E69665F58544E49474442403E3B3A383736343231302F2E2D
2C2B2B2B2B2A2A2A29292828292928282828282828272728272727272627272727262727
272727262726262626262626262726262626262626262626262626262627262626262626
262626262626262625262626262626262625262626262525262625262625262526262626
2625252626252625
252626262626262626262626262626252626262626262626262626262626262626262626
272626262726262626262626262626262626262726262627262626272626262627272727
272727262727272727272727272728272728282727282728282827272829282828292928
2929292A2A2B2B2B2C2C2D2D2E2F2F2F2F3132333434373739393A3C3D3D3E4041414244
4545464746474A494B4A4C4C4C4E4F4E4F50525253515555565658595A5A5A5C5D5C5E5E
5E606162636364666767686869676B6B6B6B6B6A6C6C6C6C6E6E6F6D6D6F6E6E70706F72
736E6F70727070727071707071716F707170716F707372727172706F70706F6F706E6E6E
6C6E6C6B6C6B6C6A6B6A6B68686968666667666467676466666466666666656462636465
6364646564666465656766656666656566686868686A6769686C6B696B6B6D6E6F6F706F
7171727374747777777677777679787A7A7A7C7A7A7A7A7A7C7D7C7D7C7B7C7C7D7D7D7B
7B7B7A7A7977787474747370706C68625C56514C4845433F3E3C3B393836343331302F2E
2E2D2C2B2B2B2A2A2A292929292828292828282727272727272727272727272727272626
272627262626262726272627262626262627262626262626262626262626262626262626
262626262626262626262626262626262626262626262526262626262625252526262625
2626262626262526
262626262626262626262526262625262626262626252626262626262626262626262626
262626262626262626262626272626262627262626262626272626272626262726272727
272727272726272727272727272727272727272728282827282828282829292929292829
2A2A2A2B2B2B2B2C2C2C2D2E2E2E2F31323234353537383A393B3C3D3F3F414243444446
474848494A4B4B4B4C4B4E4E4C4F4F4F505252535555545656585A5A5B5C5D5D5D5E5F61
60606365626666666668696A696B6C6D6E6D6E6F706F717070716E717170717173717471
71737271717271717070727171737171717073737373727272707371716F7070706F706F
6F6E6E6C6C6D6C6B6C6B6B6C696969686867676867676764656768676665666565646465
63646464656663656665636465666664656567666767676868696A6B6C6A6D6E6C6D6F70
6E71716F737273757678757678777877787B7A787A7B7A7B7B7B7E7E7F7B7A7B7C7C7E7C
7D797C7B7B79797776757475736F6C69665F58544E4A4644413E3D3B3A38373333323130
2E2E2C2D2C2B2B2A2A2A2929292829282828282728282727272727282727272627272727
262627262627272626262726262726262626262626262626262626262626262626262626
262626262626262625262626262626262625252626262626262626262625262626252626
2626262626262626
252526262626262626252626262626262626252626262626262626262626262627262626
262626262726262627262626262626262627262626262627262626272626272627262727
272727272727262727272727272727282728272828282828282928292829292829292929
2A2A2A2A2A2B2C2D2D2D2E2E2F303132333334363638393A3A3D3E3F3F40424445464647
4848494B4C4D4D4E4E4F5051505050525153535556575657595B5A5C5D5B5E5F60606063
6361636666666766696A6B6A6B6C6E6D6D6F717071707070727172717171727573757371
747373747372747471747272727573737473727173737372737372717472737172727171
6E716F6D6E6E6E6D6C6C6C6B6C6A6A6A6968696869676767676769686865666765646464
65656665666765636567656565666565636566656568676869686A6A6A6C6B6C6E6E6D6E
6F6E7172737473727573767678757878797A797A7B797C7A7E7B7D7B7D7A7B7C7C7D7D7B
7C7C7B7C7C787879777877757672706F6B68615B55504D4745433F3D3C3A383635343231
302F2E2D2C2C2B2B2A2A292A292929282828282728282827272727272727272727272727
262627262626262627262626262627262626272626262726262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
2626262626262526
262626262626262626262626252626262626262626262626262626262626262627262626
262726262626262627272726262626262626262726262627262726272627272727262626
262727272727272727272827272727272728272827272828282928292829292929292A2A
2B2A2A2B2C2C2C2E2D2D2E30303232323434363737383B3B3D3F3F404143454648474A49
4A4B4C4E4E4E514F505052525353545354565656565858595A5B5B5C5E5E5F6060616163
6265636667676969696B6B6B6D6D6E70706F727171707071737271727373737574757574
747476757477767575737274737374757474767573727472747274737272747370727371
7472716E6E6E6D706C6F6B6B6C6D6C6C6A6A686969696A69686969686766676865676665
6666656665656365646667656565646565666667676766676968696A6A696A6C6A6C6D6F
6E6F6F7071717473747574747475757878787A777879797A7C7D7B7A7B7A7D7C7A7D7C7D
7B7C7E7C7A7C7A7B7879767777747371706C68665F58534E4946433F3E3E3B3937373432
31302F2E2D2D2C2B2B2A2A29292A29292928292828282827272827282727272727272727
272727272627262727262626262626262627262626262626262626262626262626262626
262626262626262626262626262626262526262626252626262626262526262526262626
2526262626262626
252626262526262526262626262626262626262626262626262626262626252626262626
262626262626262626262626262626262726272626262627262727272627272727262627
2627272727272727272727282727282727282828282828282829292829282929292A2A2A
2B2B2B2C2C2C2D2D2E2E2F303032333436373838393A3D3D3E3F42424445474749484B4C
4D4E4D4F50525151545354555556575856585857575A5A5A5D5C5E5F5D615F6164636465
6564676667676A69696C6B6D6D6E6E6F7170717273737374757476767476757475767776
787775757778767675777978777575757576757674747675747374747673737374747573
75756F716F716F70706D6C6E6E6C6B6D6C6A6B6C6B6A6A6A6A6A6A696868676866686666
6666676566646564676566646566666464646565686568686868686A6A69696A6D6A6E6D
6E6E6E6F6F7070717071747574747475757779797A7A787B7A7B7A797C7A7C7B7C7E7C7C
7C7B7B7E7C7C7B7A7A7A78777877747472716E6B68605C534E4B4744423F3D3C3A383634
3232312F2E2D2C2C2B2B2A2A2A292A292928282827282728282727282727272727272727
272727272726262627272626272727262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262626262626262526252626262626
2526262526252525
252626262626262626262526262526262626262626262626262626262626262626262626
262626262626262727262726262727262626262726262627272627272626272727272727
272627272727282727272727282827282728282828282928282929292929292F2A2A2A2A
2A2B2C2B2C2D2F2E2F2F3031323333363638393A3B3D3D3E3F414344454748494A4B4C4D
4E5050525152545456565558565859585859595A5A5B5B5D5E5C5F5E6060626263646666
6666696966696B6A6C6C6D6C6E6D72707072727376747675737677767676767777787978
7879787977777A7776767877767775767476757576747576747577767577777574767275
76746F7073727171726F6F6F6F6D6D6E6D6C6B6D6B6C6D6C6C6C6A6A686A686868686867
676867666567666665666565666467646565646766676768686A67676B69696A6A6A6C6C
6D6D6F7071707271717272727273757575767678787979787A767A797B7A7B7A7D7C7D7D
7B7D7D7C7B7D7D7D7A7B7A7A797577757274716F6A68625D56504C4845433F3D3C3B3836
353231302F2F2E2D2C2C2B2B2A2929292929282828282828282728282727272728272727
272727272727272727272727272727262626262626262626262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
2626252626262525
262626262526262626262626262626262626262626262626262626262626262626262626
262626262626262626262627262626272626262726272627262626272627272627272727
272727272727272727272727272727272828282828282828292929292A292A2A292A2B2C
2C2B2C2C2D2D2E2E2F3031313235343638393A3B3C3E3F40424344464649494A4C4D4F4F
51535352545556575758595A5A5B5B5A5B5C5C5C5C5C5D5E5E5F60616061636164656567
676668686A6A6D6C6D6C6E6E707171717373737576757777767877787879777A7B78797A
7A7A7D7B7B7B7977787A7779787877787677777575777778767676757676767674757675
76747374737372727570706F706F6F6D706E6D6E6E716D6D6C6D6C696B6B6A6A6A686A69
69696A666866666566676666656767656565676466666866696968696869686A69686B6D
6B6C6E6E6F6F70717271727372737475757477767777797879797978777A7C7B7B7E7B7B
7C7A7D7D7E7E7A7C7B7C7A7A79797877777374716F6C6A65625A534E494643403D3D3A39
36353332312F2F2E2D2C2C2B2A2A2A292929292828282828282727272728272727272726
272627272727272727272626262727262627262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
2626262526262626
252626262526262626252626262626262626262626262626262626262626262626262626
262626262626272626262626272626262626272627272726262726262727272726272727
262727272727272727272727272827282828282828292929282929292A2A2A2A2A2B2B2B
2C2C2D2D2D2E2E2F3030323435363638393A3C3C3E3F41424344464749494C4C4E4F4F50
52535255545757585B5C5A5B5C5E5C5E5D605F5F5E5F5E5F616262626263646466666867
676769696A6B6D6D6F6F706F7171727473747474747677787A79797C7B79797B7A7A7B7D
7B7B7C7D7D7C7A797A797B777A7879797979797877787978787679797876767776767777
7578767676767773747372717270727172716E6E716F6E6B6D6E6D6D6C6A6B6A6A6A6A69
6968696A686666666567666665646566656465646465676767696668696968696A6A6A6B
6B6D6D6D6D6F6F6F707171727173727371757574777675787778797678777A797A7C7A7B
7C7C7D7E7B7D7B7B7D7C7C7C7C7A797976767574706F6F6B66625B544F4A4844413F3C3A
3A3836333331302F2D2D2C2C2B2B2A2A2A29282929282828282828282827272727272727
272727272627272727262626262726272626272626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626272626262627272626262727262726262727262727272627272727
272727272727272727282827282728272828282828292828292929292A2A2A2B2B2B2B2C
2C2D2E2E2E2F2F30313334343636383A3A3B3C3E3F4041434447484A494B4B4E4E505153
545656585758595A5B5E5E5D5F60615E6161606160606162606264646364646565696869
6A696E6B6C6C6E6F706E6F70727273767476757677777978787B7A7A7C7A7D7B7D797B7C
7C7D7D7E7D7C7D7C7A7B7C7A7C7A7C7A7979797A787A7778797977777978777776787978
78797678777776757674737374737171717172706E7171706E6F6E6E6D6E6B6C6B6B6A69
6A6A69686A68676867676668666566676666656664646766666767696B6A696A6A6A686C
6D6B6C6C6D6E6E6F6F7170707172727372737574757675747576757576797A78797B7D7C
7E7D7C7B7C7B7B7C7B7B7B7B797A797A787876767473716E6B68665D56504C4744413F3D
3C393836343332302F2E2D2C2C2B2A2A292A2A2928292828282828282827272728272727
272727272727272627262727262627272726262626262626262627262626262626262626
262626262626262626262626262626262626262626262526262626262626262626262526
2626252625262625
252626252526262626262626262626262626262626262626262626262626262626262626
262626262626272626262626262626272626262627262727262726262727272727262727
272727272828272727272828272727282828282828282929292A2A2A2B2A2B2B2B2B2C2C
2D2E2E2E2F3031313234353636383A3A3C3C3E3F4242444647494A4A4C4D4E4E50505253
56555858585A5A5C5C5D5D5E616062606363626263626562646464646465666666696869
6B6B6D6D6E6D6E706F717372727373737477777979777B797A7A7C7C7B7C7C7E7D7F7D7E
807F7F7C807E7E7E7D7D7D7D7B7C7B7B7C7C7A7C797C797C7A7C7A78797878797879787A
7A7B79797979797878787673747373727372717272716F70726E6D6E6E6C6E6E6C6D6D6C
69696969696868676867686767676666676767676465676568666A6A696A6869696A6A6A
6C6C6C6C6D6D6D6E6E6F6F71727273727271757475767876767676767877797878797B7A
7B797B7E7D7E7D7C7D7B7D7A7C7A7C7A7A78777674757371706E69645F58524C4945433F
3E3B3A383735333130302F2D2D2B2B2B2B2A2A2A29282928282828282828272727272727
272727272726272726272727262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
2626262626262626
252625262626262626252626262626262626262626262726262626262626262626262626
262626262727262627262626272627262626272727272727262727272727272727262727
27272727272728272828282827272828272828292928292A29292A2A2A2B2B2A2C2B2C2D
2E2D2F2F3031323335353738383A3A3B3D3F40414243464648494A4D4E4F515153525556
5556585A5A5D5C5E5E5F6162636263646461636563666566646666676768676A68686A6B
6A6C6C6E6D71707170737375757676767677797979787B797B7C7A7B7D7C7E7E7C7F7D7E
7F7E7F807D7E80808280807E7E7B7F7D7E7F7C7C7C7D7C7C7C7B7C7D7B7B7A7A7A79797A
7B797A797A797A7A7879777575757374737473727373737373716F716E6F6F6F6D6E6C6D
6A696C6A6B6A6B6A6A6A6666666768676868696767676568676667696768686A6A6B6A6D
6B6B6B6C6D6D6C6C6E6E6F6F707071727271737372747576767675777878797877767878
7A7A7B7C7B7A7B7B7F7D7B7C7B7B7B7B7A7977777676757273706E6B66625A544F494643
413E3C3B393736333130302E2D2D2C2B2B2A2A2A29292929292828282827282727272727
272727272727272726272726262726272726262626262726262626272626262626262626
262626262626262626262626262626262626262625262526262626262626262626262626
2626252526262626
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262727262726272627262726262727272627272727262727272727272727
27272728282727272727282827292828282828292829292A292A2A2A2B2A2C2B2C2D2D2D
2D2F30303132343535363738393A3D3C3D3F41434446474949494C4C4F51525254555758
595A5B5A5C5C60606160626264636566666565676867676666666767686A69686B6A6B6B
6C6D6D717070727271727475767776777779797A7B797C7B7B7B7B7F7A7C7C7E7F807F7F
828181818383808783807F7E807F807E807B7C7F7E7E7C7C7C7E7F7D7E7B7A797D7A7A7C
797A7A7B7C797C7A7C7978777677777474757374747374707371716F71716E6F6E6E6C70
6D6B6B6C6B6B6B6A6A6B6A6868686869696868676768676766666768666869696C696C6B
6A6A6C6B6C6C6B6D6D6D6F6F6F7170707371727674757374757574757877777A77777677
7A787A7A797A7D7B7B7C7C7D7D7B7C7A79797A7A7778747572706F6D6B67625C55504B47
44413F3C3A3837353332302F2F2E2C2C2B2B2B2A2A292929282828282828282728282727
272727272727272727272626272726262726262626272626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262625262626
262626262626262526262626262626262626262626252626262626262626262626262626
262626262626272627262626272626272627262726272627272727272727272727282727
272827272727282727282727282828282829292929292A2A2A2B2B2B2B2C2B2C2D2D2D2E
2F303131333336363737393A3B3C3D3F3F4142444746494A4A4C4D4F5153545455565757
595B5B5D5E5E616162646463636466656767686B69696869696A6A6A6A6B6C6D6C6E6C6D
6D6D6E706F71717374767475787777797979797A7B7C7C7A7C7E7C7C7D7D7D7C7E7E8280
7F8082828383838182828180807E80807F7E807F7D7E7F7F7C7D7B7C7D7E7B7D7A7B7B7D
7C7B7A7B7C7B7C7C797A79787879777576757574747473757274727271727170716F6D6D
6C6D6C6C6B6D6B6C6B6B6C6A69696A686A6968686A686768676867696766696C6A6C6B6A
6A6A6A696B6C6B6D6D6E6E6E6F6F706F7170737074717472737373767576777676757676
777A797A7B797C7B7B7A7C7C7D7E7B7C7C7A79787A797874767473706E6A69656057514C
484441403D3B3938363432312F2E2E2D2C2C2C2A2A292929292828282828282827272828
272727272727272726272627262626262727262626272626262726262626262626262626
262626262626262626262626262626262626262626262626262626262626252526262626
2626262626252525
262626262626262626262626262626262626272526262626272626262626262626262626
272626262626262626262726262726272726262626262627262727272727272727272727
2727272727282728272727282729282828282929292A292A2B2B2B2B2C2C2D2D2D2D2E2F
303032323434353737383A3A3D3D3E3F4142424646484B4C4C4D4F4F5154555558585A5A
5B5C5D5D606161626664676566686868686B6A6C6E6D6C6C6C6C6D6D6D6E6D6D6D6D6F6E
6D6F7171707371727574757776787A777A7A7B7B7B7C7D7E7C7B7D7D7E7D7F7F7E818180
838183838384828282828285808280817F7E7F7D7F7F7F7F7F7E807E7E7E7D7F7D7D7C7C
7B807C7B7C7B7C7A7C7A7A787878787878787775767474737275737173747373716E6F6D
6F6C6E6F6E6F6E6C6C6A6D6B6B6A6A6B696869696968676968686B6A6968686A696A6A6A
786B6A6C6B6B6C6A6D6F6D6D6D6D6F6D6F6F717171727172727474747676777676767677
777778787A7D7B7C7B7C7B7D7D7B7B7C7B7A7A797577797974747472736E6F69665F5852
4D4844423F3D3B393736343331302E2E2D2C2B2B2A2A2A29292928282828282828272727
282727272727272727272727262726262627262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626252626262626262626
2626262526262626
252626262626262626262626262626262626262626262626262626252626262726262626
262626262726262627262726272627272726272626272727272727272627272727272727
2727272728272827272728282828282928282929292A2B2A2A2B2B2C2C2D2C2F2D2F2F30
3132323335363638393A393C3D40414043444748494A4A4D4E4F4F51535555565959595A
5D5D5E6061616164646468696968696B6B6A6C6C6C6D6E6F6D6D6E6F6E6F6F706E6F6F70
71707273747474737574747879797A797B7A7A7B7C7C7E7E7D7D7D7C7B7C7F8082828380
808182828285858484848583838182838082808080807E817F808180817F807F7F7E7E7D
7E7B7E7E7E7C7F7E7D7D7C7B7A7A7A7A7978787678787475757576757373737473707071
6E6F6F6E6F6F716E6C6E6E6F6B6B6C6C6B696B6A6B6B6A696B69696A68696C696A6B6B68
6A6969686B6B6C6B6A6A6C6D6D6D6E6E6F6E707170707271727272737576747676757576
7876777877797A7A79787B7C7A7C7E7C7B7B7B7A787978767776767473736F6E6B66605A
524D4845423F3D3C3A3836353331302F2E2D2C2B2B2A2A29292829282828282828282827
272727272727272727272727272727262726262726262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626252626262626
2626252626252626
252625262626262626262626262626262626262626262626262626262627262726262626
262626262626272626262627262727272627262627272727272727262727272727272727
2727272728272728282828292928282929292A292A2B2A2B2B2C2C2C2C2D2D2E2E2F3031
31323335363737383A3A3D3D3E3F414344464749494C4D4D5050515354555758595C5B5C
5D605E626263646566666569696A6A6B6B6F6C6E6F71716F716F71707071717272717272
727473727374747677757977797B787A7B7D7E7F7D7C7E7E7E7E7F807E7C7F7F80818484
848584868484848585858383858584848180838280828282817F80818081807F807F807E
7F7E7E7C7E7D7D7E7E7C7C7A7A7B7C7A7A7B78797A777978777674757574747374737271
7071706F6E706F6E6C6F6F706D6C6C6A6C6D6C6B6A6B6A686A6A6A6A6A6B6B6A6B6B6A6A
69696A6B6A6A6C6C6C6B6E6D6E6C6C6E6D6D6E6F7170716F6F7172727374747475737476
767877757678777A79797A7B7B7B7B7B7C7B7B7A7A787A79777676747573706F6E6B6861
5C554F4B46433F3D3B3A3936343331302F2E2D2D2B2A2B292A2929292829282828272827
282727272726272726272727262727272626272626272626262626272626262626262627
262626262626262626262626262626262626262626262526262626262626262626262626
2526262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272726272726262626262627272726272727272727272727272727272728
272827272828272828282828282829292929292A2A2B2B2B2C2C2D2D2C2E2E2E2F303132
333436373638383B3C3C3E3F414143444648494A4C4B4D4F51515455565858585A5C5E5E
5F606262646364656767696A6B6C6D6F6F6E716E71717172737272727473747375757372
7573747676757776767778797D7B7B7B7D7E7E7C7D7E7F7E8181807F7F7E7F8281808383
848286858684848585858582858585848483838382838581808181848181837F81818180
7E7E807D7F807E7E7E7D7C7D7C7C7D7E7C7B7A7B7A7A7777787677757575767475757375
7172717170706F707070706F6F6E6D6B6C6D6B6C6B6B6A6C6A686C6A6B6A6B696969696A
6C696B6A6B6B6B6B6C6C6B6D6D6B6C6C6C706F6D6F6F6F72717272747475767274767576
7476767475767779797A7B797A79797B7D7C7C7A7D7A7A797878767876747373706F6B68
635C554D4B4643403D3B3A383834333230302E2D2C2B2B2A2A2A29292928282828282828
272727282727272728272727272726262627262727262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625252626
2626262525262526
252626262626262626262626262626262626262626262626262626262626262726262626
262726262627272626272727262626272627262727272626272726272727272727272827
2727282728282828282828282829292929292A2A2A2A2B2B2C2D2D2D2E2E2F3030313234
34353637383A3A3C3D403F41424445464847494B4B4E4F505253545558585C5A5C5D5D5E
6062616365656666696B68696D6D6F6C6F6E717270737474737575747575777476767778
77787677757776767878797B7B797B7C7C7C7D7E7E7F8082807E80807F81818082828685
85868685898588878686848585898683848483838485838280818481818382838280837F
807F7F7F7E8181817F807E7D7E7E7E797C7C7B7B7B7B7A7B797879777877767676767673
7375717372717171706F7070706D6D6C6B6E6D6D6C6B6C6A6B6B6E6B6A6B6A696B6A6B6B
6C696A696A6A6B6D6C6C6C6C6D6C6C6B6C6C6E6D6F6F6F6F6F7272727373727476757575
74757574767578777878787977797B7B7B7A7A7B79797A78787978767675757471716F6C
68635D554F4B4843403E3C3A3837353332302F2E2D2B2C2B2A2A2A292929292928282828
282727272727272727272727272727272726262727262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252626262626262626262626262626262626262626262626262626262626262627262626
262726262626262626262727272726262626262727272727272727272727272827272727
27272828272828282828282829292929292A2A2B2B2B2B2B2C2C2E2D2E2F303131333334
35363738393A3C3C3E3F3F4244464747484A4B4D4D5051505354555858595B5D5D5E6060
6162656466686968696B6C6F6E6C6E6E6F71717375747675757878767677787877767878
7878767677797B787C797C7B7B7B7B7D7E7D7E817F828182838283808481828283848384
858885868688878886878989868688868686868686828383848382838483838482848283
817F7F7E80827F7F8081807F7E7E7E7D7C7E7C7C7C7B7A797C7C787A7779777777737676
747574737375737275736F6F706E6D6F6D6D6C6C6D6C6A6B6B6B6C6B6B6B6A6A6B69696B
6C6A696A6A6C6C6B6B6C6D6A6C6D6D6C6E6D6C6E6F706F6F6F7073737272727474747576
75747374757375797678777879797979787A7C7B7B7C7C787A79787C7777757575737170
6C69635C55514D4845423E3C3938363533312F2E2D2C2C2B2B2A2A2A2929282828282828
272827282727272727272727272727272726272626272726262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262726262626262626272626272726262726272727272727262727272727272726272727
272828282828282828282928282A2A29292A2A2B2C2B2C2C2D2D2E2E2F31313133343536
37373A393B3C3D3E41414244464747494A4C4C4C50515154545657595A5A5B5D5C5E6261
6063646668686A696C6C6B6D6E6E6F72717373757578737578787A787B797B7B7A787779
7A7978797979797A787B7D7A7A797A7D7D7D807D80828282838581838483858585858686
858685878787878A8988898B878788888888888887878684838584848483828484838284
83827F828182808181808280807F7F7F7E7F7E807D7F7B7C7C7B7B7C7B7A797B78777676
77787773747374757473726F716E6D6E6F6D6F6F6D6C6C6C6B6C6B6B6C6C696D696C6B6B
6D6C6C6B6C6D6C6B6C6C6D6D6D6E6D6D6D6E6C6A6F6D6F6E6D7072717071707273727375
7273737374747674767677797778777777797A797B7A7B7C7A79797A7777767676747270
6F6D6A655E57524B4745423E3C3A3836353432302F2E2D2C2B2B2A2A2929282929282828
282828282727282727272727272727272727272627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
262626262626262626262626262626262626262626262626262626262626262726262627
262626262627262626262727262727272627272627272626272727272727272727282728
27282828282828282928292929292A2A2A2B2A2B2B2C2C2D2D2E2E2F3031323334353738
39393A3C3D3D4040414344454647494B4B4D4D504F5253565558565A5C5B5D5E5F615F62
6364656867696A6B6B6D6D6E6F6F7272727473757476787B7A7B797A7A7B7D7B7C7B7B7B
7E7C797A797B7D7C7C7C7C7F7B7D7C7F7E80808381808181858583848284848586868787
8585888889898689888A8889878787878688858789878687858883838484848483848583
8283828283838382828381838080818280807E7E7F7E7E7F7C7C7E7B7C7B7B7A7B7A7678
7876767475757475757573717170716F6E6E6C6D6D6C6C6C6B6B6A6C6B6B6A696A6C6B6C
6C6A6B6B6B6C6A6C6D6B6D6F6C6E6D6D6C6C6D6D6D6E6E6E6D6D6F6F716F726F71727272
7173757273747275747677767777767676787778787A7A7B7B7B787B7778787674767472
706F6D68646057504C4745413F3C393837353332312F2E2D2C2B2A2A2A29292928292828
282828272828272727272727272727272727262726262626262727262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
2626262625262625
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262726262727272627272626272727262727272728272728282727282727
2728282929282728292829292929292A2A2B2B2C2B2C2D2E2E2F2F313132333536373739
3A3A3B3E3F40424244444647474A494C4C4E4F50535255555758585A5C5B605F5F626263
66656568676A696B6A6D6E6E707271747573747477777A787B7B7A7B7C7B7D7F7F7D7B7D
7D7B7D7C7D7C7E7F7E7E7D7D7F7B7F7E8080818081828184858586848585848587868686
86888788888987878B898989888A88888889898887858886888887868786858687878885
848483838382848283818282828081828480807F807E7F7E7F7D7E7E7C7E7D7E7D7B7A7A
7B777875797676747572747171716F706F6F6E6E6E6C6B6D6D6D6D6E6C6C6D6B6B696B6B
6C6B6C6B6D6B6F6C6C6C6C6C6E6D6E6E6D6D6E6E6D6D6D6D6D6E6F6F706F6D6F706E7173
747272717272717274757576767677777577787979787979797A7A787A77787775767574
7372716C69666058524C4844423F3D3A3936353332302F2D2D2C2C2B2A2A292929282828
282828282728272827272727272727272727272627262626272726262626262626262626
262626262626262626262626262626262626262626262626262626262626252625252626
2625262526262526
252626262526262626262626262626262626262626262626262726262626262726262626
262626272727272626272726262726272727272727272726272627272727272727272828
282828282829282929292A292A2A2A2A2A2B2B2C2C2D2D2D2F2F3031323434353638383B
3B3D3E3E40434344454648484A4B4D4F4F4F525255565557575B595C5C5F5E6060616164
65676A68696A6C6B6D6E6E7071717376767677767779787B7C7B7C7D7C7F80817D7E7E7D
7E807C807F7F7E817E7F7F80808180808180808283818384838387878685858785858889
888886878A888A8A8A8A888A8A8B8A8B8B898A8B8988888A888988878887898886888587
8583858686858283838382827F818382828181818182817F8082807F7F807E7E7D7B7C7C
7A79797778777577767674747371707271726F6F6D6F6E6E6E6C6D6D6C6D6B6C6A6A6B6A
6B6B6B6C6D6B6C6D6D6E6B6E6C6C6D6C6C6F6E6F6D6E6E6E6F6E6D6D6E6E6F6E70706F70
7272727172737173717373747576757676747577777679797A7A7A7A7A79787976777676
7373716D6D68676059524C4845413F3D3A3937353332302F2E2D2C2B2A2A2A2928292828
2828282827282727272727272727272727272727272726272726262626261F2626262626
262626262626262626262626262626262626262626262626262626262626262625262626
2626252626262526
262625262626262626262626262626262626262626262626262626262626262626262626
262627262726272626272627272727272727272727272727272727272727282727272827
282727282828282829292A2A292A2B2B2C2C2C2C2D2D2D2E2F30313234353638393A3A3B
3E3E41414243454646474A4A4C4D4E4E5151535354555759595A5B5B5F5F606061636364
6567686868686C6B6C6D6E70717072737777787778797B7B7D7C7F807F7F808081808180
818181818081818280808180808381808283838386828485838486858886868886888788
8A8788898887898C8B898B88888B8A8C898B8C8B8A8B8B89888988888A89888888888886
878786868685878683858385848384828182808383828081807F80807F7F807D7D7E7E7E
7A7B7978787A7877767877767675727171707070706E6F706F6C6D6F6E6E6C6D6B6C6B68
6C6A6C6B6D6B6D6C6E6C6C6D6F6E6E6D6F6E6D6C6F6C6E6D6E6D6E6E6C6E6D6E6D6F7170
7170717070737272707174737473747474757676767878787A78797878797A7979797675
73737171706C6B66615B524D4944423F3F3A3937353332302F2E2C2C2B2B2A2A29292829
292828282828282827272727272727272726272626272626262626262626262726262626
262626262626262626262626262626262626262626252626262626262626262626262626
2525262626262626
252625262626262626262626262626262626262626262726262626262627262626262626
262726262726262627262726272726272727272727272727272727282727272827282728
282828282828282929292A2A2A2B2B2B2B2B2D2D2E2E2F2F30313334353638393A3B3C3D
3F40414345464748494A4C4B4D4F4F51525354565558585B5A5C5D5E5E5F5E6163646365
686A69696C6A696B6C6D6E6E7175727676787979797B7C7C7D7E7E808282808081838283
828184848381818481848283828182838283828283848486868686868786858787898888
8A8988878A8A8A8C8B8B8B898A8C8C8A8A8D8C8D8C8B8C8B8B898B8B8A88898A8988898A
8A88888887878886868485868385858483848383848181837F808081827F7F8080817F7E
7D7C7A79787B7B79767A77767575747473727271716E6F6D6E6D6E6D6D6D6C6B6B6D6C6C
6B6C6A6D6B6C6B6D6D6D6C6D6D6D6B6E6C6E6D6F6C6D6E6D6E6C6F6D6B6E6E6D6E6E6F6E
6F6F6E7272707071727070737373737575747374757576767678797A7879797778797878
76757473726F6D6C666159534D4945423F3D3A38373533312F2F2D2D2C2B2B2A2A292929
282828282828282727282728272727272727272726272627262627262627262626262626
262626262626262626262626262626262626262626262626262626262526262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
272627262726272626262627272726262727262727272727272727272727282728272828
282928282929292829292A2A2B2B2B2B2C2D2C2D2E2F2F3131333434363838393B3C3E3F
404244454648494B4B4C4D4E505052535453575656585A5B5D5C5D5E6061616163656665
676A696A6A696C6C6E6F6F7072747276787779797A7C7C7D807E7F7F8281828486848585
858583848583858385838385868685838283858485868685858787878686888987878888
8989898C898B8C8C8D8A8A8C898B8B8C8D8C8E8E8C8B8D8B8C8C8B8A8B8A888C8C8B8D8B
8A89898A8A8A8987888787858685848585848683838383818180817F8381828081807F7F
7E7E7C7E7B79787B78767678767777747374727171706F6F6E6E6F6E6F6C6A6C6C6B6C6C
6B6E6B6B6D6B6C6B6C6E6C6D6C6D6D6C6C6D6D6D6E6D6C6E6E6E6D6E6E6C6D6E6D6E6F6E
6E6E6F6F726D6E6E7071727073707372757474727474757776777A777979777A7A787877
77777574716F6F6D6A67625B534D4946423F3C3A3838353332302F2E2D2B2B2B2A292929
292828282827282727272727272727272727272627262627272726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
262626262526262626262625252626262626262626262626262626262626262626262726
262626262626262726272626272726272726272727272727272727272727282827282728
27282828282929292A2A2A2A2B2B2B2B2D2D2D2E2E2F30323234353638393B3B3E3F3F40
42444747484A4A4C4E4F4F505353555456565658595C5B5C5E5E5E5E6163626364646666
666A6A6A6C6A6D6C6E6E717273737575767879777A7C7E7E7F8082818183858385868486
8486888788888986858585838685858385868685878787868689868A898988878A898A89
8A8A898B8B8A8B8C8B8A8C8B8A8B8C8A8C8E8D8D8E8F8C8E8C8E8D8C8D8C8C8C8F8D8D90
8A8B89888A8A888989888686858585858483858686868483828184838281838281808084
80807C7D7C797B797A7A7A7A76777675757772737572717270716F6F6F6E6D6C6C6B6B6C
6B6B6B6D6B6D6A6B6D6D6C6D6B6C6C6B6D6B6D6E6D6E6C6F6E6C6D6E6D6D6C6C6B6E6F6E
706F6F6F6F70706E6F7170727074737072717273747474737476777877777878787B7675
787677747471726E6D6A65625B534E4947433F3B3939373433312F2E2D2D2C2B2A2A2929
292928282828282828272827272727272727262727262627272726262726262626272627
262626262626262626262626262626262626262626262626262626262626262625262626
2626262625252626
252626262626262626262626262626262626262626262626262726262626262627262627
262626262626262626262627272726272727272727272727272727272827282727282828
28282828292829292B2A2A2A2B2C2C2D2D2E2D2E2F303233343636383A3B3D3D3F414243
454649494B4B4C4F505152535455545858585A5A5B5C5B5E5E6062616162616463686666
68686B6B6B6D6D6E6F6E70717473757576787A7A7B7D7D7F7F8080848286838786848787
8787878888878789878788878785888787868688878685878687878888878A8988888988
898989888A8C8B898B8C8D8C8E8C8D8E8C8B8F8B8F8C8E8E8E8D8D8D8E8D8D8C8D8F918D
8E8C898B8B8A8B8A8A8B8B89888688878586838682858483828584868584848382828281
817F81807D7E7C7A7D7C7A79787977787676757572727071706F70706E6D6F6B6D6B6C6C
6B6B6A6A696B686A6B6C6D6C6A6C696C6A6B6C6D6A6A6E6E6D6D6E6F6E6B6E6C6D6E6F6C
6D6E6F706E6E6E716F716E7071716F7172727172737372727473737477757778797A7978
78777777747373726D6E6A666059524E4B47423E3B3938363533312F2E2E2C2C2B2A2929
292828292828282827282727272727272727272727272727272626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626252525262526
252626262626262626262626262626262626262626272626262626262626262627262627
272726262626262726272627272627272727262727272727272727272827282728282828
282828292929292A2A2A2A2B2B2C2C2D2E2E2F2F303132343537373A3B3D3E4041424446
48474B4A4C4D4F4F5554545657575859585A5A5C5A5C5F5F5F6161606164636467686768
696A68696B6D6E6E6E707272737376777778797D7C7E7F80828283838486858488878988
8A8B89898B8D8A8A8989888B8A87888887858985888987878687878886878A878A878989
8B8A8A8B8E8A8B8B8C8D8B8C8C8B908D8E8D8D8D8F908E8E8E908D8D8C8E8C8D8F908E8F
8D8D8E8B8D8D8A8C898B8C8C8A8A88888687868786878583858887858585868483848282
808084817F7E7D7D7E7C7C7B797B7A777676757674747370727170726F6F6D6C6B6B6D6C
6A6C6A6B6A6B6B6B6C6C6C6C6C6D6B6A6B6C6B6B6B6D6B6C6C6D6D6D6F6D6C6C6D6C6F6E
6D6C6D6C6F6E6F6E6F70717070706F716F6F707171727373737275747576777878797876
797778777575747271706C6A676159534E4A46423E3C3A38363533312F2E2D2D2B2B2A29
292929292828282828282828282727272727272727262626262627262727272626262627
262627262626262626262626262626262626262626262626262626262626262626262626
2626262626262526
252626262626262626262626262625262626262626262626262626262627262726272627
262626262627262726272727272727272727272727272727272728272727282828282828
2828282829292A2A2B2A2C2C2C2D2D2D2E2E2F303232343536393A3C3C3E404144454748
494B4D4F4F505252535657575A585A595B5B5C5E605F5F60626262636365646566666767
6A686B6C6D6C6E6E6F6F72737274767478777B7A7C7E818081818383858487878888878B
8A888B8A898B8D8A8B8C8D8B8B8B8B88898B8A8B8B898A898989868788888A888C89888B
8B8A8B8A8B8A8D8C8A8C8E8E8E8E8B8C8F8C8E8E8E8C8E8F8F908F8E8F8D908D8F8F908F
908F8D8B8B8A8D8E908C8C8D8C898A878986858588848687878687848586878385848385
84848180827E827F7D7D7C7E7B7B797A79787776747575737271726F716F6F6E6D6F6E6D
6A6B6A6B6B6A6C6C6B6C6B6A6B6C6C6B6B6A6C6A6B6C6A6C6D6B6B6B6D6D6D6D6C6D6D6E
6D6D6C6E6F6F6E6F706F706F6E706F707171706E71717070707472747475777679797879
797878767575757673716F6C69665E58534F4A45413E3C3A3736343231302E2D2D2B2A2A
2A2929292928282828282827272727272727272727262727272727262627262726262626
262627262626262626262626262626262626262626262526262626262626262626262626
2626252626262626
252626262626262626262626262626262626262626262626262626262626262627262626
272627262627262726272727272727262727272727272727272727282727282728282828
2829292929292A2A2B2B2B2C2D2D2D2E2F2F30313234353739393C3D3F4242444748484B
4B4E4F50525353555658585A5B5C5C5D5E5E5F605F606162626363646567666766666669
6A6B696C6C6C6E6E6E70737273737477767B7A7D7E818183808285858487858787898A8A
8B8C8A8C8C8D8D8E8D8A8D8E8F8D8C8D8A8C8C8D8B8D8B8A88878989898B8B898A8B8A8A
8B8D8C8B8B8D8B8D8B8D8A8D8C8C8E8F8E908E908D908F8F8F8F8F908D918F919091918E
908F8F8A8C8B8D8C8E8F8F8D8C8C8A8C8A898A8789898787878987898684868585848385
8382828480848280807F7D7E7D7A7A7B797A787775757675727272707171706E6F6F6E6C
6C6C6B6C6B6A6C6D6A6B6C6C6A6C6A6B6A6B696969696A6A6C6C6C6E6E6C6B6D6B6B6C6C
6B6C6D6C6C6D6E6D6F6E6F6F6F6F7070707171706F707072727273717273727574787878
78797979757675747573706F6C6A655F59544F4844413F3C3A37363432312F2E2C2C2B2B
2A2A29292829282828282827282728272727272726272727262727262626262626262626
262626262626262626262626262626262626262626262626262625262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626272626262626
272626262726262626272727262727272727272727272727272727272727282828282828
2829292929292A2A2A2C2B2C2C2D2E2E2F30313134353738393C3E3F4144454647494A4D
4E4F525353555658585B5B5C5B5E5F625F60626263636563646565656467656667686869
696B6B6C6D6C6E6F6F7071737473767579797A7E7F8180838281878585878789898B8A89
8A8C8C8A8D8D8D8E8F8F8F8F8F8F8F8D8F8D8F8F8F8B8D8D8C8A8B898A898A888B8A8B8D
8C8A8C8B8F8D8C8D8E8E8F8C8E8D8D8D8F8C8B8F8F90918F9092918F8F8E8E9193909191
908F908E908F8E8D8E8E8D8C8C8C8B8C8D8C8C8B888A8A89888686858785848286858787
85848583838482828282807F7E7D7E7B7D7B7A77787874777676737372736F706F6E6F6E
6E6B6C6D6C6D6C6B6B696B6A6C6B6B6A6C6D6A6B696B6B6B6B6A6A6D6B6D6B6B6C6C6A6A
6C6C6C6C6C6D6D6D6D6E6F706E6F7070706F6E70716F7070707171727273737577767579
7878797877777675737172706F6C6964605A544F4945423F3B393735343230302E2C2C2B
2B2A29292928282828282827272727272727272727272627272627262626262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626252626262626262626262626262626262626262626262626262626262626262727
262726272627272627272726272727272727272727282727272727272828282728282929
282928292A292A2B2B2B2C2D2D2E2E2F303033333537383A3C3D3F41424546494B4C4E4F
515254545659595B5C5E5D5E616261616261626565666466656765666669686869686969
696C6C6D6C6A6D6E71707073727375777A787B7E7F808081848384888889898A8789898C
8A8C8C8D8B8E909090908E908F909190908F8F90908E8D8C8C8C8A8A8A8B8C8C8B8D8B8B
8B8A8C8F8E8E8C8D8F8C8D8E8D8B8F90908E929192918E9092909392919191918F909090
90919190908E8F8F8E8D8F8E8B8D8D8C8E8F8C8D8C89898B898A86878784858682878687
8786848586828484838183827F817E7E7F7D7B7B7A7A7878777675747473726F7171706F
6C6E6C6E6B6C6B6C6C6B6B6C6C686B6B6B696A6B6A6B6B6B6B6A6D6A6B6B6A6A6A696A6A
6D6C6C6A6D6C6C6C6E6D6D6E706D6F6E71716F706E716F72706F71736F72737474747676
777777767676757674727271706D6B67645F5A514C4844403C3A3837343432302F2D2D2C
2B2B2A2A2929292828282827282828282827272727272727272726272627262626272626
262626262626262626262626262626262626262626262626262626262626262626262625
2625252626262526
262626262626262626262626262626262626262626262626262626262626262726262627
262627272626262627272727272727272727272727272728272827272728282828292928
2929292A292B2A2B2B2C2C2E2D2F2F2F3133333436383A3B3D3F41434446484B4C4E5051
53545658585A5D5D5E60606263626465646567666868686865696868696968696A696969
6B6B6B6C6E6F6E6E6E6F727473757876787A7D7D7E7F8080838584898A888B8C8C8A8E8C
8C8B8C8C8E90929291908F9191909293938E929290908E8D8D8A8D8D8B8D8E8A8C8E8D8F
8D8E8D8D8D8F8D8D8F8E8E90918E908F9091929093929190928F92939391939393909090
919291919292909092918F9090908F8D8E8B8D8E8D8B8A8B8B8887868788868686868886
86868584868285858483838480808181817D7E7D7A787A787A7875767474747271726F6F
6F6D6D6D6C6B6C6B6B6B6D6B6C6C6C6D6B6B6C6A696A6A6A6A69696B696B6B686B6B6A6B
6C6B6C6A6C6A6D6D6C6C6E6F6E6E6E6F706E6F6E6F6E6E70706F70717272727172717674
747576767977757775757274716E6E6B6965615A534C48443F3C3A3837353332302F2D2D
2B2B2A2A2A29292929282928282827272727272727272727262627272727262727262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626272626262626262627262726272626
262727262726272726272727262727272727272727272727272727272828282829292828
28292A2A2A2B2B2C2B2D2D2D2E2F30313233343638393C3C4041434547474B4C51505254
5458585C5C5E5E616062646564666666656869686A69696B6A696A6C6A6D6C6C6B6C6B6D
6C6C6D6D6E6C6C6F6E70717374767878797B7B7E7C8080808384878989878A898B8E8B8C
8C8C8F8F90908F919392939493909393929291939293919190918F8F8D8F8D8D8C8C8D8E
8D8E908E8E8F8F8E8F8F918F8E92908F9191939295929193909293929193929291929293
9391929290919191918F908E8E8E918F908E8D8F8E8C8B8C898989888988888887868787
8587878687878784878784858382828583817D7D7D7C7D7A7A787679787476757472706E
6E6F6D6E6D6C6E6A6C6B6D6D6B6D6E6D6D6B6C6C696B696A6A6A696969696968696A696A
6A6B6A6E6A6C6B6A6C6D6C6D6E6C6E6E6F6E6C6E6D6E6D706D706E6F6D6F707171727473
74747576747675757475727371706F6D6A6864615B544C47433F3C393836343331302E2E
2D2B2A2A2A2A292928282828272827282727272727272727272626272726262627262626
262626262626262626262626262626262626262626262626262626262526262626262626
2626262625262526
252626262526262626262626262626262626262626262626262626262626262626262626
262626262626262727272727272726272727272727282727272728282728282829282929
29292A2A2B2B2B2B2C2D2E2E2F2F3132333436383A3B3C403F434346494C4D4F53535555
59585B5D5F5F62626465656666676A676A696A6C6D6B6B6B6C6B6C6C6E6D6B6C6C6C6C6B
6F6D6B6D6E6E716F7171747375777779787A7C7D7F80848286878688878B89898D8B8D8C
8D8E8E8F929394919294949191959593979795949494949495939291918E8D8E8D8D8F8F
8F8E8E8F8D8F8E8E8F909091918F8F909291929192929493939292939191939594949393
939396939394939393939390908F91928E918E90918D8E8F8C8D8A8B8B8B8A8A87898B88
87888887868788898687868585838282828180807E7E7E7D7D7B7C787879777373737070
6F6F6C6D6E6D6E6C6D6B6D6B6C6E6C6C6A6A6A6B69696A696B6B68686A6B6A68696B6B6B
6A6B6A6A6A6C6C6B6D6B6A6C6C6D6C6D6D6D6F6D6D6E6D706C6E6F6F70706E7070717271
7173737575767574757374757371706E6C6A67646159524B4743403D3A38363432312F2E
2D2D2B2A2A2A2A2928282827282827282827272727272727272727272626272626262626
272626262626262626262626262626262626262626262626262626262626262526262626
2626262626262526
252626262626262626262626262626262626262626262626262627262626262726262726
262726262627272726272626262727272727282727272728282828282828282828292929
292A2A2A2A2B2B2C2D2D2E2E303131323536383A3B3D3F404343474A4B4E4F5154565858
595B5D5D6062636466676867696C6C696C6C6C6C6F6D6C6D6F6F6E70706D6F6D6F6F706D
6E6F6F716F7071737275757577767879797B7E7C7F82828384868589898A8A8C8A8C8B8C
8E8D91918F92939192929093949393969698969596969696959494929090908F8F908F90
918D918F8F8E91929090908F8F9193919392939490929493939494939393939494939694
95949395949596929394959492959493939490929192908E8E8C8C8C8C8C8B8A88898888
888987898887888887888787868383848585828182807E7E7C7C7C7A7A7978787673726F
706E6F6E6D6D6F6C6D6D6B6D6B6B6B6C6B6A6B6A6C6B6B696A696A686868696969696869
6B6A6B6A6A696B6A6B6C6B6B6C6C6E6C6E6D6E6E6D6D6D6C6E6D6F6E6E6F716F71717170
73727273737575767775737371726F6F6C6D6B67646156504A4643403C3A37363532302F
2E2D2C2B2A2A2A2929292829282828282727272727272727272727272626262627272726
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262625
262626262626262626262626262626262626262626262626262626262626262726262626
262726272727272727272727272727272727272727272827272827272828282829292929
2A2A2A2A2A2B2C2C2C2E2E2F303032333637383B3C3E40424546494B4D50525355565A5B
5B5E5F626465666767696A6A6C6E6C706E6E6F6E706E7170717173706F70716E71707271
70707373717173747273737576767878797C7D7E8081838385878687898B8A8C8D8D8D8E
8F8F91908E91929191969394939295969696979495969797969796939292919192929091
8D8F9190918D92908F919391919191929294949394939192949494919293939395959694
949595949392959795969594939295939293939191929092908F8C8D8D8B8A8A8B8B8788
8A888989898A878887898887868786858587848280827E7F7C7D7D7B7B797A7776767472
7070706F706D6E6F6D6C6F6B6A6D6C6B6B6A696B6C6B6B6A686868696867686A696A6B6A
6A6B686B6A6A6A68696B6A6A6D6C6C6C6D6F6F6D6D6F6D6E6E6B6D6E6D6F6F706E706F71
7171747274757473747374726F71726F6D6D6C6B67635D544E494541403C393836343230
2E2E2D2C2B2A292A29292829282828272828272727272727272727272727272627262626
262727262726262626262626262626262626262626262626262626262626262626262626
2626252626262626
262626262626262626262626262626262626262626262626262626262626262626262726
272726272726272726272727272728272727272827272728272828282828272829292929
2A2A2B2B2B2C2C2C2E2E2F303033333536393A3C3D40424548484A4C4F515456585B595B
6062646465666969696B6E6D6E7170717072717270737372737271737472717172727273
737372727477717474747675767879787B7D7E807E7E82858488888B8A8B8A8B8C8B8F8F
908F91908F9090949794969794939496999998989B959898969895999694929393929190
9293908F91929092939191918F9491949393949295969593919492939393939696949496
96979693969595969598969494939494969495939193928F929191908F8D8D8D8C8D8A89
8B8889898A89898A8D898A8B8489858685848684828381827D7E7C7C7C7A7A7A79767672
70706F70706C6E6F6F6B6D6C6B6B6B6A6A6B6A6A6A6B6C696A696969686969696A69696A
6969696A6A68696A696A6D6B6A6B6D6B6C6A6C6C6C6D6E6D6D6B6C6C6D6E6E6E6F706F70
6F7171737376747373747472707072716F6E6D6A6A67615C534C4844413E3B3937353431
302E2E2D2C2B2A2A2A292928282828282827272727272727262727272727272727262627
262626262626262626262626262626262626262626262626262626262626262526262626
2626262626262626
262626262626262626262626262626262626262627262626282A28262626262626272626
26262727272727262727272727272727272727272727272828282828282828282829292A
2A2A2B2A2B2C2C2E2E2E30303233353637393C3E3F41424648494B4E51535658595B5D5E
606264666969696B6C6F6F70707274727373757575737474767574757473757474707475
7573757575777575757575747878797A7A7D7B7D8180848386868989898C8B8C8D8C8E8E
8E919191909090929397979896969496979998999897969699979B999899979598959492
929295929191939291919290909093929396939495959694919493939392949495959596
989597979997969A9A999998999A95969398909393939291909191928F8F8E8C8F8E8C8B
8D8B8C898A8C898A8B8988898A8987878685848485838382827F7F7C7D7C7B7A7A7A7775
75737071716F6E6F6E6D6C6C6D6D6C6B6E6C6C6A6A6A696A6A6969696969686B6A69696A
696A6A696A69696A696A6A696B69696B6B6C6B6C6D6E706B6E6D6F6D6C6D6D706F6E7070
7172717071707173717373727171716E6E6D6C6C6B6A67615B534C4744413E3B38373433
31302E2D2C2C2B2A2A292928282828282828272727272727272727272727272626262626
272626262627262626262626262626262626262626262626262626262626262626262626
2626262526252625
262626262626262626262626262626262626262626262626262627262626262726262626
272627262726262727272727272727272727272727272728282728282829282829292A2A
2A2B2B2C2C2D2D2E2E2F3032323435373A3C3C3E40434648494C4D50535658585B5E5F61
63646567696B6D6D6F707073737474757477777778797877767577797877777776767576
757774767578777677777776767A797B7C7E7E7C7F8283858486898989888E8D8D8D8F8E
90908E8F8E91919094969A9A989897949796999C999A99989A9A9C9A999C999998989795
969492949492919491939394939292949794969797979693949394939694949593949396
9798979696979697999B9B9C9B979A99959594929393929292928F8F8E8C8F8F8E8F908B
8D8C8E8C8A8C8A8A8B89888B8A8A888789888785868684848382837F7F7D7E7A7A7B7878
7875717172706F6F6E6E6E6E6D6C6D6B6A6B6A6A6C696A6B6A6B696A696A69696A696A69
6A686A69696A686B6B69686A6A696B6A6A6A6C6D6E6E6D6D6C6B6C6B6E6B6D6C6D6E6F70
706F706F707272717171737170716E706E6F6E6E6C6B6865605B514B4742403D3A383735
33302F2E2E2C2C2B29292929282928282828272827272727262727272727262627272727
262627262626262626262726262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262526262626262626262626262626262726262626262726272727
272627272627272727262727272727272728272727272828282828282828292929292A2A
2A2A2C2C2D2D2E2E2F303032343537383B3C3E3F4145464A4C4F4F52555759595C5E5F62
65676B6B6C6C70707274737475767979797A79797A7A7B787A7B7B787979797979777977
78787678767778757876777677787A797D7D7D7C8082868688878687898B898C8C8D8E8E
90928F9190918F9093989A9A98989692989A999C9A9A999A9B9B999C9C9A9B9B99969597
999798949596969392929492949593979496949497979796979595959393989795959596
9595999798959497999A9C9D9B9A98989795939796949393939190908F8E908E8E90928F
8F8E8E8C8B8B8B898B898A8B888B898989888984868384858284848283817E7D7D7B7B7B
79777775737373716E6E6E706F6E6D6E6E6C6D6A6B6A6D6C6B696A6A6B6A6B6B69696868
6C696A6A6A696A6A696B6B6868686A696A696A6B6C6D6B6D6B6B6A6B6C6A6B6E6C6E6D6C
6C6D706F6F6F7070706F707170706F6E6E6E6D6E6D6C6B68665F58514B46423E3C3A3836
3432312F2E2D2C2C2A2A2929292829282727282828282727272727272727272726272726
262626262626262626262626262626262626262626262626262626262626262626262626
2625262626262626
252626262626262626262626262626262626262626262726262627262626262626272627
2727262726272727272727272727272727272728272827272828282928292929292A2A2A
2B2B2B2C2D2D2E2F303032343437383A3C3D40424446494B4E505154565A5B5C5F606365
6668696E6D707074747577777879797A7A7C797C7C7E7D7E7F7E7C7C7C7C7B7A7A797979
7B79797979797A797978797879797B7E7E7E7E8080818085868787878687898A8D8A8C8E
8E928F8F8E93939393969A999A9997979496989B9C999A9898999D9B9E9C9B9A9E999898
999A98979697979595949594959295969695959596979898979795959697999798999496
95949797979798989898989A9B9B9B989995989894939495939090909191909091928F92
8F8D8D8E8B8C8D8D8C8B8C8C8B898A8A878B8A888786868587868384848480827F7E7D7B
7B7877757475737270716E6D6E6F6D706E6F706D6D6C6D6D6D6C6C6C6B6C6A6B6A6A696A
6B69696A6A686A6A6A6A6A6A6A68686969696A6A6C6C6B6B6C6C6A6D6C6C6B6D6B6D6C6B
6D6E6E706D706E71706F6F706E6E6E6C6A6E6C6D6C6C6A6B67645F594F4944403E3C3937
353432312F2D2C2B2B2A292A292929282828282827272727272727272726272727262626
262626262626272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262627262627262626262727
2726272727272727272626272727282728272727282728282828282829282929292A2A2B
2B2B2C2D2D2D2F2F3032323436383A3C3D3E404446464A4C4F515256585A5D5F61626567
696B6B6E7171747276787B797C7A7D7C7E7E7F7E807F80807E7E807D7C7C7D7B7C7B7C7D
7D7C7B7B7A7B7A7978797A797C7C7C7C7E7F81828181838384858587878A8A8A8A8B8B8D
8C8D8D8E929391959395969B95969A9698989A9A9B9A9C9899999D9B9E9B9B9D9D9B999C
9C999C999799989596979697949594969897979796989A989A9899969797989998999899
9696979A9798969897999B9C9B9C989B9999969795959596939492929391929093919492
928E908E8F8E8E8F8E8D8C8C8A898A8B898B8A89888788888786858686818280807D7E7E
7B797977787674737171736F706F70726F6E6F6D6D6E6C6E6E6E696D6C6C6B6C6A686A69
696B686A6C6A6A6A6A696A686A6869696A68686A6B6A6C696B6A6A6B6C696A6C6B6A696B
6C6D6C6D6C6E6E706E6D6F6F6E6F6D6E6C6C6B6B6D6A6A6B6865625E554E48443F3D3B39
373634322F2E2D2C2C2B2B2A292928282828282827272727272727272726272726262726
262626262726262626272626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
26272626272727272727262727272727272727272828282828282828292829292A2B2B2A
2B2C2C2D2D2E2F30313234353738393D3F41434547494C4D50525556595D5E5F6362686A
6C6D6F7172757476777A7A7B7C7E7D7F7F818381808080818280838181817F817F7E7D7E
7E7E7C7E7B7C7B7D7D7C7B7C7A7C7D7F80817F817E8183838484898687888A8B8B8A8A8B
8C8D90929095939492959494969C989B9798999AA29A9C9C9A999B9B9D9D9C9DA09D9C9C
9B9D999B9998989898969497959597959897989996979A9998989699969B979798989897
97979B96999999989897999C999A98999A97969595979695949595939391939193919291
919290908E908E918F8E8D8C8D8D8A8C8C8C8B8A8A87878788888788858485838180807F
7E7D7C79797975767574747371727172716F71706E6E6C6E6D6D6C6D6B6C6C6C6B6A6A6B
6A69696A6A6A6B69686A696B686D696B696A6969696A6B69696B6A6C6B6C6A6B6B6B6A6A
6B6B6A6C6E6E6D6D6E6D6E6E6D6D6E6E6C6B6B6C6A6B6B6B696764615D534D47433F3D3A
39363433322F2E2D2B2B2B2A2A2928282828282727282727272727272727272726272627
272627262626262626262626262726262626262626262626262626262626252626262626
2626262626262626
252626262626262625262626262626262626262626262626262626262626262726262727
2627262727262727272727272727272727272727272728282828292928292A292B2A2B2B
2C2C2D2D2E2F303132343536383A3C3E41424446494A4E50525457595A5E62626566686A
6C6E707375767879797A7E7E7E8082808382828482848283848182858383848283828381
818281817F7F7F7F7F7E7E80807F817F81808282828082848383878588868A8B898B8B8A
8A8A8C8F959392939192919096A8999C9A99A6A29C9B9C9D9D9B9E9E9F9EA09E9F9FA09D
9D9E9C9C9D9A9B9797989794989696979597979A99999A99989898989999999799989796
98999A969A9999969899979B9899989D9898979896979797979796949697949592929292
909291918F8F8F8E8F8E928F8E8E8D8B898D8C8A8A898989898988888886848583827E80
7E7E7B7C7B79777776757473737273717172706F6E6F6D6F6F6C6F6D6C6D6C6D6B6B6B69
6A6A686A6A6A69696A69686B6A6B676869676968696A6C6B696A6B6A6A6A69696A696B6D
6A6A6C6E6C6D6E6E6E6D6C6E6E6D6D6C6D6A6B6C6B6A686969696763615B524A4743413C
3A38363432302F2E2D2B2B2A2A2929282828282827282827272727272727272727272626
272726262726262626262626262626262626262626262626262626262625262626262626
2626262626262626
252626262526262626262626262626262626262626262626262627272626272727272727
2626272727272627272727272727272727272828272827282828282829292A2A2A2B2B2C
2B2D2D2D2E303132343536383A3C3E41414546484B4C4F535454585A5C60616467686A6E
6E7171737578787B7C7E7D7E818482848584858585848683868686888485858484848686
8482828181818181827F818081807F838082808382838483868686868588888988878889
888C8C8F8F929291918C909095989797999A9A9A9B9A989C9D9C9D9E9D9FA0A29FA09E9F
A09E9C9C9A9D9E9B9B9B9B9A979A989996989A9997999A999A999B9898989897999C9A97
9999989998999A9A9A9A9A979A9A9C989698979897999999989696979696959593929191
92959290929293928F8F8D8E908D8E8D8E8C8B8B8B8A8888898A88898788848485848380
7E7E7E7B7B7A7879777874737374727473716F71717071706E6E6C6E6C6D6E6D6C6D6C6C
696A686A6A6B69696969696A696A6C6A6A696969696A69696A6968696B696A6868696968
6A6A6A696C6B6C6C6C6E6C6D6D6E6B6C6D6E6D6C6A6C6A6A68686A69635F59504A45413E
3C3937373332302F2D2D2B2B2B2929282829282828282728272727272727272727272627
272726272626262626262626272626262626262626262626262626262626262626262626
2625262626262626
262626262626262626272626262626272626262726262627262626272726262727262626
2727272727272727262727272727272727272727272727282828292929292A2A2A2B2C2B
2C2D2E2E2F303233333538393B3D3F414445484A4C50515355585A5B5E61636667696D6E
7073737677797C797D7E818384848587848588888886878788898B898C8A8A8786848987
8586848585858284838184848083828382828282838285848686858586868889898A898B
8B898C909093918F908F8E93929798999A999699999B9B9B9C9D9B9D9FA0A09FA1A0A3A1
A09F9D9EA09E9E9F9E9C9E9C9B9C9A9A9B9997999B969A999B9A98999898979A989B9999
999A9A999C9A9A979A999C9B9B9B98999A99989A97979698989798989998989796939394
9393929093918E8F91908F909390908F8C8F8A8D8B8A8B8C8A898B898987878685848584
80817F7F7C7B7B7A77767675747575747172727274727071706F6F6D6E6F6D6B6D6C6C6A
6B6B69696969696A6869696A6A6A696A696969696A6768696967696A6A6966686968686A
6969686A6C6D6D6C6C6D6D6E6C6D6B6C6C6D6F6D6B6A68696869696869645E56504A4341
3E3C3A363433322F2E2D2C2B2B2A2A292929282828282827282727282727272726272727
262627262626262627262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262625262626262626262626262626262626262727262627272727272727
272727272727262727272727272727272827272827282828282829292A2A2A2A2B2B2A2C
2D2D2E2F303132343636393A3D3F40434447494B4E4F525556595C5F626264676A6B6C6F
72747576797B7D8080818285858685868889888A8B878B898C8E8C8B8C948A898C898A89
898A87888786848684878585858482868285848485858483858684858986878689898889
898A8B8B8D8E90908F90919294979997989897979898989C9C9E9DA09F9FA1A3A2A5A1A3
A1A19FA2A0A29FA09E9E9D9E9D9D9C9A9C9A99979B98999A9A98999B9B99999A9B9D9C9D
9B989A9997999B9C9B9B979A9C9A999C9B9B989B9B999A9998989A999B9A989997959393
919394929492919192919191908F8F918F908F8F8B8B8B8A8B8C8C8C8989888888888785
8382837D7C7E7C7D7B7A79787776757473737470717372727071706F6E6D6C6D6C6D6C6D
6A6B6968696B696A6A6A696A6A696A686A6869696A686A6A686A68696867676869676965
686A68696A6C6C6C6E6E6C6D6C6E6E6E6B6C736F6C6A6A6A69696B6B6865625C564D4843
3F3C3B39373432312F2E2D2C2B2A2B292929282928282828272727272727272727272626
262726272727272626272626262626262626252626262626262626262626262626262626
2625252626262625
262626262626262626262626262626262626262626262626262626262727262726272726
26262727272727272727262727272727282728272828282828282829292A2A2A2B2C2B2D
2C2D2E2F3031333536383A3C3D3F414345494A4C4F515456595B5E5F6464656A6A6E6D72
7376757A7B7C7E7E81818486898889898A8B8B8B8B8A8D8D8F8F8F8D8D8C8A8D8C8D8D8B
8B8A8A8A8C8A898A88898689878887868783868688858786878687868986888885888887
868889898B8A8D8F909093919496989494939797969B9A9B9B9C9EA19FA1A0A0A2A2A2A6
A2A3A1A2A0A2A0A3A2A19EA09EA0A09C9C9B9A9A99989C99989B99989B999B9A9B9A9B9C
9B9A9A989A999B9B999B9C999A999E9D9D999C9E989C9A9799989A9A959A989897979496
9494959493929295939293938F8F91908F8F8F8E8C8C8C8D8C8B898C8B89898987888785
848383837E807D7D7A7979777876777575737472717272717273716F6F6B6F6E6C6B6D6B
6C6B6A6B6B6A6B6B6A696A6A6B6A69696968686969686A68696A69686A68686868686869
68686769686A696B6A6C6B6C6D6D6C6C6D6C6B6D6C6A6B696A6869696866635F5B534C45
413F3E3A37353432302F2D2D2C2B2B292929282828282828272727272727272626272726
262626272726272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627262626262626262626262626272627
27272727272727272728272727272727272727282828282829282929292A2B2A2B2B2C2C
2D2D2E303133333537393B3E3E414345474A4C4F4F525657595D5E62626468696C6E7174
747878797E7C7E8182828586878B8B8B8C8B8E8F9090919191929091908F909090919090
8D8E8E8C8E8D8A8C8B8A8A8B898A88888688848787858587878487868686888688878889
878888898A8B898D8E90929394979493919295989B9A9A9D9C9E9C9FA1A09EA0A0A5A4A2
A5A5A5A6A4A2A2A3A3A1A2A09FA19C9F9D9D9D9B9B9E9B9B9B9C999A9B9A9C99999A9D9C
9B9D9A999A99999799999898999C9C9B9E9B9B9A9E9B9B9C9A9A99999B999E9898979697
95959493949391959495939591929091908F90918E8D8C8C8E8E8D8D8B8D8A8B8B898887
858485838481817E7C7D7B787677787776767373747372737373736F6D6D6F6E6D6D6C6D
6C6B6C6A6A6A6B6B6B6A696A68696969696A686B69696A6A6A6969686967676767676569
666767676868696A6B6C6C6C6D6D6E6C6C6D6D6B6B6C6B696A696769666666635F595149
4442403B3837353432302E2E2C2C2A2A2929292929282827282727272727272727272726
262627272626272626262627262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262627262626262626262726262626272627262626262727
272726272627272727272728272727272727272728282828282929292A2A2B2A2B2C2D2D
2E2F303032333537393A3D3D4042464549494D50525355595C5E61636767696A6D707374
77787A7D7C7F84818485888988898B8C8C8C8F8F93929395939493929294939295929493
909191909090918E8D8D8C8B8C8A8A8A888A8B8A88888887868688888786858786878887
868A8888898C8C8C8A8D8E9092949393929797989A9C9C9C9A9CA09EA1A2A0A2A2A0A2A4
A4A4A3A5A6A4A4A6A4A2A4A3A3A2A1A0A09E9F9B9A9A9C9D9B9B9A9A999B9A9A9B9B9C9E
9A9B9B989C9A9C979A99989A9A9C9E9E9E999B9D9D9E9A9D9C9A9B9A989A9B9E9B999B99
9694969593949693949495929392919190918E8F8D908D8F8B8E8F8D8B8D918C8C8D8886
87858586838383807F7E7D7B7A787978777575767373737374747472716E6F6F6E6E6D6C
6B6C696C6A6E6A6B696A6A696C686A6968676A686A69686B6A6B6A686669676668696767
67666666676868696969696B6C6D6D6C6B6E6E6B6C6C6C6A6B696A6867666663625E5750
49453F3D3B3737353231302E2D2C2B2A2A29292828292828282727272727272727272727
262627262626262626262626272626262626262626262626262626262626262626262626
2626252626262625
262626262626262626272626262626262626262626272626262626272627262627262627
2627272727262727272727272727282728272828272828282829292A2A2A2B2B2C2C2D2E
2D2F3131333536383B3B3E40414246484B4D4F515456585B5C60616565686B6D70737376
78797C7D7F7F81858687888A8C8F8E8D8E90909192939699949697959596959795959695
96949292939392908F908D8E8F8E8B8D8C8C8A8B8A898988878987898785878685868687
878A888888898B8B8C8C908F928F8C90929497979B989C9B9DA09E9E9F9F9DA1A0A1A2A3
A3A7A6A7A5A8A6A6A5A3A7A4A5A3A2A3A2A19F9D9F9E9B9E9B999C9B9B9B9A9B9A9B9E9C
9B9C9D9D9C9C9B9B999B9A9B9A9FA09F9A9A9C9C9D9D9F9F9E9A9B98989A9B9C9A9A9C9B
99999797989796959495949595929291918E918E8D8F8D8E8E8E8F8E8D8E8D8E8B8A898A
898588838586848282817D7D7E7C7C7B7A787776757575777574747273726F706F706F6D
6C6C6B6C6B6C6A6A6A6B6A696D68696969696969686969686A6868666867686667686766
656867676767686A68696B6C6A6D6E6E6D6C6C6C6C6C6B6B696869686664666461615E55
4D4743403C3A38363433302E2D2D2B2B2A2A292829282828282727272727272727272727
272727262627262726262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262726272626262626262627262626272626272727262727
2727272727272726262727282727272727282728282828282829292A2A2A2B2B2D2D2E2E
2E303133343637383B3D3E41424446484C4E505355565A5B5E616366696B6B7071727477
7A7A7F817F82848687888A8C8C8D8E8E8F92939293949799969699999A97979897999798
989596979594959292949291929091908F8D8C8D8E8C898B8A8A8A898A88898988878787
89888A8A8888898B8D8C8F8E8E9293919294979598979B9B9E9F9E9EA1A1A19FA1A2A2A4
A5A6ABA9AAA9A8A6A8A6A4A5A5A6A4A5A2A2A3A1A1A1A09D9E9C9D9A9D9D9C9A9B9C9C9C
9C9D9B9D9F9B9D9D9A9C999B9D9E9E9D9D9C999B9EA19F9F9E999A999C9C9B9B9C999A99
9B999998979797959695979794969393929394918D908D8D8F8E8E8B8D8F8E8C8B8B8889
8687858887888586828281807E7C7E7B7B797A7978777876767674767471727172706F6C
6D6B6E6E6E6D6B6A6A6B6C69696B6B6A6A6A6969696A676A6A6869676765676765656667
6665686767696666676868696B686B6C6C6B6C6C6B6A6C696A6A6867666766656563605B
534B45433E3C3938353331302F2D2C2B2B2A292929282828272827272727272727272727
272727272727272727262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262726272626262627262627262726272727
2727262627272627272727272727272828272828282829292929292A2A2B2B2C2D2D2D2E
303031323437383A3B3E40424346494B4D4F525457595C5D616265696A6B6F7073757779
7D7B7D8082848586898A8B8F8E8E9090939193969596989896989C9A979B9A9E9B9B999A
9C9C9A99989696969694949594929290918F90908E8D8E8B8A8B8A8C89898A8989888788
8687888687898B8B8C8C8D8C8F8F9092929596959897999B9D9C9C9FA0A1A19EA0A3A6A2
A6A5A8AAA7A6A9AAA9A8A8A6A7A7A5A3A5A5A3A3A1A0A0A29E9F9C9E9E9A9D9D999C9D9C
9E9C9A9B9D9C9D9F9D9C9B9D9D9E9F9E9E9A999D9D9FA2A09F9B9C9C9C9F9C9E9D9A9C9A
9B9B9D9A999895989798969595939293929393939190908B8E8E8E8E8F8F8F8C8D8B8A8B
89898588888885858585848482817F7E7D7C7A7A78787A7776777774767473737371706D
6F6E6E6F6E6C6D6D6A696B6B6D6C6B6A6A6C6B696B6969696A6768676766666666676366
68676766676766686868676869696B6A6A6C6C6B6B6D6B6B69696967676667666564625E
58524943403C3B3937343331302F2D2C2B2A2A2A29292928282827272827272727272727
272626272627272626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262627262726262727272727
2726272726272727272727272727272728282828282929292929292A2B2C2C2C2C2E2E2F
3031323436383A3A3D40424445474A4C4E515556595C5D5F6065666B6B6C707074757879
7D7F7E83848588888B8C8B8C8F8F8F949395959496979997979A999DA09D9D9D9DA19D9C
9E9B9A9D999A9999999997959695949492939091908E8F8E908F8C8B8D8B898889898A89
888788868A8A89898B898D8C8F8D9090959593979797999A9C9FA09DA09FA1A1A2A7A4A7
A4A6A4A8A7ABA7A7ABA8A8A7A7A8A7A7A6A6A7A2A5A1A1A0A1A0A09E9F9D9D9D9B9B9C9E
9F9B9A9A999E9E9F9D9C9C9E9E9F9E9E9D9D9D9B9C9E9FA39F9C9E9F9E9E9F9D9B9A9B9B
9D99999A9B98969799989899979796939393929293928E8F9090918F8E8C908B8D8E8C8D
8B8A888888878885878586858383817F7E7E7D797B7C797A787877747677777573737370
6E706F706F6E6D6D6B6D6D6C6969696A6A6B6A6B6A696B6B6A696A696767666566666665
6565666666676766686A696968686B6C6B6B6B6B6A6B6B6A6B6B69686868676865656360
5C564E48433F3C3938363431302F2D2C2C2B2A2A29282829282828272827272727262727
272727272727272626272626262626272626262626262626262626262626262626262626
2626262626262626
262626262626262626272626262726272626262626262626272626262627262727272727
2726262727272727272727272728282828282828282829292A292A2A2A2B2C2C2D2E2E30
3032333537383A3C3F41434647494C4D505255585A5B5E606364676B6C6D71727478777D
7E7F8082848585898A8E8D8F8F9291909794979797989B979B9D9D9E9C9E9E9E9F9F9F9F
9D9EA09E9C9C9D9D9998989997999695949492939492928D8E8E8E8E8C8C8C8C8B8B898A
8A8B8989888A89898B8B8C8E8C8E8F93939693939695999A9A9D9E9D9D9DA1A3A1A3A4A6
A5A6A8A8A7ACA9ACACAAA9A8A7A9A9A7A6A8A6A6A6A4A1A4A1A3A2A0A09E9B9F9C9F9D9D
9D9B9E9B9C9A9EA09E9D9FA1A19E9D9D9D9E9C9D9D9E9FA19F9B9DA09E9F9EA19E9C9E9D
9C9E999B999A989A9997999698969798969593959493919291908F8F8E8E8D8D8D8E8C8E
8C8A8A8B87898889888384858583828081807D7D7C7A7B7A7B7979787877757675737270
70727172706F6F6D6D6C6D6D6B6C6B6D6A6A6C696A6B6B696B6868666767656666666665
65686466646565676668686869686769686A696A6C6B696C6B6B6A6A6968686867656562
5F5A544D46413E3B3937353332302F2D2C2B2A2A2A292928282728282827272727272727
272727272727262726272626262626262626262627262626262626262626262626262626
2626262626262626
262625262626262626262626262626262626262626262627262726262726262727272727
272627272727272727272728272728282828272828282929292A2A2A2B2B2C2D2E2E2F31
31323536383A3C3E40424446484C4D505254575A5C5F60646767696D6E6E737379797A7D
7F818183848889898C8E90919295949495959999999A9A9C9B9D9F9FA1A1A0A2A4A5A1A2
A2A2A3A1A1A09D9D9E9F9B9D9B989A99989796949793939292918E918C8E8D8E8D8D8C8C
8B8A8B8B8A898C898B898C8A8D8E908F90939693969797999C999D9FA1A0A0A2A4A3A5A4
A3A2A7A6A7A6AAA8ACACA8ACA9A8AAAAA8A8A7A7A5A7A6A4A4A3A3A4A09FA29F9F9F9F9E
9D9E9D9C9B9A9B9C9DA0A0A0A2A1A09D9E9E9D9F9DA0A0A09E9C9D9D9E9E9F9F9F9E9F9F
9F9D9D9B9B9A9B99999C999898969695939694939492919391938E918F8E8F8C8E8D8D8F
8E8A8D898A898A86888787828585838381807F7E7E7C7B7C7B7A7A787876757677757171
7172747471706F6D6E6D6C6C6D6A6B696B6C6A6A6B6B6C6B6A6A68676766676565676367
6666676765646564676869696767676A696A6B696D6B6C6B6C6A696A6968676865666463
625D59524A45403D3A38363532312F2E2D2B2B2A2A292929282928272827282827272727
272727272727262626262726262626262626262626262626262626262626262626262625
2626262626262626
262626262626262626262626262627262626262626272726262626262627262726272726
272627272727272727272727272727272828282828292929292A2B2B2B2C2D2D2E2E2F31
32343537393B3D40424446474A4A4D505456575B5C5F626466696C6D70737377797A7A7E
7E8284858689898B8E8F8F929297949597999A9A989C9B9D9E9FA1A3A1A3A2A3A4A2A5A3
A0A4A2A2A1A2A1A29FA49FA29F9F9D9D9B9B9A9A979794969594929391908E8F8E8E8D8E
8C8B8D8A8C8C8A8C8B8C8C8B8D8E9092919091939597999A9A9A9B9D9FA0A0A3A1A6A4A6
A3AEA6A5A6AAA9A9A8A8ABABACA8ABA9AAA9A7AAA9A9A8A7A6A4A4A5A29FA1A39F9F9F9F
A1A09C9C9C9C9D9E9EA09FA09FA39F9D9F9D9F9EA09FA09D9C9E9D9C9F9EA0A1A0A2A29F
A09E9D9C9B9B9C9B9A9B99989A9798969795969695959595949291908F908F8E8E90908F
8F8F8C8C8C898A8A8889888686848485828381807F7D7E7B7A7C7B787879777877757470
7374737272716E6F6D6C6C6C6E6E6B6B6A6C6B6A6A6B6A6B6B69696A6768666565656565
67666566666767666565676867676767676A6A69696A6B696B6D69696967676666676362
61615E564E48423E3C3A37363332302F2D2C2B2B2A2A2928282828282827272727272727
272727272726262626262626262627262626262827262626262626262626262625262626
2625262626262626
252626262626262626272626262626262627262626262626262626262626262626262727
2727272727272727272727272728282828282828292928292A2A2B2B2B2D2C2D2E2F3031
33353738393B3D40434347494B4E4F5354565A5B5E626267676B6D6F72747678787D7E80
818384858A898B8C8E90919293949897979C9A9C9A9E9BA0A1A0A3A4A2A4A4A6A4A5A5A6
A5A5A4A6A5A6A4A4A2A2A4A3A1A09F9EA09E9D9A999A99979796939492939290928F8F8E
8D8E8C8D8E8C8B8E8C8B8C8E8E8F908F928E91929495989A999A9B9EA09FA2A5A4A3A6A4
A8A8A8A8A8A9ABA9AAA7ABAAACACA9ACAAA9A8A9AAAAA9A9A7A6A6A4A6A5A6A2A3A0A0A2
A09F9D9C9D9C9E9C9C9F9F9F9FA1A2A0A0A19E9F9E9DA19D9D9C9D9E9C9FA19FA3A8A3A5
A19F9F9C9D9A9C9B9B9D9C979B9798989895979696969697939292918E9091908F8E8F8E
908F8E8E8E8C8B8A8B8A8987878786858685878381807F7D7C7D7C797979787A78777376
7273757373706F6E6D6C6E6C6E6D6E6B6B6B6B6A6C6B6B6B6A696A696868666565666665
666467666665656665666567666867676868686A6A6C6A6A6A696A686968676868666564
62605E5A544C46413D3B3837353331302E2D2B2A2A2A2929292828282827272727272727
262727272627262627262626272626262626262727262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627272626262626262626262727262727
2727272627272727272727272727282828282829282929292A2A2A2B2C2C2D2E2E303132
3335363A3B3C3E424346484A4D4E505454585B5E5F6365686A6A6E71717577797B7B7E81
82848587868C8C8E8E928F939395969A98999A9D9C9F9DA1A1A1A2A3A4A4A7A6A5A7A7A8
A7AAA6AAA5AAA3A5A6A7A3A5A6A2A1A3A2A29D9E9C999A999B9899979893969192929190
8F8E8F8D8C8B8D8D8E8E8C8D8E8F8E8E8D9290929293979A999B9C9D9D9D9FA0A1A3A3A5
A5A8A6A8A6A9A6A9A7A9AAABADABADAFAAAAAAA9A8ABAAABAEAAA7A9A7A7A6A7A2A1A29F
A19E9FA09F9E9EA0A0A0A09D9F9F9EA19EA2A09FA1A09E9B9E9B9B9E9EA19D9DA4A6A5A7
A2A29E9F9DA09EA09E9A9B9A9798999B9799979897979894949494929492959391908F8F
90908E90908E8C8B8B8A8C8B8788868785868686848381807F7E7B7D7B7A797878787674
7374757473726F6E6C6F6D6E6E6E6C6C6C6B6C6B696B6B6B6B6C6B696868656765676665
646666656566676466646666666767686867696A6869696A6A696A686969686866676565
62625F5D59524A45403D3A38363433302F2E2D2B2B2A2A29292829282828272727272727
272727262727272727262626262626262726272626262626262626262626262626262626
2626262626262626
252626262626262626252626262726262626262626262626262626262626272726272726
27272727262727262727272828282828282828282829292A2A2A2B2B2C2C2D2E2F313132
3437393B3D3E40434447484B4E50555457595C5E616265686B6D71707477777A7B7D7F83
848687888C8B8C8F8F90949594979897979B9C9C9EA1A1A2A1A2A6A4A7A5A6A8A9A6ACAB
A8ABA8ABABA7A7A7A8A6A8A7A7A5A3A4A3A3A2A19F9F9E9E9C9A97989795959592929092
91928F908D908F8D8C8E8E8F908F908D8F8E92909592989698979C9E9EA0A0A0A0A3A4A4
A3A5A5A7A6A7A8AEA8A7A9A8A9ABACABACADABACABAEAAABADA9AAABAAA7A8A6A6A7A4A4
A1A3A1A0A19F9FA09E9F9D9F9EA09FA0A0A3A09CA1A09F9D9F9C9D9D9F9D9E9DA2A3A7A5
A4A2A09FA09D9E9C9F9E9C9C9C9A9C999997989697969594949694949394949592909091
918F90908E8D8D8C8B8A8C89878A8887878A868685848381807F7F7C7C7A7A7A79787676
767778747473726F706F6F6E6E6D6C6D6B6C6B6B6C6C6B6A6A6C6A6A6965656667666465
676666656665666666646766666767686768676768696B696B696A686C6B6A6967656765
6562615F5B584E49423E3B3937353332302E2E2C2B2A2A2A292828282827272728272727
272727272727262726272626262626262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262626262626262626262626272727262726
272727272727262727272728282828282828282929292A2A2A2B2B2C2C2D2E2E2F313134
3537393B3D3F414345474A4D4F505355565A5C5E6263676A6D6F72747776797B7D7F8181
838689898C8D8D90939592949799989B9B9F9D9D9CA0A3A2A5A2A4A6A4A6A6A8ABACABAA
ACACA9ACAEABABA8A7ADAAAAA8A8A9A9A9A6A5A3A0A29FA09E9B9C9A9A99979796949595
90939390928F8C92918E8E8F918F90929091908F9393939798989A9D9C9D9F9E9EA1A3A5
A3A4A7A5A8A6A7A8A8ABA8A9A7ABAAABADACADACACAAABADACAAABADAAAAA9A7A7A7A3A5
A3A3A2A1A1A29FA09FA09F9FA2A1A2A0A1A1A2A0A0A0A09D9EA09CA09E9D9DA1A0A1A3A2
A39E9E9F9C9EA19F9C9E9C9A9D9E98979998979695979896969695959596979693929192
92919091908F8E8F8E8B8B8A898B898A888884858687848281817E7E7F7D7E7A7A797977
76777776767472726F727071716D6D6C6B6D6C6C6C6B6A696C6A6A6B6866676668666466
64656666666667646566656666656766676768686869686A6A6A676A6C69686965676666
646561605D5B544C45413D3B3836353331302E2D2C2B2A29292928282828282827282727
262727272727262727262627272626272626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262726272627272727272627
27272727272727272727272827272828282829292929292A2B2B2B2C2D2E2E3031323336
36383A3C3F40424446494B4D4F525556595B5E606564686A6C71727374777A7C80818284
85898A8A908D8F9093959595979A9C9A9F9FA0A0A1A3A3A1A4A6A5A6A5A8ABA9AAADADAD
ADAFACABACAEADA9ACAEACACABADADABAAA7A6A7A1A6A4A39F9F9C9E9C9A9A9899959695
9594949394919093908F928F8F92928F918F919293939497969898989B9D9C9DA0A0A1A4
A5A7A2A6A5A7A7A5A9A7A5A8AAA8A9A8ACADADAEADABACABAEADADACACACAAAAABA8AAA6
A8A2A3A3A3A2A19FA0A0A1A2A09EA0A2A1A1A19FA1A19D9F9F9F9F9D9D9E9F9F9F9FA1A0
A1A19F9E9E9E9E9D9E9B9F9C9E9C9B9C9A9A999796949795979597999895959692959191
9090908F92918E8E8E8D8E8C8A8B8B8A88888787878583858482837F7E807C7C7B7B7A7A
777977777675747373727071706F6E6D6D6C6C6D6D6B6B6A6B6C6B6A6969676664676565
666665666666676666656465656667666669676667696A686A6A6A686969696766676565
6663615E5E5C585149433F3C3938363432312F2D2D2B2A2A292929282928282828272727
272726272727272626262626272626262626262627262627262626262626262626262626
2626262626262626
252626262626262626262626262626262626262726262726262626262627272627272727
272727272727272727272727282828282829292929292A2A2B2B2B2C2D2E2E2F31323435
373A3B3E3F414346474A4C4F515355575C5D616465686A6B6D707373757B7D7E80858485
87898B8C8D8E9191929694979A9D9CA09F9F9FA2A4A1A0A5A6A5A5A5A7A9ABABADABADAC
AEB3ADAFB0B0ADAEADB2AFB0AFAEACABACA8AAA6A8A3A3A3A2A19F9F9E9C9D9C99999898
9594959595959293949290918F918F92939092919192959596969698989C9D9FA0A1A1A3
A4A6A4A6A7A5A8A8A5A9ABA7A6AAA9A9ADABACADAFAEAAAEACAEAEAFACADACAAA9ACAAA7
A6A6A6A4A5A3A5A2A0A1A1A2A2A3A1A0A1A1A1A0A19C9EA09FA1A1A0A0A09EA1A2A09E9E
9FA09E9D9E9E9E9C9B9D9E9E9D9C9D9B9C9C989998959594969997999897989796949394
929090918E928F8D8D8C8F8D8E8F8A8D88888988888987848486848280807F7D7C7B7C7A
79797877777675757473736F70706F6D6D6F6E6D6D6C6D6C6B6C6A69696A676666666566
6565646666666666666464656565656669666767686968696B6A68686968696768676766
666463605F5E59554E47413D3B39363533312F2F2C2C2A2A2A2929282828282828272727
272627272727262727272626262626262626262626262626262626262626262626262626
2626262626262626
262627262626262626272626262626262626262627262726272626272627262627272727
27272627272727272727282727282828282828292A292A2B2B2B2C2C2D2E2F3032333436
393A3C3D41424547494B4E50525458585C5D616466696B6D6F7275777B7B7D8183868688
8A8D8A8D90919193939598979B9BA2A0A1A2A3A1A4A5A7A8A5A9A8A6AAAAA9ACAAADAEB1
AFB0B0B1AFB3B1AFB0B0B1B4B1B2B0ACAFADACABA8A5A7A7A3A2A4A2A3A1A0A29F9C9997
98959897959692949393909192959293929293959294949295969997999D9B9CA09FA2A1
A5A3A4A5A4A5A6A9A7A8A7A8ACA7AAA9A9AAADADAEB1ACADADADADAEB0ADACACAAAAABA8
A9A7A8A4A6A6A1A2A2A0A39FA1A39EA19FA19EA09E9EA09D9F9FA19F9EA1A1A09FA29F9F
A19E9EA09E9FA19D9D9E9C9EA09EA09C9B9B9A9C9C99969899989996979A989797979593
9392909092908F90908F908F8D8F8E8C8B898989898B8786868686838280817D807C7C7B
7A797978777775747573737270726F6F6F6E6E6D6F6E6D6B6D6B6B6A6867676865666766
646566666666676767646766656567656666676665686867676868686968676868686766
65636363605C5C58514B45403C393736343230302E2C2C2B2A2A29292828282828282827
272727272727262727272626262626262726262626262726262626262626262626262626
2626262626262626
262626262626262626262626262626272726262626262627272626272727262726262626
272727272727272727272827282828282928282A2A2A2A2A2B2C2D2D2E2F303132333537
393B3C3F40444649494C4E515355585B5C60606568686C6C70727577777B7D8182838989
8C8A8C908F9393969899999B9A9D9FA1A0A3A3A5A6A6A6A9ABA9AAABACAEADACAAADAEB0
AFB0B1B3B2B1B2B3B7B3B4B1B5B1B1AFB1ACAFAFADABAAA9A7A6A6A6A6A4A1A19F9D9C9C
989998989797999596969492929192929192949293969597969696969D9A9C9C9D9EA0A1
A1A4A4A5A4A4A6A8A6A7AAA8A9AAAAABA8AAAAACACAEB0AFAEAFADAFAEAFB0ACAAABABAA
AAA8A9A7A6A6A4A29FA4A1A39F9FA19CA1A19C9E9F9FA1A19F9EA1A1A1A2A1A1A1A09EA1
A0A29DA2A0A19F9F9FA09DA0A0A09F9F9E9E9B9A9B9B999A989A999A9999999A98959696
9594939293928F91919090928E918D8D8B888A8B89898A8988868586848280807F7E7D7E
7C7A79797A7876797676757371716F71706F6F716F6E6D6B6B6B6C696868686866676667
646565656466666664656665666665676767666668676867696967676869696769666665
65666463615F5E5B574E47433F3B38373533322F2F2D2C2B2A2A29292928282828272727
272727272727262726272627272726262626262626262626262626262626262626262626
2626262626262626
262626262626262626262627262626262626262626262627272727272727262726272627
2727272727272727272827272828282829282929292A2B2A2C2C2D2D2F2F303134343639
3A3C3D40424447494B4D4F525457595B5E616466676A6E70717374767B7C7F818486898C
8C8C9090939292969A989D9C9C9FA0A0A1A2A5A6A8ABACAAACAAABAFACAEAEAEADB2AFAF
B0B2B3B1B4B3B4B4B4B6B4B3B2B4B3B3B1B1B0AFAFACACAAAAA7A7A8A8A6A6A3A1A29F9C
9F9B9A9C9A9798989897979593959292939395959495949495959698999B9B999B9C9F9E
A1A1A4A1A5A4A5A7A8A7AAA8A7A8ACACACAAACAAAAACAEAFADADB1B1B1AEB0B1B0ACADAA
A9A9ACA9A8A9A8A5A6A3A4A1A2A1A1A0A1A09E9C9F9DA0A19FA19FA1A0A0A1A1A1A3A3A1
A0A0A09F9FA3A2A1A1A1A09EA19D9E9F9E9F9D9C9E9A9E9A9D999A9B9A999D9B9C989A97
9897959394929192928F909293918F8D8A8A8C8A8B8889898A8687838484848281807F7D
7D7B7B7C7A7779787775757574727271727270716F6E6F6C6C6C6B6B6A69696B67696765
666463666466666565666365666766646564676667656765666769696867676865686667
6763626361615E5C58534C45413D3A38353532312F2E2C2B2A2A2A292828282828282727
272826272726262626262727262626272626262626262626262626262627262626262626
2626262626262626
262626262626262626262627262626262626262626262626272627272627272726272727
27272727272727272727272828282828292929292A2A2B2B2B2C2D2E2F30313333353739
3B3C3F41444647494C4D505355575A5E5F6263666B6B6D717275787B7D7F7E848486888C
8C8E9091939395999C9B9B9D9FA0A0A1A2A2A4A8A7ABABADADADADAEAEAEAEAEB1B1B2B1
B0B3B3B3B6B6B5B5B4B4B7B5B6B6B1B3B3B5B4B2B2B2AFAEAAABACAAAAAAA8A9A6A5A4A4
9DA19F9C999D9D9C9B9B9696959795949694949596959493979795979A99989A9C9D9FA0
A2A0A0A5A4A4A5A4A5A6A7A9ABA9AAABAFABACADAAAEADAEB0B0B1AFB0B3B2B0AEADAEAD
AAA9AAADA9AAAAA6A4A5A4A5A3A3A5A2A1A1A1A29E9F9D9FA0A0A0A1A1A19DA2A1A2A0A2
A1A2A2A2A1A09EA1A0A19E9C9D9D9F9F9FA0A09EA0A09F9F9D9D9E9D9C9B9A9B9C9C9998
999797979794929192938F929190918F8E8E8C8D8D89898B8A8889868585848382808180
7F7F7D7C7A797A7777757475737472727172727271706E6B6E6B6C6C6A6B686867666667
656364656564656664666567666664656666666567656666666767696867676666686765
6664646361605E5C5A574F49433E3C3937363332302E2D2C2B2A2A292928292828282827
272727272727262727272627262627262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262626262626272626272626262727272727
27272827272727282728282828282828282929292A2A2B2B2C2D2D2E2F30323435353839
3C3E40414545494A4C50535456595D5B606265686A6B6F737276797A7D7F80838686898A
8E919092929598979C9B9EA09FA19FA3A4A3A6A9ABACAEADABAEAFAEAEB0B2B1B0B1B1B3
B4B0B4B3B5B7B5B7B6B4B8B4B4B4B5B4B5B6B4B4B4B1B3B3B1B0B0ACAFACAAA9A6A7A6A6
A3A3A49F9F9C9D9A9A9B9A9A98979598959696979696969695979897989A98999B9D9F9D
9FA1A19FA1A1A2A5A8A6A7A6A7A8A9ABABABACABACAEAEAFB3AFB0B0B3B0B2B1B2B0AEAC
ACACACABABABAAA9AAA8A4A2A7A4A3A4A3A1A0A39FA0A0A1A0A0A1A1A1A0A29F9FA0A0A3
A4A2A2A4A4A1A19D9F9FA09F9C9E9F9FA4A1A0A0A09F9E9F9F9E9E9E9E9D9F9C999A999A
999A9999979693959394909390919091918F8C8D8F8C8E8B8B8B8A868887848384848183
7F7E7E7A7A7A7979777776777673737274737272706D6F6E6D6C6C6B6C6B696969696865
666564656564626564656768666563636466656565676565656666676866686765686566
656664636363615E5B58544B46413D3A3836353231302D2D2C2B2A2A2929282828282828
272728272727272626272627262627262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262726262627262727262626272727262626272727
272727272727272728282728282828292929292A2A2A2B2C2C2D2D2E2F3032333537383B
3D4041434547494A4D515155585B5D5E626366686A6C6F707475787C7D7E828487888C8C
8F9393939597989A9C9D9B9F9FA2A2A8A4A6ABA9AAAAAFACADB1AFB0B0B1B4B6B5B3B1B2
B5B3B5B4B4B5B5B8B6B5B5B6BAB4B6B8B8BAB5B6B7B6B4B4B3B3B0B1AFAEAFAFACABA9A8
A5A4A3A4A2A19F9D9E9D9B9B9998989897989797989796959796979899989998999B9C9B
9E9D9FA0A29FA1A3A5A3A5A7A5A9A7A9ABABAAAEADACAFB1ADB0B2B0B0B3B2B1B0B2B2B2
B0AEADACADAEA9ABAAA9A7A7A6A6A4A5A3A2A2A1A1A0A1A1A0A0A0A09F9DA09F9FA3A2A3
A3A2A3A1A1A0A09D9E9E9F9F9E9F9EA0A1A1A3A09FA49FA2A09FA09EA0A09C9D9D9C9A9C
9B999B9B9B9A989493948F9193909190908F8F8F8C8D8C8D8A8D8A8A8887858585858383
8281807D7B7D7A7B7A77787776767674727273727272706D6E6C6C6C6B6C6A6967696667
656566646464646563646566686565646567656566676663656666666766666668676666
66666563626160605C5A56524B443E3B3938363432312F2D2C2B2B2A2929292828282827
272727272627272727272727262626272726262626262626262626262626262626262626
2626262626262526
252626262626262626262626262726262626262626262726262626262726262726262726
2727272727282727272728282828292829282A2A2A2A2B2C2C2D2E2F3032333435383A3C
3E40424445484A4D50515355595A5E5F616366696B6D6F737476797B818082848787898D
8F8F94949699999B9E9D9EA0A2A2A3A1A7A6A8ABAEAFAEADAEAEB0AFB4B2B3B2B5B2B4B6
B6B5B5B5B9B5B6B7B8B7B7B7B8B8B8BAB7B8B7B7B6B7B7B5B6B4B5B4B1B4AFAFB0ADADAB
A9A9A8A7A6A1A39F9FA0A09EA09B989998999A9B9994969795979899979A9A9998999A9C
9D9A9D9E9CA0A1A2A3A5A5A5A6A6A9A8A8AAACAEADACB0AEABB0B1B0AFB1B3B0B3B3B1B0
B1B0B2AFAEACAFABADAAA9A8A7A7A9A7A4A2A3A2A0A2A0A2A0A2A0A1A19FA19FA0A3A1A3
A5A7A3A4A2A39FA19EA09F9D9EA19DA2A4A2A2A0A2A1A1A1A0A29F9FA09EA09F9E9D9C9B
9A999B9C9D9B9596969492949293949493928F8D8E8B8D8D8D8C8B898988888587888486
84828180807C7B7D797979787874757675737473727271706E6F6C6D6B6B6B6769676A66
656566646463626364656565656566636564666563646666676365656667656768666863
666464636161615F5E5B5B544E47423E3A3836343331302E2C2C2B2A2A2A292828282827
282827272727262726262627272726272626262626262626262626262626262626262626
2626262626262626
252626262627262626272626262626262626262627262627262626272727272627272727
272727272727272727282828292828282929292A2A2C2B2C2C2D2E2F2F32333637383A3D
3E41424446494C4E51535556595C5E606364666B6B6E717375777C7C7E82828487898A8D
91919397999A9C9D9E9E9DA2A2A2A4A8A9AAAAACADACAEAEAEB0B0B4B3B4B4B7B5B5B5B5
B6B7B8B7B5BBBAB7B7B6BABAB7BBB7B9B6BBBABBB9BABBB9B6B6B7B6B2B2B0B6B2AFAFAF
ABAFAAA8A6A4A2A5A0A1A1A09E9A9C9B99999A99989A9898999999999999979B9A999C9C
9C9A9E9C9D9E9FA0A0A1A4A4A5A6A5AAA9ABADACAEAEAFADACADAFAEAEB1B2B2B2B6B5B4
B6B0B1AFADB1AFACAEACA8AAA8A7A6A7A4A5A4A3A1A3A1A1A1A09EA3A1A2A2A2A2A0A2A1
A3A29FA1A19F9D9FA1A1A09FA0A09FA1A2A3A5A39DA3A2A2A0A0A1A2A2A19E9D9C9F9A9D
9B999B9C9C9B9899979695939494939495908E8F8D8B898C8E908E8A898B898885868785
828480817F7E7B7B7B7B7777777778747473737372727071716F6D6C6D6B6B6967696767
676665666466646464656463656763666465636466656664656364666666666465656865
646564646262605F5E5C5A57524C45403D3A37353332312F2D2C2C2B2A2A292929282827
272727272727272727272727272627262727262726262626262626262626262626262626
2626262626252626
262626262626262626262626262626262627272626262626262727262627262727272727
272727272727272827272728282828292A292A2A2A2B2C2C2E2E2E3031323436373A3D3D
3F424445484A4E50505355585A5C5F616366696B6D6E707576777D7C7F8184898A8A8B90
90949495999A9D9C9FA0A5A3A3A5A8A8A9A9A9ADAEAFADAEB1B1B5B2B4B3B6B8B7B7B8B6
BAB9B8B6B7B9B7BBBBB9B9BABABCBAB8B9BCBABABABBB8BBBBBBB8B6B7B5B2B6B3B4B3B2
AFAFADACA8A7A6A3A5A6A3A1A09D9C9C9A9C9E9B9C989B9A9B999A999B9A97999A9A9A9C
9C9D9B9DA09C9E9C9EA2A4A3A5A4A4A8A7AAA9AAABACAEADACAFB1AEB2B2B2B2B0B3B4B5
B4B3B2B2AFAFB0B0AEADAEACA8A9A8A6A7A3A7A5A4A2A1A2A1A2A4A1A19FA3A39FA1A1A1
A4A2A1A19EA19FA29FA0A1A3A1A19FA1A1A3A2A2A3A1A2A4A0A3A1A1A2A2A29D9F9F9D9B
9D9C9C9B9A9A9B979596959894939492938F90918C8D8E8E8D8F8C8B8A8B898887878884
87848382827F7F7B7A7B7A79787977787576747572726F72716F6D6D6C6A6B6969696867
666766656765646364646565656465646465646466646464646364626666666566666565
64646464636261615F5C5B59554E48423E3A38373533312F2E2D2C2B2A2A292929282828
272727272727272727272727272726262626262626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262627262627272727272727272627272727
27272728272727272728282828292829292A2A2A2B2B2C2D2D2E2F2F32333536383B3D3D
3F424447494B4E5052545559595D5E606467686C6D71707477797B7D7F81858787898D8D
93919496989B9CA1A1A1A4A7A6A7A7AAAAAEABADADAFB1B0B0B2B3B4B3B8B8B8BAB8BAB8
B8BABBB8B6B8BAB9B9BABCB9BBB8B8BBBCBBBCBCBBBFBCBCBABABDBCB8B9B6B9B6B8B4B6
B2B2B0ABAFA8A9A8A7A7A4A3A3A19FA09D9C9D9D9C9B9A9A9C9A9B999A9A96989A9A9A9A
9B9E9C9B9B9B9DA09FA0A0A2A2A1A4A6A7A9AAABACAAADAEAFB0B0B0B0B4B2B0B1B2B2B8
B2B6B4B5B5B1B1B3AEB1ACAFADABABAAA8A8A7A6A7A5A4A3A5A3A1A0A0A4A2A2A3A1A39F
A0A0A0A1A3A3A3A3A49FA19FA1A0A0A39FA3A2A3A2A2A5A2A2A5A3A1A0A0A2A0A0A1A19E
9C9D9B9C989B98969897949697959496939592918F8F8E9190908D898B8A8C8988878685
8685838282817E7E7C7E7B7A797A777876767474737472727171706E6E6D6A6A696A6968
686667656465636465646365646665646565656564636363636365636466636464666765
6666656462626161605C5C5A57524C45403C3A38363532302F2D2D2B2A2A2A2929282828
272827272727272727272727272626262726262726262626262626262626262626262526
2626262626262626
262626262626262626262626262626262626262626262627272726262627262727272727
27272728272728282828282828292829292A2A2B2B2B2C2D2E2E303131343536393B3D3F
414446484A4C4F50535457595C5E61666567696B6E737274797A7B7E7F828387888C8C91
92949696989A9DA0A0A5A3A2A6A7A9A9ACADACAFAFAEB2B2B6B5B6B8B8BBB9B9BCBABBB9
BCBBB8B8B7B8BABBB9BBBABCBBB9BCBFBCBFBEBCBDBFBBBDC1BFBCBCBCBBBBB8B8B9B5B5
B6B3B4B1B0AEAEABAAA9A8A5A6A5A4A3A2A09FA09F9C9E9C9A9C989B9A98999999999B9B
9A9B9A9B9C9C9D9D9E9E9FA1A1A0A2A5A7A6A6A9ABABACADACAFB2B4B2AFB3B0B1B3B2B5
B5B4B4B3B1B3B1B2B0AFB0B0B0ABADABA9AAA7A7A9A4A2A3A4A3A1A1A2A5A1A3A0A1A3A1
A19FA39FA2A4A2A2A49FA1A2A2A1A2A3A2A5A4A4A2A2A3A1A4A1A4A5A2A2A4A1A1A09EA1
9F9D9E9B9B989998979897989696959894949393928F90909090908F8C8C8A898A898886
86858385828483817E7E7C7A7B78787778757575747473727170706D6D6C6B6A6C6B6A69
686A67676667656565636465646664656465646364636362646465636262656464656364
63656365646661605E5E5D5C59545048423F3C38363533312F2E2D2C2B2A2A2929292828
282728272727272727272726262726262626262626262626262626262626262626262626
2626262626262626
252726262626262626262726262626262627262726262627272627272727272727272727
272727272728282728272728282929292A292A2A2B2C2D2D2E2F3031333435383A3C3F40
424445494A4D4E50545657595D5F616365686A6C6F707473767B7D80808485888C8D8E8E
92959597999E9D9EA2A3A6A4A5A9A7A9A9ABADAEB0B2B3B4B4BABAB9BAB8B9B7BABBBABD
BCBDBABBB9BABCB6B7B8BDBCBCBEBCBDBEC0BEBDBEBEBDBEBCBCBDBCBABCBAB8BDB8BBB7
B7B7B5B3B1B2B0AFABAAABA9A8A7A5A4A3A1A09E9F9EA09C9E9C9A9D9B98979A9A9A9C9A
999B999B9B9B9B9F9D9D9DA19FA1A3A3A5A8A7A8A9ACAAABAFB0AEB0B1B2B0AFB2B2B2B5
B2B6B5B7B2B4B2B2B3B3B2ACADB0AEAEABAAAAA8A5A7A5A6A5A5A3A4A3A5A3A2A5A4A19F
A0A3A0A1A2A2A5A6A3A2A1A0A4A1A1A0A1A3A3A1A3A4A4A3A2A2A4A2A4A3A2A5A2A1A2A1
9E9F9E9D9B9C9999989A979699959696989695919391929291908D8D8E8C8E8B898C8988
8886858586838181817F7D7D797A7A7A7778767676747572737370706F6D6C6C6B6C6B6B
696968686769686664646364656565656463636263626462636463636263636764646564
6463636362626362605D5C5D5957544D46403E3B38353432302E2E2C2A2B2A2A29292828
272828272727272727272627272626272726262627262626262626262626262626262626
2626262626262626
262626262626262626262626262627272626262626262727262727272627262727262727
272727272827272828282828282829292A2A2A2B2B2C2D2E2F2F3031333536383A3C3D41
4345474A4C4E505254555A5B5D5F646467696A6D6F73767879797E80818186898A8F8F90
91959798999C9F9CA4A0A4A8A9A9AAABADAFB0ADB3B0B3B4B7B8BBBAB8BBB7B8BABBBDBC
BABFBABBBBBDBDB9B8B9BFBCBFC0BEBEBEBFBEBFBCC0BCBCBFBEC1BDBFBEBEBDBAB7BABB
BABCB8B9B9B4B2AEB0AEACAAA7ABA8A5A6A6A1A1A2A19E9FA09D9D9C9C9A9A999B9A9898
9C9A989A9B9B9B9C9B9D9CA09E9FA2A5A2A5A6A6A8A9A9ACABAEAFACAFB1B1B4B4B2B1B2
B3B4B6B4B5B4B5B3B3B2B3B1B0B0AFAEAEADACABA9A8A6A6A6A6A4A4A3A4A3A5A4A5A5A0
A0A1A0A3A3A2A5A2A5A5A3A3A0A1A3A0A4A09FA4A1A1A1A5A4A4A2A4A2A3A5A4A3A1A0A3
A09FA09E9D9B9A9698979998979898989A97959493939390928F918E8E8D8D8B8C8B8988
898885878684848482807C7D7C7B797A7978777976757674757272726F6F6F6E6C6C6C6A
6A6869676968666564636465656565636363626263636264636363616361626462636565
64646463626460605F5F5D5C5B59554F49433F3B38363533312F2E2D2C2B2A2A29292828
282828282727272727272727272627272727272626262626262626262726262626262526
2626262726262626
262626262626262626262626262626262626272626262626262626262727262727272727
2727272727282828282728282829292A2A2A2A2A2B2C2D2E2F2F3133343637393B3E4041
434548494B4D51525658585B5E606366686A6C6F707275787A7A7D7E828586888C8B8D90
9295969B9B9A9CA2A3A6A6A7A7A9AAABAEB0B0B2B1B2B0B2B6BAB8BAB9B8B8BCB9BBBCBD
BCBCBABCBCBCBDBDBDBFBBBFBFBEBDC2BFBDC1C0C3BFBCBEBCBEC0C0BEBFBEBBBFBDBEBD
BEBBB9B9B7B7B6B5B1B1AEB1ADA9AAABAAA8A7A9A6A2A2A2A1A1A0A09F9B9C9B9B9B9B9B
9A9A9B9C999B9C999A9C9C9C9DA09EA0A2A4A4A5A5A7A8AAAAADAEAFAEAEAFB2B1B2B4B1
B2B1B4B2B2B4B6B5B6B3B2B3B0AFB0AFAEAEADACAAA7A8ABA6A6A4A6A5A4A5A6A5A4A2A2
A29FA4A3A2A3A5A4A2A1A4A4A2A2A0A1A0A0A3A0A2A2A4A4A5A5A1A5A4A3A3A5A5A2A2A4
9FA29F9F9C9C9D9C9B999B9A9797969698979594939393939192908E8D8E8E8E8D8A888A
8B8A8986858684858181807D7C7C78787979777774767575767473747070706E706C6B6C
6B6B69696766676466656365656564636363646361636162626262626364626363646363
6263636364626261605F5E5C5B5A57524C46413D3938363432312F2D2C2B2B2A2A292928
282828272727272727272627272727262627262626262626262626262626262626262626
2626262626262626
262626262626262626262726262626262627262627262726272626262627272727272627
272727272727282827272828292929292A2B2A2B2C2C2D2E2F3032333436373A3B3E4041
4346494A4E4F51535458595C5F616267676B6D70727477787A7D7D7F828686898C8D9090
929495999A9C9EA0A0A1A4A8AAA8AAAFAEB0B0B0B5B5B4B7B6B8BBB8B9B9BAB9BDBFBEBC
BEB9BEBCBEBCBEBBBDBFBEBFC0C1BFC0C0C1BFBFC0BFC2BFBFC0C4C1BFC1BEBFC0BDBEBF
BCBEBCBEBCBABCB8B9B4B4B0B2B2B1AEACA9ABACA8A7A6A4A5A1A2A1A09FA09B9E9C9C9B
9B99999C999A989D9A9B9B9B9E9F9F9EA1A3A0A4A8A5A9AAAAACAAABAEADB0B1B3AFB1AF
B2B3B2B3B7B4B4B5B4B3B2B4B1B1B2AFB1AEACABABACABABAAA8A6A6A4A4A5A4A4A6A2A2
A1A1A3A3A3A0A2A5A4A4A5A2A2A1A6A19FA3A3A3A3A2A2A3A4A3A39FA3A0A4A6A5A3A4A3
A2A2A2A0A19E9D9C9B9A9A999899979898979698959695949394928F8C8E8F8E8E8C8E89
8A89878789858883838381807D7F7E7D7D797878787574767573737272706F706F6E6E6C
6B6C69696767676565666664656563636363656361626263626161616262616263636364
6362636260636260615F5E5D5C5B59554F4A433F3B3837353431312F2C2C2B2A2A292928
282828272727272727272727272726262726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262627272726262627272727272627272727272626
2727272727272828282828282929292A2A2A2A2C2C2D2D2E2F3031343536373A3C3F4144
4547484C4D50515555585B5D5E6364686A6B6D71737478797C7E7E828586858A8A8D8C90
939496999B9C9C9FA2A4A3A8A8A9ACADAFB1B2B3B5B6B6B6B9B9B4BAB8BCBBBEBCBDBCBA
BCC2BEC1BDBFBEBFBEBEBFBEBFBDBEBFC2BFC2C1BFC1BFBFBCC4C2C3C3C3C3BFC2C0C1C4
BDBCBEBFBCBBBFB8BCB8B7B7B6B3AFB1B2AEACABAAADA9A6A6A4A3A5A29FA09C9F9C9D9B
9B9A9C9D989A9B9B9A9A9D9C9A9C9D9EA1A2A0A1A5A7A7ACA8ACAAADACADABADB0B0AFB0
B2B3B2B0B3B6B4B5B5B3B4B5B2B0B0B1B1AFAFAFAEADAAABA9ACAAA7A6A5A7A5A5A4A5A4
A8A2A2A2A4A3A0A3A3A3A3A2A4A3A0A2A3A0A1A4A2A2A5A4A3A4A0A2A1A3A3A3A2A4A1A2
A2A2A19E9F9E9E9E9D9C9B98989898989796969796969793948F93908E8F908E8D8D898B
8C8889878B858687858482827F807F7E7C7B78797779777674747575737272706F716D6D
6C6B6A6A6A68696767676465656564636362636263636362636261626161606262626264
6361626262625F605F605E5E5D5B5857534D46413D3937353332302E2E2C2B2A2A292A28
282828272827272727272727272726272626272626262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626272626262726272727272727262727272627
272727272727282828282829292929292A2A2B2B2C2D2D2F2F30333436383A3B3C3E4143
46474B4D4F505355585A5B5F606367676A6C6E70747677787C7E82828284878B8C919191
939597979B9C9CA1A1A2A4A7A8ABAFAFB3B0B4B3B7B6B8BBBBBBBDBABDBBBDBDBFBEBBBE
BEC0BFBFC0C2C0BFC0C2C0BCBEBCBDC0BEC4C0C1C6C1C2BFC1C2C3C3C2C4C1C2C2C3C3C3
C0C1C1BEC1BFC2BFBEBEBEBABCB7B7B8B1B2B2AEB0B0A9A8A7A5A6A5A4A2A1A0A09F9F9D
9E9A999B9C9A9C9C9C9C9C9A9B9D9E9E9FA19FA0A1A3A5A8AAAAA9ABAAAAACADAFADB1AE
B2AFB0B3B4B3B2B4B3B5B3B3B4B3AFB1B2B1B2B0AEACAFADACAAA8AAAAAAA8A6A6A3A6A5
A7A3A5A4A3A2A2A0A19FA2A1A1A0A1A2A3A1A3A2A4A2A4A5A1A2A2A0A09FA3A3A2A2A4A3
A3A1A1A1A09FA1A19E9C9D9A9A9997999A95959695959596939390908E8E8E928E8F8B8B
8D8A8B8A8689878687848382827F7F7D807D7D7A79777875767475767473747073706F6C
6D6E6C6A6A69686867666767656465636562626263626262626261626161616261636162
646163616260626060605F5E5E5B5A5955504B433F3B3836343331302E2D2C2B2A2A2929
282828282827272727272727272627272726262626272626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262627262727262627262727272727
262727272727282728282929292A2A2A2A2B2B2C2B2D2E2F303133353539393C3E3F4243
46494B4D4E515255575A5D5E626367686B6D6F707475787A7D7E81838485878B8C8F8F92
959498989B9C9FA0A2A3A4A7A8AAACACAEAFB3B4B6B7B6B8B8B8BABCBDBDBFBEBEBDBEC0
BDBFBCBDC1C0C1C3C2C0C2BDBFBDBEBFBDC0C1C6C6C5C2C2C3C4C3C6C4C3C3C5C1C6C6C8
C1C5C1C2C3C4C3C4C2BEC0BDBDBAB9B9B8B6B4B4B3AFADAFAAAAA8A6A6A6A5A3A2A29F9E
9B9D9A9B9B9C9A9A9B9B9B9A9D9C9B9D9E9FA29FA0A4A4A4A7A9AAA9AAAAADACAFAEAEB0
B2B1B0B0B1B5B1B5B2B1B1B3B2B3B3B2B2B3B0B2B2B1AEB0AEAFAEAAACA8A7A8A5A7A8AA
A6A6A4A5A2A0A1A3A3A4A2A4A0A2A3A1A1A6A0A4A2A2A2A2A2A3A1A1A0A2A1A1A3A2A5A3
A3A7A2A2A1A09FA0A2A09B9C9A9A9D9D979A969692949394939290918F908F8F908E8B8A
8A8A888B8A898A8986858682827F8182807F7C7D7B7A797976757474747272727171716F
6E6D6B6B6A69696767676667646365636265636362616262616061615F61626061626162
6261616262605F60605F5F5E5E5B595956544D46413D3A37353332312F2D2C2B2A2A2929
292828272727272727272627272726272727262727272626262626262626262626262626
2626262626262626
252626262626262627262626272627262626262626262627262627272727272727272727
2728272728282828282828282829292A2A2B2B2C2D2C2E2F3032333537383A3B3E404145
46484C4D50535355595B5D5E626667696C6C72737474797A7E808185848588888D909090
9395999C9D9C9EA0A1A3A6A7ABAAB0ADB0B0B1B2B6B5B8BABCB8BCBBBEBDBFBDBDBFC0BC
BDC2C0C1C1C0C0C2C4C6C3C1BEBFBDC1C1C2C2C6C7C5C2C0C5C3C5C3C5C5C5C4C8C6C3C8
C6C5C8C8C6C6C3C5C2C4C3C4C0C0BDBCBAB9B9B9B6B4B3AFAFADAAAAA9A7A6A5A7A3A0A1
A09DA09F9E9D9C9C9D9B9D9D999E9D9C9CA0A19CA0A1A2A0A6A6A6A8A9AEACADADAEADAF
B0B0AFB0AEB0B1B0B0B2B0B1B2B0B3B3B3B3B0B0B3B0AFAFB2AEB1ADADACA9A8A9A9A9A6
A8A5A7A4A4A6A4A3A3A2A1A1A3A4A1A4A1A4A3A3A2A2A1A1A09FA0A3A1A2A6A4A3A2A0A1
A3A2A2A4A0A1A1A0A39F9B9E9B9B9A9A9B9B999897949593929491929092918E918E8E8E
8D8C8A898A898A8786898785848482828281807E7C7B7979797876767573737271727270
7270716C6B6A69686865646565656465636363626261616061616060605F5F6160616360
60616162626060605F5F5F5C5E5D5B585755504B433F3A3836343331302E2D2C2B2A2A29
292928282727272727272727272727262726272627262726272626262626262626262626
2626262626262627
262626262626262626262626262626262626262626262727262627262627272827272727
2727282727282828282828282929292A2A2B2C2C2D2C2E2F3132333537393B3C3D404245
46484B4E4F515557575D5E62626467686A6E70727476797C7C7F7F84868788888D8E9095
979496979A9C9DA0A1A5A7A8ACABAAAEAFB1AFB3B4B9B8B9B9BBBABCBCBFBEC0BFBEBEC0
C1C3C0C1BFC1C3BEC2C4C2C1BDC0BEC3C1C2C2C7C5C5C2C2C4C3C5C3C6C6C5C5C8CBC8C5
C7C9C6C9C7C8C7C3C6C5C5C5C2C4C0C0BEBCBBBAB9B7B3B1B0B3AEABA8A8AAA8A6A3A5A3
A19E9E9F9E9E9E9D9D9E9D9E9D9D9FA09F9FA0A19FA1A2A3A5A4A4A7A9A9ABA9A9ACADAC
AEACAFAEAEB1B2AFB0B1B2B2B2B5B4B4B2AFB0B3B3B2B2B1B1B0B0B1AEABA9ABAAABAAAB
A9A5A4A5A4A1A4A3A4A1A3A3A2A3A3A2A2A1A1A3A1A1A2A1A1A19FA2A4A2A0A2A3A3A5A2
A1A2A3A2A2A2A1A2A0A0A39E999B9C9D9A9C99989898959495949593909292928F8D8E8E
8C8A8A898B898888868987898586848581847F7F7E7E7D7C797878787474747373737371
7171716F6D6D6B6B6967666665676464636364626362626260616162616062625F606061
60616161606261605E5F605F5D5E5C595857524D46413D3938353331302E2D2C2B2A2A29
292828282827272727272727272727262627262727262626262626262626262626262626
2626262626262626
262726262526262626262626262626262626262626262626272726262727272727272627
27272727282828282828282929292A2A2A2A2B2D2C2E2F3031333435373A3A3E3E404345
46484B4D505255585A5C5E60636566686B6F6F7174757A7A7D7F81838588888A8B8F9290
94979799989D9BA1A2A2A7A6A9AEABAEADAFB0B3B7B4B8B9BBBABCBBBDBFC0BDBEBFBFC0
C0BFC1C0C2C3C2C0C2C1C0C1C2C0BFC3C3C3C4C5C9C4C4C4C6C7C7C5C6C8CBC7C9C7C7C8
C9C8CACCCBCBC7C5C6C8C7C5C7C3C1C5BFC0C2BDBDB9B6B5B4B1B0B0AFADABA8A8A7A4A7
A3A0A09DA09E9F9F9EA09D9D9E9D9C9EA09E9E9FA0A0A1A0A4A2A5A5A5A8A7A7AAA9ABAD
ABADAFADADADAFACB1ADB2B4B3B1B4B0B0B4B3B4B2B1B2B3B3B5B3B1B2AFACADABABADAB
A8A9A8A7A3A6A5A5A3A4A3A4A2A4A3A3A3A3A4A1A3A4A3A19EA0A3A1A1A0A6A2A2A3A2A1
A1A0A3A1A4A0A1A0A2A1A09EA09B999D9C9D9B9B989997979691939393929092908F908E
8F8C8A8B8A8A8A888789888688858684858480827D807F7D7C7B78787874767474747572
737772716F6F6A6C6B676967666564646463636363616261616162626160625F6161605F
6161616160605E5F615E5E5F5D5D5C59595755504A443F3B39373432312F2E2C2C2A2A29
292928282827272727272727272726272726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262627262627262627262626272627272727272727272727
2727272728282828282829282929292A2A2B2C2C2D2E2F303234353638393D3D3F414345
474A4C4D525356585A5C6061616566696D6E707274767C7C7D7E81848589898B8D908F95
959696969B9D9FA0A1A5A6A9ABA9ADADAEB1B1B4B6B6B9B8BBBEBCBBC0BEBFC0C2BFBFC1
BEC2C1C1C3BFC0C1C0C0BEC0C3C3C1C4C4C6C5C6C4C4C4C7C3C6C7C8C9C7CBC7CCCEC6C9
C8C8C9CBCBC8CACCCAC7C8C7C9C9C4C3C1C0C2C1C0BDB9BAB7BAB6B4B0B0ADACABA8A7A7
A7A4A4A29FA0A19FA19E9F9E9D9F9D9E9F9DA19FA2A0A0A1A2A2A0A1A3A5A6A7A8AAA7A9
AAAAAEADAAACAEAEAFB1AFAFAFB3B0B1B2AFB0B0B2B0B0B1B3B3AFB1B2B0B0AFADAFACAA
A9A9A8A8A6A6A8A4A4A7A4A3A4A4A3A2A1A29FA2A1A2A4A1A1A2A1A0A5A3A2A4A3A2A2A3
A1A2A4A3A3A0A0A1A2A2A19E9E9D9E9D9A9D9F9D9A999997979795959392929290908E8E
908C8D8A8B898A8988878787898784858183837F8381807E7B7B79797875787675737574
737573726F706E6E6C6D6768686666636464636463636164615F606161605F5F605F6062
60605F605F5F5F5E5E5E5E5F5E5E5B5B595955534E47413C3836353331302F2D2C2B2A2A
292928282728272727272727272727272626262727262626272626262626262626262626
2626262626262626
262626262626262626262626262626262626272726272727262627272727272727272827
272727272728282828292928292A2A2B2B2C2C2C2E2F303132333636393A3C3E3F414346
484B4B4F4F5354585A5E60616366696A6C6F6F737577777D7D8083838686898D8D909193
9496989A999C9BA0A4A4A6A7A9ACABAEB0B1B1B4B5B6BBB9BBBCBCBEBFBFC1C0C0C0C3C1
C0C2C3C3C0C5C1C0C1C2C3C2C6C2C1C7C6C4C2C4C4C4C0C5C7C6CBC7CAC9CAC9CAC9C8C9
C8CACDCECDCBCBCACCCDCACDC9CACCC9C6C7C8C4C1BFBEBABCB8BBB8B6B1B0B0AEADACA9
ACA6A5A2A3A3A3A3A0A3A1A2A19F9E9F9F9E9F9FA0A1A1A1A0A1A2A2A3A1A4A5A8A5A6A7
A8A9ABA9ABACADAEB0ADACB1B1AFB1B0B2B3B1AEB3B5B4B1B3B1B4B4B2B0B5B2B0ACABAD
AAA9A8AAA7A7A7A5A7A4A6A6A5A6A5A2A2A1A2A2A6A3A4A1A29FA1A0A19FA2A29FA3A3A2
A1A1A2A2A2A1A19FA1A19FA09FA09D9E9D9CA09A9C999B97989698939690918F91908F90
8F8F8A8E898B8A898A87878786868583848383818082817E807E7B7B7976787675767575
757574736E6E6F6D6C696A696867656464636461636363636361626262615F5F5E5F6160
60605F5F5F5F5E605F5E5F5F5E5D5D5C5A5856545149423E3B3835343231302E2C2B2B2A
2A2829282828272727272727272727262726262727262726262627262626262626262626
2626262626262626
262626262626262626262626262626262626262627262626272726262727272727272727
272727272827272828282929292A2A2B2B2B2C2D2E2E303133343636393A3D3F42434446
494B4D4F505355575C5C5F61656667696D6F717374777A7C7D7E8184838688888E8F9191
959798999A9B9EA3A2A5A3A9A8ABADADACB2B4B2B3B9BABBBBBCBDBFBFBFBDC1C2C2C3C5
C2C3C2C4C1C6C2C2C3C3C4C3C2C2C7C6C5C3C4C6C4C5C6C7C7C6CACBCBCBCBCBC9C9CACD
CCCDCDCECDCDCDCECDD0CFCED0CECDCFCCCBC9CAC6C4C2BFC1BDBDB9B5B5B6B2B3AEB0AE
AEABADA5A6A6A5A4A0A2A0A1A19E9FA1A1A39EA0A2A09FA2A09FA19FA0A2A1A5A5A2A6A8
A6A8A9A9A9A8ABAAABADACAFACB1AFB0B0B3B0B1B1B2B2B0B3B4B2B3B3B4B1B0B2B1ADAE
ABACADAAA9A9A7A7A6AAA4A8A3A6A4A2A2A4A4A4A1A5A2A2A3A2A0A2A1A2A3A4A2A0A3A1
A1A2A19FA19FA2A0A2A2A3A4A2A0A09C9FA19B9B9C9C9899979B989695929291918F8D90
908D8A8A8A898A888A8A8888868586828484838482828181817D7E7D7C79757675777474
7477767471716E6F6D6C6B6A6A6866646563646363636362616261615E61605E5F606161
5F605F5F5F5E605E5E5F5D5E5D5E5C5A5A595754524C463F3C3936353331302E2D2C2B2B
292929282827282727272727272727272726272726262626262626262726262626262626
2626262626262626
262726262626272626262626262626262626262726272627262727262627262727272727
272727282828282828292829292A2A2B2B2C2D2D2E2F303233343637393A3E4040434547
494B4D50525456585A5E60636465696A6C70717376767A7C7D8080838487878D8B8F8F94
9196979A9A9F9EA1A2A3A3A7AAACADAEAFB2B2B4B3B7B8B8BABCBEBEC0BDC2C2C2C3C0C6
C5C2C7C0C4C3C2C3C4C6C6C3C5C4C7C8C6C6C6C4C5C8C8C7C9C8CDCACBCACBCDCCCCCFCD
CFD1D1D0CFD0D0D2D0D0D1D2D1D4D2CFCFD0CECCC9C8C4C1C3BFC1BEBDBAB7B7B4B2B5B2
B4AFADABA9A6A6A2A5A4A4A2A4A1A29E9F9FA19F9E9FA2A0A0A2A19FA2A0A1A3A3A2A3A4
A7A4A6A6A8A9A9ACA9AAAEACACADAFAEB0AFB3B3B3B3B4B1B2B2B2B4B3B1B4B3B2B4B3AE
B0AEACABADACA7A8A9AAA8A3A7A4A6A5A4A1A6A4A4A4A5A0A1A2A2A1A2A1A29FA19EA0A0
A29CA2A0A1A3A0A2A1A2A2A3A4A29E9F9C9D9D9A9D9C999A999999989694929290929090
928E908C8B8D8B8A8D8A8989898683858384858581818283808081807C7A797878777876
757675727371716F6E6C6A6B6969686666666463616163636262626161615E5E5F605F60
5F60615F60605F5E5F5E5E5D5E5C5C5C5A5A5A56554F49433E3A38363332312F2E2C2B2A
2A2A29292828282727272727272727272726262726272626262626262626262626262626
2626262626262626
252626262626262626262626262627262626262726262626272726272727272727272727
2727272828282828292829292B292A2B2C2B2C2E2F2F303234353739393C3D3E41434748
494B4C505353555A595C60616566696D6C6E717175777A7A7E7E81818488888A8C8F9093
92959899989C9DA1A0A4A3A9A9AAACB0AFB2B1B3B5B8B5B8B9BCBEBFC0C0C2C4C0C2C3C4
C3C6C2C6C4C2C4C3C3C7C7C6C4C5C5C5C5C7C9C8C7C5C8C9C8CBCFCCCECCCCCDCBCFCED0
D2D2D3CFD0D1D2D1D4D3D3D7D7D6D7D6D5D1CDCBCBCBC8C7C7C4C3C4C1BCBDBABCB9B3B9
B5B0B2AEAEA9A9A7A8A8A3A6A4A3A2A3A1A1A1A0A1A19FA1A1A0A1A2A19FA1A1A1A1A3A2
A2A5A3A4A6A8A8AAAAAAABA7ABAEAFB0AEAFAEB3B2B2B3B2B5B6B4B5B2B4B4B4B7B4B2B3
B1B1B1ACAAADADA9ABA9A8A9A8A5A6A5A2A4A2A4A5A3A3A2A4A1A0A19EA1A1A29EA0A19F
9FA5A2A1A1A39EA1A09FA3A4A3A09F9D9E9C9B9E9E9C9D9B97979A979694919191929092
90908E8D8E8C8A8C8A8A8A888686848583828583848282848585837F7E7C7B7A797C7879
78767473706F706E6E6E6C6D6B69686967666564626360636261626161605F5F5F60605E
5F6060605E5E5E5E5E5E5D5D5C5D5D5B5A59595854504D463F3D3837343331302F2C2C2B
2A2A29292829282727282727272727272727262626262726272626262626262626262626
2626262626262626
252626262626262626262626262627262626262627262627272726262726262727272727
272727272728272828282929292A2A2B2C2C2D2D2F303132343537373A3C3E4042434548
494D4E4F535557585A5C5F626366676A6D70737475767C7D7E7F7E848486888B8A8F9391
94979999999A9F9EA2A2A4AAAAADAAADADAFB3B5B5B5BABCBBBCBBBCBFC0C1BFC1C1C5C4
C7C1C5C5C7C7C6C4CAC7C4C4C4C4C3C6C5CCCACACCCACBCAC8CCCACED0CED0CBCDD2CECE
D1D2D2D0D1D1D1D3D6D7D5D7D6DCD6D7D9D3CFD0CDD1CCCBC9C8C9C6C1C1BFBFBABBBAB7
B7B7B3B1B0AFADACAAA8A7A7A5A3A4A3A4A1A2A1A19FA1A3A0A3A0A0A19EA0A0A49FA2A3
A3A1A3A5A7A6A8A7ABABAAA9A9ACABAEADACB1AEADAFB2B2B3B5B3B3B2B4B6B8B5B5B2B5
B6B2B3B0AFAEABACADAAAAA9A7A6A6A8A7A7A3A8A5A3A5A3A4A4A19FA09FA19FA0A0A29F
A1A2A0A2A1A0A1A1A0A5A1A6A1A2A09FA09F9E9AA09D9A9997989897959593909492918F
90908D8E8D8D8D888B898A8889888686868685848584848585858681807F7D7B7B7B7979
777677737371726F706E6F6D6C6A686A686766646462636462636061625E5F5F605F5F5F
5F60605F5E605F5E5E5E5F5E5E5D5E5C5C5B595755514F48423D3937353430312E2D2C2C
2A2A29292928282727272727262727272627262726262627262627262626262626262626
2626262626262626
262626262626262626262626262626262626262727262627262726272727272727272727
2728272828272828282829292A2A2A2B2B2D2D2E2F303232343636393B3C3E4040444647
4B4C4E5152555759595E5F616366696B6E6F70727477777B7C7E8182868688898E8D9093
959596999C9D9FA1A3A4A7A6A7ABAEB1AFB1B2B1B4B8B7B9B7BABDBDBDC2BEC0C1C5C1C4
C5C4C4C7C3C8C7C7C7C7C6C6C5C3C4C6C6CACACBCACBCBCACBC8CCCDCECECCCDD1D2D2D0
D0CDCDD1CECFD1D3D8D8D6D6D8D6D9D7D5D5D6D0D1CDD2D0CDCAC9CCC6C3C4C0C2BEBFBB
B7B3B4B3B0B2ADAFABADA9A9A8A8A8A1A4A3A4A5A4A0A1A2A2A2A0A0A1A09FA09FA1A1A2
A2A0A2A0A5A5A3A6A9ABA9AAA7AAAAACACABAEAFAFAFB2B4B0B1B3B4B6B5B5B8B7B4B7B6
B6B3B5B5B1AFAEADAEADABA8A7A8ACAAA8ACA4A4A4A5A1A4A3A3A3A2A1A2A0A0A1A39FA0
A3A2A2A0A0A0A1A1A1A0A2A2A1A1A1A29E9E9FA09E9F9C9A9A9A98969695959593929192
8F928E8D90908E8F8A8C898A8986878887868586858583858686868580817F7D7B7B7B7B
787775757371716F6F6E6E6D6D6B6B69676865666564636362626162615E5E5F5F5F5E5E
5E5F5E5E5F5F5E5E5F5C5C5E5C5B5D5A5C5B5B585655514B443F3B38353332302F2E2E2C
2A2A29292928282728272727272727272727272727262626262726272626262626272626
2626262626262626
262626262626262626262626262626262626262626262626262626272727272727272727
2727272828282828282929292A2A2B2B2C2D2D2E2F313233343737393A3D3F4042454748
4B4C4E50525557595C5C5F5F6367696B6C6E71727578787B7C7E81818587898A8D8E9294
959598999A9C9FA1A3A3A6A7AAAAAAADAEB1AFB3B3B7B7B7B8BBBCBBBDBFBEBEC2C5C5C3
C4C7C6C8C8C7C6C6C8C7C3C9C4C7C5C6C7C9CCCDCCCACACCCCCBCCCED2CFD1D2D4D0D3D0
D1D1CFCFCFD1D4D5D6D5D4D3D5D8D8DADAD9D5D7D2D0D3D1CDCBCBC9CACBC7C7C6C5BEBB
BAB9BAB5B7B6B4B1B2B0ABAAABACA9A8A7A6A5A4A2A0A0A2A3A0A09EA0A0A19F9FA1A0A0
9E9F9D9FA2A2A3A8A6A5A8A6AAA8A7ACABABADAFAFAFB2B5B3B5B0B2B4B6B3B7BAB4B4B5
B6B7B8B6B3B5B1B0AEAFABADA9ABAAAAA9A9A5A4A4A3A3A2A3A2A5A3A3A2A2A2A1A0A0A2
A0A0A0A1A0A0A5A1A3A3A2A4A2A1A2A1A2A4A09FA09C9D9E9E9D9A989794949595959292
9393909190908E8C8D8A8D8B8B8A878887878785868684858587868682837F7F7D7C7B7B
787877767473716F6F6E6E6C6C6B6A6969686766646464656260616161606060605F5F5F
5F5E605E5F5D5F5D5C5D5C5D5C5C5B5B5B595A595853514D47403B3936353331302E2D2C
2B2B2A292828282827282727272727262727272626272726262726262626262626262626
2626262626262626
252626262626262626262626262626262626262627272726272727272727272727272727
27282828282828282929292A2A2A2B2B2B2C2E2F30313133353737393B3D3F3F42434649
4C4D4E50535658595D5D5F616366686A6A6F7271737579787E7E8084858789878B8B8E93
95949698999C9F9EA3A4A5A8A7AAACAEADB0B1B4B3B6B7B8BABABFBBBBBDBDC2C3C3C4C5
C6C4C8C7C6C5C5C8C7CBC8C8C7CAC5C8C5CBCCCACCCCCED1CBCECECFD2D2D1D2D3D5D6D2
D1D2CECFCBCED0D3D4D5D4D6D6D9DBDADCD7D6D7D4D8D4D2D1D5CFCDCDCCCDCACAC4C5C1
BDBCBBBABBB8B8B5B3B0AFB0AEAFACABA9A8A8A6A4A5A1A2A0A2A0A09EA19E9D9F9EA09C
9EA09F9D9FA0A0A1A3A1A4A5A5A7A8A8AAADABACAEADAEB4B3AFB5B2B6B4B8B8B5B9B8B6
B5B4B6B7B8B4B3B4B0AEB0AFACACACAAAAA9A6A6A5A3A5A5A5A5A4A0A0A3A1A1A1A1A0A2
A19EA0A1A4A19FA2A2A6A3A5A3A3A1A2A2A2A29FA09F9C9E9B9E9F999999979795959492
92939190908F8E8D8F8C8C8C8B8B888A86878885868584858586858582837F7E7E7D7B7C
7B797678757472726E6F6D6F6C6B6A6A6A696A6A6766666462626262626160615E5E5F5D
5D5F5E5F5E5D5E5E5E5D5E5C5C5B5B5A595A5B595856535049433F3A38353331312F2E2D
2C2A29292928282828272727272727272727262727262626262726272626262626262626
2626262626262626
252626262626262626262626262626262726262626272726272627272727262727272728
2727272828292828292929292A2B2B2C2B2D2E2F303233343637383A3B3C3E4142454748
4B4C4F515355585A5C5F5E63646768696B6D6F727677787C7B8082828584868B8B8D9090
92949596989E9C9FA3A4A5A6A8A9ABAEAEB2B1B3B2B6B9BBB8BBBBBFBEC0C1BEC1C2C4C3
C5C6C4C4C3C6C8C7C8C7C9C9CBCAC6C8C9CAC9C8CDCACACDCFCFCDD1D5D3D2D4D4D4D6D2
D1CFCCCDCECED2D2D5D6D7D7D9DDDCDADCDAD8DBD7D7DBDAD5D1D1CFCECDCECDCDC7C6C3
C1C2C0BFBFBDBCBBB6B4B3B2B2AFADA9AEAAA7A9A4A5A2A3A3A19F9FA19F9F9D9D9F9D9E
9D9E9E9E9E9D9E9EA1A3A1A4A5A7A6A8AAABACABABAEAFB1B5B2B3B1B3B6B5B4B8B6B5B6
B5B4B8BAB7B7B4B5B3B3B1AEABAEACABACADA8A7A4A5A7A3A7A5A3A3A5A2A1A0A1A2A19E
9F9FA0A2A1A4A2A1A4A1A3A2A2A4A3A2A1A2A29E9F9F9F9D9C9E9C9C9C9A9B9997959497
94939090928E8C908F8E8D8C8C8C8D8B8A8888888785848685858483827F80817F807C7B
7A7C78787675727272706F6E6D6B6B6A686A68686665646364626362616060605E5F5E5E
5E5D5F5C5C5D5F5C5E5D5E5E5C5B5B5B5B5B5A5A585753514C46403B3835333232302F2D
2C2B2A2A2928282828282727272727272727272726262626262626262626262626262626
2626262626262626
262626262626262626262627262626262626262627272627272727262727272727272727
272728282828282829292A2A2B2B2B2C2D2D2E2F313233343537393A3C3E3F4244454749
4A4D51525457585B5C5E5F636566686A6B6F6F737474777B7E7E81838587878B8B8F9091
93959595999B9F9EA2A3A6A5A7A9ABAEAEB0B0B0B0B3B4B9BBBDBCBBBDBDBFBEC2C3C3BF
C6C6C7C6C4C4C7CACBCDCBCCCACCCCCBC7CCCBCECACCCFD0D2CFD0D3D5D7D4D4D5D6D4D4
D1D2D1D3D1D1D2D5D9D9D7D8D8DCDDDFDCDBDDDDDFDDD9D4D5D5D1D3D2D2D2D0CDCEC9C7
C5C5C3C3C5C1BFBBBBB7B8B5B4B3B0B2AEAFABA9AAA7A6A4A49FA0A1A09F9DA09D9C9F9C
9A9E9B9E9C9E9CA19D9FA2A1A1A5A2A4A7AAA9A9AAAEAEAFB0B1B1B3B5B5B6B7B7B7B4B6
B6B6B6BCB9B8B8B7B6B5B5B4AEAEAEABACA9A7A7ABA6A6A8A5A7A7A1A3A5A4A4A1A1A19F
9FA29F9EA29DA0A3A1A3A0A4A2A0A2A0A3A2A2A09E9F9E9C9D9F9D9D9D9D9D9B9A979493
9594929290908E8D8D8E8F8C8C8C8C8B888A8B868787868584868682818181817E7E7E7D
7C7B7B797875747471706F6E6D6D6C6C6B6A6967676566656564626260605F5F5F5E5E5D
5D5F5E5C5E5D5D5C5C5C5E5B5B5C5B5A5A5B5B58585654514F49413D3937353331302E2D
2D2B2A2A2929282828272827272727272727272727262727262726272626262626272626
2626262626262626
252626262626262626262626262626262726262726272727272727262726272727272727
272727282828282828292A2A2B2B2C2C2D2E2F2F303233353737393B3D3E40414345474A
4B4C50515457575A5C5D5F64646668696B6E7070737677797B7F81828388888D8A8C9090
93929593999C9E9FA0A3A3A5A7A7ACAEADAFB1B3B2B6B6B7B7BBBAB8BDBFBFC0C0C2C3C3
C5C6C6C4C5C7CBCBCDCBC9C8CACDCDCCCDCDCDCBC9CBD1D2D4D0D1D1D4D5D5D5D5D2D5D6
D3D3D4D3D4D2D3D6D9DADAD8DADFE0DFDFE1E4E1E2DEDCD9D8D7D7D5D3D7D6D1D1CDCCCC
CBC8C7C5C5C6C3BEBEBBB9B9B8B5B3B1B2ACB0AEABACACA7A4A4A5A2A0A19DA09F9E9C9D
9B9B9D9D9D9AA2A09D9E9DA0A1A3A3A3A5A6A7A9A8A9ACADB1AFAFB5B4B5B7B5B7B8B5B4
B5B6B8BBBDBBB8B7B7B5B8B3B3B2B1B0AFADACABAAAAA8A7A6A7A3A3A2A0A2A3A2A3A1A2
A2A09FA3A0A09FA3A1A2A0A1A0A4A3A3A19F9F9D9E9D9E9B9C9C9E9B9E9D9D9B99989895
96939392928E8F8E8E8E8D8D8B8B8B8A8A8986878786878684848282828280807F7E7D7C
7B7B7C7A797775747270706C6E6E6B6B6C6A6A68696966676665636361605F6060605F5E
605E5D5E5C5D5D5E5D5B5B5C5C5D5A595A595959575654534F4B453E3A37363332302E2E
2D2C2B2A2929282828282827272727272627272726262626262626262626262626262626
2626262626262626
262726262626262626262626262626262627272627272627272727272727272727272727
282828282828282929292A2A2A2B2C2C2D2E2F303133343635383A3C3D3F404243454749
4C4D4F535557595A5D5F62636465686B6D7071737574777B7B7D8282848786898B8E8F91
92949696979B9D9F9FA0A3A3A7A9ABACAEB0AEB4B5B6B5B7BCBDBBBBBDBDC0BFC0C2C4C4
C5C5C6C5C8CCCBCECACDC9CCCDCFCECCCDCDCECBCED0CFD5D4D2D4D3D1D3D3D4D2D5D3D4
D6D3D4D7D6D7D6D9DADBD8DCDDDEE1E1E2E4E3E4E3E1DEDCDCD9DADAD9D9D7D6D2D2CFD0
CECCCCC9CBC7C3C2C2C1BEBDBCBAB5B5B1B5AFAFADACAAAAA6A6A5A0A1A19F9F9F9D9E9B
9C9A9E9D9C9B9D9B9D9D9C9D9C9EA09DA3A3A1A4A4A5A8ADACACAEAEB4B8B5B5B4B7B6B8
B3B9BABCB9B9BABBBAB6B7B5B4B4B2AFAEADACA8ABABA9AAA5A9A3A4A2A3A5A3A3A1A19F
A2A0A1A2A1A1A0A19FA2A3A0A0A2A2A29FA39F9F9D9D9D9C9D9DA0A09E9F9C9C9B9B9596
9697959491908D8F8E8D8F908C8D898B898A8888868585858584838483837F7F817F807E
7D7C7C7A7A7978737470716E6C6D6D6C6B6A686B6A67656866666462616160605F5F5F5D
5E5D5A5B5D5C5C5C5D5B5B5B5C5A5A5A59595A5757565653514C47403C3A36343231302F
2D2C2B2A2929292928272827272727272727272727262626262626262626262626262626
2626262626262626
262626262626262626262726262626262726262626272727272727272727262727272727
272828282828282929292A2A2B2B2C2D2D2E2F303132353636383A3B3D3E41414446474B
4C4D50515455595B5D5F6062666667686C6E6F71747677787B7E7F81848587898C8D9092
92949495989B9B9D9EA2A1A5A4AAABACACAEB1B2B0B1B5B6B9BBBBB9BEBDBEBDBFC1C6C4
C4C6C6C9C7C8CAC9CECAC8C9CDD0CCD0CED0D3D4D0CED5D0D6D0D1D1D1D5D2D4D6D3D6D4
D5D6D8DCDAD8D7D7D8DADDDADEDFE1E2E2E3E5E4E5DEE0E0DEDBD8D9DADDD7D6D6D5D4D1
D0CFD1CDCDC7C8C6C4C2C3C0C0BABBB8B6B2B3B2B0AFACAAA6A5A5A3A3A1A4A19F9E9B9C
9E9E9D9B9C9A9D9C9C9D9C9A9C9D9D9F9FA3A2A5A2A4A6A8ABACADAFAFB5B3B2B4B5B7B6
B9B9B9BBB8BCBCB9B9B9BAB9B4B6B4B2B3AEAEAEAAAAAAABA6A6A6A5A2A1A2A3A6A3A1A0
9FA1A0A0A09EA09FA09F9FA3A1A39FA0A09FA09F9F9C9C9E9C9D9B9F9E9E9F9D9C9C9796
969594949391908F928E8D8E8D8C8C8B8B8A8B8C89868686878585838282828080807D7D
7D7D7C7B7B78787676747270726D6C6B6C6B696A6B68686667656462645F60605F5E5E5E
5C5C5D5C5D5E5B5C5B5C5C5B5B5A5B5959585858565655534F4E49413F3A373532312F2F
2E2D2C2A2A29282928282827272727272627272726272626262627262627262626262626
2626262626262626
262626262626262626262626272626262626272626272727272727272727272727272727
2727282728292929292A2A2A2B2B2B2C2D2E2F313133353539393B3B3E3F42444447484A
4D4F51515358585C5C5F62616467686A6E6D6F71737676787B7D7E7F868786888C8C8E8F
929496969898999D9FA1A1A5A7A7A6AAACAEAEB1B4B2B3B8B5B7B9BCBBBDBCBFC0C0C3C2
C2C4C6C6C7CACBCACBCBC8CFCFCECFD1CCD2D1D4CED3D3D4D0D3D3D4D3D4D5D9D6D5D4D5
D5D8D9D6D9D9D5D6D7DADBDCDDE1E1E1E4E7E1E0E0E2E0E4E3E0DFDEDBDDDBDBD7D6D7D4
D1D2D3D3D2CCC6C7C6C7C6C6C3BFBCB8B8B6B5B2B3B1B0A9AAA6A5A4A1A2A1A1A0A09EA0
9C9D9F9E9D9A9B9C9B9D9A9C9A9C9CA0A1A19FA3A3A0A3A6A9A9ACACAEB0B1B4B1B4B6B7
B6B6BABCBBB9BBBAB8BBB8B9BBBAB7B6B5B4B3AFAEADADAFA9A9A5A3A5A4A3A4A3A4A3A3
A3A0A0A0A1A29FA3A0A09FA0A0A09E9DA29DA0A19C9D9D9C9F9DA09F9F9F9E9D9C9C9B99
9797949694959390918F8F8F8C8D8D8C8C8B8A888887878886848687838383837F807D7F
7F7F7C7C7B7A7778767372716F6E6F6E6B6A696B6968686766676664646261615F5F5F5D
5B5D5B5B5D5C5D5C5A5B5B5C595A59585858585857555452514E4B453E3C38353331302F
2E2D2C2B2A2A282828282827272727272727272727272726262626262627262626272626
2626262626262626
262626262626262626262626262626262726272626272727262627262727272727272728
2828272828282829292A2A2A2A2B2D2D2E2E30323333353638373B3D3E3F42434546484B
4C4F4F52555758595C5F6163656667696C6E6F707374767A797C7C7E818487878A8B8E8F
91929597989C9C9B9B9EA5A4A4A5A7AAABADB1AFB3B2AEB5B6B8B8BBBCBEBDBEBFC2C1C2
C5C3C5C7C9C8CBCACBCCCCCBCDCFCED0D1D2D6D5D2D4D6D6D6D2D7D3D4D6D9D7D5D6D4D1
D6D5D8D8DCD9D6D7D7D6D8DDDEE0DEDFE2E5E3E1E3E3E1E3E3E4E0E0E0DEDEDCD5D9D6D5
D7D7D3D2D3CFCBCAC8C9CAC8C2C5BFBEBDBCB8B6B7B3AFB0ADA9A7A4A8A3A3A0A1A09F9F
9F9D9C9C9B9B9B9A9C9A9B9C9A9C9E9C9FA0A19FA2A2A0A2A7A8ABA9ABADB0B0B1B3B3B4
B7B8B9B7B7BABAB8BDBCB7BAB9B8B9B9B7B6B6B4B1AEAEAAAAAAA8A9A6A3A5A3A2A1A4A2
A1A6A4A2A1A1A1A2A0A09FA19F9FA09FA19EA09E9F9D9D9D9E9EA09E9EA09F9F9E9C9B98
97979894959694939291918F908D8D8C8E8B8B878B888A88888486848683848380827F80
7E7E7D7E7C7A7978767675737171706F6D6C6B6A696A68676767646665616261605E5C5E
5E5C5C5B5B5C5C5B5C5C5B595B5B58595756565654555352524F4C48433C38363331312F
2E2D2C2B2A2A292828282828272827272727272626262627272627262626272626262626
2626262626262626
252626262626262626262627262626272626262626272627272727272727272727272727
2728282829292929292A2A2B2B2C2D2D2F2F303233333636383A3B3C3E4043434548494B
4D4F51525455595C5C5E6163666768696C6D707171767678797A7E8182868385898E8C8F
9093959698979D9C9AA0A0A1A3A5A8A8AAAEADB0B2AEAFB3B3B8B8BBBBBFBEBBBFC2C0C3
C2C4C4C7CAC9CBCCCBCCC9CDD1CFD0D0CFD2D4D3D6D8D3D5D6D8D5D8D5D8D5D7D5D7D3D7
D6D2D4D5D7D9D7D8D6D8DADBE3DEE6E7E4E3E3E2E2E1E2E4E6E4E0DFE0E0DDDDDDDCDCDA
D9D5D6D4D3D4D0D2CECACCC8C7C7C5C0C1BCBAB8B6B3AFAFABAAA9A9A7A5A3A5A4A0A0A1
9F9EA09B9A9E979B9A9B9C9E9A9C9C9F9E9E9E9F9FA19DA2A5A6A6A9A9ABABB0AFB1B2B2
B3B5B5B7B5B9B8B9BBB9BEBEBBBDBDB9B9B5B6B5B3B0ACABABABAAAAA7A8A5A5A6A6A5A5
A2A3A1A3A2A2A1A1A1A0A19FA0A29FA0A0A09FA09CA19E9E9D9F9F9F9C9B9B9D9C999C9B
989B96979695949291928F908E8F8E8F8D8B8C8C878A878A87878586888581838281817F
7E7E7D7E7C7B7A797877757573727272706D6D6B6A6A686A6869676764646360605F5F5E
5D5D5B5D5C5C5C5B5C5C5959595959585757575557565452514E4D4A443D393634323230
2E2D2C2B2A2A282928282828272727272727272626262626262626262626262626262626
2626262626262626
262626262626262626262626272626262627262727272627272727272727272827272728
27272828282929292A2A2B2B2B2C2D2E2E30313333353637393A3C3D3F4043424546494B
4D4E51525555595B5E5F61626368696B6D6C707273757676797A7D818383848688898E8D
909396949899999C9D9CA1A1A2A4A6AAABABADACB1B0B5B3B6B8B6B9B9BDBDBCC2C3C6C5
C4C4C7C4CBC7CCCBCBCECCCCCED1D2D0D2D3D0D4D4D4D7D7D7D5D3D7DAD7DADADDDADCD7
D5D8D6D6D4D5D8D4DBDADAE0DFE2DEE3E1E3E2E3E4E1DFE5E6E5E1E6E3E4DFE4DFDCDBDA
DCD8D3D6D5D3D8D1D1CECFCACBC8C8C6C0C2BFBAB9B5B3B1AEAEABA9AAA6A7A7A6A1A1A4
9F9E9D9F9E9C9D9A9C9A9C9D9B9C9F9C9E9B9C9FA0A0A1A0A1A4A7A6A8A8A9ADADAEB3B3
B1B6B5B6B6BAB9BDBBBBBABBBABBBBBCB8B8B6B5B2B3B1AEAEAEADABABA7A8A6A3A7A5A4
A3A4A6A3A2A4A1A0A2A2A1A09EA1A29FA29E9EA09F9AA19E9E9F9D9E9F9D9E9E9B9B9A98
9697979796969692929291918F908E8D8D8C8A8B8B89898B898786878686858483828081
817E7E7D7C7B7C7B7779787576757372706F6E6C6C6A696B686668666564646461605E5F
5D5C5C5C5C5C5C5D5C5A5B5A595A58575557555453525252504E4D49463F3A3734323230
2F2F2D2C2B2A2A2928282828282727272727272727272726262626262626262626262626
2626262626262626
262626262626262626262627262626262626262727272727262627272727272727282827
2828282829282929292A2A2B2C2C2D2D2F30313333353737393B3C3E3F42434446474A4C
4E4F515354575A595D5E60646566686A6A6F717372747677797B7C80818283848789898C
8E9091959996999C9C9F9FA1A4A5A4A4A8ABAEAEB0B2B2B1B4B5B4B4B9BBBBBDBFC4C3C5
C3C3C5C4C6C8CECBCECDCDCED2D0D2CFD3D3D2D2D3D6D7D9DDD5D5D8D8D8DADBDBD9D9D5
D6D5D6D6D7DADCDCDCDDDEDFE0E4E3E3E3E1E1E5E4E4E4E8E4E4E5E5E2E1E5E1E3E0DFDC
DDDCDDD8D5D9D7D6D6D1D1CFCFCCC7C9C6C6C1BFBFB8B5B4B2B0ADABA9A7A6A5A7A4A3A2
A1A09E9E9E9E9A9B9A9C9A9A9B9B9C9E9D9F9D9C9E9FA0A1A2A6A1A6A7A7ABA9ADADB1B2
B5B3B6B5B6B9BABCBBBEBCBDB8BCB9B7B9BABBB9B4B2B1B0AFAEAEADADACAAA8A7A6A7A5
A4A3A5A4A1A3A1A4A2A0A1A0A19FA29FA09E9F9E9EA19D9D9E9E9E9C9A9A9B9E9C9B9A9A
99979A9997979693949090908E8E8C8D8C8B8D8A8C8B8A88868788868485868383818180
80807F7E7E7C7A7B7A7B7A767675757471706E6E6C6B6A6B6A6A6869686764646262605F
5D5D5C5D5B5B5B5A595A595A5959585757565554545351514F4F4D4C48423D3936333231
302E2D2C2B2A292928282828282727272727272726272727272627262627262626262626
2626262626262626
262626262627262626262626262626272626272726262727272727272727272827282728
272828282929292A292A2A2A2C2D2E2E2F303233343537393A3B3C3D404142454748494B
4E5151545455585A5C5F6162646669686C6B70727374757879787A7D808286858685898B
8B9094949499999E9C9BA0A0A2A4A3A7A9ABA8AEADB0AEB2B4B5B6B7BABDBDB9BFC0C4C5
C5C3C7C8C6CAC9C9C3C3C5C5CCD2D2D1D0D1D3D3D2D3D9D9D6DBD9D6D8D9DADADBDADAD8
D7D9D7D4DBDBDBDADEDBDCE1E1DFE5E2E5E5E2E6E6E7E5EAE9E6E8E3E5E4E6E4E4E2E1DD
DEDFDBD9DCDBD7D5D5D9D3D1CDCECDCCC7C8C3C0BCB8B9B7B4B1AFACADACA6AAA7A6A5A5
A1A39F9EA09D9D9D9B9C9B9D9A9B999A9E9C9B9A9F9DA09D9F9FA2A7A4A8A8AAABACB0B0
B1B4B5B6B7BAB7B9BABBBCB9BCB8B9BCBABABBB8B7B5B5B5B3B2B1B0AEADAAA8A9A8A7A4
A5A4A4A3A3A2A2A2A3A3A0A09FA1A1A1A09DA09E9D9D9E9E9D9F9F9C9D9D9C9A9A989A99
9999979896989595939190908F8D8E8F8F8C8A8C8C8C8B89898685878685868383828280
83817E7F7D7C7D7D7D7A7979787675737172716F6F6D6C6A69696968676766666261615E
5F5D5B5D5C5C5B5B5A5A5A595958595855555453535252514F4E4D4C48443D3B37343331
302E2D2D2B2A2A2A29292828272727272727272627272626262726262626262626262626
2626262626262626
262626262626262626262626262626262626262627272727262727272727272827282727
28282828282929292A2A2B2B2B2D2E2F30313233343738393B3C3D3E40434445464A4B4C
4D5050535556575A5A606162646568696A6D6F7173757678797B7A7F7F80848488888B8B
8E8D909497979A9A9A9EA0A0A0A3A6A7A6A7AAAAACAFB0B2B3B5B4B7B7BBBABEBDC1C2C5
C7C5C5C3C7C7CBC9C9C7C7CECED3D1D2D1CED2D3D4D8D7D6D5D9DAD9DAD7D6DCDBDAD8DB
DAD9D9D6DADBDEDFDDDEE1E2E3E6E6E7E5E6E8E9E5E7E6E8E4E8E4E5E5E9E6E5E8E6E2E1
DFDFE0DCDADDDDDAD8D8D5D5D1D3D0CBC8C9C4C0C3BDBDBCB9B7B1B4AFAEA9ABA9A6A5A5
A4A2A3A29F9D9E9E9CA09D9B9B9A989B9B9B9C9C9D9D9DA09DA0A1A0A5A6A6A9A9A9ABAF
B3B1B4B7B5B6B6B8B9BBBBBEBCBFBCBDBBBCBABBBAB9B8B5B4B5B1AFAFAFADABABABA8A6
A7A7A4A6A4A0A4A1A0A1A0A1A2A09E9F9F9F9F9F9E9F9D9DA09C9DA09C9F9B9C9C9C9A9A
98999997949797959494929490928F8E8E8F8A8C8B8A8A8A878986868483848484848284
83817F7F807E7C7C7C7A7B7A787874737373726F6E6E6D6B6B6A6A6A686968656262605F
5E5F5D5D5B5C5A5A5A5A59595A58575755555455535551514F4D4C4B4A46403B38343331
302F2E2D2C2A2A2929292828272728272727272726262727262726272626262626262626
2626262626262626
262626262626262626262626262626262727262626262727272627272727272727282828
282828282829292A2A2A2B2C2C2D2D2E30323334353738393A3D3E3F4143444749494B4B
4E5152535656595B5C5E6062636566696B6B6D7172747877797C7C7E7F83828486878788
8E8E8F9195969A9A9B9D9EA0A1A2A4A5A9AAA8AAABACAEB2B4B4B4B6B9BCBABCBFC0C1C4
C0C3C4C7CACACCC9CACACECED1D4D1D4D4D2D1CED7D5D4D4D8D8D7D9D7D6DADCDADBDDDA
DBDDDCDFDFE0DEE0DFE3E2E5E2E4E7E2E2E4E4E3E7E8E5E8E8E5E8E3E8EAEAE6E7E6E6E3
E3E1E1E1DFDEDEDCDCD7DAD8D4D3CFD1D0C8CAC4C4C1C2BDBAB7B4B0B0B0ADABADA8A4A5
A6A4A6A3A2A0A09D9F9D9D9D9B989998999A9B9B9E9C9C9B9D9D9DA2A3A2A4A7A6A9AAAC
B0B2B5B3B6B5B6B7B9B9BDBABEBABBBBBCBDBBBDBDBBB8B7B6B5B2AFB0B0AEAEACACAAA7
A9A6A7A4A5A5A3A1A3A2A2A0A2A1A09F9F9E9E9C9D9F9F9E9C9D9E9E9C9E9A9D9D9A979A
9C999998979494959494959192918F8F8D8D8D8D8A898B87888887868687858784868483
80817E7D7E7E7B7D7E7B797A78777774737573706F6F6E6A6A6969696A68666565626261
5F5E5F5C5D5B595A595A595857565756555555545452524F4E4E4C4B4947413C39363432
302F2E2D2C2A2A2A29292828282727282727272727262726272627272626262626262627
2626262626262626
262626262626262627262626262626262626262626272727272727272727272728272727
2828282829292A2A292B2B2C2C2D2E2F303234343738393A3A3C3F4041434546484B4B4E
4F4F52535559595B5F5F5F6363656769696C6F6F7374757779787C7B808085858788868B
8C8E8F919597989A9C9B9CA09FA3A5A5A6A6AAAAAEADB0AEB3B5B6B2B7B7BBB8BDC2BFC1
C4C3C5C7CAC9CBCBCDCCCDD0D1CFCED0D4D3D6D4D7D4D5D4D7DADBD9D6D9D8DCDADDDCDF
D9DDDEDEE0DFE0E0E1E0E7DFE3E4E3E8E8E5E5E8E8E8E6E6E6EAE6E9E8EAEBE8E7E7E5E4
E0E3E2E1E0DEDFDDD9D8D8D7D4D7D4D2CFCAC7C7C5C2C1BEBCB8B5B5B4B1AEABA9A9A9A6
A6A4A6A4A2A3A0A09F9F9D9F9D9A999C9A9A9A9C9C9C99989A9A9CA09FA1A4A8A7A8A9AE
ADB1B0B5B4B3B6B7B9BBB9BEBABFBCBBBBBDBDBBBBBCBBB8B9B8B4B2AFB1AEB1ADACA8AB
AAA6A5A7A3A6A4A6A5A2A1A4A1A39F9EA19F9FA19C9D9C9E9A9B9D9D9C9D9C9B9B9E9B9C
999B98979895959395949691938F938F928F8C8D8B8B8B8B888988878886858485838282
838080817D7E7E7E7C7C7B7C787876767574717270706D6C6B6C6A686969666665636261
5F5F5E5E5D5D5A5A59575857565658565553555454514F4F4E4C4C4C4B48433E3A373533
31302E2E2C2B2B2929292828282727272727272727272727262626262627262626262626
2626262626262626
252626262626262626262626262726262626262727272727272727272727272827272728
2828282829292A2A2A2A2B2C2D2D2F2F323335363639393B3C3E404242454649494A4C4F
4F50525556575A5A5C5E5F6164646768696B6F7072747477787C7A7A7E8083848487898A
8B8C8F90929497969A9D9D9A9EA2A2A3A7A9AAA6A9ADAAAFAFB2B2B3B5B4B8BBBABFC1C3
C1C2C5C6C7CACDCACDCCCFCFCFCED0D4D8D5D6D4D6D5D6D5D8D7D9DADCD7D8D6D9DDDCDC
DDDEDFE0E0DDDEE1DEE2E4E6E4E5E5E3E6E6EAE8E3E7E6E9E6E6E9E6E9EAE7E9EAE8E8E8
E8E7E5E4E0E0E3DDDEDED9D9D9DAD6D3CED0CAC9C8C5C5C0BCBCB8B4B3B6B1AFAFAEABAA
A6A7A8A7A4A3A39FA0A0A09C9E999A9C999A999C9B9C99999C9AA0A19FA0A2A5A7A9AAA8
AFAFB2B0B2B6B8B9BABAB8B7B7BAB9BEBCBDBFBEBBBBBDBDBCB7B7B5B5B3B2B3B0AEAEAF
AAAAA8ABA7A4A5A6A3A4A3A2A2A09F9E9FA0A1A1A09F9E9E9B9C9C9B9D9E9D9D9A9B9A9A
9A9C9999979796959795949492938F908F8E8F8C8C8B8A8C898989898786868584838282
818180807D7E7E7E7D7C7D7879777674747373727171706D6D6B6A6B6869676764646262
615E5D5D5D5C5B5A5B59575656575355545553545451534F4E4D4D4C4A4A46413B373533
31302F2E2D2B2B2A29282828282828272727272727272626262726262726262626262626
2626262626262626
262726262626262626262627262726262626272626262726262727272727272727272827
2828282929292A2A2A2B2B2D2D2D2F303133333637383A3B3B3F4041434447484A4B4D4F
4F51535457585A5B5C5E60616366676A6A6B6C6F7373757777797C7C7F8081838688878B
8A8D8E9190939598989D9C9BA19FA4A4A8A3A4A9A8ADABACAFB2B2B2B5B6B7BABCBDC0C3
C3C3C3C4CAC7CACCCCCCCDCED0CFD1D2D3D6D4D7D5D8D6D5D6D7DBDBDBDBDCDBDFDEDFDC
DDE0DFE0E1DFDDE2E0E4E5E3E4E5E5E8E4E4E5E8EBE6E6E6E8E7E8E6E8E9EAE8E9EAEAEB
E8E6E9E2E3E2E3DEDFDBDADADAD8DAD6D5D1CFCCCBC8C7C6C1BEBBB9BAB6B6B5AFB1ACAC
AAA7A7A6A8A5A4A3A1A19F9C9F9E9C9C9A9C9B9A97989A9B999C9C9E9FA0A2A1A7A4A7A9
AAADAFAEB3B6B6B7B8BBBBB9BDBBBCBBBBBDC0BCBBBCBDBBBABBB8BAB6B5B3B4B4B1B0B0
ACAAA9A9A9A6A7A7A6A4A2A2A3A19F9E9FA0A0A3A09F9D9E9D9E9F9C9E9D9D9C9E9B9B99
9B9C9B9A97989697949696949492928F918F8E8C8D898B8A8A8A89888784868386848585
8384828081807F7E7D7B7B7A7B787777777473757170706E6D6C6A6B6967676566646362
606060605D5C5D5B5C5858565655565554545353525251504F4C4C4B4B4946413C393634
31312F2E2D2D2B2A29292828282727272727272727272726272626262626262626262626
2626262626262626
262626262626262626262626262627272626272627262627272727272727282728282828
292828292929292A2A2B2C2D2E2E2F303234343739393B3D3D3F4143434747484A4C4D4E
505154575758595C5E5E6163656567696A6D6D6E7274767878787C7C7F8184858586878B
8C8D8E90939393969698999D9E9D9FA4A5A7A6AAA8AAADADAEAFB0B3B5B6B7BAB6BCBCBF
C2C1C3C5C6C8CAC9CCCDCFCBD0CFCFD1D2D2D7D3D7D6D5D8D6D7D8DBDDDEDCDEDBDFDDDC
DEDDE2E2DDE1E1DEE2E2E3E4E7E6E8E9EAE8E7E9E5E2E5E6E7E8E7E7E8ECE8EBE8EBEAEA
E9EBEAE7E7E5E2E2DEDFDDD9DBDBD9D8D6D1CFCDC8CBC6C5C4BEBCBDB8BBBAB7B4B1AFAE
ACABAAA8A6A6A6A8A1A1A0A19F9E9F9D9C9E9A9B9B9D9A9B999A9BA09FA3A5A5A4A6A8A8
AAAFABB0B2B5B6B7B7B7BABAB8BABDBCBDC0BABCBFBCBABBBDBBB9BAB9B6B7B8B3B1B1AE
AEAEA9ABA8AAA5A8A5A5A4A2A4A4A1A1A2A0A0A49D9F9E9E9F9D9D9F9A9B9F9E9C9C9B99
9B989798979999979694949593959191908F8F8E8E8E8B8B898988878788868785838182
8082807F817E7F7D7F7D7D7B7B797775767475737272706F6E6C6C6A6968666765626261
615F5E5D5F5C5A5B5B59565656575355545454525252514E4D4D4B4A4B4946453E3A3734
32302E2E2C2C2B2B2A292928282828282727272727272727262727262726262726262626
2626262626262626
262626262626262626262626262727272726262626262727272727272727272727272828
2828282929292A2A2B2C2C2C2D2F2F3032343636393A3B3D3E414143454547494B4C4E4F
5053545557595A5A5D60606163656669696C6D6F72727676797B797B7E8081838883888B
8A8F8F9190939594969A999B9CA0A1A5A5A8A8A6ABAAAAADADAEAFB2B0B6B7B8BABBBFBD
C0C2C6C6C7CBCBCACBCDCCD0CDD0D0D1D4D4D3D7D6D7D5D6D3DBDDDCE0E1E0DEDDDFDEDE
DEE0DFE1E0E0E1DEE2E2E4E4E2E6E5E8E6E7E5E9E7E4E6E9E3E7E7E8E9E9E6E7E8EDEFED
EDEAEAE9ECE7E5E2E3DEE1E0DBDBDBDADAD6D6D4CEC9CAC6C4C2BEC3BFBDBCBBB5B6B3B2
ADAFADACAAA8A9A5A4A5A2A0A19FA09F9D9D99989B9A9D9C9A9A9AA09FA1A4A4A6A5A7A7
A9A9ADB0B0AFB5B8B8B7B8B7BABBBCBDBDBDBBBCBDBBBDBCBEBBBBBAB9BBB6B5B7B4B0AF
B1B0B3AEABA9A6A5A6A6A5A3A5A39FA29F9F9FA19FA09E9F9DA09D9D9F9E9E9C9A999A99
9A9997989A9995969696949595949393928F928F8F8F8C8B8B8888888786878684858283
848280817F807E7D7F7D7A7A7A78787775767274727271706C6E6C6B6968666666626562
605F5E5E5D5C5C5C5A595757565755555454535352515150504D4D4B4A494845413B3735
32312F2E2D2D2B2B2A292828282827272727272727272726262626272626262626262626
2626262626262626
262626262626262626262627272626262626262626272727272727272727272727282828
28282929292A2A2A2B2C2C2D2E2E3031333437383A3B3D3E40404243464748484D4E5050
5253545758595B5C5E5E6061646568666B6A6D6F7072747578787C7F817F828485868687
8A8D8E8F919191939897989B9A9E9FA0A6A3A5A9A9A8A6ABA9ADB0B0B1B2B6B9B9BABDBF
C1C1C6C3C9C8C8CCCCCAD1CCD0CED1D0D3D4D6D9D7D6D7D8DBD9DDDBE0DCDDDCDDDEDEDE
E2DFDDE2E1E3E3E2E4E3E5E4E6E2E7E7E5EAE7E8EAE8E7E4EBEAE8EAE7E9E9E9ECEAECE9
ECECECECEAE7E6E4E0E4E1DFE1DBDEDBD8D9D5D6CFCBCAC7C7C4C6C3C2C2C0BDBBB6B5B7
B3B0B0ADABACAAA7AAA6A4A4A4A3A09F9F9B9B9B9C9D9C9C9D9D9A9C9F9FA2A5A9A6A7A6
A9A8A9ADAEB2B2B5B4B6B6B6BBBABBBABBBBBEBBBBBCBBBEBABBBCBDBCBBBAB8B6B6B5B4
B1B1AFB1AFACADA9A7A6A5A5A5A4A5A3A1A0A19FA29E9DA09E9E9D9D9E9D9D9D9C9B999A
99999B98979995959A94959594949293929395908F918F8B8C8989878A87878683838583
81828280837F807D7D7C7D7B797A7878767573747270716F6D6D6D696B69666664636262
605F615D5E5C5C5B5B5B58565855565555545252515251504F4E4D4B4B4B4947423C3835
3331312E2E2D2C2B2A2A2928292827272727272727272626262626272626262627262626
2626262626262626
262626262626262626262626262626272626262627262727262727272727272827272828
2828282929292A2B2B2B2C2D2E2F3032343537393A3B3E3E404142464848484C4D4E5051
5255555758595B5C5E60616265666768696B6E6F6F737674767A7A7E7E81828386858587
8A8C8D8E8F919394969695999C9C9CA0A2A3A5A8A9A6AAA9ADAEADB1B1B7B6B8B7B9B8BB
C0C0C3C6C6C7CACACBCFCDCDD1CFCFCFD0D6D6D7D6D5D7D9D8DBD9DCDBDEDEDDDFDFE2DF
E2DFDAE0E0E4E2E3DFE4E6E2E4E9E4E6E5EBEAE8E6E7E8E8ECEAEDE9EDE6EDEBE8EBEBF1
EFEAEEEDEBEAE9E8E9E5E7E3E2E2DDDCDBDAD8D2D2CDC9CAC6C5C6C5C4C4BFBEBFBBB8B8
B8B6B3B1AEAEAFACA8A8A7A7A5A39FA3A19F9B999C9C999A9A9A999A9A9EA2A3A6A5A7AA
A9ABABABABAFAFAFB4B4B5B8B7B9B7BABABABBBCBDBABCBDBDBABBBEBDBBBAB8B8B7B9B6
B4B5B4B3B1AEABA9A9A9A7A6A7A3A4A3A2A2A1A1A09E9E9E9E9E9E9E9E9B9B9B9D979B9B
98989B97959997969795989594929592929191908F8E8D8B898A88898787878485828482
8382827F81807D7E7C7C7D7C7C7B7A7778767672757372706F6F6E6D6B6B676664646262
615F605F5D5D5D5A5B5A585758555655555352525151514F4F4D4D4C4C4A4A47443E3936
3431302F2E2D2C2B2A292829282827272727272727272627262626262626262626262626
2626262626262626
262626262626262626262626262727272627262627272727272727272727272728282828
28282929292A2A2B2B2C2D2E2F2F30343436373A3B3C3E404142444646484A4B4D4E5152
52545556595B5A5D5E606364676767676C6D6D6D71737375767B7A7D7D7F808283858587
8B8A8D8D8F939295949598989B9C9B9FA1A3A5A8A7ABA8ADAAACAFAEB3B3B2B5B7B5BBBC
BFBDC0C4C3C7C6C9CAC8CCCFCED2CFD2D5D6D3D6D3D8DADBD9D7D9DED8D9DCDBDEDEE0E1
E0DED6E3E2E1DFE4E2E6E6E8E7E6E1E4E8E4E8E7E9E8EAECE7E6ECEBE9E9EAEDECEAEDED
EDEDECECECEEE8E8E8EAE5E7E3E3E2DFDDDBDCD5D2CCCCCCCBCBCAC9C5C4C2C0C0BABBB9
B6B9B5B5B2B5B2AFACA9A9A8A5A6A7A4A19F9E9F9E9E9E9D9D999C9D9B9EA0A0A1A5A8A7
ABA7A8A5AAAAADAFB2B5B3B6B6B7B9BDB9BBBDB9BCBBBABBBABABABBC1BEBCBCB9BAB8B5
B4B4B5B4B1B2AFACA9ABA9A6A6A4A3A3A3A3A19FA0A09C9E9E9E9E9D9C9D9D9C9A9B9B9A
9A98979A999A98969898959695949495939091918E918E8E8A8B8A8A8787878586838383
8182817F807F7F807D7C7C7A7D7C7977787675747375727071706E6D6B6B686765656562
64615F5F5D5C5D5C5B5A59595857555654535453525152514F4E4B4C4C4A4948463F3B36
3332302F2E2D2C2B2A292929282828282727272727272727262626262626262626262626
2626262626262626
262626262626262726262626262626262727272727272627272727282727272827282828
28282929292A2A2C2C2C2D2E2F2F3232343738393B3D3E4043454548494A4D4E4E4F5252
55575759595A5D5E60616263646766686C6D6C6F6F73727676797B7C7B7E808082838586
888C8B8E8E90929394979899999B9E9F9FA2A7A4A6A7A9ABA9AFAFB0AFB0AFB8B7B8B9BA
BABDC4C1C0C7C6C9C9CACACCCFD1D3D1CFCFD5D4D6DBD8D7D6DBD7D8D7DBDBDCE1E1DFE1
DDE2DFE2E2E5E2E7E2E1E6E1E1E6E3E7E8EAE9E7E9E8E8EBE8E9E8ECEAECEBEEEBECEDEB
EEECEFEFF0EFEEEAEBE9EAE7E5E5E1E2DEDDD8D9D6D1D0CFD0CECCCBC9C4C0C2C0C0BFBD
BEBAB8B9B6B7B3B1AFAEACAAA8AAA6A6A4A1A0A09E9E9E9C9A9B9A9C9A9D9DA0A0A2A2A6
AAA6A8A6A8A9ACAFAFB0B1B5B9B9B7B8B6B8BABBB9BCBCBABABBBCBDBCBDBDBABABAB8B7
B7B6B6B6B5B3AEAFACAEA9A9A7A7A4A3A4A2A0A09F9FA09E9F9DA19F9F9E9D9F9A9D9C9A
989B9A989995989896969494969793929093928F8F8F8F908F8B8A8A8889878687848483
81838381827F807F7C7D7C7E7B7C7979767576757574727270706E6D6C6B6A6967666565
63615F5F5C5E5D5B5A5959585756565754555352525151504F4E4D4B4C4A494946413B37
343231302E2E2D2B2B2A2A29292827272727272727272727272627262626262626262626
2626262626262626
262626262626262626262626262627272727262727272727272727272727272728272828
282929292A2A2A2B2C2C2E2D303032333637393A3C3E404143444748494C4D4F50525154
575858595A5C5C5E5E626263656669696B6D6C6F71737477767A7A7C7C7C7B8282838587
858A8B8E8F90919093939499999D9B9D9F9FA3A3A8A8A9AAA9AEADAFB0AFB3B1B4B8B6BB
B9BDBFBFC2C2C3C7C8C8CCD0D0D0D1D2D0D4D4D9D5D5DBD7D8DAD7D9DADCDBDCDDE0E1E2
E2E1E1E1E4E4E3E2E1E6E4E6E4E3E5E3E7E6E7E8EAE8E9E9EAE9EBEDECEAEBEBECECE9ED
F1F2EEF0EFECEEEDEBEAE9ECE8E7E7DFE0E0DBDAD5D3D1CED1D0CFCFCAC7C7C4C3C4C3C2
C0C0BCB7B8B8B5B4B3AFAEACADAAA9A7A6A1A3A1A0A39F9E9B9C9D9F9BA09F9E9FA0A3A6
A9A7A8AAA5AAADADAEAFB1B6B5B8B7B7B7B6B8B7BCBEBCBCBBBABCBABDBCBBBCBBBCB9BB
B8B7B9B6B7B6B3B3B0AEACA9AAA6A6A6A5A4A29F9E9E9EA0A1A0A0A09D9D9D9B9B9B979B
9D9A9A9997979699969795959495949394919091918F908F8C8B8B8B8A89888A86858484
83828280817F807E7C7D7C7C7A79797A77797775757473716F716F6D6B6C6A6968666566
636361605F5D5E5C5B58595857575656555555535252504F4E4D4D4C4C4A484846433D37
353231302F2E2C2C2B2A2929282828272727272727272727262727262626262727262626
2626262626262626
252626262626262626272626262726272627262627262626272727272727272728282828
282929292A2A2A2B2B2D2D2E2F3032353638393A3C3F4142434748484B4C4E5051525353
57585A5A5B5D5D5F616163646767696B6A6E7070717373757578797A7C7D7D8082848286
87888A8C8D91909291939998989A9C9D9DA1A2A2A4A7A7A9ACACADAEB2B1B5B4B5B7B7B9
BBBBBFC0C0C1C2C4C8CAC8CFD2CECECFD1D2D4D5D5D8DAD6D9DBD7D8D9DADBDDDDE1DDE0
E1E2E1E2E2DDE5E7E3E4E2E5E3E5E6E2E4E6EBE8E9E8E5E8ECE7E6EAEAEEEEEBEAEDEEEE
EEEDEFEFF1F1EEEFEDECEDEBE9E6E5E2E0E2DDDBD7D6D3D2D3D3D2D3CBCCCAC9CAC6C6C6
C4C2BFBFBCBAB8B8B7B3B4AFADAEAAABA9A6A5A5A5A3A29E9E9F9BA09E9E9DA09F9FA1A6
A6A7A7A7A8A8A9A9ACADB0B1B4B3B7B7B4B7BABCBABDBBBAB9BBBBBCBABCBEBEB9BBB8B9
B9BBB9B6B5B6B2B5B6B0B2ABABABA8A6A9A6A2A1A1A0A0A19E9DA09F9D9D9C9C9B9D9B9C
999B97999A9998979697979594939395939292929090918D8C8D8C8B8B89898887878586
84808182817E7E7F7C7C7B787A7A797776777576757274716F6E6F6F6D6D6B6A68676667
656462605F5F5F5C5C5B585757575657555454525252504F4F4D4C4B4B4A494646433F3A
3533312F2F2D2D2C2B2A2929292828282727272727272627272626262626262726262726
2626262626262626
262626262626262626262626262627272626272627272627272727272727272727282829
292829292A2A2A2B2C2D2E2F303133353638393B3E3F4244454649494C4F4F5152535555
57585A5A5C5E6060606364656667696A6D7070717272727476777A7C7C7B7F8282838484
87888B8A8C8E91919395959698989B9AA0A0A1A1A4A3A5AAA9ADACADACB0B1B1B3B6B8B5
BDBBB9BEC1C2C4C7C7C9CACCCDCFCFD1D4D4D6D5D4D7D8D7D6D9D8DADAD9D9DDDFDBDEDE
E3E0DFDFE3E6E4E3E3E5E6E6E6E4E7E8E6E5E4EBEBE9E6E7E9E9EBECEBECEDEAEEE9ECEE
EEEBF1ECF3EEEEF0EEE9EBEAE9E5E4E3E3DEE1DCDDD8D8D4D5D7D7D2D5D1CDCCCBC9C8C7
C8C4C3C0BFBEBAB8B9B8B5B5B4B0B0ABADA9A9A6A8A4A4A2A0A3A3A29EA09F9EA1A0A1A3
A6AAA6A6A8A9A7A7AAAEADB0B0B3B3B5BAB6B8B9BABABBB9BCBCB9B9B9BCBCBABBB7BBBB
BEBBBBB5B5B5B4B2B3B3AFAFACAAA9A7A9A9A5A4A5A19FA2A19FA19E9C9D9B9D9C9B9C9C
9E9B999A9797969997969698969592949292939291918F8E8E8C8C8D898B898886888785
84848282837F7F7F7D7B7B7A7A7979797876767473747271737070706E6D6B6B6A686664
6564636161605D5E5D5C5B5959575656555554535352514F4E4E4E4C4A4948474743403A
373332302F2E2D2C2B2B2929282828282727272727272626272727272626262627262626
2626262626262626
262626262626262626262727262626262726262726272727272727282727272827282928
282829292A2A2B2B2C2D2F303032333437393A3C3E4042454647494B4D4F515253535657
595A5A5B5E6060616263646367686A6A6D6E7072717374747577797A7A7B7E8081838286
84898A898B8E8F949493959798969B9D9E9FA0A1A4A6A4A6ABA9ABAEB0B1AFB4B5B5B6B9
BCBBBABDBEBEC4C2C4C7C9C8CFCFCFCFD4D1D2D2D1D4D9D5DAD9D8D7D7DADCDADAD9DADE
E0E3E2E1E1DFE4E5E6E4E2E5E6E7E6E4E8E6E8E7E7E8EAE8ECEBEAE9EAE9E9EDEBECECED
EDEDF0EFEDF0EFEAEDEDEDEBECECE9E5E3E2E0E0DBDAD8D6D8D6D8D7D7D3D2CFCFCDCCC9
C5C7C5C4BDC0BFBCBBB9BAB7B3B3B0B1ACACAAAAAAA6A6A3A2A3A6A2A4A0A29FA19FA2A5
A4A2A6A4A6A8AAA9A9A7A9ADB0B2B2B6B5B7B8B7BAB8B9BBBBB8BCB8BAB8B9B9B7BBBBBA
BDBCBAB8B5B6B7B6B5B5B1B2AEABABAAACA7A9A5A3A3A5A2A19F9F9B9D9D9C9D9C9C9B9A
9A9B9B9999989898969697939393929292929191908F918E8D8D8D8B8B8B8B8887878686
838383838181807E7E7C7A7B7B79797779757775757472717170706E716E6B6B69676765
6565656261605E5C5C5C5B5A5A5957565353525352525151514E4D4B4A4948474743413B
37343330302F2D2C2B2B2A29282828282827272827272727272727272626262626262626
2626262626262626
252626262626262626262626262626272626262727262627272727272727272827282828
282929292B2A2A2B2D2E2F2F3031343638393B3C3E424244464A4B4C4F50525254565858
5B5B5C5D5E606161626364656769696A6B6D6E717474757575767A7C7A7C7E8182848486
8787888A8F8F8F9391929497999A9C9B9C9E9F9FA1A1A4A3A6AAAAABACAEB2B1B5B4B6B5
B6B8BBBCC0BCC1C1C2C7C8C9CCCDCFD0CED2D4D3D5D4D6D9DBDCDAD7DADBD8D9DCDDDDDE
DFDEDFE1E0E4E4E6E0E6E6E5E8E5E5E6E8E7E6E8E9E7E8E7EBE9E8E8E9E9EBE9EAEAEAEA
EBEFF0F0F1EEEFEEEFEFEEEBEBEBECE7E5DFE3DFDFDCDADCD8D9D8D9DAD8D5D4D3D1CFCD
CDC7C5C8C5BFC1C1BFBBBBB8B8B5B5B2AEAEACAAAAA6A6A7A5A7A4A6A3A4A1A0A2A09FA5
A6A5A7A5A4A7A6A8A8A8ACABAEB0B0B3B3B6B7B7B9B7B9B9BBB7BBBBBBB7BBB9B8B8B9BB
BBB9B9B7B7B7B6B2B8B7B5B2B1AEADAAAAA8A9A8A6A5A4A3A29FA09E9F9F9F9C9D9B9C9B
9D9B9A98999998969997959495949294959290928F908F8E8F8E8D8D8B8A8A8989868784
848281828282807F7E7D7D7C7B7A787778767776747373747271706F6E6D6D6C6A696766
666564636361605D5D5D5C5A5A5758565654545352535251504F4C4B4A4948474745423C
373432302F2F2D2C2C2B2A29282828282728272727272727262726262726262726262626
2627262626262626
262626262626262626272626262627272627272627272727272727272727272828272829
2829292A2A2A2A2B2C2E2F2F3032333638393B3D3F41434548494C4D4F52525356585A59
5B5D5D5E5E6063636566686869696A6A6D706F7173717479777A79797B7E7D8282828387
8487888A8C8B9091929595949899989CA19E9D9FA3A2A1A3A3A7A9A9ABABB0B1B5B5B4B4
B7B8B9BCBDBFBEC0C2C6C5C8C8CACCCECECED0D3D1D2D7D7D9D6D7D9DAD8DADDDAD9D5D7
DCDFDFE1DFE4E0E4E5E1E7E6E8E4E4E8E7E6E8E8E6EBE6ECE8EAE9E7EBEAEAEAEAECEAEB
EBEDEDEFEFEEEFEFEEEBECECEBE9EBE8E6E7E4E2DEDEDADADBDBDCDCDBDAD7D9D7D3D2D0
D0CCCCC6C8C6C7C6C1BDBDBAB9B4B6B7B4AEAEADACA9A5A7A8A9A8A7A5A4A4A3A2A1A3A1
A5A1A5A3A4A5A5A5A6A7ABABACAEADADB0B4B4B6B8B9B8B7B8B8B9BABAB8BBB7B8B8BBB8
BCB8B9B6BAB6B8B9B7B6B3B2B1AEADACACAAA8A8AAA5A4A4A4A1A09E9F9E9E9F9E9B9A9B
9B9A999C999A9799939796969493919492919291919090908D8D8E8C8D8D898B89888886
85818282838181807F7D7E7D797B797C787876737672727171716E6F6F6E6C6969696869
686866656461605F5E5E5C5C5958575555545252535250514F4F4C4B494947484644413D
383533312F2E2E2C2B2A2A29282928282727272727272727262627272626262726262626
2626262626262626
262626262626262626272626272727262727262627272727272727272727282728282828
28292A2A2A2B2B2B2D2E2E2F31313436383A3C3E3F41444647494B4E505054565759595D
5D5D5E5F61636464666669676A6B6C6D6E6E707073757675797A7A7C7D7C7D7E81828387
878586878B8B8F919193929597989A9A9B999EA29FA2A2A6A6A6A9AAA9AAAFAFB1B2B2B4
B7B5BABCBCBDBEC0C0C1C6C9C6C6CBCCCBCED1D4D1D0D4D6D5D8D6DBDAD8DBDBDAD8D6D6
DEDCDDDEE1E3E7E3E8E6E5E7E5E6E8E2E6E5EBE7EAEAEAEBEAE5EAECEEE9EDE8E9EAECEB
EBEFEBEEEDEBEFEDF1EDEFE9EDEDEDEAE8E9E5E5DBDFDEDCE1DEDDDCDFDBDCDBD8D8D4D5
CFCFD0CECBC6C7C5C3C1BFBDBDB9B6B7B6B0B3AEACABA8A9A9A8A9A9A6A4A4A3A2A3A2A2
A3A4A3A0A2A3A7A5A6A7A9A8A8ABADABADB0B2B2B9B8B7BAB7B8B9B9B9B8B8B9B7BBBABB
BCBAB8B9B9BAB8B7B7B7B5B6B4AFB3B0ABAAAAA9A9A6A6A5A2A2A1A19EA09F9D9C9D9C99
9C99989A9A97999598979793939494939190929191908F8D908E8D8E8C8C8B8B8B888685
88868584818282807D7E7C7B7B7C797979777975747472727271706F6D6E6C6A6C6C6B69
676665646463615F5E5E5D5C595A58585656545354515252514F4E4B494A47474643413E
39363331312E2E2D2C2B2A29292928282727272727272727272626262726262626262626
2626262626262626
262626262626262626272626262626272727272726262727262727272728282827282829
2929292A2A2B2B2C2D2E2F3031333536383A3B3D40434446484B4D4F51535456595C5C5D
5D5E6060626264656767686A6B6B6C6D6F6F7273737577797A7B7D7D7D7D817F80828384
85858688878A8E8F91919494969599989C9C9E9EA2A2A1A4A1A6A9A7ABAAADAFAFB0B3B6
B5B9B5B8BBBCBCBEC4C1C3C5C9C7CACBCDCDCCD1D4D3D1D1D2D5D7D7D9D6DBDADADADBDD
DEDCDBE0E0E5DEE1E2E3EEE7E8E9E6E5E5E8E5E7E7E6EAEAEDEBEAE9EBE9EEEBE9E8ECED
ECEBEEEDEDEDEFEDEAEEEAEFEDEBEEE6EBE6E5E4E2E2DFDEDADDDFE0DEE3E0DEDBDBDBD9
D4D3D3CFCECFCBC9C6C4C2C2BEC0BCBAB8B8B2B2ADACACABA7A9A7A9A6A8A3A4A5A4A2A3
A0A1A1A2A4A4A5A5A3A6A7A9A7A9A9A9AAABACB0B4B5B4B5B4B5B7B8B8B7B8B9B7B9BABB
B9BBB9B9B9BBB9B8B9B7B5B6B3B3B5B1AFAEAAA8AAA9A5A4A5A2A2A29F9F9E9D9C9B9D9B
9A99999499989599999895959495929291939291918F8F908F8F8D8E8E8C89898A8A8687
8783848483838180807F7D7E7D7D7D787A777675747373717271706E6E6D6D6C6B6C6B6A
6969676563646361615F5E5B5A595857575454525352535152514E4D4C4B47454442423F
3A3734322F2F2E2D2B2B2A2A292828282828272727272726272627262626262626262626
2626262626262626
262626262626262626262626262626272627272727272727272727272827272828272829
28292A2A2A2B2B2C2D2E2F2F31333537393B3D3E3F424546494B4D4E52535757585A5C5E
5F6161636464666768696B6C6B6F6E6F6E707173737677797B7A7B7C7C7F7E8081838287
878587888A8C8C8D8D9093949596999C9B9B9E9C9E9EA3A3A3A6A6A8A8AAABB0B1B0B5B2
B4B5BBB9BEBDBDBDC1BCC1C1C4C5CAC7CBC8CBCBCED0D1D2D2D3D3D4D7D8DBD8D9D9DBDA
DDDCE0DFE0E2E0E3E5E5E4E6E5E5E6E6E5E7E5EBE7E5EAE7E9EBE7EDEFEBECE6ECEBE6EA
EDEAECEBEDEEEFEEEEECEFECEBEAEAECE9E8E4E6E6E2DFDFDFDFDFE2E2E2E8DFDDE0DBD9
D8D6D4D3D0CDD0CCCAC8C5C1C1C1BEBEB9B8B6B2B4B0B0AEABAAA9AAA8A7A6A6A6A6A5A4
A2A1A3A1A4A3A2A2A4A5A8A6A9A7A6A9A7A7ABACB2B0B3B3B1B2B8B6B8B8B8B5BBB7BAB8
BDBBBAB9BAB8BAB8BABAB9B5B5B4B4B2B2B1AFADACAAA8A7A6A5A2A2A3A09F9D9D9C9E9D
9B9B9999989C97989796949593929292919291908F8F8F918F918E8C8B8C8B8C89888985
878785868182837F7E807F807E7A7D7C7978777475757372736F706E6E6D6C6C6D6D6A6A
686667666663626261605E5D5B5A5958575555535251525150524F504E4C47454442413E
3C363432302F2D2D2C2B2A29292828282827272727272726272727272626262626262626
2626262626262626
262626262626262626262626272626272626272727262727272727272727272828282829
2829292A2B2B2B2C2C2E2F3031333638393B3C3E41444446494D4D51535556565A5B5D5F
61636466666765686A6A6D6C6D6E6F6F71727374747678797A7B7B7C7D80807F81838384
858687898A898C8C8C8F909395969A9A9B9B9BA19FA0A3A2A3A3A7A5A9A9ACADACADB1B0
B4B6B7B7BABABABEBBBBBEC3C2C4C7C6CAC9CCCCCFCECFD0D0D3D3D6D5D6D7DBDAD9DBDC
DCDDDDE0DDE2E0E6E6E1E5E2E7E6E8E9EAE8E8E9EBEBE7E9EAEAEBE9ECEEEBEEEBE9E9E9
ECEAEAEDE8EAEAEDECECEDEBEDEBEDEBEDEDE9E9E6E8E7E5E4E1E2E3E2E5E4E5E1DFDCDD
D8D6D3D5D1D0D0CDCBC8C8C5C4C0C1C2C1BDB8B9B2B7B5ADACAAACABA9A8A6AAA6A7A6A3
A3A2A1A4A4A4A3A3A4A5A6A6AAA9A8A7A8A7A8A9ADADB1AEAEB3B3B5B5B8B6B8B9BAB6B9
BCB8B9BAB8BAB9BBBEBBB8B7B9B6B8B5B4B2B1B0AFACAAAAA7A5A5A6A1A19E9E9F9E9D9D
9C9B9A9A9A9797969A989696969495929492918F8F8F8E8C8E8D8E8E8C8F8E8B89898988
898686868584818181807E7E7E7C7D7A7A777876767573737270706F6D6E6D6B6C6C6C6B
6867666364646363615F5E5D5C595A5957565553515150514E4F4E4F4E4F48444240403F
3C373432302F2E2C2C2B2A2A292928282728272827272727272727262726272626262626
2626262626262626
262626262626262626262626262626272627262726262727272727272727272828282828
292929292A2B2C2D2C2E2F3132343538383B3C3F41434647494B4F51515355595B5D5D5F
616465656968696A6B6A6A6E6F71716F707276767678787A7A7C7B7C7F81818285828385
85838788898C8D8E8C8E91939494989A9E9D9D9C9F9FA2A1A4A6A4A7A7AAAAABAFB0B1B4
B1B4B4BAB7BDBCBDBCC0BEC0C1C4C6C5CBC9C5CCCECCCCD1CED2D5D2D5D4D7D7D8DADBDA
D8D8E1E1DFE0E1E1E3E3E6E3E4E7E7E6E8E7EAE7EBEBEAECEEEAE9EEE8E8EAEDEAEDEDEB
EBECEAECE8EBEDEBEAECEFECEEEEEEECEBE9E6E7E9E4E5E7E6E3E5E3E3E4E6E2E3E2E1E2
DEDDD9D5D7D4CFCFCEC8CBC5C8C7C4C1BEC0BBB9B8B8B5B4B3B0B0ACABAAA8A9A6AAA8A4
A4A4A5A6A1A4A2A3A5A5A5A9A8A5A6A9A7AAA9A8ACADACACADAFAFB1B7B4B6B7B8B7B6BA
B9B8BABABABBB9B9BAB8BAB9B8B9B6B7B5B1B5B0B0AEADADACAAA7A7A4A3A1A09F9E9F9B
9D9D9B9A9899989B9797969795959592919295919090908E8F8E8E8C8C8D8A8A8C888A89
87878585868483827F7F7F7E7D7C7D7D78777877767675737171706E6F6D6A6A6D6B6D6A
6968676564646362615F605E5D5B5B5957575453535051504F4F4E4E4F4C4A4441414040
3C383532302E2E2E2C2C2B2A292828282827272727272727262626272726262626262626
2626262626262626
262726262626262626262626262727272627272627272627262727272727282828282828
2929292A2A2B2B2C2D2E3030323436373A3B3D40414346484A4D4F4F535657595A5C5F5F
6163676767686A6C6B6D6E6E717373717374747577787B7B7B7C7C7B7C81818483848586
88868A8A8D8B8B8D8E92919395979A99999A9C9B9D9EA1A1A2A3A4A6A7A6A7A9ABACAFB1
B4B7B6B5B9B7BABABCBDBBBEC3C4C2C3C6C8CACBCACDCECDCFCFD0D1D0D2D7D4D7D6D8DB
DADEDEDCE0DDE2DCDFE2E2E5E6E6E6E5E8E9E9E7E8E6EAECE7E9E9E9ECEAEBF0EFECEAEA
EAECEBECE9EDECE9F1EDEDEFE9EFEDEFF1ECEBEBE6E6E7E7E8E8E7E4E7E7E8E6E8E1E6E0
DFDBDBD7D7D3D6D3CECFCEC9C8C9C7C4C6C1BEBEBBB8B8B8B2B3B0ADACABA9AAAAA9A9A8
A4A7A4A4A4A2A3A3A1A2A2A2A4A7A4A3A6A5A8A9A8AAAAAAACADB0B0B0B1B3B6B6B7B9B8
B8B6B9BABCB8BAB9B8B8B6B7B6B9B8BAB6B6B5B2B4B2ACACACACA6A6A6A2A3A0A19FA0A1
9E9D9F9C9A999A98979795979797959595929291918E8E8D8E8E8E8C898B8A898B8A8A87
87888686858385828380807C7D7C7E7B7C797878767575757272726F6E6C6C6C6D696D6A
696867656563656463605E5D5C5B5A59565554545452504F4F4F4D4D4A48474242413F3E
3E38353331302E2E2C2B2B2A292929282827272727272727272727272626262627262626
2626262626262626
262726262626262626262626262726272626272726272727272727272728272827282829
28292A2A2A2B2C2C2D2E2F30323336373B3B3D3F42434647494C4E50535456595B5E5F61
64656767686A6B6D6D6C706F707474737477767779797B797B7C7C7F7E81828584868688
8788888A8D8E8F8E918F939293939498999A9C9EA19EA0A0A2A2A6A5A8ABA7AAABABAEB0
B0B6B2B6BBB6BCBBBCBDBEBFC1C1C3C6C6C8C8CBC9C9CCCACDCFCECED0D1D1D1D5D3D6D9
DADBDEDFDEE0DFDDE3E4E5E8E4E6E7E7E7E7E9E2E6EBEAE6EDECEAECEAEBEBE8EAECEDE9
EBECEAEAE7EBEEE8EBECEDEEEFEDEDECEDE9EDEAECE9EAE9E8E7E8E8E8E7E8E9E7E4E4E6
E2DBDDD8D8D5D8D4D3D0CFCEC8C9C8C6C2C4C1BEBCBBBAB8B7B4B2B1AFB0ADACA9AAA9A8
A7A9A7A5A5A3A1A3A1A1A3A3A3A3A3A3A8A7A7A8A7A5A8ABABACABAFACB0B2B3B4B3B7B5
B4B6B6B6B6B7B8B9B8B6BAB6B8B9B7B8B8B6B5B7B4B1AFADABABABA9A8A6A5A3A1A09EA0
9F9E9D9E9D999899989899959494939494919293918E918F8E8D8C8C8B8B8A8A89888B89
898885878684818282817F7F7F7D7E7D7E7C79787975757572716F706F6D6C6A6B6D6C6A
68676765636464656361605C5D5B595A58565553525150504E4D4D4B4948474343423F3E
3E3B373331302F2E2D2C2B2A2A2929282828272728272627272726262626262626262626
2726262626262626
252626262626272726262626262626262726262627272727272727272727272828282829
2928292A2A2B2B2C2D2E3031323435373A3B3D40414445474A4D4F505355575A5B5E6162
62636768696C6E6F6F71707174757475787877797A7B7A7D7B7D7E7D7F80808481868787
898A898B8E8D8F8F8E93919193949597989B9A9D9F9E9FA0A2A2A5A4A5A8A7AAABACAEB0
B3B1B2B3B7B6BABBBEBDBFBFC1C2C3C5C7C8C8C8CCC7CBCDCACBCDCDD1D0D1D0D2D3D6D6
DCDADCDCDEDFDEE0E0E2E4E4E5E4E3E5E5E8E6E3EBE6EDEEE8ECEAF0EAEDEDEFEDECEDEC
EBEAEDE9EDE9EDEDEAEEEAEDECECEFEEECEBEBEAEAEAE4EAE8E8E9E6EAECE9E8E7E7E5E3
E3E0DFDDDBD7D7D3D7D2D3CFCDCBCBC7C6C4C2BFBFBCBBB7B7B5B3B0B4B0AFAEADADABAA
A9AAABA5A7A5A4A4A4A29EA2A4A0A4A1A3A2A3A3A7A6A7AAA9AAA9ABB0ADB0B3B3B2B4B4
B6B7B4B8B7B8B7B6B9B6B8B5B6B6B8B5B6B8B7B5B5B3B1B0AEABADA9ABA7A5A4A4A2A2A1
A19D9B9A9C9B9B9A9999979796959494939291918E8F91908C8D8D898B8B8B898A88888A
878485848483848382818280817F807D7D7C7C7A7976777473737170706E6D6D6B6C6B6B
69686666666466646262615D5D5B5A59575555545451504F4D4D4C4B4A4947454342403F
3E3A373331302E2D2C2C2B2A292929282827272727272727262627272626262726262626
2626262626262626
252626262626262626262626272627272626262727272727272727272727282828282828
2929292A2A2B2C2D2E2F2F30323435383A3B3D3F41434548494D4E515457585A5B5E5E62
6466676B6B6E6E72707170717276777578787D7B7C7B7D7D7D7E807F7E80818282868687
8A888B8B8B8F8F8D8E9092939295979498989A9C9D9FA2A1A3A1A4A4A4A6A7AAABACADAC
B1B2B2B3B6B8B6B9B9BEBDBFBBBEC2C2C4C4C4C5C7C9C9CACACCCBCCD2CFD0D1D1D7D3D8
D9D9DCDCDDE1E1E2DFE2E3E0E6E2E5E9E8E8E7E7EAE9EDE8E9E9EAECEDEAEFEBF0E9EDED
ECECE8EDE8EBEAEBECECEBEAECE8EFECEAECECEDEBE8E9E9E8E7ECE8EAEDEAECEFEAE5E4
E2E1DFE0DFDBD7D6D4D6D2D0CECECECAC7C7C4C4BEBEBCBBB9B8B5B4B4B4B3B0AFB0AEAB
AEABABA6A9A6A4A3A5A3A3A4A4A29FA2A3A6A5A8A5A5A7A9A7ABABA9ABADAEAEAFB1B3B7
B5B4B6B5B5BAB8B8B8B6B8B5B7B6B7B9B8B6B6B6B4B3B1B0B0AEADABA8A5A9A6A6A2A2A0
A09D9B9C9C9C9B9A9B979A9698969694959393909091908E8E8D8F8C8C8A8B8889898888
888686878485868282828280807E7F807E7D7D7B7A79777873747173716F6D6B6C6B6A69
696967676565646162605F5E5D5C5C59575654535352514F4D4D4B4B4A4747444442413E
3D3B383431302F2E2D2C2B2A292928282827272727272727262627272726262626262626
2626262626262626
262626262626262626262626262626272727262627272727272727272727272828282928
29292A2A2A2B2B2C2D2F3030323436373A3B3E40424446484A4C4F52535557595B5F6162
636667696C6D706F7171727576777879787A7B7B7D7D7C7E7F807F808080828381838687
8B888A8B8C8F8E8E90908F9392939595969697999C9EA19FA2A2A4A6A6A8A9A8ABABADAC
AEB0B1B1B4B6B6B7B9BBBBBCBDBFBFC3C4C5C2C6C4C7C8C8CACBCCD0CED0CFD1D2D3D5D3
D7D8D9DBDBDDDFE0E1E1E3E4E0E2E1E5E3E4E6E8E8E8E7E9E9EAEEEEEAECECEFEFEFECF0
EFE9EAE9ECECECECE7EBECEBEEEDECE9EDEDECE9EBEBEBEBE8E8EBECEBEAECEAECE9E7E6
E4E0E1DEDDDBDADAD8D4D7D2D0CFCDCBCBC5C4C4BEBEBEBCB9B9BAB9B4B5B2B2AFAEAFAE
ABACADABA9A7A7A9A3A4A4A6A4A1A4A3A4A1A4A4A6A4A5A6A7A7A7A8ABABACADB0B0B1B4
B5B4B6B3B4B3B4B9B6B3B6B8B6B8B6B8B9B7B7B3B2B5B4B1B2B0AFADAAAAAAA8A4A3A6A0
A09D9F9D9B9B9B9B9B9A9B999594959495949092919293908E8B8B8B8B898B88878B8A8A
87878885888487848381828381807F7F7E7D7B7B787A787674737171716E6F6D6C6A6B6B
6869686665646364635F605E5D5C5A59575655545352514E4C4D4B4A4A4746434342403F
3E3B383431302F2D2C2C2B2B2A2929282828282727272727262727272627272626262726
2626262626262627
262627272627262627262626262726272627272727272727272727272727272728282828
28292A2A2B2B2C2C2D2D2F3032343539393B3E3F424446484A4D4E50545559595D5F6063
6466686A6B6D6F707372757677767A7C7D7A7F7D7D7E807E828183818282848383858688
8B8A8B8C8B908E8E8F8E8F92929491959A989A9C9C9C9FA1A3A2A3A4A7A9A9A9A9ACABAE
AFADB0B2B1B5B5B5B6B8B9BCBDBBBCC1C1C1C1C5C6C6C7C8C9C7CCCDCCD0D1D5D4D1D3D6
D8D9DAD9DBDCDDDCE4E1DFE1E2E1E5E4E5E3E4E8E6E6EAE6E9E9E9EDEDECECF0EDEBEEF1
EEEDEAECEFECEAEAE9EBE9EBE9EBECECECEAECECECE9EBEBEBECEBE9ECEAEEE9ECEAE9E3
E5E4E3DEE0DCDCDBDAD8D4D3D3D2CECEC9C7C6C6C4BFBDBFBBBDBCBABBB7B5B4B3B2B1AE
AEAFACA9A9A5A8A4A8A5A6A2A1A2A1A2A3A3A5A3A2A2A4A7A4A7A3A7A9A9ABABABAEAFB3
B2B2B2B5B6B5B6B6B8B7B6B4B7B7B6B6B8B6BAB7B6B4B6B3B0B1AFACAAACAAAAA8A6A3A2
A2A19F9F9D9E9C9B9A99999998989897959391939191908F8F8D908E8D8B8B8A89888889
86888884858586858381818280807F7E7D7D7C7B797A78757675747271716F6C6C6C6A6A
6A6967676665666361605F5D5D5B5A5A575655545552514F4F4B4B4A494646444341403F
3E3B393632312F2E2D2C2B2A2A2929282828272727272727272627272626272726262626
2626262626262626
262626262626262726262726262727262626272627262727272727272727272828282929
29292A2A2B2B2B2D2D2E303032343738393B3E3F414246474B4C4F525455585A5B5F6062
6366686A6B6C717074737474777B7B7D7B7E7E7D7E7F8080838383808281838486868888
8A8B89898A8D8B8B8F8F93939491959898979A9A9DA09FA1A0A2A3A5A4A4A8A8AAABABB0
ADB1B0B3B3B2B2B4B8B7B9BBBDBDC0C2BEC1C1C2C5C4C5C6C6CACDCBC7CECFD2CFD4D0D4
D6D7D7DCDADBDCDCE2E0E2E6E2E6E3E7E3E4E7E2E7E8E8E8EAEAEAE9ECE9EDEDEEEDF0EF
EFEDEDEBECEBEFEAEAE9EBEDEAEBEAEDEBEAEDEAECEBEBE9EEEBE9EAEEE8E8EBEAE8EBE4
E7E5E5E4DFDEE0DBD9D9D9D9D7D3D1CFCFCBC8C8C7C5C4C0BEBEBDBBBABAB7B5B4B5AFB4
B1B1AEAFAAA8ACAAA8A9A8A7A5A4A3A2A4A2A3A3A4A2A5A4A4A6A6A4A6AAA8A8AAACB0AF
B0AFB2B3B5B2B4B2B6B7B6B3B6B7B7B8B4B7B5B5B4B4B4B5B3B4B0AFAFACACACA8AAA4A5
A5A2A29F9E9C9C9B9B9C98999A979693949393939190928F918E8F8E8B8C8A89888A8A87
88888685848686848384828381807F7D7B7B7B7B7B7A7977787575727170716E6D696969
676769666765656260605F5D5D5A5C5856575454535251504F4E4C4A494847464341403E
3D3B3A3633312F2E2D2C2C2A2A2929282827272728272827262626262627272626262626
2626262626262626
262727262626262726262626262726262727272627272727272727272727272828282828
29292A2A2B2B2C2D2D2E2F3032343638393B3D3E404344474A4D4E4F5455585A5B5D6063
6465686A6C6F6F7071737877797B7C7D807E7E7F7F80818482838384848385858A898889
8C8C8B8B8A8B8D8D8F92919193949696979799989A9C9F9EA0A2A4A7A6A9A7A8A8A9ACAC
AEAEAFB1B3B1B2B1B4B4B4B8BABDBCC0C0C1C0C4C5C1C7C4C7CCC8C9CCCACCCECED2D1D4
D6D5D7D8DADDDCDCE0DFDFDFE2E4E3E6E6E4E7E5E9E4EAE9E8E6EBE9ECEBECF0ECECEEEC
EEECEDECEEEEEEEAE9ECE9EAE8EBEBECECEBECECEDEBEFE9EAE8ECEAEAEBEBEDEAEEECEC
E9E5E5E1E5E5E1E0DED9DAD6D8D6D6D3CFCFCDCEC8C7C6C2C2C0BFC0BDBBB8B9B7B7B5B2
B3AFB2AFABACAEABA9ABA8A7A7A5A5A1A3A3A09DA0A3A2A4A1A5A6A6A5A9A7A7ABAAABAB
AEAFAFB2B0B2B1B4B6B5B4B4B5B5B7B7BAB9B5B6B6B6B2B2B5B4B4B0B3ADB0ABADABA7A6
A7A5A6A3A19F9C9B9899989A9696969495949393939392918D8E8E8D8B8C8B8989888787
87878585858684838485838181807E7D7C7E7A7B7B7A7978777575737272716F6D6C6A6A
6A6769676763656160605E5D5D5B5B58585655545452504F4E4F4C4A494746454441403F
3F3C3A3633312F2E2D2C2B2B2A2929292828282827272727272727272727272626262626
2626262626262626
262626262626272626262626272627272727272726272727272727272727272828282829
29292A2A2A2B2C2C2E2E303132343638393C3D3F424245484A4B4F525355575A5D5E6262
646768686A6F6F7172757477787A7C807F807F807F828183848684858785878989898A8D
8D8D8C8E8D8F908E8F91939496949796989A979B9C9D9C9EA1A3A2A6A6A7A7A6A8AAADAB
ACADAEB0AEB2B1B2B3B4B9B5B8BCBBBCBFC0BFC2C1C2C1C4C8C6C6C7C4CAC7CCCDD2D4D4
D5D4D4D5D7DBDCDDDCDDDEE2E5E2E3E5E5E5E7E4E7E7E7E7EBE7E9E7E9ECF0EDECEDECEF
E9EEEFEDF1EFF0EBEDECEBEAECEEECECECEDEEEBECEAECECEBEBEDECECECE6EAEDEAEEEC
E9E9E3E7E7E0E1E0DDE0DBDBD9D7D9D2D1D1CCCDCCC8C9C7C1C3C2C2BCBFBBBAB8B9B8B4
B6B1B3AFB0AEADACABAAA9A7A5A6A5A4A4A2A0A0A2A2A2A0A2A2A4A7A6A8A5A8ABA9AAAF
ACAFB0B1B0B3B2B1B7B4B5B6B7B7B7B6B9B9B5B6B5B7B6B4B0B5B0B2B2B0AFAEAEABAAA5
A8A8A4A4A0A2A09E9D999B989A989599959496919292919190908F8D8C8B8C8B8A8B8888
8786878687848585838483838280827E7E7E7B7B7C7B7B7977787573747471716E6B6A69
686768666564636260605E5E5C5B5A595657565552535151514D4D4A4A47454444434240
3E3C3B3833312F2D2D2C2B2B2A2A29292928282827272627262727262726262626262626
2626262626262626
262626262626262626262626262626262726272726262727272727272727272728282828
29292A2A2B2B2C2D2C2E303033343637393C3E3E41434648494C4D50525557595C5D5F62
6367686A6B6E6F727474787678797E7E8180808184848485888986868787888A8A8C8B8D
8C8B8F8D8F9294928F94939494959599989A98979D9C9C9EA0A0A4A5A5A8A6A8ABA8A8AC
ADABADAFB0B0B3B4B3B3B3B5B6B8BCBCBBBFBFBEC1C2C1C6C6C6C5C5C6C4C8C8CACED1D0
D4D3D9D6DBD9DCDCDBDEE1E2E1E4E4E6E5E3E6E4E5E4E5E8E8EAE6E9E8EBE8EBEDEBEEE8
EEEEEEEEEEF0EDEDECE9ECEAEAECEBEBECECEEEEEAECEBECEDEFEAEBEBEAEDEEEBE8E9E9
E8ECEBE7E4E2E3E3DFDEDFDFDEDBD8D6D6D3D1CFD0C9C8C8C6C4C5C2C2C2BFBBBEBDBCB8
B7B6B4B1AFAEB0AFACAEAAA9A9A9AAA6A6A1A4A3A2A1A0A1A2A1A4A5A5A3A4A4A6A3A7A8
AAADAEACB0B0B2B3B3B1B2B4B2B3B3B5B5B5B7B6B5B5B6B6B5B5B3B1B2B3B3B2B0B0ABA9
AAA6A8A6A5A0A19E9F9B9A99999799959796969493929191908F8D8D8D8C8B8B8C898789
898686888586848383828383828181807F7F7D7C7C7B7A7977767575737370706F6D6D6B
6B6964666663626261605E5E5C5A5B5A59585555535151504E4E4C4B4A4846434443413F
3F3D3A373431302F2D2D2C2B2A2A29282829282827272727272627272727272726262626
2626262626262626
252626272626262626262627262726262726272727272627272727272727272828282829
28292A2A2A2B2C2D2D2E303133343638393A3C4041424546484A4D50535557585B5D6061
646567686C6C6E70737479787B7C7C7F7E80838484858687898887868884898D8C8E8B8D
8A8E8C90949492949494949393939696979998999A9B9F9E9F9FA2A4A5A5A6A7A6A8A9AB
ABADADAFB0AEAEB1B1B5B4B5B6B8BBB9BCBCBEC0C1C0C4C1C4C6C3C4C3C6C4CAC8CBCFD0
D2D2D3D3D5D9D8DADCDFE0DFE0E1E5E5E4E4E5E8E1E6E8E6EAE9EAE8ECE8ECEDEEECEDEF
EDECEDECECF0F1ECEFECEDECEEEAECEBEBEBEBECEDECEDECECF0E8EBEEECEDEDEEEAEDEA
EBEBEBE7E9E6E3E3E5DDE3DDE0DDD8D7D3D2D5D2CFCCCBCAC6C8C8C7C6C2BEBEBEBCBDBC
B9B9B5B3B2B1AFAFAEAAAAABAAA7A8A7A6A5A4A1A1A19FA1A0A0A1A2A0A1A5A7A5A4A6A8
A7AEABACADACB0B0B1B0B2AFAEB2B3B3B4B5B1B6B7B3B7B3B6B3B4B3B3B1B5B0B0AEAEAA
A8A9A8A5A5A3A2A09E9D9B999B999A97969796949493929290918F8F8D8B8C8C8A8B8C8A
878784848485838584808483807F828080807C7E7C7A7A797876757674727371716E6E6C
69686766656463615F5F5F5E5C5C5C5A58585754545351504F4C4D4B4A4848454343403F
3E3C3B373431302E2E2D2C2B2B2A29292928282727272727272727272726262626262626
2626262626262626
262626262626262627262626262627262627272627272727272727272727282828282828
29292A292A2B2C2C2D2E3031333435383A3C3D3E40424547474C4C5052545758595C5E61
6467696A6C6C6E71727677767A7C7C7E82808485868886898A8A8888888C8A8D8E8C8B8D
8B8B9091929394939392949395949497999A989A9D9B9C9EA1A09E9FA4A4A5A6A6A7A7AA
ACABAEABABB1B0B1B0B1B6B5B3B6B6BAB9BCBFBDC2BEBFC5C2C4C2C4C5C5C7C7CACACDCE
CDCCD0D3D2D7D6DAD9DDDDDFDFE1DFE1E3E3E5E5E7E6E6E8E7E7E8E7E7E8EAE9ECEEEBED
EAE9EBEEEDECECECF0EFF0ECEDEAEAEDECE9E7EDEEEEEBEFEFECEEEBEAE9ECECECEDECE9
E7E6E7E8E7E4E6E3E0E0E0DFDEDEDADAD9D7D9D4D1D0CECCCCCBC6C5C7C7C3C2C2BFBEBD
BDB8B6B4B4B0B4AFAFAFADABAAA8A9A6A7A3A2A1A0A3A09FA0A2A0A3A1A1A3A3A2A5A6A5
A8A6AAA9ABABADADAEADAFB0AEB3B3B1B3B2B4B8B4B1B4B3B3B2B3B4B4B4B3B3B2B1B0AD
AEABA7A7A7A7A2A1A09D9C9C9B99999A97969793969493929292908F8D8C8B8C8C8A8988
8888888587868584848085828480807F7F807E7D7C7A7A7979787876757370726F6F6E6B
69696869666462625F5F605D5D5B5B5958565654545352514E4E4D4B494745454442403E
3D3D3B393532302E2E2C2B2B2A2A29292928282728272727272726272726272726262626
2626262626262626
262726262626262626272626272726262726262627272727272727272727282728282829
29292A2A2A2B2C2D2E2F2F3233353536383C3C3E3F414646484A4D4F525355585A5B5E63
636666686B6C707175727678787B7E7F8083868586888B8A8C8B888A878A8C8C8F8D8F8E
908E908E9595939494939496989595979B9B9A9A9C9B9A9C9C9BA1A0A4A4A4A6A7A8A7A8
A9ABACABADADAEB0B0B1B2B7B3B6B2B8B9B7BCBEBFBEBFC0C2C5C4C5C8C5CAC7C7C1CBCD
D0CACFCFD1D2D7D6DADADBE0DFDCE0DFE1E4E2E4E7E9E9E6E5E8E8E9E7EAE7E9EBE7ECEF
ECEEEEEBECE9ECEFF3E9F0F0EAEAEEF0EEEEEAEAEEE9EEEEF0ECE9EBE9EBEAEBEEF0EFE9
EAE7E9E9E4E4E7E7E3DEE0DFE1DEDDDBD9D8D5D6D6D4CBCFCDCDCCCBC7C6C5C5C3C2C2C1
C0BABBB9B8B8B5B2B3AEAFAAAAA8AAA7A6A4A6A3A5A2A3A09FA2A2A1A3A1A1A0A2A5A4A2
A2A4A7A8A8ABA8ABAFADAFAEB1B0B2B3B0B4B3B2B6B2B2B5B6B4B4B4B2B3B4B4B4B0AEAD
ADAEACA9A6A5A3A3A4A09E9E9C99999A9797979594939291908E908F8E8F8D8B8B8A8988
888B878585838586818382818183817E817E7F7D7C7A7A77797878757473756F706F6E6D
6A6A6A686665636262615E5E5D5C5A5B5858585554535150514D4D4B4949484544434040
3E3C3A383532302E2E2D2C2B2A2A29292828282827272727272726262627272726262627
2626272626262626
262626262626262626262626262626262726272626272627272727272728282828282928
2929292A2A2B2C2C2E2E303233343538393B3C3F4143454648484B4E51545455595B5D5F
626465676B6C6F717374767A7A7D7D7D808285858689878A8C8B8B8A8A8E8C8F9190908F
908D9293949492959495969496979595999B9E9B9A9B9A9D9D9D9EA3A2A3A4A5A7A5A7A8
ABACACABADAEAEB1B0B4B4B3B3B6B2B2B6BABABCBEBDC0C0C1C4C5C6C9C8C9C3C8BBCBCB
CDCFD1D0D3D2D2D3D8D7DBDDDEDFE0E3E0E3E0E5E5E3E4E8E6E3E8E6E7EAEAE8E8EBECEB
EFECECE8EAECEFEFEEEDECECEBEEEDF0ECECEDEFEDEFEDEEEDECEDE6ECE8ECEEECEEEAE9
EDE8E7E4EAE8E8E3E7E2E0E3E3DEE2DFDEDCDBD8D7D7D3D0D2CDCECCCDCACAC6C3C3C4C1
C1BFBCBAB8B8B5B3B1AFADAFACAAA8ABAAA6A5A5A5A3A39EA2A09EA09FA0A1A2A1A0A3A1
A4A4A3A7A5A6AAAAABABAFB0B0ADB0AFB0B1B3B3B2B2B3B4B3B2B3B3B3B2B2B1B3B4AFAF
ADADAAABA7A7A8A4A3A6A2A0A19B9C9A979898939595929293919290908E8D898C8A898B
8B8A868685868583828283818183817F817F7F7D7E7B7A7A7B78797775737372726E6E6D
6D6B6A6766656463605F605F5C5D5B5A58585756545252514F4E4D4B4B4947474443423F
3E3C3C393633302F2E2D2C2B2B2A29292828282827272727272727272626272626262626
2626262626262627
262626262626262626262626262626262727272726272727272727272727272827282928
29292B2A2A2C2B2D2E2E2F3133343537393A3E3E4043424648494C4E50515356575B5C60
626465686B6B6F727277787879797E7C7F818384858785898C8C8C8C8D8F91908F92908F
8F8E909294939593959593979896979798989C9B9C9C9C9E9FA0A1A0A2A2A3A2A5A5A6A9
ABACAAADB0ABACAFB0B1B3B2B5B2B2B5B7B8BCBBBCC0BDC0C1C2C5C7C7C4C5C6C7C4CACA
CDCACBCCD1D0D3D5D3D5DBDADBDCDDDDE2E0E0E4E3E5E3E7E7E5E8E7E6E8EBE7E7E9ECEA
E9F0EFEEF0ECEAEDF1EDF0EEEDEBECEEEDEEECEFEEECE9ECEBEAECEAEAEDEAEDEFEEECEC
EAE9E9E6E5E8E6E7E4E6E2E2E0E3E5E0DFDED9DBDAD6D5D1D0CFCFCDCCCCC9C9C7C6C7C3
C4C1BFBDBEB8B6B5B4B1B0ACAFACAAAAA9AAABA7A9A4A2A2A39FA1A2A0A2A09FA1A0A1A3
A3A4A4A3A4A5A6A6A8A7ABB0ADAFAFAFACB1B0B3B3B2B5B2B4B4B3B3B2B2B3B0B3AEB3B0
AFAEAEAAA9A7A8A5A5A3A39F9E9E9B9C9B99999796949593908F938F8E8C8D8B8D8A8C87
8B88888784848584818382828182807F7E817D7E7D7B7B787A78777576747472716F716E
6E6C6A6B676665636360605E5D5C5B5A59575754555352504F4E4C4C4A4848464443413F
3E3C3B393633312E2D2D2B2B2A2A29292828282827272727272727272727262727262626
2626262626262626
262626262626262626262626272626272726272727272727272727272727272828282828
2929292A2B2B2C2D2D2E2F3133343538393B3D3E3F414244474A4C4E4F50525657595B5D
606365686A6C6E7073757776797B7C818181828485878A888B8C8E8F8F90919293949193
939292949595949594969796959999989A999B9E9C9CA09F9E9D9E9EA0A1A2A2A4A5A6A6
A9A8ABAEADACADAFAEB1B1B3B1B4B5B6B7B6BABBBBB7C0BFC2C0C4C3C4C5C6C4C5C5C5C8
C9C9CBCFD1CCD0D0D5D5D7D7DDDBDADCDFE3E1DFE5E2E4E4E6E6E7EAE6E7E9E7EAECEBEA
EAEBEAEBEDEEECEDEDEFECEFEBEAEFEFEFEDEAECEBE9EAEBEFECECEBEEEEEFEAECEBEAEA
EAEAEAEAE9E9E7E6E4E6E4E3E7E4E2E2E2E1E0DBDBD8D6D5D9D4CFCCCDCACCCCCBCCCCCA
C8C5C1C1C0BDBCBAB6B4B4AEADAFAEACAAABA9A6A7A4A4A3A2A2A2A09FA1A09FA09FA0A2
A1A1A2A1A4A1A4A3A5A6A7AAAAAAAEADADB0B0B0B0B2B0B3B2B2B3B3B1B0AEADB0B1B0B0
B3B1B0ACADACA9A6A3A2A3A2A0A09D9F9B999699959493949191918F918F8F8D8C8C8B89
8B8889898884868486858281817F80807F7C7D7D7D7B7A797B7A7877777675747372706E
6D6C6B69696767656362605E5D5D5A595857575555545152504F4E4B4A4A474645424040
3E3C3A393734312F2E2D2C2B2A2A29292928272727272727272626272726262626262626
2626272626262626
262626262626262626262726272627272727272726272727272727272727272827282828
29292A2A2B2C2C2D2D2F2F3133343638393A3C3E4043434546494B4E4E515354555A5B5D
61616466686B6D6F717476797A7A7D7E8182848487878A8A8D8F8F949093929294959394
9294939898979897979896989A97979A9B98999C9C9E9A9E9F9EA19EA09EA0A2A5A4A4A5
A7A7AAABABAFADB0B0B0B3B1B4B5B5B6B5B6BBB8BABCBBBDBDBCBFC0BEC3C5C1C5C4C6C7
C7C9C8CBCDCCCFD2D3D6D4D3D9DCDCDCDCDEE5DDDFE0E1E5E4E3E7E6EAE6E7E9E8EAE9ED
EEEBECE9EDEBECEEECEDEEEFEEF0EEECF0EBEAEAEBEEEAE9E9EEECEBEDEEEDEDEEEDE9EB
EBECECECECE9EBE9E8E5E4E7E4E7E0E3E1E2E1E1DCDBDBD8D3D7D2CFD0CFD1CECBCDD0CE
CBCACBC5C3BFBDBDBCB7B4B2AFB1AEAEABA9ABA8A8A8A6A5A6A5A2A19FA0A1A19EA09EA0
A19F9F9FA1A2A2A4A5A6A5A6ABABADADABADADACAEAFB4B1B3AFB1B1B1B2B2B0AEAFB0AF
AEAFB1AFADAAA7A9A7A4A2A2A2A2A09E9D9B9A9797949591938F92918F8E8F8E8C8D8E8A
898D8787878684848785838281807F7E80807C7B7A7A7B797A7A7979777674747471706E
6C6B686968686766646361605F5D5B5A5A595854555352504F4D4C4C4B4948464542413F
3E3D3A39373332302E2D2C2B2B2A29292828282727272727272726272626272626262626
2626262626272626
252626262626262626262626262626262627262727272627262627272728282828282928
2929292A2A2B2C2D2D2F303133353537393B3C3F4042444647494B4D5051525358575A5C
5E606166676A6B7072747675787A7D7F7F8384868886898A8C8E91919192919395959695
989797999A989997979798999A9B9D999C9B9A9A9E9E9D9D9FA09E9EA19FA2A1A3A6A5A5
A7A5ACACADACB0AEAFB2B1B6B4B6B5B4B9B8B8B9BBB9B9BABBBAC0C0C1C3C6C4C5C1C4C6
CAC7CCCACCD0CDCFCECED4D1D6D7DAD8DCDAE1DEE1E1E1E5E6E6E7E4E5E6E5E8E9E6E6E7
E8EAEAEBEEEBEEECEFEFF1F3EEEEF0ECECEEEEECECEDEFEEEDEDEEEDEEEDEEEDEEEAEBEB
EBECEDEDEBEBE9E7E8E6E9E6E9E6E8E6E5E4E2E1E1DBE0D9D4D2D3D1D3D0D0D2D3D2D4D1
D1D0D0C9C6C4C5C0BEBABAB7B3B1B0ADAEACACABA7A6A6A5A7A3A5A2A5A2A39EA29F9FA0
9EA09FA09EA1A2A1A5A2A6A4A5A9ADABADAEACABAFB2AEAEAFB0B0B1B0B3B2AFADB0ACAE
B0B1AEAEACABABABA9A6A4A5A6A3A1A19E9B9B999797959495929193908D8B8D8D8C8A8B
8C888A8789888785838585857F837F7E7F7D7D7B7B7B7A7A78787778767774747472706F
6D6C6C6A69686865656362635E5D5A59595857565452524F504E4D4C4C4A484644444240
3E3C3B39363431302E2D2C2B2B2A29292928272827272727272727272726262626272627
2626262626262626
262726262626262626262626262726272727272727272727272727272727272828282828
29292A2A2B2B2C2D2D2E303133343637393B3D3E3F434444464A4A4C4F4F51545558595C
5D61626367686B6F7172757476797D7F7F848584858889898B8E9091909093959698989A
999A979C9999979A999B9B989A9B9B9B9C9C9B9B9B9C9D9D9EA1A0A1A0A2A2A3A4A3A5A7
A7A9ABABABADADB0AFB1B4B6B5B3B5B5B7B4B6B7B6B9B9BAB9BBBBBCBDC2C2C2C4C1C0C5
C5C6C7C9CECDCECBCECFCED2D5D3D5D9D9D9DBDEE1E3DDE2E4E5E8E8E8E7E8E7EAE6EAE7
E9E8F0ECEBE9F0E9F0F0EEF2EFF1F2EFEFEDF1EFEDEDECF0ECEEEAEEEDEBEFEEECECEDEB
EBF0EEEBEAEAE8EAE8ECEAE4E9E7E3E5E4E5E3DFE0DDDEDBD8D7D3D3D5D3D6D2D4DAD8D7
D5D4D2D1CCCAC4C4C0C0BCB8B6B7B4B0B0AFAFAFA8AAA7AAA7A6A7A5A5A4A2A3A2A09FA1
A09D9EA0A1A0A0A0A1A5A3A1A5A7A8A7AAAAADABACACACACAFADB0AFAEB1ADAFAFAFAFB0
AFB0B1AFB0ADACABAAA9A6A3A2A4A19FA29A9D9998989892949391939090908E8D8D8C8A
8B8C888986868687858482828180807F7E7D7E7B7B7A79797A7776767878767573727270
6D6E6C696A6767666663625F5F5D5D5A5A59575653535150504D4C4B4A4947454543423F
3F3C3C39373432302E2D2C2C2B2B2A292828282727272727272727262726262726272626
2626262626262626
262626262626262626262627272626262727272727262726272727272727272827282829
29292A2A2B2B2C2C2D2E303233343537393A3D3E4043434547474A4B4E5051545557585B
5D5F626366696A6D6F72737576787C7D808282858785888B8C8E908F9192939396969898
9B9B9C9B9C9C9B999D9B999B9B9B9D9C9A9C9D9E9F9D9F9EA09FA1A1A1A3A2A2A4A7A5A7
A4A7A6ABAAABAFB1B1B3B3B2B0B2B5B3B3B6B6B8B7B7B8B6B9B7BBBCBDBCC2C2C2C2C5C4
C5C7C9C8C9CBCDC9CDD2D2D1D4D3D7D3D6D7DADBDDDDE0E0E1E1E6E8E5E7E8EBE7E5E8EA
E9EAEAEAEEEEEBEDF0EFEEEEEFECF2F0EDF0EFF0EBEEEDEFEBF0F0ECEBEDEDF1EAEEEFEC
EFEAEFEEEBEBE9E7E9EAEAEBEDEBE6E7E8E9E8E6E8E4E1DDE0D9D8D7D5D4D6D6DAD7DBD9
D7D7D8D5D3D0CBC7C4C2BEBDBBB7B3B1B1B1AEACABA8ABA9A9A7A7A9A5A3A2A3A1A0A0A1
A0A0A19F9DA09F9EA2A0A2A4A5A4A5A8A3A9A9ABAAACACACADB1ADB0AEB0B0ADB1ADACAF
AEAFAFB0AEABAEAEA9AAA6A5A3A3A4A3A09D9C9C999A959794949592918F8E908F8C8D8B
8C8A8A8A8A898886868583838180807B7E7D7E7C79797878797879787775767575727272
6F6D6C6A6B696866656361615F5E5D5D5B59595554545251504F4C4B4B4847464544413F
3E3E3B393734322F2E2D2C2C2B2A29292929282727282727272727272727272626262627
2626262626262626
262626262626262627262626262627262726262727272726272727272727272828282828
29292A2A2B2B2B2D2D2F303133343537393A3C3D4042434545484A4D4E4F535356575A5B
5C5C60616467696A6D70747578787C7E7F818381848787898D8E8F909191929595989798
9A9B9A999D9D9E9D9B999D9C9C9C9C9C9E9C9D9D9E9F9E9FA1A3A0A5A2A4A4A2A5A5A4A5
A6A6AAA6A9ACADAEAFAFAFAFB2B0AFB2B4B2B7B9B7B5B7B8B8B7BABABEBEBEC2C2C4C4C6
C7C3C5C6C9CBCCCECFCCCFCFD1CFD1D3D4D5D6D7D8DEE0E2DEE2E0E3E6E7E5E3E8E8E8E7
EBE9EDECECEBEFECECF0ECEDEEEFEEEEF0EDF1EDEBF1F0EDEEEDEDEBEEEEEFEEECEDEEE9
EEEEEEEEEAEBEBEBECEEEBEBEAEBEDE9EAE8EBE6E5E4E7E1DFDDDBD9D7D9DBD7DCDDDDDF
DDDCDDD9D6D2D1C8C8C4C6C1BFBBB8B7B6B2AFAFAEADABA9AAA7A8A6A6A4A4A3A5A0A2A4
A2A0A1A19FA29E9F9FA1A29FA2A0A3A2A4A3A9A9A7AAAAACAEACAEACB0B0ADADB0AFAFAF
ADAEAFADADABADACAAAAA6A7A7A5A5A6A0A19F9B9C999A9995959491928E8F8F8F8E8B8A
8B8A8A87888787888585828481828180807E7C7C7C7B777A79787778787875767473726F
6F6F6C6B6A6968666465626160605E5D5B5A5956545351504F4D4D4C4A49484745434040
3F3C3B39373532302E2E2C2C2B2A2A292828282827272727272727272626262626262626
2726262626262627
262726262626262726262626262726262726262727272727272727272727272828282829
2929292A2A2B2C2C2D2D303233343637383A3B3E3F42434546494B4D4E51525455575859
5B5E5E616366676A706E7074787A7C7C7E827F828887888A898D8E91909394959495989A
999B9D9D9B9B9C9E9C9D9C9B9F9E9D9FA19C9FA09E9E9F9F9FA1A1A2A2A2A3A1A1A5A6A4
A5A9A7A7A8AAAEAEAFB0B0AFAFAFB0B2B4B3B7B8B6B9BDB6B8BABDBBBEBEC1C1C0C4C7C6
C2C2C5C8CACBC8CACCC9CDCBD0CFD2D5D5D5D3D6D9D9DDDEE0E2E3E2E5E4E4E7E8EAE8E8
E8E9E8EAEAEBEDECECEDECEDEFF0ECEFEFEBEDEDEDEFF1F0EEEEEDEDEEEBF1EBEFEFF0EC
EAECEFEDEBE9EBEAECEDEAECEDECEBECEBEBEEEBEAE8E9E6E2E1E0DFDFDDDBDDDDDDDEDC
DFDEDFDCD9D7D3D2CCCBC7C7C0C1BFB9B8B6B6B3AFABADABABAAAAA7A7A7A7A5A5A2A3A1
A2A1A09FA09F9F9F9EA0A1A0A1A0A0A1A3A5A6A6A9AAACABAAABADAAAEAEAEADAEADB0AF
B1ABAEB0B0AFADADABA9A9A8A8A6A7A7A5A2A19F9D9B9A989897939292928F91918C8C8D
8B878B8A888988858685858282838080817F7D7E7B797976787779757676747474737270
706D6B6B6B69676565646362605D5F5D5A585858565352514F4D4D4B4B48474644424240
3F3D3A38373432302F2E2C2C2B2A29292928282728272727272727272627262726262626
2626262626272626
262626262626262626262626262627262727262627272727272727272727272828282828
2929292A2A2B2B2D2E2F303133353536383A3C3D3F42424546494B4B4D4E52525556575A
5B5F5F61636567686C6F737476777B7C7C7F7F8384858687898B9090909294949697989A
9C9C9A9C9C9E9F9FA09EA09D9EA0A19EA0A0A29FA09FA2A1A3A2A0A1A2A4A4A3A4A5A6A7
A9A5A7AAA8ABACADADA9AEADB1B0ADAFB2B1B6B4B9B8BABABABABBBCBBC0BEBFC4C3C4C4
C1C5C2C8C7C7C8CBC9CFCACDCCD1D2D1D2D2D3D2D2DADADFDFDEDFDFE3E2E5E4E4E3E9E9
E6E9E8EBE8EBEDEEEBECEBEEEEEDEFF0EFEFF1ECEDEDF2EDF1EEECEAEBEAEEEAEEECEFEE
EFEEEDECEDEEECEEECEBECE8EEE9EBEDEEEDECECE9E9E8E8E4E4E3E4E3DEDDDCDFDFDFDF
DFDFDFDBDEDAD9D7D6CECCC6C7C1BFBFBDB9B7B5AFB0ADABABACAAA9ABA7A8A6A3A3A3A3
A3A2A2A09E9FA1A09F9EA09F9FA09EA3A1A2A3A4A4A8A6AAAAACAAADACABACACAEB0ADAE
B0AFB0ABB0AFADACA9ABAAA8ABA9A7A5A6A5A1A2A09E9D9999969596929090918C8D8D8D
8B8A888B8A88878785878484838183828080807E7C7A7A78777777767776757572737170
6F6F6D6C6A6A696768656462605E5E5C5C5B585856525351504F4D4C4B4A48484543433F
3E3D3A39363431302F2E2C2B2B2A29292828282727272727272727272726272626262726
2626262626262627
262626262626262727262626262626262626262726262727272727272727282827282929
29292A2A2B2B2C2D2D2E30313233363638393B3D4042434445494B4C4E4D4F5153555858
5A5C5C616364666A6C6C6F737578797A7B7E808286888887898B8D91918F93959797979B
989A9B9BA1A1A0A0A1A2A09FA29F9EA0A1A0A2A0A2A2A2A29EA1A2A2A3A5A4A3A5A7A4A7
A8A7AAAAA7AAABABAFADADB1B0AFB0B0B4B4B6B8B9BABEB8B6BBBABABABEBCC0BDC3C0C1
C2C6C3C4C5CAC8CBCACACCCACBCCCED0D2D2D4D6D5D6D9DADEDADEDEDFE3E8E4E4E7E5E7
E8E8EAEAEDEAECEDEDECECECEDF0F3F1F2F0EFEEF1EFEDEDEEEFEDEDEBEDECF0F0EDEAEC
EFEFECECECECEFECEEEDEFEDEEF1EFEBECECEEEDEBE6EAEAEAE7E8E7E4E6E1DEE0E0E0E2
E4E3E3E0DFE0D8DCDAD4D2CFCCC8C4C4C1BDBBB9B5B4B0ADADACAAABA9A8A7A5A6A3A4A4
A5A3A2A1A19F9F9DA09E9D9D9F9E9F9FA19FA5A1A2A7A7A7A7A7ABA8ACABAAACAEABAEAE
ADADAFABAEACADACADAAADABABA9ACAAA6A5A4A39FA09E9B9A97989593938F938F8E8E8B
8B8C8989898989868685858583878384837E7E7D7C7B7A77797776757674757473717373
706F6F6E6D6A686866656463615F5D5D5A59585656545452504F4E4D4A4948474444433F
3E3C3A38373532302F2D2C2C2B2A2A2A2928282827282727272727272627262626272626
2626262626262626
262626262626262626262726262626272626262727272726272727272727272827272829
29292A2A2A2B2C2B2D2E30313234353638393C3C3F40434546474B4B4D4E505355555759
5B5D5F61636266686B6D7071757678797A7D7E808387878987898B8B8F91959697979A99
9A9A9C9C9F9FA0A1A0A2A0A4A1A2A1A1A1A1A6A2A4A2A4A0A2A3A2A2A5A5A6A6A4A7A8A9
A9A6A9AAA7AAA9A9AAADAEACAEADAFB0B2B4B5B5B9B9BDB7BDBABBBABDBCBEBFBEC0C2C2
C1C5C5C4C6C5CACACAC8C8C9CCCAD0D2D0D2D5D1D2D5D5D6D9D7DBDCDCE2E4E3E2E5E5E5
E7E7E7E6EBEBEDECECEDEBEEEEECF4EFF1EEEFF1EEF2F0F0EDEFF0F0EAEFEDEDF1EFECEF
EFEFECF0EEEDEEF1EDEFEEEDEDEDF1F4EEEEEEEEEDEAECEAF3EDEEEDEBE6E4E2E2DEE0E1
E3DFE3E2E1DFE0DADAD8D4D3CFCBC7CAC5C2BDBDB8B4B3B1AEAEAEAAA8A9ABAAA6A5A4A4
A4A3A1A2A19EA0A09F9A9D9D9D9E9D9DA09F9DA1A0A3A3A6A6A7A8A5A6A8AAACACABACAB
ACADAEABACAEAAADAAAAAAABACACAAAAA9A9A3A4A3A2A09D9D99979696959592908F8E8C
8D8B89898988888686828686868485848080827E7D7B7A7A7A7975767475757375727273
70706F6D6C6A6A676665636361605F5E5B5A585856555352504F4E4C4C4B484745434140
3E3D3B39373532302E2E2D2B2B2A2A292828282828272727272727262626272726272726
2626262626262626
262626262627262626262626272626272627272727262727272727272727272827282829
2829292A2A2B2C2D2D2E303132343637383B3B3D3F4042454548494C4D4F515155575858
595C5D5F626366676A6A6D7172757579797D7F7F84838587898B8B8C909094959796999A
999C9C9DA0A1A1A1A1A3A4A3A2A3A4A5A5A3A3A4A4A2A5A1A6A4A3A6A4A4A5A7A5A9A7A6
A7A9A8A7A9ACAAABAAAAABADAEAFB0B1B1B2B4B3B6B6B9BBBCBCBCBABABDBABDBEBFC2C2
C2C3C5C5C7C3C8CAC8C8CACCC9CCCCCFCCCECECFD0D2D5D7D4D8DBD8DADCE0E0E5E3E4E7
E6E5E8EAEBEDEBEEE9ECEEEEEDF1F2EFF0F1EDEDEEEEF0F0F1F0EEECEFEFF1F1F0EDF0EF
EEEEEEF1F0EFEAECEDF2ECF0F0ECF0EFF0EFF2EEEDEDEDEDEFF1F2EDEBE9E9E5E3E4E2E2
E6E5E3E1E2E1E0DFDBDDDBD9D6D1CECAC9C4C4C0BBBAB6B5B2B1B0AFACA9A9AAA9A8A8A9
A4A4A4A1A1A1A19FA19E9D9B9C9D9D9D9D9D9F9EA1A1A2A3A4A3A6A7A7A8A8AAA9ABACAB
ADADAFAFAEABACACAAACADACABAEACA9A9A8A8A5A4A2A19F9D9A979796949492918F8E8E
8C8C8C8A888987858885838584828383827F7E7E7C7C7C7B7A7876757675767573737470
726F716E6C6B69696764636262605F5E5B5A595757575553514F4E4D4C4948464642403F
3E3D3938363533312F2E2D2B2B2A2A292828282827272727262727272626272627262627
2626262626262626
262626272626262627262626272726262627262626262727272727272728272828282828
292929292A2B2C2C2D2E303133343637383A3B3D3E4041454648494C4C4D4F5152555759
585B5F6061626567676B6D7070747777777A7F7E8083848587898C8C8F8F909295979898
98989B9F9E9EA1A0A2A2A3A5A5A4A7A3A4A6A5A1A4A6A7A6A6A5A6A4A6A4A8A7A8A8A8AA
A6A7A9AAA9ACAAAAACA9AEACACAFAFADB2B1B3B2B5B8B8BABABABEBABDB9B9BCBBBBC4BE
C3C1C5C4C2C4CAC6C8C9C7C7C8CAC9CACECCCDD2D0CED0D0D9D4DAD9DBDEDCDFE0E0E2E1
E6E3E8E9E6EAEDECEEE9EFEBEFEFEFF3F0EFF2ECF0EDF1EDEEF2F2EEECF0F1EFF1EFEEEF
F1F3ECEEF1EEF0EFEBEFF0EDF0EDEFECEDEEECF1ECF0EFF3EDEEF3EFEAECECE8E9E6E5E6
E5E8E6E4E3E0E3DEDFDFDFDCD7D3D3D0CCC7C7C1BEBFBAB6B7B4B1AFAFACA9A9AAA9A8A7
A4A5A5A3A3A19FA0A09FA09D9E9D9D9C9C9D9C9D9E9FA0A39FA3A2A4A5A5A5A8A7A7A9AB
ACABACAAABACAAACACABADAEABABACA9AAABA8A5A5A3A39F9F9C9B98999494959393928F
8D8D8C888A88868A86858484838382847F7F807F7F7D7D7A7A7A77767576747473727271
6F706E6D6E6B6A676A666664635F5E5E5C595A575856555352504E4C4A4947464444413F
3D3D3A37373533302F2E2C2C2B2A2A292928282828272727272727272726262626262626
2626262626262626
262626262626262627262626262626272726272627262727272727272727272728282828
29282A2A2B2B2C2C2E2F303132343537383A3B3D3F40424446484B4B4D4E4F5152535657
5B5A5E5E6061646667696A6E6F707175767A7B7C818185848888878C908F909395979797
9B9A9B9DA09EA1A1A2A1A4A5A5A6A7A4A5A7A4A4A7A8A8A7A5A6A7A6A5A7A9A5AAA7A9AA
A8A9ACAAA8A9ABABABAAADABAEADAEAFB3B2B4B2B4B5B8B6B5B9B8B9B8B9BABAC0BEC1BF
C0C1C4C3C4C5C7C9C7C8CBCBC7CBCCCECACFD0CFCFD2D1D2D1D6D6D9D9D6DBDDE0E1E1E2
E2E3E9E1E8E8EDECEFEDECF1EFEFEEF3F1EFF0F1F2F0EFEFEEEFEFF3F1F3F0F3EFEFF0F0
EFECEDEDEDEEEDEEF3F2F1EEEEEFEDEDEEECF0EEF2EDEBEFF0EEF1EDF2EEECE9EBEDEAE9
E9E8E7E8E7E5E3E5E3E2DFDEDDD6D6D6CFCDC8C8C5C0C0C0BBB8B3B4B0ADB0A9AAACABA8
A9A6A7A4A19FA09FA09F9F9D9F9D9D9E9D9CA09D9C9E9DA0A29FA2A1A3A3A5A5A5A8A8A8
A9ABACABAFAAABB0ACA8ABA9A9A9AAABAAA8AAABA6A6A3A2A19D9F999897969595939190
8E8F8C8C8C8B8889878686848483838381817F7F7E7D7D7C7B7878787573757474737072
6F6F6E6B6B6C6A6B6866666461615F5D5D5B59585755545352504E4D4C4A49464443413E
3E3C393937343331302E2C2C2B2A2A292929282827272727272727272727262726262626
2626262626262626
262726262626262626262626262626272626262626272727272727272727282727282829
29292A2A2A2B2B2C2D2F2F3133343638383A3B3C3E3F424446474A4A4D4E4F5153555557
595A5D5F5F6263666568696B6E6F727375777A7D7F8081848387878A8B8D909392959798
989C9E9D9EA0A0A0A0A4A5A6A9A7A7A5A7A6A7A6A9A8A9ABAAA8A7A6A9A9A6ABA7A8A9A8
ABAAA8AAABABACADAAACABACAFADADB1B3B2B3B2B3B3B8B7B9B9BAB8BBB9BBBCBDBCC0C1
C2BFC3C1C3C1C4C6C8C8CAC9CACACCCCCFCECED1D0D3D0D0D3D5D7D7D7D4DBDCDEE0E2E1
E2E3E1E8E7E9E9E9EBEAEEEFEFEDF2F0F0EEEEEDF0F1F4F2EDF0EDEFF3EFF1F0F1F0F2F0
EFF2F2F2F0EDF1F2EEEEEFEFEEEBECECECEBEEEFEEF1F0F2F4F3F0F2EFF1F2EBEDEBEEED
EAE7EBEAE7EAE4E7E5E4E2DFDCD9D8D6D1D0CFCAC8C5C1C0BEBDB7B6B4B2B2ACABAAABAA
A8A7A7A5A3A5A1A2A2A39E9EA09DA09E9E9E9B9A9B9EA09E9F9DA19E9FA4A3A3A6A6A6A6
A8AAABABABA9ABABABACA9ABA9AAA7AAACAAA8A6A8A8A5A3A1A09E9B9D9D999697929194
928F8D8D8B8C8987898683848582837F817F7D7F817E7D7C787A7877777674737473716F
706E6D6C6D6B6A6A6865656363605F5F5B5B5A595755545452504E4D4C49474644444140
3E3C3A38363533302F2E2D2B2B2A2A292928282828272827272727272726262727262727
2626262626262626
262626262626262626272626262626262626272627262727272727272728272828282828
292A2A2A2A2B2B2D2D2E303132343537383A3C3D3E4043454748494B4D4F505352535758
5A5B5C5D5E6163626768696B6C6C707172767A797B7E8382828487898C8E8E9192949597
969A9C9E9DA09EA0A1A1A3A3A7A8A9AAA8AAA9A7A6A9AAA8ABA7AAADA9A8A9A9A9AAABAB
ACA8ABADADABABACACA9ABA9AFAEADAFAEAFB2B1B1B2B2B9B7B6B7BBBABABBBBBEBEBEBF
BFBEC1C1C4C4C3C6C7C8C8CBCBCCCCD0CCD3CECCD0CFD2D5D2D4D4D2D8DADADCDEE1E1E2
DFE1E5E3E8E7E8E7E7ECECECF0EDEEEEEDEEEEF1F2EFF0EEEEEEF0EDEEF1F3F4F1F2F1F1
F3F1F0F0EDF1F1F1F1EFF1F8EFEFEFECF0EDF2F0F0F4F0EEF0F1F4F0F2F3F0EEF0EDF0F1
EEEFEBEAEDEAE9E8E9E2E1E1DFDDDAD8D8D6D2D1CFCAC7C4C0BEBAB8B6B6B3B2B1AEA9AB
A8A7A4A6A8A5A3A4A4A1A3A29E9D9EA19D9D9C9A9C9D9A9B9E9B9F9EA1A2A1A2A3A5A9A4
A9A9A8A9AAA6A8A9ABAAA9A9A6A9ABA7A9A9AAA9A6A6A8A4A4A1A09F9D9B9A9797979593
92908F8C8B89898788878485868281827F7F817D7E7C7D7B7A777977777676757471726F
6E6E6E6C6C6B696A6967666465615F5F5D5B59585756565251504F4D4C4948454542413F
3D3C3A3837343331302E2C2C2B2A2A292928292827272727272727272727272726272626
2626262726262626
262626262626262626262627262726272726272726272727272727272727272828282828
292A2A2A2A2B2C2C2D2E303233343537393A3B3D3F41424546474A4B4C4E505253545657
585B5C5B5F6162636666686A6A6C6F72757576777B7C807F838685898B8E8F8F90919796
9B9A9B9AA09D9EA0A1A4A4A5A6A7A8A8A9ABAAABAAA9ACAAABAAADACAAACABABACA9ABA9
AAA8ABAAADACAAADADA9AAAEACADB1AFB1B2AFB2B1B6B6B6B8B6B9B7BABCB9BCBBBDBEBE
BFC3BEC3C3C4C4C5C8C5C6C6C9CAC9CCCCCACECCD0D1D0D2CFD1D1D2D5D2D6DADBDCDCDF
E2E3E6E2E7E5E8E9E9E9EBEBEDEDEEEBECF0EEEDF1F1F4F1EFF0F0F1F4F2EEF0EEF0F1F0
F2F2F0EFF0EFEEEEF1F2F2EFF1EFECEFECF0F1F1F0F0F2F0EEF2F3F2F6F6F5F1EFEFEEF2
F0EEEFEFF0E7EBE8E7E6E6E3E2E0DDDADAD9D6D3D2D1C8C5C7C2C1BCBBB7B7B4B2B0AFAC
A9ABAAA6A6A5A3A5A4A0A1A09DA1A09E9F9C9E9C9D9C9F9B9C9D9C9E9DA09FA1A3A3A2A7
A6A5ABA8AAA9AAA8A9A9AAA9A8ABA6A6A8A9A7A6A8A7A5A6A6A3A29FA09C9A9799979395
95928E8D8E8B898A8685858483858381837F7F7D7F7D7D7B7C7A79787976747574737271
706F6D6D6B6C6A6A68666664636260605D5C59595755555252514F4C4B49474644433F3F
3D3A3A38383533312F2D2D2B2B2A2A2A2928282827272727272727272726262626262626
2726262626262626
262626262626262626262626262626262726272727272627272727272727282828282829
292A2A2B2A2B2B2C2C2F2F323334363839393B3E3E40434446484A4B4D4F515254525557
585B5C5C6060626465676869696C6E7071747375787979817F838486898A8B8E908E9196
96999B9B9E9DA0A2A2A3A5A7A7A8A7A8A9ABA9A9AAABAAABAAAEABACABADACABA9ADACAE
A9AEAEACAEACAAACACADAFABAFB0AFAEB3B0B0B3B2B3B3B5B7B8B6B9BABEBBBCBEBFBEC0
C1C0BDC2BFC3C2C2C3C2C7C4C5CACAC9CAC9CDCBCBCDCACDCFCED3D3D3D4D5D9D9DADAE0
E0E2E1DFE4E4E4E8E6E9ECEBEBEEEDF1E7ECEDF4EFEDF0EEECF0ECF1EFEEEFEDEFEFECF2
EDF2F2EFEFEEF5F3F1F3F0EFEFF2F2F0EFF1F4F0EFF3F3F2F0F0F5F7F5F6F4F2F1F0F2F2
F0F2ECEFEFE9EDEBE7E8E5E2E5E0DFDDDEDADAD7D1CFCFCBCAC5C3C2C0BDBDBBB6B6B4B1
ACAAABAAA8A9AAA5A5A3A29FA19F9E9E9F9D9D9B9C9E9A9B9B9C9E9D9E9E9FA19FA3A5A7
A4A5AAAAA5A7AAA7ACA7A8A9A8A9A7A6A8AAABA4A7A6A7A4A8A3A39FA19F9B999B979896
9291908F8D8D8C8A87868684838384827F80807C7F7C7F7B7C7A78797775757573737372
716E6E6C6B6B6A69686764676362615F5C5E5A595656545251504F4C4A4948454442403E
3C3B3938373433302F2E2D2B2B2A2A292929282828282727272727272627272626262626
2626262626262627
262626272626262626262626262726262726262626272727262727272728272728282828
2829292A2B2B2B2D2E2E303133343537383A3C3E3F40424546474A4D4D4F505353545658
585A5B5E5E5F616365656769696B6D6D7174747576787A7B7E8284868A888D8C8D909293
969A999C9D9E9FA0A2A0A2A3A4A9A8A9AAAEADADADADAEADACAEACADABAEAFAEAEAEADAD
ACABADADACAFACADADB0B0AEAEAFAFB0B0AFB1B3B4B4B3B7B8B9B5B9BAB9BCBBBDBBBEBD
BFBEC0C0C4C2C2C1C1C5C5C5C5C5C6C8C8C9CBCCCBD0CACDCFD0CED1D3D4D6D4D6D9D9D9
DEE0E1E0E3DFE5E6E3E7E9ECECEBEEECEEEEEDECEFEDF1F0EDF2F3EFF0EFF0EDF0EEF4F2
EEEDEEF0F0EFF4F1F1F0F3F3F3F0F1F0F1EEF1EEF0F0F3F3F1F3F9F4F8F5F7F3F4F2EFF3
F5F3EFECECEEF1EDECEBE8E7E5E2E1E0DDDCDCD9D2D3D1CDCCCCCAC9C6C3BFBEBBB5B3B1
AFABACACACACA7A9A6A6A2A0A29FA2A0A09C9E9C9C9B9A9A9A9C9D9C9D9CA09D9DA0A1A0
A2A5A9A8A7A7A8AAA7A6A7A5A9A8A9A9A9A7A8A4A8A3A7A6A5A5A4A2A09D9F9B9B9A9898
979490918E8C8C8B8A86898684848583817F807E7C7B7E7E7B7B78797A78767576747471
716E6D6B6D6B6B686A6867656361625F5D5C5B595756555351514F4D4A4947464442403F
3E3B393736343432302E2C2C2B2A2A292928282828272727272727272726272627262627
2626262626262626
262627262627262626262726262626272627262627272726272727272727272828282829
29292A2A2A2B2B2C2D2F30323234353738393C3D3F4143454547494C4F4F525254535655
585B5B5C5F5F606365676867696A6C6E717175757676797B7D7F82848688888A8D8D9093
939796999B9B9F9FA1A2A3A5A6A7A9ABADACAEADAEAEAEAEAEABB0AFAEAEAEACAEADADAD
B2ADAFACAEADAEACAEAFAEAFB0ACADAFB0AFB3B5B3B7B6B5B8B8B8B9B8B7B9B8BABFBBBD
BEBDBFBFBEBFBEBFC3C2C5C4C6C5C9C7C9C7CBC9CBCBCECECECFD0D1CFD1D1D2D2D5D5D7
DCDDE1E0E3E4E2E6E5EAE9E7ECEAEEEDEDEBEFEFEEF4F1EDEDEEEFECEFEEF0F0F1EDF1EF
EEF1F0EFF1EEEEF1F3F2F1F2F0F3EEECEEF0F3EEF2F2EEEFF4F4F7F4F8F3F4F5F5F4F4F3
F3F1F4EEF1F0EEEDEAE8E7E8E6E2E4E1E1DCD9DBD9D5D5D1D0CBD0C8C9C4C4BDBCBAB8B4
B2AEADAEADACA9A9A7A7A5A3A29E9FA0A09E9D9E9C9E9B9B9C9C9B9D9B9C9A9B9B9D9F9E
9FA0A5A6A8A5A6A6A7A7A5A9A7A9AAA9A6A9AAA8A5A7A7A5A6A3A4A3A1A19D9C9C999A96
97959495918C8E898B88878686868283817F7D7D7E7C7C7D7C7C77797877777675737271
716E6D6C6C6A6A6968686567636161615F5E5A59585653525051504D4A4947464442403F
3D3B3A38363532312F2E2D2C2B2A2B2A2929282828272727272627272726272726262726
2626262626262626
262726262626262626262627262626262727262727272727272727272728282828282828
2929292A2B2B2B2D2D2F303133343738383B3C3D3F40434446484A4D4F50545554545656
565A5A5D5F5D606164656568696A6C6C6E7170737475787A7C7F8082858587898B8E9190
9395979B9C9C9F9EA0A1A0A4A5A7ABAAA8AAADAEADAFACACACB1AFAFB0B0AFADAEACAFAF
B0AFB2ADB1B1AEAEB0B0B0AFB1B1ACB0B1B0AEB2B4B4B3B6B4B6B7B7B8BAB9BBBCBCBCB8
BDBABDBFBDBFC1BEC0C4C4C4C4C5C5C7C6C9C7CAD0D0D0CCCBCDD0CFCDD0D6D4D7D5D8D7
D8DCDEE0E0E1E3E3E4E5ECE9E7E8EAEEECEEEDEFF0EEF0EEF0F0F0F1F2EBECF0F2F1F0F1
F0EDEFEFF0F3F2F0F4F1F1F2F4F2F1F3F1F3F3EFF0EFF2F2F6F7F9F5F4F3F3F1F4F5F4F6
F4F1EEEFEDEDEBEBEEEBEBE9E7E7E6E3DEE3DDD8DAD6D3D5D0D2CFCCC8C8C6C5C1BCBAB6
B2B1AEABACAEADACACA9A5A4A3A5A2A1A19D9E9E9B999A9B9A9A9A9B9D9B9D9B9A9BA09C
9F9EA1A2A5A5A3A5A7A7A9A6A9A8A8A8A8A7A6A5A6A5A6A8A6A6A3A2A4A0A09D9C9B9B97
999794928F928E898A888887868385848281807C7D7D7C7A7C7A79787677757673757572
706E6D6C6A6B6B6A67676664626362605E5B5B585757555251504F4F4B4847444343403E
3D3B3937363532312F2E2D2B2B2A2A292928282828272727272726272726272727272626
2626262626272726
262626262626262626262726262627262626262727262726272727272727272728282829
2929292A2B2B2C2C2D2E3031323436383A3C3D3D4040434447484B4E4F53555655555557
58595A5E5D5E606265666767686B6B6B7071737474747879777E7C8081838586888C8F91
9496979D999B9C9CA09DA3A3A6A7A8A8A8AAABADAFB0B1AFB0B0B1AFB2B0B1B2B3B2B2B1
B0B0AFB0B0AFB0B2AEB1B2B0B0AEAFB0B3B2B2B3B0B7B3B4B7B2B6B7B7B9BAB9B9BDBCBB
C0BCBEBDBFC2C0BEC1C2C4C4C1C2C6C8C7C8C7CDCACCCCCBCCCECFD1D1CDCFD0D2D3D2D3
D8DCDDDBE0DEE0E3E0E4E7E5E5E6ECEBECECECEBEFEFEFF0F1EEF0EEEEEDEFEEF0EFF2F0
EFEDF0F1EEF0F2F1F4F3F1F0F1F2F3F0EFF0F1F4F4F0F4F0F3F4F7F7F5F3F5F6F5F5FAF7
F4F1F1EEEBEFEEF0EDEDE9E9E8E7E4E4DFE0DDDCDFD8D7D4D1D4D1CCCDCBCAC6C3C2BEB9
B7B2B3AFB0ABACACABAAA8A5A6A2A3A1A19E9D9C9C9A9B9B98999A9C9A999B9C9B9A9C9D
9D9FA2A0A1A3A39FA3A5A6A5A7A8AAACA7A9A7A5A7A7A4A4A6A3A7A5A3A2A19DA19E9C9C
9897969594918F8E8D8A8A8688868382827F807F7E7D7C7C7B79797A7A76767675737472
71706B6D6C6B696A68686664626162605F5D5A595755535351504F4D4A4A48464442403E
3D3C3A38373534312F2E2D2C2B2A2A292928282828272727272727272727262626262626
2626272726262626
262626262626262626262626262626262626262627272727272727272727272828282828
2929292A2B2B2C2C2D2F2F3132343537383A3C3E4041434546494A4F5254565757565557
59585C5B5D5E606263646667696A6A6C6D6F6F71757377787A7A7B7E80818388878A8D8E
9391979898989C9F9F9FA1A4A5A4A7A6A8A9ACA9ABADAFAEB2AEB1B0B1B4B6B2AEB0B2B1
B2B4B3B2B0B1B1B1B4AFB0B1B1B2AFAFB2B0B2B1B6B6B4B6B7B6B8B5BAB8B9BCBDBBBDBE
BCBDBBC0C0BDBDC0C1C4C5C4C4C4C6C4C7C6C7C9CCCFCFCDCDCDCED0CECED0D2D1D5D7D1
D5D8DCD9DBD9DFDFDDE3E6E5E9E7E9EAEEEDEBECEDEBEFEDEDEFF0EFEFF0EDEFF2EFF3F2
F3F0F1F0F1F0F1F1F2F4F6F1F2EFF1F2F1F4F7F4F5F3F3F4F6F5F6F8F6F3F6F5F5F8F9F9
F6F3EFEFEFF0EFEFF3EEECE8ECE8E4E4E2E4E1DDDBD8D9D5D4D3D4D2CECACACAC7C3C1BE
B7B8B4B1AFAFAEADACADABA5A5A5A3A3A59FA09E9D9B989B999B9B9A9C9B9A9B9A999B9C
9B9F9F9FA1A0A0A1A4A3A4A6A7A5A7A5A6A8A6A4A6A8A6A6A3A4A5A4A5A1A3A0A09F9C9B
9B9A9A9695938F8F8C8D8889878485848283817F7D7C7C7D7C797B797A7A767474727470
706F6F6E6C6C6B68686665656363615F5E5E5B595756545351514F4D4B4948454441403E
3D3B3A37363533312F2E2D2C2B2B2A292928292828272727272727272626262626262626
2726262627262626
262626262626272626262626262627262626272627272627272727272727272828282829
292A292A2A2B2C2C2D2E303133343637383B3E3D3F40434547484A4E5155555858565657
595A5B5D5D5F60636565676767696A6D6D6C737373737578797A7C7B7E81828485878B8C
8E8F94959599999A9D9EA0A3A2A3A6A6A8A8ABABB0ADADB1B0B1B2B3B3B2B0B3B5B2B4B3
B2B0B4B2B2B1B3B2B2B0B3B1B2B1B1B1B2B4B2B2B1B6B7B4B6B5B7B8B9B6BABAB9BDBEBC
BDBCBCBCBDC0BFC0C2C4C5C5C4C4C3C2C4C6C8C7CDCCCDCDCBCDD0CAD0CFD1D2D4D1D2D0
D6D7D5D5D9D9DCDDDEE1E5E3E4E3E9E9EBEDEDE8EAEDECEDEEEDEEEEEFF1F1ECF1EFEEF2
EFF2EEF5F4ECF3F3F2F4F4F3F5F3EFF1F4F4F3F7F6F1F1F5F4F7FAF4F3F5F9F4F8FAFCFB
F7F5F3EFF1F0EFF1F1EDEDEEEAE3E5E6E6E1E3E0DDE2DCD8D7D5D5D0D4CECCCAC7C5C4C1
C0C0B7B2ADB2B1AFB0AEADAAA9A8A8A4A3A6A29F9D9B9B9B989A999B9C999C9B9A9A9A9B
9D9B9D9E9B9EA0A0A1A3A1A3A5A5A6A8A5A8A6A4A5A4A5A6A3A3A4A4A3A3A3A09E9F9E9F
9D9B989894969190908F8E8988868582858380807E7D7E7C7B7B787A7776777473736F6F
706F6F6E6B6A6A6968676663636260605D5B5B595856555352514F4D4B4947454443403E
3C3B3938373433322E2D2C2C2B2A2A292929282827272727272727262626262726262626
2626262626262626
262626262626262626262626272726262726262727272727272727272727272828272828
2929292A2A2B2B2C2D2E2F3133343636393A3B3F3F40424546484B4F5155565757575757
57595A5A5C5E606062646466676A686D6C6F71747274747779797B7B7D7F80848788878B
8C8F91979498989C9C9E9EA0A2A5A7A9A7A9A8ABAEADB0ADB4B2B2B5B1B5B5B4B2B8B2B4
B5B4B3B5B2B3B1B4B4B5B5B6AEB2B1B2B2B3B2B6B5B5B4B8B7B8B7B8B7B8B9BBB9BCBEBC
BCBDBFBDBCBFC0C0C0C3C6C4C9C5C3C4C1C5C5C9C7C9C9CACBCDCCCFCECFD0D3D0D2D2D3
D5D2D8D3D8DBDADBDEE1E2E4E4E7E4E7E9E8E8ECECE9E9EEEEECEFEFF1EDEFEEEDECEDF1
EEF0F0F2F2F3F2F6F1F3F2F2EFF3F5F5F4F4F3F6F6F1F4F4F8F2F8F6F6F2F4FBFBFBFFFF
FEF7F3F4F3EEEEEFEFEDECE8EAEBE8E6E7E5E2DFDEDFDBDDD7D8D9D6D1D1CFCECBC9C9C5
C3C2BEB9B8B8B4B2B2B1AAACACA7A7A8A2A4A19F9FA19C9A999B999A9B999A9A9A999A9C
9C9D9D9C9E9EA09FA0A2A2A3A1A2A3A4A5A2A6A4A4A6A5A4A5A4A2A2A1A2A2A19FA19E9E
A19B9B9A989693939091908C87878986868483817F7D7C7C7C797A767876747372727071
6F6F706E6D6B6A6969666465626160605D5D5B595858545451504F4D4A4949454542413D
3D3B393936343332302F2D2C2B2A2A2A2929282828272727272727272727262626262626
2626262626262626
262626262626262626262626262626262626262627262726272727272727272828282828
292929292B2B2B2D2D2E2F3132343537393A3B3E4041414446484A4F535657585A575757
585A5B5C5D5D5F616262656767676B6B6E6D706F717175777779797C7C7F818083868588
8E8C8E939596979A9C9B9B9EA4A2A7A8A7A8ABABACAFB0B0B0B1B2B4B2B3B5B0B6B7B7B5
B7B7B7B2B4B3B5B4B2B0B3B5B3B0B1B3B1B3B7B6B6B5B5B6B7B6B9B9BBB6B8B5BABABABB
BAB9C0BFBFBFBEC0C1C1C3C4C7C5C2C4C8C5C5C8C8C7C8CBC7CBD0CCCCCFD3D0CFD2D3D0
D3D3D4D6D4D9DBDDE0DFE1DFDFE4E2E3E8E8E8EBE8EBEEE8EEEEF0F0EFECEEEEEDEDF0EC
F1EFF0F2F3F3F1EEF2EFEFF1F3F5F1F5F9F3F4F6F4F8F1F4F5F5F4F3F4F6F5F6F6FAF8FA
F6F7F6F7F8F1F2F0EDEBE9EAEDE9ECE8E6E2E3E2E3E1DEDCDBDAD8D3D8D4CFCFCBCAC8CB
C7C7C1BBBCB9B9B7B5B0B0ACABAAAAA7A8A6A3A3A2A09DA09E9F9C9B9B9A9B9B9B999B9B
9C9A9D9B9D9D9E9CA2A09F9FA2A3A1A5A7A3A4A6A5A4A4A3A5A3A3A2A3A2A0A09D9EA0A0
9D9E9B9A9695969594908F8E8B878A8787848281817F7D7D7A787A767875767574737170
716E6E6F6D6B6A66676766646362615F5E5C5C5A5755555453514D4D4A4948464442423E
3D3A3939363533312F2D2D2B2B2B2A292929282827282727272727272727262627262626
2626262626262627
262626262626262627262626262627272627262727272726272727272727272727282828
29292A2A2A2B2C2D2D2D2F3132343537383B3B3D3E40424445484A4E5255575757575759
58585B5C5C5F5F5F626464656869676B6E6F6F707072747477787B7C7C7E7F8283848886
898D8C9193979498989B9B9C9DA3A3A4A6A9A8AAACACAEAEB2B5B4B3B5B6B4B4B6B6B8B9
B5B4B4B6B6B5B3B7B6B5B5B4B8B3B6B4B1B2B4B6B4B4B5B6B6B8B8BABBB9B5B8B9BAB7B8
BBBABDBCBFC1C3C1C2C2C2C5C4C2C5C3C5C6C5C6C5C8C7C8C9CCCCCED0CCCECED3D3D3D3
D4D3D3D4D3D6D8D8DBE0DEDFE1E2E2E4E5E2E8E7E6EBE9EEEBEDEDEFEEEDECEBEDEDEDEE
EEF2F0F1F3F0EFF3F1EEEDF2F2F5F5F3F4F7F8F7F5F4F7F9F5F5F6F6F3F7F9FAF9F8F5F9
F2F3F3F4F6F5F1F1F1F1EEEAEAECEAE7E8E4E3E3E4DFDFE1DCDFD8D5D3D3CED3D0CED0CD
CBC8C8C3BEBDBABAB9B6B3B1AFACAAABA7A9A8A3A4A4A0A0A19D9E9D9B999A9D999D9A9C
9C9A9E9C9B9C9B9E9DA09FA1A1A1A2A2A2A5A5A3A3A4A5A6A4A3A2A1A2A4A2A0A0A19FA1
9C9C9C99989896979493928F8D8C8C888886868381817E7D7B7C7979767575747473726F
716F6D6C6D6C6969676667636262615F5F5D5B585957545452504F4C4B4A48454442403E
3D3C383836353431302E2D2C2B2B2A292929282827282727272727272727262727272726
2626262626262626
262626262626262626262626262626272726262626262727272727272727272827272828
2929292A2A2A2B2C2C2E2F313234363739393B3E3F40414346484A4E5154575858595859
585A5B5C5E5D5D6062606264656769696A6E6D6E727273757778797A7C7D7F7F81838488
868C8C908F8F9295999B9A9C9CA0A3A3A4A6A5A6AAABADB0B0AEB1B3B2B7B5B7B5B7B8BC
BBB9B7B7B6B4B5B7B8B9B5B6B3B5B5B6B5B4B5B7B4B5B4B2B7B9BABBB8BBBBB6B9B9BAB8
B7B8BCBCBCC1C0BFC1BFC1C3C1C5C3C3C5C6C6C6C4C6C5C6C9CACDD0CBCECCCDCDD0CFD0
D0D1D0D1D1D5D9D8DADEDEDCDFDFDCE0DFE6E3E7E7E7EBEAEAECE7ECEEEEEFEFEFEDEFED
EFEFEEEFEDF0F1F1F0F0F2EFF2F5F4F7F7F5F6F7F4F6F5F5FBFAF6F4F5F8F9FAF8F6F2F1
EEEDF2F3F7F5F6EEEDF0F2F1ECEAECE6E6E7E8E3E1E1E1DFDEDEDBD9D7D2D5D5D0D3D1D1
CFCCCAC9C4C1BFB9BDB7B6B3B0B0ABAEABA7A7A4A4A7A4A0A3A09DA09D9A9B9A99999B9B
9B9B9B9A9A9B9C9D9F9E9FA1A19DA0A2A1A2A2A2A4A4A5A3A2A2A1A4A1A1A29F9FA0A19E
9C9E9D9A99999895939293908E8E8A8E8A87848482807F7B7E7C7B787676747672727374
726E6F6C6B6B6969656564646261605F5D5C5B595757555452514F4D4B4847454442403F
3D3B393736353332302E2D2C2B2A2A292928282827282727272727272726272626272726
2626262626262626
262726262626262626262626262626272726272726272627272627272727272828282829
282929292A2B2B2C2D2E2F313233353738393B3D3F3F41424547494C5054555857585857
585A595B5D5D5E5F62616363656768686B6A6E6E707173757576787B7B7E7E8180848486
8587888C8D938F92969798999A9EA0A1A5A8A9ABACAAADB0AFB1B1B4B3B3B5B8B8B6B6B7
BBB9B9B9B8B6B6B5B9B8B7B7B9B6B8B7B6B4B7B4B7B7B9B8B8B8B7B9B7B9B6B6B8B9BABA
B6BBBABBBDBEC1BFBFC1C4C4C2C2C4C6C3C6C2C4C1C5C3C7C8C8CCCECDCDCCCDCFCCCBCC
CFD0CFD3D2D1D6D9D7D6D8D8DBDDDEDDDDE1E1E4E1E6E7E5E5E9EDEDEAE7EEEEEDEEE9EA
ECEEEEEEEDEFEFEDF0F2F2EDF5F6F4F4F2F6F5F9F7F3F6F7F9F5F7F6F7F9FAF9F5F3F1F1
EDF0EEF5F4F7F5F1F0EFF0EFECEDE9E9EAEBE3E5E3E3E0E1DCDFDBDED9D7D5D4D6D4D4D3
D0CFD1CAC9C6C4BFBCBCB6B6B3B2B2AEAFABAAA8A7A7A6A4A2A2A09FA19DA09C9B9C999E
9E999B9CA09D9A9A9B9E9C9D9FA19EA0A0A0A2A5A1A1A4A2A2A4A2A2A1A1A0A0A19E9C9E
9B9B9C9D989A9997969294918E918F8C8C8A868483827F7E7F7C7A7A7677757474747371
716E6E6E6B6B69686667646564635E605D5B5B595756565352504F4D4A4A474744423E3D
3C3B393737353332302F2D2D2B2A2A292929282728272727272727272626262626262726
2626262626262626
262626262626262626262626262626272626262627262626272727272727272827282828
292929292A2B2B2C2C2D2F303133353638393C3D3E3F40424546494C4E53555759575857
57595A5B5E5D60605F6261636466686A6A6B6D6E70707073767678797B7B7F7D80828485
8587888A8D8E909293969696999A9E9FA3A4A6A6A9AAAEAEB2B0B0B0B5B5B6B7BAB6B6B7
B7B9BCBDBCBBBBBAB9B9BAB9B9BAB7B6B8B4B8B7B5B8B6B9B9B8BABABAB7B9B8B5BAB9B9
B8B7BDBABCC0BFC0C2C1BFC1C3C4C1C2C4C5C4C3C4C4C5C7C7C8CACBCCCECACDCDCDCECE
CFCDD1D1D2D6D5D4D5D7D9D8DAD8DDDADFDFDFE1E1E3E4E4E6E6E8EBEBEAEAECECEBECEC
ECEDEDEDEEEDEFEFEFF0F3F0F5F2F2F3F5F1F6F6F3F5F6F7F9F7F3F3F4F8F7F6F7F6F4F2
F0F1F2F6F6F5F2F2F2EFEEEDEDEDECE8E6E6E7E2E5E2E0DEE0DEE0DDD9DCD8D7D9D6D6D5
D4D4D0D2CFCBC6C7C2C0BBB9B9B5B4B4B1B0B0ACAAA9A6A5A6A3A2A09F9F9E9E9D9E9A9A
9A9B9B999B9C9B9C9A9E9B9C9C9C9E9D9FA0A0A2A2A1A1A1A2A2A0A09EA19E9DA09E9D9B
9E9B9C9A9898979795959490938F8F918E8B8985858282817F7F7C7A7775757273737273
71706F6C6B686968666664646262605F5D5E5B595656545352524F4E4B4946464441403E
3C3A3A3736343431302E2D2C2C2A2A292929282728272727272727262727262726272727
2626262627262626
262726262626262626272626262627262727272626272727262627272727272728282828
282A292A2A2A2B2C2C2E2E303234353738393B3C3D3F41424446494A4F51535856575656
55575A5C5D5C5F5E6060616465666767696A6C6E7170727272767679797B7C7E80828285
848888898A8D8F9090979697979C9F9FA2A5A5A6ABABAAADAFB0AEB1B3B4B5B8B8BAB6B8
B9BBBBBDBBBDBBBABAB9BBBAB9BBBABAB8BBBABAB9B7B9BAB9BAB8BAB8B9BAB6BAB8BBB9
B9BBB9BBBBBCBEC0BFC1C2C4C4C4C4C1C2C2C4C3C3C5C8C4C7CAC9CBCBC9CACBCFD1CCD2
D0D1CDCDD4D3D5D3D5D5D6D5D9DCDADCDEDCDCE0E0DFE4E3E7E6E7EAE8E9E8E8EBEDEBED
EEEDE6ECEBEDF0EFEFEEF0EEF2EFF3F3F6F5F1F4F5F6F5F6F7F5F6F5F5F6F5F7F8F9F6F0
F1F5F0F0F3F6F2EFEEEFEDEEEFEBE9EFE6E8E5E6E4E3E0DFDFDEE0E0DEDADBDCD6DAD7D8
D7D6D6CFD0CCCDC8C7C4C2BCBCB9B9B7B5B4AFB0ADAFA9A8A4A6A3A3A3A2A09D9C9D9D9B
9B9C9D9D9A9C9A9D9C9C9C9B9D9E9D9F9E9EA0A1A0A09FA1A0A29F9FA09F9C9E9F9D9E9C
9B9A989B9B9B9899959595938F9190908E8B8B878683838182807C7A7976757473727271
706F6C6D6B6A69696667656462615F5E5D5C5B5B5655555352504F4D4A49474544423F3E
3E3B3938363532322F2E2C2C2B2B292A2928282828282727272727272726262726262626
2626262626262626
262626262626262626262626272627262726272627262727272727272728272728282828
2929292A2A2B2B2B2D2E2F303233343638393A3C3E3F41424246484A4D51535658565555
57585A5C5B5D5F5D5F5F62626367676869686C6D7071707273737678787B7B7D7D818182
8384888887898B8C929394929A9B9C9DA1A2A2A5A6A9ADAFADAFB0B0AFB2B5B4B6B8B8B7
B9BBBDBEBCBEBBBBBABCBAB9BBBDBABCB9B7B9BBBBB8B7BAB8BAB7BABCBBB9BBBABBBABA
BABABABFBDBDBCBCC1BDBFC0C4C3C1C1C2C3C1C2C4C2C8C9C5C6C5C7C9CBCACECED0CED2
CCCFCCD0D2D1CFD4D1D5D4D7D9D9DEDAD9DDD8DADCE0DFE0E0E5E6E4E5E6E6E8E8E7E9EF
EEE9EBEBEDEDEDECF0F3EDF0F4EFF0F1F3F1F5F5F6F6F9F6F6F4F2F5F6F7F9F9F9FAF3F4
F1F6F3F4F4EFEFEEEAF1EDEDEBEDECE9E8E6E5E4E6E4DFE0DDE2E0DDDAE0DDDDDBDDDBD9
D9D4D4D3D4D4CCCDCAC6C3C4C2BDBBBCB9B8B5B4B2AFAFACAAA7A8A6A2A2A3A3A09C9C9E
9D9C999B989B9C9C999C9C9D9D9C9D9C9D9D9E9F9FA09EA0A19F9DA09FA1A09F9F9F9B9C
99999A999A9898979594939191918F8C908E89878786858281817D7C7B78767474727172
70706E6E6B6A6968666665656262615E5C5C5B59595655525150504D4B4947454342413F
3C3B3A3836353331312E2C2C2B2A2A292929282827272727272627272727272726262727
2627262626262626
262626262626262626262626262727262627272626272627262727272727272827282829
29282929292B2B2C2C2D2E303134343636393A3C3E3F3F42434445484B4F515455555555
545658595B5C5D5F5E605F62636466696C6A6B6D6E6F717272737478797A787C7C7F8081
81848487878B8A8D9091939495989A9A9E9DA2A2A5A7A9AEACAEAEAFB0B2B3B6B6B9B9B8
B6B9BCBDBFBDBBBBBCBEBEBDBBBCBCBABBBAB8B9BDBBBBB8BCB8BABCBABABBB8BABBBDBC
BCBBB9BBBABABCBDBDC0BFC0C2C1BFBEC0BFC1C1C4C6C6C6C8C7CAC9C7CAC8CBCFCED0D1
D1CFCDCDCFCFD1D0D1D1D3D4D3DAD8D9D8D9DADBD8DDDDE0E0DFE2E6E6E4E4E6E8E9E8EB
E8E8EBE7E8EAEBEEF0EEEFEDEFF0F4F4F2F5F4F1F2F7F6F8F7F5F4F6F6F4F7F7F8F8F6F5
F7F2F5F8F7F2F2EFECEBEEEEECEDEAEBE9E7E6E6E5E2DFE2E3E2E0E3DEDEDDDFDCDFDCD8
D9D7DBD6D2D3D3D2CFCBC9C6C6C4BFBEBEBAB8B7B4B3B3B1AEACA9A9A5A6A3A49FA19F9C
9C9E9D9B9B9B9C9C9D9A999A9A9E9D9D9C9B9E9F9B9E9F9E9F9DA19FA0A09C9F9D9B9C9D
999B979B9A9998959795959592918E8E8D8D8C8B8785828582807E7E7B79777575727171
716F6E6D6C6C6B686666646361625F5E5D5C595857575453514F4F4D4A49474544423F3E
3D3A3A3736353332302F2D2C2B2A2A292928282828282727272727272726262727262626
2626262626262626
262626262626262626262626262626262627262726262726272727272727272727282828
2829292A2A2B2B2B2D2D2F303233343537393A3B3D3E4142434346484A4C4F5353535253
545756595A595D5E5F605E6262656668676A6C6D6F7072727075737577787B7B7D7E8181
8585878888898A8C8D8E9092959698999C9F9FA2A4A9A7AAACADAEAEB2B3B3B4B4B7B9B9
B7BBBBBBBEBBBDBBBEBCBABBBDBBBBBBBCBDBABDBBBBBCBABCB8B9B9BBB6BBBDBBBDBBBB
B7BCB8BAB9BCBCBFBCBDBDBEBFBEC1BDBFC0C2BFC3C4C1C5C7C4C4C9C9CBCFCFCBCECDCD
CBCFCECECFD1D1D2CFD0D3D5D2D6D5D1D7D7DADAD7DBDADADCDFDFE0E2E3E1DFE5E3E9E9
E7EAE6EAE9EEEEEEEDEFECEDEEEFECEEF0F3F3F4F5F3F6F7F5F8F5F6F3F2F6F3F6FBF4F3
F7F6F8F5F6F4F4F1EDF0EFEDEBEAEBEAE9E7E6E3E5E3DFE2E0E3E2E1E1E1DCE2DFDDDEDA
DADAD8DAD9D6D3D4D0CCC9CBC9C6C2C4BEBEBDB9BAB8B6B5B1B2ADADABA7A5A4A0A3A2A2
9D9F9C9B9D9B9D9B989C9B999A9D9E9A9A9D9B9D9C9C9D9D9C9F9EA09E9EA09E9D9D9B9C
9B999A989798969894969395928E9190918D8B8789868583807F81807A7B787674747272
71716F6D6D6D6A67676665645F615F5F5D5B59595755545151504E4C4B4847454341403F
3B3B3A3737353332302E2D2B2A2A2A292928282828272727272726272627272726262726
2626262726262626
262626262626262626262627262626262726272626262727272727272727282728272828
282929292A2A2B2B2C2E2E30313333343637393B3D3E3F42424445474A4B4E4F51535254
54555658595C5D5F5E60616162636668696B6C6A6E6F7070707373737878797B7D7D8080
8282868585888A8A8E8F9292949797989BA09FA1A2A4A7A8ABACAFADB0B2B3B4B7B8B8B7
B6B9BABBBEC0BABCBCBFBEC0BFC0BDBEBDBCBBBCBDBFBEBEBBBCBBBBBDBCBCBBBABDBEBF
BEBDBBBCBBBABEBDBFBEBBBEC0BFBEBEBFBDC1BEC1C1C2C4C2C6C5C8C8CCCBCBC9CCC9CB
CCCFCECDD0D0D0D0D1D2D2D5D2D2D2D5D7D5D7DAD7DBDADADBDDDEE0DFE0E5E3E4E4E5E5
E9E8EAE8E5E9EBE9EEE7EDEBEFEEECF2F0F1F3F2F3F4F5F4F5F2F5F7F4F4F7F3F4F6F6F8
F7F6F5F3F7F2F2F1EFEEECEDEBECEAEDE9E5E5E6E3E2E2E2E1E3E2E2E0DFE1DFE0DDDFDD
DCDCD6D9D7D7D2D2D6CECDD2CBCAC7C4C4C2C0C0BDBBB9B8B6B6B2B2ACA9A8A9A5A4A2A0
A1A19A9B9A9C9C9A999B9A999A9A99979A9B9C9C9C9C9A9D9E9E9C9D9E9C9D9B9E9A9A9C
9B98989C9B9795949594929393908E908E908D8C88888682828280807E7C7A7977757471
6F706F6E6D6C68696764646360615F5E5D5C595957555352524F4D4C4A4947454342403E
3D3B383736343332302E2D2C2B2B292A2928282828282727272727272726272726272626
2626262626262626
262626262626262626272626262626272727262626272727272627272727272827282828
282929292A2A2A2C2C2D2E30313234353738393B3B3D3F4143454448484A4C4E4E505252
51545657595B5C5D5F5F5F616264646869696C6C6D6C6E6F727072727678777A7E7B7E80
838386868686868B8B8E928F92959596989A9B9EA0A3A5A5A8ABABB1AEAEB0B5B6B9B8B9
B7B8B9BCBDBCBBC0BEBFBEC2C0BFC0BEBDBEBFBDC0BDBEBEBDBCBCBABCBBBBBDBEBBBBBD
BBBBBDB9BDBCBDBDBCBFC0BCBEC0BEBCBFC1C0C3C1C3C5C3C4C5C3C6C5CECFCBCBCCC8CB
CCCDCDCFCECED1D3D1D0D2D2D4D3D7D4D7D7D6D8D7DAD8D9DAD9DEDBE0DCDEE0DEE4E5E6
E7E7E6E7EBE9E7EBE6ECEBEDF0EBEDEBF2EFEEF0F0F1F2F4F4F8F2F5F3F5F2F3F5F3F4F7
F2F7F2F6F6F2EEEFECF1ECEFEBEFECECE8E5E4E6E2E5E3E2E2E2E2E2E5E4DFE0E1E0DCE1
DCDDDED7D8D5D7D7D3D2D1D0CECDCBC9C8C5C5C1C0BFBEBCB9B9B8B5B3AFADA8A8A6A6A4
A2A1A09F9C9B9A9B9B9B9B999C9A9A9A9899999A9D9B9B9B9C9B999C9C9D9D9B9C9B9A98
9A98989499969593939292949091918E918C8B8C8B8887838381827F807D7A7A76767472
726E6F6D6C6E6A686865646261615F5E5C5B5959565654524F4E4D4B4A4948474341413E
3C3A3A3837333331302E2D2C2B2B2A2A2929282827272827272727272627262727262626
2626262626262626
262626272626262626262626262626262627262626262627262727272727272728282828
282929292A2A2B2B2C2D2E2F313233353636393A3B3D3E404244444649494C4D4D505152
52545557585A5C5D5F5F616163636466676A6B6B6D6C6D706F727473747678797B7B7C80
80828383838689888A8C8F8F8F9396959899979CA0A0A1A4A6A9ACAEAEB3B3B5B5B3B5B8
B9B8BABABEBDBBBEBDBEBEC0BFC3C1BFBFC0BFC0BEC1BDBCBBBFBDBFBBBEBCBEBCBBBABC
BCBEBBBBBDBDBFBEC2BEBABFBFBBBFC2BEBDBEC0C3C5C6C8C3C3C7C8C9C9CACBCBCCC9CA
C9CECBCACBD0D1CFD2D3D0D2CFD5D3D2D6D2D4D3D8D6D5DBD6D8D7DCDADDDDDEDCDFE2E4
E2E6E4E6E1E6E9E8ECEDEBECECECEAECEBF1EEF0EEF0F0F1F1F7F3F5F7F4F4F5F5F7F4F1
F1F4EEF5F0F0EFEEEFEDEEEDEBEDECECEAE6E5E6E8E3E4E8E5E5E0E3E1DFE1E3DFE0E0E0
DADCDDDEDAD9D6D8D4D7D4D4D1CCCDCCCBCBC5C7C6C2C2C1BDBEBAB6B6B5B0B0ABA8A9A5
A2A1A4A19E9E9D9A9D999D9A999B999A9A989B9B9A9E999A999A9B98999A9C9B9A999B9A
9897989697959595949390939292918F8E8E8E8B88878584858280817F7E7B7A78787673
7071706E6C6D6A6866656363635F5F5D5C5B5857575554524F504D4C4A4A47454443403E
3D3B383836343432312F2D2C2B2A2A292A29272828272727272727272726272626272626
2626262726262626
262626262626272626272626262626262627262727272727272727272727272827272828
282929292A2A2A2C2C2C2E2F313233343536383B3B3C3D404142434648484C4B4C4E5051
5254555656595A5C5D5D6061606263666667686A6B6D6E6E70717373737677767A7A7D7E
7F7F8184818486898A8C8C8F9091929395969A999DA2A0A4A8AAAAAAAEAFB0B3B4B4B4B7
B7B9B8BAB9BCBCBDBEBFC2C1C4C1C2C3BEC0C0C0C1C1BEC2C0C0BEBDBDBFBBBEBEBBBDBF
BBBFBEC0BFC0BFC0BFBFBDBBBEBEBEC2C1C0C2C1C1C4C4C5C6C7C6CAC9CDCAC8C6C9C7C8
C8CFCCCCCDCCCDCDCED0D0D0D3D1D0D1D2D4D3D5D3D4D2D5D7DAD6D8DADFDADDDCDEDFE4
E3E3E0E0E4E6E5E8EAEAEBECE9EDEBEFEDEEEDF0EAF2F1F3F0F2F2F2F5F3F3F0F3F3F1F3
EFEEEEF4F0F4F4F0EDEEEDECEFEFEEEDE5E4E5E5E6E9E3E8E3E4E5E4E1E2E3E5E0E3E2E1
DBDFDCE0DADBDCD6D8D6D3D1CFD1CECDCCCCC9C9C5C7C4C3C4C1BDBEBAB5B5B0B2AEAEAB
A7A7A5A59FA1A0A09C9E9C9E9D9C9899979B9A9A999A98979A989B99989A9A999A989997
999796979795929593919191929192908F8D8C8B8989878484858682807F7D7C7A767575
71706F6E6F6A6A6766666364625F5E5D5D5B5757555453504F504D4C494846454342403E
3D3C3A3836353332302F2D2C2C2A2A2A2929292828272727272727262727262726262726
2627262726262626
252726262626262626262626262726272626262627262727272726272727272728282728
2828292A292A2B2B2C2D2D2E30323234343739393B3C3E3F4142444447484A4A4C4D4E50
5154565657575A5C5D5E5E606463636564666A6B6D6C6C6E7171727373747679787A7B7D
7F7F7F838384848688898B8E8F8E908F919595979BA1A0A1A2A7A9AAAEB1ADB2B1B4B6B4
B9B8B8B7B8BCBCC0C0C2BFC1C0C2C2C0C2C0C1C1C0C2C0C0C1BFBFC1BFBFBDBEBBBEBEBF
BEBDBBBEBCC1BFBEBFC2BDBFBABFC2C1C2C3C3C5BFC3C4C6C6C6C3C8CAC9C7C6C2C5C6C9
C6CACCCCCBCCCECCCDCECFCFCFCDCED0D0CFD0CFD3D1D3D3D5D5D7D7D8D8D9DBDBDEDDDD
DFDFE0DEE1E3E8E5E6E6E8E8E9E8EAE9ECEBEBEBEFF0EEECF0F4F3EFF0F5F2EFF1EFEFF4
EEEDF1EFEFECF1F1F0EEEBEDEEEEEEECE9EBE8E9E7E7E5E5E5E4E2E5E3E0E3E3E6E1E5E2
E3E0E0DFDEDEDCDCD6D8D4D3CDD0D4D2D0D1CDCACAC6C8C6C5C2C2BEBDBBB6B5B2B1B0AF
AFAAA9A5A5A5A0A09D9C9C9D9B9A9A989A98999B9A9A999A999796989997969997999696
9497979594959393959492919191918F8E8D8D8A898A8A8785858481807F7B7D7A7A7876
76716F6E6E6E6A686565646161615E5E5C595855555353514F4D4C4B4A48454443403F3E
3D3B393836353332302F2D2C2B2B29292929282828272727272727272627262726262626
2626262626262626
262626262626262626262626262627272627262626272727272727272727272728282828
282829292A2A2A2B2C2C2D2F313133343537383A3A3B3D3E414343454547494A4B4C4F50
5153535456595A5C5B5C5E6060626363656769696B6B6F6F6F7170717374767778787A7B
807E81808184848586888C8D8F8E8E8F919596989C9D9E9EA0A3A3A7AAABAEB2AFB1B0B6
B6B8B8B8BBBCBCBDC2BFBEC1C4C1C5C4C3C0C0C5C3C3C4C1C3C2C2C2C3C3C0BEC1BEBDBF
C0C0C0BFBFC0C1C1C2BFC0BFBFC0BDC4C5C4C2C1C2C3C4C6C3C3C8C7C9CBC2C6C3C6C5C5
C8CBCCCAC7C6CBCDCDCDCDCECDCECED0D1D0CDCDCDD1CED5D1D4D6D7D6D5DAD8D8DDDADB
DCDCDBDEDEE3E3E3E3E6E5EAE9E9E8EAEBECEDEBEDECEDF1F0F0EEF1F3F0F3F3F0F6F3F3
EEF0F0F1F2EFF1EEECF0ECEFECEDEEEAE8E8EAE9E7E8E5E4E4E4E2E4E4E3E3E4E5E4E8E3
E3E2DFE4E0E2DBDEDCD8D4D5D4D5D2D0D1D1D1D0CCCEC8C8C8C4C3BFBDBCB8B8B6B5B4B3
AFAEACA9A8A5A1A1A09F9E9C9D9B9A999997989897989998979696969796949797959796
9697959693949296919091918F908E8F8E8F8C8D8B89888986858483817F7D7C7B797876
75746D6F6E6C6B696866646162605E5C5B5A5757545352514F4F4D4B494647444341403E
3C3A393836343431302F2D2D2B2A2A292928282827282727272727272627272626272726
2627262627262626
262626262626262626262626262726262726262627272727272627272727272728272728
282829292A2A2A2B2B2D2D2F303133343436383A3A3C3E3F40414343454749494B4E4E50
515253555657595A5B5B5D5F616361636666686A696B6D6F706F70737374747778797A7C
7D7F807F828283878688888B8C8C8E8F91949498979A9A9C9FA3A2A5A8AAADAFAFAFB3B0
B3B7B7B5B9BCBBBBC0BFC0C1C1C1C3C3C3C0C2C2C2C6C4C3C4C2C2C2C0C3C3BDBEBFBDBF
C0BFC1C0BFC2BFC2C0C0BDBCBEBEBDC2C1C1C5BFC3C3C3C2C6C3C4C7C6C5C7C8CACCC8C9
C8C8CACACBCDCDCECCCCCDD0CFD2D0D0D1D3CECACDCFD0D1D3CFD4D3D3D5D4D6D8D7D6D9
DADADCDBDFE1E1E3E5E5E5E8E8EAE9E6EAE9EBECEEECEAEFEDF0EFF1F0F0F3F3EFF3F0F2
F1F0F1EFEFEFF1F0F0EFE8EEE9EAECE8E6EAEAE9E6E7E4E7E4E8E3E5E3E3E2E4E7E8E6E5
E2E2DFE4DFE0DEDEDAD8D9D4D4D4D3D2D2D1CED0D0CFCBCACBC5C4C2C0BDBDBDB9BCB7B2
B5AFADAEAAA9A7A4A3A09E9F9E9C999B9A9A9898979A9797959698969496969695969594
95939495929390919391928F8C908F8E8F8D8B8C8A8B88898587848584817E7E7C7B7876
7573716F6E6D6B686668646360605F5E5B5B585856545251504E4C4B4947464543413F3D
3C3B393736353332302F2D2C2B2A2A292929282828272727272727262727272726262726
2626262626262626
262726262726262626262626262626272627272627272727272727272727272727282828
282828292A2A2A2B2C2D2D2F2F313334353637393B3B3D3F404141444546474A4B4C4D4E
4F515254555557595A5B5D5E6060636464666867696B6C6D6F707071727475767878787B
7B7E7F80818383858486888A8A8C8E8F9196939696999A9C9DA0A1A4A5AAAAABAEADB0B1
B2B3B8B8BAB7BBBDBABEC1C0C1C0BFC1C3C3C5C2C3C4C4C6C5C6C4C3C3C3C3C2C3C2C1C3
BEBEBDBDBEBFC1C0BFBEC0C0BFC0C1C1C3C1C2C4C4C2BFC2C1C3C4C6C6C8CDCACBCECBCA
C8CCCACECBCACED2CDCCCCCCCED0D0D1D2D2D2D0D2CECDCFD0D1D3D2D6D4D0D5D4D8D3D7
D7D7DADBDCDEDFDDE2E2E3E4E3E7E5E8E9E8E8EAEAEEECEDE9EBEDEEF0F1F0EDECF1F1F4
F1EFF3F1F1F0EDECF2EDEAEBEDE9EBE7EBECE7E7E8E7E4EAE4E7E5E4E1E0E2E6E5E8E8E2
DEE2E1E0E0DFDFDFD9D8D9D6D7D4D3D3D1D6D4D3D2D0D1CDC9C7C9C7C3C2BEBFBCBAB9B6
B2B2B0B0AEAAA7A7A3A5A19E9E9D9A989A999B9698979597959595949496949395939595
9394959493929291908F90908E8F8D8D8D8E8C8C8A8C88898687868480827E807E7B7979
767671726F6E6C6B6667636363605E5E5C5B5957545452504E4E4B4B4947464443413F3D
3C3A383836353332302F2D2C2B2A2A292929282828282727272727272727272626262627
2626262626262626
262626262626262626262626262627262626262626272727262727272727272727282728
28292929292A2A2B2B2C2D2F30313234353637383A3C3D3E3F404243444647494A4B4D4F
50515152545758595A5B5B5E6061626365676767696A6B6C6F6E706E717275777677797A
797E7D7E7F818284858587888C8D8C8E919393959598979A999CA2A3A5A6A6AAACADB3B0
B1B0B3B6BABABCBDBDBDBEBEBFC1C0C1C5C3C3C6C1C6C6C6C4C4C4C4C1C4C3C6C4C0C2C1
C1BFBFBFBCC2BEC0C1C3C2C1C1C1C3C2C1C2BFBFC0C1C1C1C3BEC5C2C8C9CACDCBCCC8C9
C8CBCACACCCDCDCDCCCDC9CACECED0D3D0D3CDD1CDCED1CFCDCFD2D1D0D3D4D4CFD6D3D4
D6DBDBDBDCDCDDE0E2DEE3E3E3E6E3E5E8E6E8EAE9EAE9ECF0EAECEFEAEDEEEFF2EEEFEF
EFF1F1EEF0EFEEF0EDEFE9ECECE9E8E9E8E9E8E9E7E6E6E3E2E5E6E4E4E6E4E3E5E6E6E3
DEE1DFE3E0E0E4DDDCDDDAD8D6D5D4D4D3D5D1D1D1D1D0D1CDCCCBC9C5C1BEBEBDBAB9B8
B3B2AFAFAEAEACA9A6A3A5A2A09F9C9C9D9A979796989698969694959295929394949292
939093919293919090908F8C8D8E8E8F8C8E898C8A8C8988898687858383807F7C7C7A79
77747272716E6C6B6967656463625F5D5B5B5857565553504F504C4A4948464340413E3C
3C3A383736353332302E2D2C2C2B2A292928282728272727272727272727262627262627
2726262726262626
262625262626262626262626262626272627262726272626272626272727272727282728
28292929292A2A2A2C2B2D2F2F31323434373838393C3D3F3E3E4042444646474A4C4D4D
5051525355565757585B5B5E61606164636464656A6A6B6A6C6E70707072757474797779
7A7B7F7E7F80808184858688898A8B8C8D91949294969A9A9A9C9F9FA2A4A4A6A9A9ACAD
B1B1B2B6B5B8B9BBB9BDBDC0BCC0C1C3C4C5C4C3C3C2C3C3C4C5C4C4C2C4C2C4C4C1C3C2
C4C2C0BEBFC0C1C1C2BDC2C2C0C1C6C3C2C5C2C5C1C1BFC0C3C6C5C5C8C4C6CDCDCCCCCB
C4C8CBCDCDCCD0CFCECDCCC9CACDCED0CFD3CDD1D0CFCDCDCECDCBCDD0D1D0D3D2D1D3D4
D2D7D4D7D9D8D8DCDEDDDEDFE1E6E4E5E5E8E8E9E8EBE9E9EAEDEEEDEEEFECEDEFEBF1F1
F0EEEDF0EBEEEFEFEFEEEBECECE9E9E8EAE9EBE9EAE7E4E5E2E7E3E4E2E6E5E7E9EBE5E6
E5E5DEE2E2DFE0DEE0DBDBDBD6DAD7D7D4D3D3D2D4D3D2D0CFD0CECCC6C4C2BFBABBBAB8
B8B4B2B3ADAFAFAAAAA7A2A7A5A1A09F9A9A989997979494939494929194929291909292
8F91939190908E8C8F8E8D8F8F8B8D8F8D8C8A898A8A8788878486838381827F7D7D7C78
77767573716E6E6B6868666561615E5D5B595957555352524F4F4C4B4847454442423F3D
3C3A383736353332302E2C2C2B2B2A292928282828282727272727262727262726262626
2626262626262626
262626262626262626262626272626272626262626272626272726272727272727272828
282828292A2A2B2A2B2C2D2E30313233353637383A3B3C3C3E414143434546494A4B4C4E
4E4F52535455575A5B5C5C5D5F5F5E616365676868696B6C6C6D6F707173747576777878
7B7A7A7D7E807E80828384858889898D8F8E8F919392969499999C9EA0A2A4A6A8A7AAAC
AEB1B1B5B3B7B7B8B8BABBBDBDBEC0C2C4C4C4C1C4C4C2C4C3C5C2C4C3C4C1C3C6C5C4C4
C4C2C1C3BFC1C3C2C1C1C0BEC3C3C1C4C6C3C1C2C4C2C4C3C0C6C6C4C7C6CAC9CACDC7C9
C9CAC9C9CECCCBCCCBCCCBCFC8C8C7CECDCDCBCFCFD1CDD1D0CDD0CCCED0D4CFD2D6D3D3
D4D6D6D5D6D8D8D8D8DDDCDBE2E0E4E5E4E6E7E7E4E6EAE8ECEAEBECEBECEBECEAEDEBEC
EDF0EEEDEBECF1ECEAEFEAEBEBEBEBE9EAEBE6E7E9E4E6E1E2E2E5E7E8E4E5E7E9EBE6E6
E6E5E1E2E2E3E2E6E2DEE1DDD8D9D9D4D6D5D6D4D4D3D6D3D1D3D0CDCBC5C3C2BFBFBABB
BAB8B6B3B1B2ACAFACABA9A8A6A4A2A29D9C9E999696989594929591909292918E8F8F8D
918C9090908E8D8F8E8D8C8D8D8A8C8E8A8B898B8989888888868585838280817E7E7B7A
76757572706F6E6C6A67666462615F5D5D595858575451504F4D4C4B48474545423F3E3E
3B3A393635343232302F2C2C2B2B2A292929282828272727272727272727262627262726
2626262626272626
262626272627262626262626262626262626272626272627272727272727272727272828
28282929292A2A2B2B2C2D2E2F313134353637383A3B3C3E3E3E424344444648484B4C4D
4D50515254565658595A5A5C5D5E6161646464676768686B6B6F6E717172747577797979
78777A7A7F7D7F7E808281858686888A8A8D91909091969499999A9C9BA1A3A3A6A3A8AB
ACADAFB1B0B6B3B9B7BABABCBEBEBDC0C2C1C2C3C3C3C3C3C5C6C5C4C4C4C5C3C2C3C5C6
C4C2C3C5C1C1C2C2C4C3C2C1C1C2C0C1C5C4C3C3C6C4C0C0C4C4C1C3C5C9C7C6C4C6C8C9
C8CACACBCDCCD0CBCBC8CCCCC8C9C8C9CBCDCCCBD0D0CFD1CCCCCACDD1D1CED1D2D2D1D1
D3D3D4D6D4D6D7D9D9D8D9DEDFE1E2E3E4E5E7E8E5E8E7E7EAEDE9EAE9EBECEBEBF0EDEB
EBF1E9EFEBEEEBEBEDE8F0ECECE9EBECE7E8E9E8E3E5E0E5E3E6E8EBE7E8E8E9E9E7E9E8
E5E5E5E3E1E3E2E3E0E0DDDCDDD9D9D6D7D9D6D4D5D6D3D7D4D2D0CECAC5C7C4C1BFBCBB
BABDB8B5B6B6B2B1B0ADABAAA9A9A6A0A29F9B99979897969792919090929190918F8E8F
8C8E8C8F8D8E8C8C8D8C8A8D8A8C8B8B8C8A8A898988868784858685838281817D7E7B77
7875737072706E6C6B68666564605D5E5B5B5857565453504F4C4A494947444242403E3C
3B393837363433312F2E2D2C2B2B2A292929282828272727272727272626262627272626
2626262626262626
262626262626262626262626262626272726262626272727272727262727272727282828
2828282929292A2B2C2C2D2D2F303133353537383A3B3D3D3E3E40424344454748494A4D
4D4E505253535657585A5A5B5D5F6060606364656768686B6C6B6E707172737675777877
777A7A797C7E7C7E807F8180848686878B8B8D8C919193939796999A9D9FA09EA3A7A2A6
A8ACADB0B1B5B5B9B6B8B9BBBCBDBDC0C0C2BEC2C6C2C3C6C7C4C7C7C5C7C6C9C6C6C5C4
C3C1C6C6C2C2C4C4C5C0C1C2C2BEC0C2C1C3C2C1C3C4C4C3C2C5C6C4C6C6C5C6C7C7C8CC
C8C9CACCCDCBCCCBCAC9CAC8CAC9C8C9C9CBCACBCBCFCECECBCCCDCCCDCCCECFCFCFD3D1
D3D2D3D1D1D2D2D8D9D6D5DADBE0DDE1E3E0E0E2E4E6E8E9E7E7EAEBE5E7EBEAEBEEEBEC
ECEEECECEDEAECEBEBEBEAEEE6EAEBEDEBEAE7E7E7E4E4E4E7EAE9E9EDEBE9E7EBE9E8E5
E5E9E5E7E1E4E6E2E2E1DDDFDDDBDBD8D6D7D6D8D8D6D3D6D3D2D1D3D0CDC9C6C4BEBFC0
BDBDBBBAB7B6B8B3AFB2ACADAAA9A6A4A2A19F9D9999989992959291918E8F8E8E8E8D8E
8C8C8B8C8A8C8C8B8B8B8B8B8D8B8C8A8889878A8A88858785848385848381817E7D7A7A
757775737270706D6A696664625F5F5D5B595957555352504E4E4C494746454442403E3C
3B39393735343231302D2D2C2B2A29292929282828282727272727272727272627262626
2726272626262626
262626262626262626262626262626262726272726262626262727272727272727282728
2828292929292A2B2B2C2C2E2F2F3233353637383A3B3B3E3E403F414345454647494A4D
4C4F4F515252555657595A5A5C5D5E60616265666667686A6B6D6F6E7072747575777778
7878797B7D7D7E7D7D7F80808082838788888A8D8D8C9295979699989A9D9FA1A2A4A2A4
A4A9ACACADAFB5B5B6B7B9B8BCBEBDC0C0C0C4C2C0C3C5C7CAC9CAC9CAC7C6C8C7C5C5C7
C4C4C5C5C4C5C5C7C6C5C4C1C1C8C0C2C2C5C4C3C4C4C5C1C3C5C5C5C7C3C4C9C1C6C6C7
CBCBC8C9CBCFCBCAC9C8CACBCAC7C6C7C8C9C6CAC9CDCECFCCCECBCDCACCCECCCBD0CED0
D0D4D0CFD0D3D1D7D4D5D8D8D9DCDEDDDEE0DEE4E4E7E7E9E5E8E9EBE8EBE9ECE8E9EAEB
EBE6ECEFEBEBEFEEE9EFEAE9E9ECEDEEECECE7E5E8E4E2E7E6E6E7E8E7E5E7EAE6E7E7EA
E7E4E7E4E7E7E5E3E2E2DEDEDCDBD8DBDCD8D3D3D7D5D7D5D6D4D4D3CCCAC7CBC3C2C1C2
C0BFBEBBBAB8B4B4B6B0ADADABACA8A5A3A4A39F9D9A97989794919392928F918E8B8C8A
8A8B8B8B888A8B88898B878A8B8B898989888886878788878685848282818181817E7C7B
797776757372706C6A6A676663625F605C5B5857535451504F4D4B4948464444423F3D3D
3B3A383635343331302E2C2B2B2A2A292928282827272727272727272727262726262626
2627262626272626
252626262626262626262726262626262626262727262627272726262627272727272828
28282929292A2A2A2B2C2C2D2E2F313234363638393B3C3C3D3F3F414243454748494A4B
4C4D4E505253565558575A5B5C5D5D606164636565666A696B6B6E6E7171747777787979
7B7A7A7B7C7B7D7E7C7D7D7D7F8182848588898B8C8F9194949596999A9A9C9DA09FA4A6
A7A6A7A8ADAEB0B3B2B5B6B7B8BBBCBDBEC1BFBEBFC3C2C7C7C7CACACACAC7C6C7C8C8C5
C6C8C5C4C7C5C5C8C7C5C2C2C2C3C2C4C7C3C4C3C2C4C2C4C3C6C7C9C7C5C6C6C5C4C4C7
CBC7C7CBCCC9CCCAC7C8C8C9CAC9C8C7C5C7C7CAC6CACBCECBCBCBCDCDCFCACECACECECB
CFCECED0D0D1D1D3D3D7D4D5D6DCDDDEDEDCDFE4E3E4E2E4E5EBE9E9EBE6E7E8EAECEAE8
EDECEBEAEBEFEEECE9ECEDE9EAEBEDE8E5E8EAEAE5E6E8E8E7E6E4E4E4E5E5E7E3E5EAE9
EAE9E9E8E7E7E6E4E4E0DFDDDBDED8D7D7D9D7D6D7D6D9D9D7D6D5D3D1CDCBCBC4C5C3C2
C0C0C1BBBCB8B7B8B0B1B1B0ACADABA7A5A3A1A1A0A09D98969594918E8F8F8E8E8E8A8A
8B8B898A898A898785878888888987888587878785898785858384818281807F7F7E7C7B
787877777271706C6B6A68666464605F5C5A5B575553514F4F4D4B4A4846454241403E3D
3B393737353332302F2D2D2C2B2A2A2A2929282828282727272726272727272727262726
2626262626262626
262726262625262626262626272627262626262726262627272727272727272727272728
2828292829292A2A2B2C2C2D2E2F313234353637383A3B3C3D3E3F404242444647464A4A
4B4C4F4F515353555657595B5B5D5E5F60616262656666696B6D6D707072737679797879
787A7B7B7A7B7D7C7A7D7C7B7E7F818083868789888A908F9192959698999C9B9D9FA2A0
A3A6A7A9AAAAACAEB0B5B3B6B7BAB9BDBBC0C0BEBFC1C1C4C6C7C6C9C5C7C8C9C6C7C7C7
C7C5C7C8C5C7C7C4C5C5C4C5C5C6C2C4C5C6C5C2C6C3C3C2C4C7C8C9C6C4C8C5C2C5C5C7
CBCBC7CBC9CBC9CECBCCC8CAC7C6C7C8C8C9C6C5C8CBC6CBC8CCC9CAC9CECDCECBCCCECD
CCCECECFCFD0D1CFD3D4D3D4DBD7D6D8D9DBDCE1E3E1E1E4E2E3E3E6E4E9E8EAE8E9E9E8
E9E9E5EBEDEAEBEBEDECEAE8EAEAE8E9EAE7E6E8E4E9E7E8E7E5E3E4E0E3E0E3E3E5E5E5
E8E9E6E4E6E7E6E5E1E1DFDEDCDCDAD9D9D9D6D9D8D7D7D4D8D2D6D3D0D2CDC9CAC7C0C6
C0C1BFBEBBB9B9B7B4AFB0B1ADB0ADACA6A7A5A2A09E9E9B9896969394928F8D8C8A898A
8A898A8987888986878585868786878685868587868683848483838282807F7E7E7F7D7A
7B7A757674736F706E6A68676662605F5C5C5A57565353524E4D4A494846444240403E3D
3A393936353333312F2D2D2C2C2A2A282928282828272727272727272627272626262626
2626262626262626
252626262626262626262626262726262627262727262627272727272727272727272828
2828282929292A2B2B2B2C2C2E30313334353637393B3B3D3D3E3E40424344454648484B
4C4B4D50505153535456595B5C5C5D5D5F6364636565666A6A6C6E6F71717576797A7A7B
7A78787B7B7B7A7C7D7C7A7A7B7D7D8181848586868A8C8E8F90939796989B9A9C9FA0A2
A2A5A4A7AAAAA9ACB1B0B0B4B7B6BAB9BABEBFC1C0C1C3C4C3C6C6C6C5C5C9CBC9C9CACA
C7C8C9C8C7C6C6C7C8C5C7C7C2C3C5C4C5C4C4C5C3C3C0C2C4C4C6C6C6C4C3C5C6C4C8C9
CDC9C8C7C7CBC9CACCCDCBC9CAC5C7C9C9C8C3CAC9CDC8C7CAC6CACCCCCFC8CDCBCCCACB
CCCECFCED2D1CFCFCFD2D0D3D5D2D6D9DAD9D9DAE0E1DFE2E3E4E3E3E2E3E6E5E4E7E9E8
E5E8E8EAEEE9EAEDEBEDEDEBE6EBEAEAE9E6E3E6EAEAE7E8E8E7E1E4E0E3E3E0E4E5E4E7
E8E8EBE6E3E3E3E0E3E1E0E0DEDEDDDAD9D9D5D7D4D8D5D4D5D5D3D1D1D2CFCCCCC8C6C6
C3C1BDBDB9B9B7B4B3B3B0B0B1ACAAAEAAA8A4A2A19E9D9A9999959591918E8F8C8B8B8A
888889888688868686858484848686868786868483868485828281817E807F807D7E7D7B
787878757372716F6E6B6A66646460605C5C5A58555351504F4D4B4A47454442413F3E3C
3A3A3737343332312F2D2C2C2B2A29292928282828272727272727262627272727262626
2626262626262626
262626272626262626262626262626262626262627272626272627272627272727272728
282828292929292A2B2C2D2D2E2F31313334363738393A3B3D3E3F3F424246464747494A
4A4C4E4F50525156555757595A5B5C5E5E62626365666469686A6C6D6F717175797A7D7B
797C787A797B7A7A7A79787B7C7E7C7E82838386858A898E8F91919496969798999B9C9F
9EA2A3A4A5A9ABAAACADB1B2B4B4B7BABDBDBEC0C1BFBEC3C2C5C5C2C7C6C7CAC8C7C9C7
C8CAC6CCC6C6C5C5C6C5C8C6C4C5C3C5C4C6C2C4C2CCC5C3C1C8C3C6C5C8C7C6C4C9C7CE
C8CAC8C7C9CDCACCCCCBCEC9C7C7C8C9C8C6C4C7C8C7C9C8C4C8C6CBCAC9CBCBCCCBCCCB
CCCDD0CECCCFCFCFD1CFD0D4D4D6D6D6D9D9D9DEDFE0E0DEE0E3E3DEE2DFE7E5E4E7E8E6
E9E6E9E8E9EAEBEAE7E9EBEBECE7E8E7E6E9E8E7E9E6E8EBE6E4E3E5E2E1E2E5E4E5E8E4
E6E1E8E4E4E3E2E3E6E2DEE2DFE1DEDDDDDBD8D6D7D8D7D5D2D4D2D2D2D1CECECAC9C7C6
C4C1BFBABAB7B7B8B6B2B1B0AEAAACA9AAA6A4A1A0A09D9B9B98969492928C8C8F8C8A88
8787878485858384838383828584818183828484838382828182828080807E7E7D7D7A7B
797A7775737373706E6C6967656461605D5E5A59555552514F4E4C4A4846444241403E3D
3A393737353432302F2E2D2C2B2A29292829282728282728272727272627272626262627
2626262626262626
262626262626262627262726272626262626272626262626272727272727272727282828
28282829292A2A2A2B2C2C2D2D2E30323234373738383A3B3C3E3F40414244454647494A
4B4D4D4E5051535455565859595B5B5C5F5E62626463676767696B6D6D70747578797A79
7B7979777A7B7B7B7A797B7A7C7B7D7D808183838487898B8C8E8F949295969B9A9B9C9F
9FA2A1A0A3A6A9AAACAEB0B1B2B2B4B6BCBBBCBEC2BFC1C0C0C2C2C5C4C4C4C7C9C9CCC9
CACCC8CCC9C9C7C7C8C7C4C9C5C6C6C4C6C5C7C8C5C6C4C3C6C5C6C3C7C9C9C9CAC9C8CA
CAC7C9C5C6CAC9C9C9CAC8C5C8C8C9C8C5C6C9C8C8C8C8C5C6C6C7C7CACBCBC8CCCDCDCD
CFC9C9CDCDCED0D1D1D3D3D0D0D3D1D4D5D6D6D9D9DADDDFDFDFE2E0E2E3E1E6E2E5E7E6
E6E6E6E8E8E8E9E9E7E9EAE8E9E8E5E8E7E7E7E9E5E7E6E9E8E5E3E5E5E6E7E2E8E6E6E2
E2E4E6E7E1E4E5E0E3E1E2DFE0E7E0DEDBDCD8D8D6D9D4D5D7D3D6D3CFD1D0D0CCC9C5C3
C5C0BEBBBCBCBCBAB8B7B4B3AFACAFACABA7A6A4A09DA09B9C9A9994959190928D8B8A89
888884848383838484817E8381808281818483808181828181827F7F807F7D7F7C7B7C7A
77787777747372716E6C6C6A66636260605D5A58565452514E4D4B4948454542403F3E3B
3A393737353332312F2D2D2C2C2A2A292928282827272727272727272727272626262626
2626262626262626
262626262626262626262626262626272626262727272627272727272727272727272728
2828292928292A2A2B2B2B2D2D2F31313335353737383A3B3C3D3F40424343474547494A
4A4C4E4E504F5153555657595A5C5B5C5D5F61626264656667676A6B706F6F7276787978
7879797879797B797B7C7A7B7A7D7F7C7F807F8384848788898A8E8F92949797999B999E
9F9E9FA3A4A5A9AAAAACABADB0B1B3B5B7B8BBBCBCBDC3BEC1C0C0C2C4C3C5C6C9C9C8C9
C9CAC9C8CBC8CBC9C8CBC7C8C8C7CAC8C7C9C6C5C6C4C5C4C2C5C3C3C6C6C8C9C7C8CBC7
C4C6C7C6C6C8C7C8CACAC8CACCCACAC9CAC7C9C6C7C4C6C4C7C4CAC8C6C8CACBCACDCDCD
D1CCD0CDD0CFCDCDCFD0D1D2D2D0D3D3D3D8D6D6D9D9DDDCDDDDDFE3E3E0E3E2E3E1E6E3
E5E1E9E5E6E8E7E7E8E8E9EBE7E9E7E4E5E7E5EAE6E7E9E6E5E5E5E5E9E8E6E9E7E7E5E6
E4E5E6E4E2E3E3E4E1DFE2E3E5E3E2DFDED9D8DADAD8D5D4D7D4D4D2D1D0D4CFCBCDC9C7
C7C5C1BEBFBFBEBEBAB3B9B3B1AFAEAFAFAAA6A3A2A29F9D9A979696939291928C8B8B89
878687848383818181827F8180807F807E80818081818282807F7F807F7D7E7C7B7A7A79
79787476757372716F6C6B6866646361605C5C5958555352504E4D4B4746444341403E3B
3A383736343332302F2D2C2C2B2A2A292928282827282827272726272726262627272626
2626262626262627
262626262626262626262626262727262726262626272626262627272727272727282828
2828282829292A2A2B2B2C2C2D2E3032333535373739393B3C3D3F3F414243454649484A
4A4B4C4D4F52515354565557585B5B5D5D5E5F616361646666676A6B6C6C6F7374777776
7677787877797A7979797B797A7B7B7D7D7E80808184868687898F8E9092959398989B9C
9B9F9D9EA2A5A7A8A8AAABACAEAEAFB3B6B9B9BBBCBFC0C0BDC2C3C3C1C5C3C5C7C7C7C6
C8CCC9CBC9CDCACAC8C8CACCCBC9C7C6C4C5C6C8C5C3C5C7C5C3C2C6C7C5C7C5C8CBC9C8
C8C6C5C6C6C7C5C8C5C7CAC7C5C9C7C7C9C8CAC8C5C6C3C6C6C7C7C9C6C5C8C7C8C9CBCA
CCCCCDCECDCCCED1CDCCCED0CFD2D2D1D2D2D2D4D9DAD8DADDDCDDE1DDE0E3DFE2E1E1E5
E1E6E6E6E7E6EAE6E9EAE6EBE8E9E8E9E8E5EAE8E9ECE4E6E4E6E7ECE9E8E8EAE7E6E7E4
E2E4E5E7E1E2E2E5E0E4E5E2E3E2DFE0DEDCDBD8D9D8D9D7D6D2D6D4D2D3D4CED0CDCCC8
CBC6C5C0C2C2BFBEBFBCB8B6B6B1B0ADADAAA8A3A3A2A09F9E9B9897959692908E8D8889
858783848384808282817E807E7E7E7F7F7E7E7F7F81817F81807E7F7D7E7D7C797B7979
79787475747271706C6C6C6C67666360615F5D5B575555514F4E4C4B49464341413F3D3D
3A393735353333312F2E2D2B2A2A29292928282828272727272727272726272626262627
2626262626262626
262726262626262626262626262626262627262726272726272627262627272727272728
2828292929292A2A2B2B2C2C2D2F3031333435363738393A3B3C3F40414243444446484A
494C4E4E4F5151525357555758585A5C5D5E6061626565656668696A6C6E6F7072727273
75767677787778797A7A7B7A7A7B7D7D7E7E7E818281828388898A8C8C8F909197989B99
9C9C9FA19FA2A3A5A7A9A8A9A9AEAFB3B4B4B7BCBAB8BBC1C0C2C2C6C4C5C6C6C9C7C9C7
C7C8C9C8CACACBCAC8CAC9CBCCC8C9C9C7C7C8C7C6C7CAC5C4C4C2C2C4C3C5C4C6C5C8C4
C8C4C5C7C6C4C8C6C7C8CBC7CACACECACCCAC9C9CBC4C4C2C7C8C5C7C8C5C7C7C8C9CCCB
C9C9CDCCCECBCECCCCCDCBCECECED0D2D2D1D7D6D3D4D6D6D5DBDBDCDEDFDFE2E3DDE1DF
E4E1E8E5E5E6E6E5E5E8E7E8E7EBE7E8E8EBE6EBE6E5E8E8E8E5E9E4EAE6EAE7E8E6E4E6
E3E5E4E5E5E2DFE1E3E1E4E2DFE6DDDFDDDBDDDBDCDBD7D8D7D6D5D3D5D4D1D6D3CFCCCC
CAC5C5C3C4C5C4C2C3BEBCB8B5B4B3B4ACACACA8A7A5A09F9C9C999895949391918D8C8A
898785858181817F807F7F807E7D7D7E7E7E7E7F7C7F7C807C7F7D7C7C7E7C7979797979
777674777373726F6E6C6B6867626462605F5D5B58555450504D4C4A4846454241403D3B
3A383736343332302E2E2D2C2A2A2A292928282828272727272727262726262626262627
2626262626262626
252726262626262626262627262626262626262627272727272627262727272727272728
2828282928292A2A2A2B2B2C2D2F3031323435353637383A3B3C3E3F4041424445454949
4B4C4D4D50515353545556565759595B5B5F5F6262636565666768676B6C6E6E71717374
7375757676777A7B7A7B7B7C797B7B7B7D7D7E8081828384848688888B8D8F9294979598
999C9C9C9FA3A2A3A2A5A7A7A9ABADAFB1B6B6B7B5BAB9BFBEC1C2C1C5C3C6C7C5C7C7C8
C8C8CAC9CCC7CBCBCBCACCCBCAC8CAC8CBC9C5C6C7C9C7C7C6C5C5C3C5C4C6C4C9C7C4C7
C5C7C5C6C6C8C6C5C6C9C6C8C9CBC7C6CBCACCCAC8C8C6C6C7C6C6C7C4C4C8C8C7C8C8CB
CAC7CDCDC9CDCDCACCCDCCCBCDCFCFCECFD0D0D2D3D4D1D3D7D5DADADEDEDCE1DFE2DDE3
E1E2E3E4E5E4E3E5E3E7E3E5E7E8EDEBEAEAEBE8E7E6E6E6E9E7E5E5E4EAE8E7E6E4E3E2
E3E3E2E3E4E2E2E2E3E4E0E1E2E1E1E1DEDEDEDDDCDAD8D7D7D6D3D5D2D3D4D5D1D0D2CD
CACACAC6C7C7C6C6C3C3BBBBB9B5B1B2B1ADADABA6A7A3A0A09E9A989B969491918E8D8B
89888586868182817E7E7D7F7C7C7B7C7D7C7D7D7C7C7D7C7D7C7D7F7D7A787C79787877
777674737373706E6D6D6B6966666363615E5D5C58565452504F4C4C48474343413F3E3C
3A383836343331302F2D2C2C2B2A2A292928282827282727272727262727272626262626
2626262626262626
262626262626262626262626262626262626262726262626262727272627272727282728
272828282829292A2B2B2B2B2D2E2F31323434363637383B3B3C3E3F4041424446454749
4A4B4C4D4F5151535654565758595B5C5D5E5F6261616564666567696B6C6C6C6D70716F
727474767876797A7A7B797A7A7C7A7A7C7C7F7F8182828282848089878B8D8E8F909396
93989C9C9EA0A1A2A2A5A7A6A6A9AAABB1AFB1B3B6B9BABCBDBDC2BFC0C4C2C2C4C4C4C4
C9C8C8CBCACBCCC7C7CBCCCBCCCCC9C9C7C9C9C8C6C6C9C9C9CAC6C8C6C2C7C5C6C5C8C4
C5C8C7C6C6C9C6C8C6C9CAC5C6C7C7C6CBCACAC8C7C7C5C5C3C9C7C6C7C8C9C7C6C7CBC8
CAC9C9CACBCACAC9CBCBCECDD0CDCED1D0CFD2D1CDD1D0D0D3D5D6D7D8DADBDBDDDFE1DE
E0E0E3E4E6E2E5E3E3E2E5E6E6EAE9E9E8E5E5E8E7E8EAE7E8E6E6E6E5E8E7E6E3E4E2E1
E4E2E4E2E3E3E0E2DFE3E2E6E4DFE4DFDBDDD9DCDBDBDBDAD8D7D5D2D3D4D3D5D1CED0D1
D0CCC9C6CCCAC8C8C6C3C1C0BDB9B8B6B4B0AFACA8A5A6A4A0A09D9A97979494918E8F8A
8A89878483828281807F7F7E7B7E7B7E7B7C7B7B7A7A7B7B7A7C7B7C7B7B7B7978797777
757674757271706E6F6B6A6869666462615F5E5D5A585553514F4C4C48474542413F3E3C
3A383835343231302F2D2C2B2B2A29292928282827272727272727272627272626272626
2626262726262626
262626262626272626262626262626272626262627262626272727272727272727272728
282828292929292A2A2A2C2C2D2E3031323334363637383A3B3C3C3F4040424344454848
484C4C4D4E5053535453565759595A5A5D5C5D5F5F62646365646668686B6A6A6C6F6E6F
6F747375767977787B7A7C7C7D7B7B7C7C7D7D7E7D818282818384858788888B8E8F9194
959597989B9C9E9FA3A4A6A7A4A7A8AAACB0B3B1B3B4B8BABBBEBCBFC2C1C2C2C3C2C5C6
C8C5C9CDCCC9C8CACCCDCACCCDCDCACCC9C9C7C7C8C9CACACACACAC9C9C9C5C9C7C6C5C8
C7C6C5C7CAC9C9C6C7C7C6C7C5CAC6CACACAC7C9C4C4C8C6C7C8C8C9C9C9CBC9C7C7CBC9
C7C7C9C9CACECACECDCCCBCCCCCECCCDCFCFCECFCFD0D1D0CED5D4D8D7DADDDCDEDBDEE2
E4E1E1E1DFE2E3E3E2E6E2E7E5EEE9E7E7E4E3E5E6E7EBEAEAE9E5E8E4E6E6E8E6E4E7E5
E3E4E4E4E5E4E3E0E3E3E1E3E1E3E3E0DFDDDEDDDADEDCDCD8D5D6D4D5D5D2D2D0CFCAD2
CCD2CDC8C9CCC6C7C6C5C2C3BDBDBBBAB8B3ABADAAABA8A6A59F9A999A979496908F8D8C
8A8A878584828181817D7C7D7C7C797B79797A797B79797979797C7A797A777877777676
7576737371716F6E6C6A69696866646261605F5C5A595753534F4E4B49484544413F3D3B
3A383636343231302E2D2B2C2A2A29292828282827272727272627272726272627262727
2726262626262626
262726262626262626262626262626262626262626262726262727262727272727272828
2728282929292A2A2A2A2B2C2C2E2F3032333536363738393A3B3D3E3F3F424344454747
4A494C4E4D4F51525355555757595A5B5D5C5D5F606062626466676867696C6A6C6B6D6D
6F72717275767577787A797B7C7B7C7D7D7C7E7E7F81818182848484878687898B8B8E90
909598989C9D9C9D9FA3A3A3A4A6A6A8AAAAACADB0B0B4B8B6B9BBBEBEBEC1BFC3C4C5C5
C5C6C8C8C7CBCCCBCDCCCCCCCCCDCAC9C8C9CBCACBC8C9C8C9CDC9C7C8C8C5C7C9C8C6C5
C8C6C7C6C9C6C7C8C8C8C7C7CAC6C6C9C7C9C6C8C6C5CAC8C5C5C9C5CBC6CBC6C9C9C7CA
CBC6C6C7C8C8C8C8CDCACCCCCDCDCECDCCCECDCDCED0D0CBD1D1D7D6D6D5DBD9DCDBDDDC
DCE0DEE0DEDFE1E1E2E1E3E3E3E5E7E5E7E2E3E3E7E9E8EAEAEAE8E4E5E4E3E4E8E4E5E5
E5E3E4E2E4E4E4E6E0E4E2E3E2E3E1E1E1DFDEDADFDFDED8DBDBD8D9D6D6D4D1D2D0CCCE
CFCECFCCCBCBC8C8C7C3C6C3C2BFC0BCBAB5B3AFAEABADA8A5A29E9D9D98979490918D8A
8B8B8886838582807F7F7D7A7B7A7B797A797A7A77797979777877787977777677757473
737273727070706B6C6B696865666363615F5E5C5B57575453514E4C4B474543403F3D3C
3B383635343330302E2D2B2B2A2929292928272728272727272727272727272626262726
2626262626262626
262626262626262626272626262626262726262626262627272727272727272727272727
28282828292929292A2A2B2C2D2E2F3032333436363638383A3B3D3E4040424344444647
474A4C4C4F4E505252525557575A595B5B5C5D5F5E6063636362626566696A6B6A6D6C6B
6E716F71737375787678787A7B7D7F7C7E7F7B7E7C7C7F80818182848585858785888D8E
8F9395969C9A989B9F9D9FA3A4A4A7A8A5A9A9AEB0B1B3B2B5B7B9BABABABBC1C0C1C4C5
C8C7C3C7CDC9CBCBCBCBCACCCDCECACBCACCC9C9C9C9CAC9C8C7CAC8C9C5C6C8C7C7C5C6
C5C8C7C6C6C5C6C6C5C9C6CCC7C8C7C7C6C9CAC9C8C7C7C6C5C8C8CBC6CAC6CAC9C8C9CA
C9CAC9CBC9C8CAC8CCCDCACACDCECCD0CECECFCDCDCDCBD0CED3D0D1D6D8D6D7D9D9DADB
DADCDEDEDFE1DEDFE0E0E1E4E2E5E3E6E5E2E5E2E7E7E4E9E9E8E5E5E4E7EAE9E6E5E8E6
E4E5E5E5E5E0E3E5E1E2E4E5E0E2E2DFDEE2DBE0DFE0DEDEDADAD8D6D7D8D4D5D2CED1D1
D0D0CFCECACCC9CAC7C7C4C4C5C3C1BBBCBCB4B4B0ADACAAA8A3A1A39C9999979191908D
8E8B8987868583827F7F7E7A797B787A7878777777767677777879787877767675747473
7371716F706F6E6C6A6A6A6767656561605F5E5D5A58565452514F4C4B4A4643413F3E3C
3A3836353432312F2F2D2C2B2A2A29292828282827272727272726272726272626272627
2626262626262626
262626262627262626262626262626262626272626272726272727272727272727272827
272828282929292A2A2A2B2C2C2D2E303133343536363939393C3C3E3E40414343444647
49494B4C4E4F4F51525254555759595A5B5C5B5E5F5F63626264646466696B6C6D6D6D6E
6E6E7070717375747577787B7B7D7D7D7E7F7F7F7C807F81808381848485878788888B8B
8E8F939595979A9D9B9CA1A1A1A3A5A3A5A7A8AAACACAEB2B3B5B4B6B9BABDC0C1BFC4C3
C5C6C5C5C8CACBCBCFCCCDCBCCCAD2CCCBCCCACCCACBCCC8C8C8C5CAC7C6C9C5C8C6C8C5
C7C5CAC8C6CAC5C4C7C9CACACAC7C7C5CAC5C8C6C5C7C4C4C6C7C7C5C7C8C9C9C8C9CACA
CBCACACAC5C6C5C4CBCACAC8CCCBCCCBCACBCACBCBCECDCBCECFD4D0D2D1D4D4D5D7D9DA
D9D9DFDBE0DCE2E1E0DFDFE2E4E2E5E4E5E5E4E8E7E4E6E7E8E7E6E6E3E7E5E5E4E8E6E8
E8E5E6E5E2E3E5E0E2E5E0E4E3E3E1E1E4E1E0DFE2DEDEDADCDBD8D9D6D7D8D4D5D1D0D2
CFCED0CCCBC7CAC7C8C6C7C4C4C4C3BEBEBBB8B6B5B3AFABA8AAA4A0A09C9B989795928F
8A8C898787838481807F7E7C7C7A7C777777797575757576777676757674747473737472
717271716F6D6D6B6B6968676664626160605C5B5B58565352524E4E4A494644413F3F3C
393937353332302F2E2D2B2B2A2929292928282827272727272727262627262726262626
2626262726262626
262626262626262626262626262626262626272626272727272627272727272727272728
272828282929292A2A2A2B2C2C2D2E3031333434363737393B3B3B3D3F40404144454748
48494A4B4E4F4F5151525558575B5A595A5A5C5D5D606161626363646669686E6C6D6C6E
716E6F72717272727575747A797C7C7D7E7C7D7D7E7E7E7F818180818283868687898888
8D8C90919596959B999A9CA1A1A0A2A3A4A8A6AAABABAAAEB0B2B3B5B6B9B9BEBEBEC4C2
C6C6C6C7C6C8C9CBC7CBCCCECED0CCCCCECBCECBCCCBCBCDC9CBC9C9CBCCCAC7C8C9C8C9
C6C9C7C6C6C6C5C4C5C6C9C9C9CAC7CBC6C9C6C5C8C6C7C6C8C8C7C9C9C7C9C8CAC8C7C5
CAC9C5C6C6C5C6CACDCDCACBCACDCCCBCCCBCCCAC9CCCBCECECECFD0D1D4D3D2D4D9D8D6
DBDADADCDEDDDCDDDDDCDEE4E0E4E6E7E1E7E6E7E3E5E3E6E5E7E7E8E5E6E8E6E5E7EAE5
E7E9E5E3E3E7E2E6E4E1E5E4E2E4E3E0E1E2E1DEE1E2DFDCD9DED8D9DBD9D6D5D4D4D2D2
CFCFCDCECCC9C9CBC7C7C4C3C8C7C3C0BDBBB8B7B4B6B1AFA9A8A7A39E9D9C999894928F
8E8B8987878783837F80807E7D7979787878757775767576777373747475757275747170
7171706F6E6B6C6A6B67676764636161605D5C5A5957565353514F4D4B49464442413C3B
393836353331302F2E2C2C2A2A2A29292928282827272727272727262627262726262626
2626262726262626
252626262626262626262726262626262626262626262726262627272627262727272827
272728282829292A2A2A2A2B2C2D2E3032333335363637393B3B3B3D3F3E404143444446
474A494D4C4F4F505152535554585758595B5C5C5D5E6062606363666468696B6A6F706F
6F6E6E7071747373747473767A7B7B7E7C7E7E7C807E7F7E81818381818481838685878B
8B8C8B90919596979A9C9D9B9E9EA0A3A3A4A7A7A9ABACADADB0B3B3B4B6BBB9BEBFC1C3
C0C4C5C7C7C7CAC8C7C8C8C9CBCDCFCFCECECCCECCCCCACCC9CDCBCCCACBCBCCCBCBC6CB
C8C7C8C9C7C9C6C8C5C8CAC8C9C8C8C9C8CAC7C7C7C8C4C3C9C8C7C8C6C6C9CAC9C6CAC9
C7C6C6C5C8CAC9CAC7C8CBC9CAC9CBCECDCBCBCDC8D2CBD0CCCFCDCBD0CFD3D2D4D5D4D7
D6D9D8DADCE0DEDEDFE0E3DCE3E4E5E6E7E7E8E5E8E4E7E7E5E4E6E5E9E8E4E4E5E9E6E8
E7E8E6E8E5E3E7E4E5E4E5E1E2E7E2E2E4E2E0DEDBDFDCDEDADDDCDBDAD6D7D7D3D7D2D3
D3D0CFCBCDCDC8C8C7C5CBC9C7C3C3C3C1BDBCBCBAB4B0B0B0ACABA8A3A19F9A9B979492
8F8B8C8A8888838582807F7E7B7B7B797877767677767674747372727271717371717070
6E706F6D6D6C6A6A6867676564636161605D5C5A5856555251504E4D4A4A464542403D3B
3A3737353332302F2E2C2C2A2A2A29292828282727282727272727272626272627262626
2626262626262626
252626262626262626262626272626262726272726262626272727272727272727272727
2828282828282929292A2A2B2B2D2E2E3032333535363839393B3C3D3E3F414043434546
474A4B4A4B4F4E505152535556575758585B5B5D5B5F6062616362646665686A6A6E6D6E
6E6D6F6F727372747474747377797A7A7D7C7E7E7D807F7F817E82818181838486848688
8C8D8C8E8F949497979A9B9D9C9FA0A3A2A3A6A5A8ABAAABB0ADAFB3B2B3B8BCBDBEC1C1
C3C4C2C2C5C4C7C7C5CAC9CAC9CECBD0CDCBCCCDCDCECACACCC9CACDCDCAC9CDC9CAC8C7
C8CAC8CAC8C7C6C5CBCACCC8C9C9C7CBC7C9C8C8C6C6C5C7C5C9C9C7C4C7C6CAC8C7C5C7
C9C6C5C7C8C7C5C7C7C8C8C5CAC9CDCDCDCBCACBCBCCC8CCCCCDCED0CCCDCED0D4D4D5D6
D8D7D9D7D8DBDCDEDEDDDFE0E1E0E1E7E3E8E9E7E7E6E4E4E4E2E4E6E7E5E7E4E2E5EAE8
E6E5E3E6E5E7EAE5E5E4E0E2E2E1E3E3E4E2E3E2DEDDDFDDDCDEDBDCDBD8DAD9D6D6D3D4
D1D0D1D0CBCDCBC8C7C9C8C7C5C4C3C3C3C2BEBBBBB6B4B4B2B2ACA8A5A2A09F9E9C9794
918F8D8A8A86878683817F7F7E7D7B7779757674777774737372717071726F737071706E
6E6D6C6A6B6A6A69686765646463605F5D5D5B595857545352504E4C4C484645423F3E3C
3A3836353333302F2E2C2C2B2A2929292828282827272727272727262627262726262626
2626262626262626
262626262626262726262626262626262626272726262727262727262627262727272727
2728282828282929292A2A2B2C2D2D2F3030333436363738393A3C3C3D3E404142434546
47484B4B4C4D4F515052535555565858585A5C5D5F5E5F6061646264676566676B6A6C6C
6D6D707072737172737474747677797A7C7B7C7D7D7C817F807F7F818181838285858487
898A8C8B8C8F9091939596999C9BA2A1A3A1A5A5A6A6A6ABAAABAEAFB3B5B3B8BBBBBCBE
C0C1C3C2C6C4C8C4C5C7C9C9CBCDCECFCBCED0CDCDCBCBCDCDCDCDCACCCBCBCCC9C9C9CB
C8C9CBCACCC8C6C9C7CAC9CCC9C7C9C8C6C6C6C7C8C9C7C3C6C8C9C3C8C8C8C6C7C3C5C9
C5C7C8C5C5C6C3C2C4C5C8C6C9C8CACDCACBCAC8CDCCCDCDCDCBCCCFCECED0CFD3D0D1D4
D4D5D6D7D9DADBDDDCDAE1E0DFE1E0DDE5E2E7E7E5E5E5E2E4E2E4E5E5E7EAE4E5E5E5E6
E6E5E7EAE9E6E6E5E4E2E5E2E2E1E3E4E4E2E3DFDCDDDDDFDFE0DDDADADBD7D6D9D8D6D4
D3D0D0D2CDCCCDCAC9C9C7C8C8C3C2BFC5C2C1BBBCBAB9B5B3B0AEA9A8A7A49C9C9C9795
93918E8D8A8A8A868482817D7D7A7A7B7976767974747574717371717070716D6F6F6F6C
6F6B6B6C69696A686666646261605F5D5D5A5A5857575453514E4E4C4B47464341403D3B
3A3835353332302F2D2C2B2B2A2A29282828282827272727262727272727262627262626
2626262626262626
262726262626262726262626262626262626262626272726262626272727272727272727
2727282828282929292A2B2B2C2C2E2E3032333435363737393A3C3D3E403F4042424546
4749494A4B4E4E514E52545354545759595B5C5C5D5D5F5E616262626565666E67696B6B
6C6D6F6F71717273727172757677797777797C7B7E817F80817F80807E80828084868687
858788888B8C8F91909696959C9E9E9E9FA2A2A5A4A8A6A8A7ACA9ADAFB0B2B4B9BDBCBF
BDC4C2C2C0C4C6C5C6CAC7CACBCCCCCBCBCECCCDCCCECDCDCACECCCECFCCCBCECDCCCAC7
CEC9C9C9CCC7CACAC8C9CDD4C8C5C5C8C5C5C6C6C6C8C7C6C5C8C4C6CAC5C7C8C5C6C2C6
C4C2C3C4C4C6C7C5C5C6C3C7C9CACBCCCACBCACDCCCDCCCDCECFCCCDCBCBCFCDD0CFCFCF
D0D4D5D8D5DAD9DEDCDDDDDEDFDDE2E1DCE4E3E5E5E2E3E3E1E2E4E6E5EBE6E6E5E7E5E4
E8E6E5E5E8E8E9E7E6E1E3E2E0E3DFE5E3E0E5E0DBDCDCDCDEE1DEDDDCD8D9D9D9DCDCD7
D6D6CFD0CECDCDCBCACBCAC9C5C9C3C3C1C3C0C2BCBEBAB9B3B1B1ABA9A7A4A29E9F9B97
959390908B8A8885848183807D7F7B7A797875767274757070717070706F6D6E706E6C6D
6B6C6A69696867666565636361605F5C5C5A5A585953545451504D4C4B48464342403D3C
3A3836343332302F2D2C2B2A2A2929292928282827272727272726262627262626272626
2626262626262626
262626262626262626262626262627262626262626272727262627272627272727272727
2827282828282929292A2A2B2C2C2D2E2F3032343435373739393A3D3D3F424141434447
4847494A4B4C4D4E50525352565657585A5B5B5B5D5D5D5F60616363656467696769696A
6C6C6D6D7170717271737275787878797A78797B7E7F808180818082817F807F81838283
87858889888B8D8B8E9391979B99999B9BA1A0A4A3A3A5A6A7A7AAA8AEAEB3B4B5B5B8BB
BCBBBBC1C1C3C0C5C4C6CAC7C9CACAC7C9C9CBCECDCECDCBCDCDD0CCCACDCDCBCBCCCDCC
CDCBCBCBCBCBCCC8C8C9CCD1BDC2C7C9C5C7C6C5C7C7C7C7C8C5C5C6C5C5CAC8C9C5C6C4
C3C3C2C4C8C4C6C6C4C6C6C8C6C7C9C7CAC6C9CCC7CBCDCDCCC9CFCDCFCECBCFCECFCCD2
D3D0D6D4D6D5D6D5DADADDDDDFDADCDEDCDDE0E4E4E4E2E2E4E4E4E5E5E6E3E0E5E2E4E6
E5E5E8E4E5E3E6E8E5E1E4E2E2DDE0E0E0E0E2DEDFDDDFDDDEDADCDBD7D7D8D8D7DBD8DA
D6D3D1CFD1D0D0CFCECCCBC8C8CAC6C5C1C4C3BFBFBBBEBBB7B7B3AEAEA7A7A4A2A09D9A
98969392908B8789858E83807F7D7C79787978757673757272706F7170706E6E6C6C6B6A
6B6A6B6868646663646362615F5E5E5C5B5A595756565352504D4E4C49484443413F3D3C
3A38353533312F2F2D2C2A2A2A2929282828282727272627272727272627262626262626
2626262626262726
262626262626262626262626262726262626262626262627262627272727262727272727
27282828282828292A2A2A2B2C2C2D2E2F31323335353638383A3B3C3D3E3F4241434345
464847494C4E4E4E505153535455565859595C5B5C5D5E5E61606362646466676568696A
6B6C6E6E6F6F6E717072757573777979787A7B7B7C7F7F7E81807E8080817F8382808586
8786858789898B8E908E9195969799989B9C9DA2A2A1A4A6A1AAA5A9ABADAEB0B5B2B7B8
B6B9BBBDBDC1C2C1C2C4C6CAC8C9C9C5C8C8CCCECECECBCFCBD0CED0CDCCCDCACCCCCBCA
CBCDCCCACBCACBC9C7C7C7C6C3C5C7C7C8C7C5C5C8C5CBC9C8C6C2C3C1C6C6CAC7C7C4C5
C1C2C2C3C7C4C6C7C3C6C3C4C5C5C4C7C7CAC8CBCACBCDCBC9CBCBCCCBCBCECECFCFCECF
CDCFCFD4D6D5D7D9DDDADBDCDBDCDFDCDADEE0E0E0E2E2E1E3E6E1E5E5E5E3E2E2E4E5E5
E5E6E6E3E2E7E5E3E2E3E4E5E0E2E1E0E0E2E4DFDEDDDEDCDCDADBDADADAD8DBD7DBD7D5
D3D3D7D5D3D0CFD2CCC9CAC6C9C6C7C5C3C2C1BEBEBEBDB8B9B5B3B3AEABA9A8A5A29F9D
999796928E90898B86878383817E807E7B7A7778777373727170706F6E6D6D6C6B6C6A6A
6A686867666664636361605F605E5C5C5B5A5856555354504E4E4C4B48464543413F3D3C
3A3736353231302E2D2C2B2B2A2A29292828282727272627272726272627262627272626
2626262626262626
262626262626262626262626262626272626262626262626272727272727272727272727
2727272828282829292A2A2B2C2D2E2E2E3132333435363739393B3C3D3E3F4141434345
444649494A4C4C4F505151535556575859585C5C5D5C5D5E5F5F60636564636566656868
696B6C6C6F6E6F71727273757577787B7A7B797D7D7D7E7D7D7F7F7D8082848383838181
8587868686888B8D8D8E90919193949798989C9DA2A1A3A5A9A4A5A8AAAEADAEB0B1B5B6
B7B7BBB9BCBFBFC0C2C5C6C5C9C6C5C6CBCACACACCCCCBCCCBCDCECFCDCECDCDCECACACB
CBCCCDCBCBCACBC9C9C7C9C9C9C7CCC7C8CACBC6C7C9C5C7C6C6C3C5C3C3C5C6C7CAC7C4
C4C1C2C3C5C7C5C7C5C4C3C5C4C7C6C5CBC7C7C6C9CACBCBC9C8CCCDCECCCCCBCDCDCDCD
CECFD0CFCFD5D8D5D8D9DAD9DDDCDDD9DEDEDDE1E3E2E1E2E2E2E3E1E1E2E2E2E4E3E4E2
E4E5E2E6E5E2E5E2E5E6E4E4E2E2E0E3E1DEE0E1DFDEDFDEDBDCDCDDDAD8D6D9D9D9D6D6
D6D5D2D2D5D1D0CBCBC9C9C6C9CAC7C7C4C1C4BFBFBCBDBEBBBBB7B7B1AFAAAAA8A4A39C
9A97979390908D8B86878680837F7D7C7C7A7A767675747470716F6F6D6C6B6B696B6968
69676967656464626262605F5E5C5B595C58575555535251504E4B4A49474443403E3E3B
3A39363432312F2D2D2C2B2A2A2929282828272828272627272727272626262727262626
2626262627262626
252626262626262626262626262626262626272727262627262726272627272727272727
2727282828282929292A2B2A2B2C2D2D2F30323435353638383B3A3B3D3E3E4141434245
4447484A4B4C4F4D4F5050525555565857595B5A5C5D5E5F5F6061626564666665676767
6A6B6C6E6E6F707070737575757377777A7A7A7B7E7E7D7E7C7F7F818282838582838284
848685858586888B8C8B8C908F9093929398979D9EA3A2A3A3A3A4A7A6A8AAAEAEB1B0B3
B3B4B9B9BBBEC3C0C1C1C4C5C3C7C5C6C6C8C6C9CACDCECDCACECBCBCFCDCECDD0CDCFC9
CECCCAC8CAC9CCC7C8C7CACBCBC8C9C9C9CAC8C7C7CAC6C8C7C9C6C7C4C5C0C3C4CBC8C6
C5C1C4C6C7C7C3C4C7C7C5C8C8C9C5C5C6CAC7C7C8C7C8CAC8CCCAC9CCC9C8C8C8CBCBCC
C9CDCED1D1CFD3D5D6D7D5D9DADADDDBDCDBDADDE0DDE1E1E1E3DFE2E2E3E1E0E5E3DFE4
E2E4E3E3E5E3E2E4E5E4E3E7E4E2E1E1E2E0DEE2DFDFDDDEDBDCD9DCD6D8D7D9D8D8D9D5
D5D3D6D6D2D1D1D0CECBCBCBC9CAC9C7C4C3C3C1C0BDBCBCBFBAB9B8B3B2ADABA9A8A5A2
A09B99969692918B898887848382817F7D7878757676737272716F6F6D6D6C6A6A6A6867
67676764646362615F605F5F5C5A595A595756555453514F4F4C4B4848454442403F3D3B
3A38353431312F2D2C2C2B2A292929282828282828272726272727262627262627262626
2626262626262626
262626262626262626262626262626262626262627262726262626272627262727272727
272728282828292829292A2A2B2B2C2D2F2F313334353637383A393B3C3D3E3F41424444
45474748494B4D4D4F4F5252545455565859595B5A5B5D5D615F62616363656667676869
6A696C6D6F706F70727373747474737576787A797C7B7B7B7B7E7F7F8180838386838281
82858682858685898A8C8C8F8E9091929497999C9EA0A0A2A2A2A3A3A6A7AAABAEADAFB0
B2B2B6B6B9BCBBBEBFBEC2C3C2C4C6C5C8C9C9CACBC8CDC9CDCCCDCECFCECDCBCDCBCDCD
CFCCCECECBCBC9CBCBCACACCC8CACAC7C9C9C9C7C9C8C5C5C2C6C7C8C7C3C3C6C6C5C8C7
C4C4C2C2C5C7C5C6C4CAC8C5C7C7C9C4C4C3C6C6C8C5C6CBC9C7CEC9C8CCC8C9CACACCC8
CFCFD0CFD0CFD2D0D6D7D9D6D8D8D7DBDADADBDEDADFDEDEE0E0E1E1E0E1E2E0E3E1E1E2
E3E4E4E3E7E2E3E2E5E3E6E5E4E0E2E2E4E2E3E0E2E0DEDFE0DCDBDBDCD9D9D7D7D8D7D6
D3D3D5D5D2D0D2CECCCACDCBCAC9C9C9C9C4C3BFC3BDC0BEBDBBBAB6B5B2B1ADADA8A7A3
A09F9E989894918E8D8A868584827F7E7E7A79777775747371706E6E6C6D6A6969696968
676666646260605E605E5E5D5B5A5A58585655545351504F4E4C4A4848444342403F3D3A
3937353332302F2D2D2B2B2B292929282828282727272727272627262626262726262626
2626262626262626
262626262626262726262626262626262627262627262626262726272727262727272727
2727272828292829292A2A2A2B2B2C2D2E2F32333435353638393A3B3C3E3E3F41414343
45464649494B4B4D4E50505253545657565858595C5C5D5F5E5F62636264646466676869
686B6D6E707071706E7172737475747475787978797B797B7D7E7E7F7C82828387848582
858386868585888888898D8D8E8E8E90919395989C9A9EA0A1A0A3A6A4A7A9A9A8ADADAC
ADB1B1B2B3BCB8BDBDBDBDC0C2C2C3C5C8C8CBCBC7CACCCECBD0CCCDCCCDCBCCCDCDCECF
CECBCFCECDCCCACCCCCFD1CAC8CAC9C9C7CBC5C6C8C9C8C7C3C9C6C4C7C6C4C3C4C5C6C7
C5C5C0C3C1C7C4C6C5C9C8C9C4C6C5C5C6C1C6C3C6C6C6C6C6C6CACDC9CACBCAC9C9CBCC
CAC8CCCCCECFCDD1D3D5D3D2D6D4D8D9DDDBDDDCDCDADBDADDE0DDDDDFDEDFE1E2DFE0E0
E3E6E4E0E1E2E5E6E3E7E4E8E4E4E5E6E2DFE1E2DFE0DEDDDCDBDDDDDBD6D6DBD7DBD8D6
D7D6D4D3D2D5D1D0D0D2CACACEC9C8C7C6C8C4C2C0BFC0C0BCBCBBBBB8B7B2B1AFABAAA4
A4A09B9B999592938D8D8B88858581817E7E79787474747372706F6E6D6C696967686666
6565646461625F5E605D5B5B5B585856565554535151504E4B4A4949464543413F3E3A3B
3937343332302E2E2C2B2B2A292929292828282727272727272727272627262627262626
2627262626262626
252626262626262626262626262626262626262626262727272626272726272727272727
2727272728282929292A2A2B2B2B2B2C2E2E30333535363637393B3B3C3D3F3F40424342
444647484A4A4C4D4E505050525456565756595A5A5B5C5D5E5F60626363646465666769
68696C6B6F71716F6F7072727274757274757878797A797B7E7B7E7D7F80828382818382
86868686878588878B8B8D8E8F8D8E8F8F9494959B9B999A9C9DA1A2A4A4A7A7A8A8A7AB
ACACB0B2B2B5B6B7BBBCBCBDBFC0BEC3C5C5CAC7CBC8C8CBCDCCCBCCCFC8CFCDCDCECCCE
CFCDCFCDCECECDCACDCECDCEC9CACCC8C6C6C8CBC9C5C9C5C4C9C9C7C3C8C7CBC6C6C5C6
C6C8C5C3C4C6C8C7C8C8C7C7C5C2C7C3C4C3C4C4C4C6C1C8C7C7C8C9C8C9C8C9CBCEC9C7
C9C8CACBCBC9D0CDCED0D2D1D2D5D9D6D9DED6E0D9D9DBDADDDADCDBDBE1DDE1DFDDDFE1
E3E3E2E7DFE0E2E7E6E4E2E0E6E2E1E0E3DFE1E0E3DDDFDCDADCDFDDDCD9DADDDAD8D8D4
D8D5D5D2D5D2D2D3CECDCECCCBCACBCBC9C5C8C5C3C0C1BDBDBEC0BAB9B7B8B4B0AFACA7
A5A09E9E9A989694918E8B89878485837F7D7A797775747372706E706C6B6B6967676565
66646561605F5E5E5D5B5C5B5A5857565454535252504E4C4B4B4848454542413F3D3C3A
3837353331302F2E2C2C2B2A292929282828272727272727272627262727262626262627
2626262627262626
252626262626262626262626262626262626262626262726272726262727272727272727
27272728282828282A2A2A2A2A2B2C2D2E2F31323436363738393A3B3C3D3E3F40434445
45454647494B4A4C4D4D515052535356545658585A5C5C5E5D5F61616364646566666669
69696B6B6C6E70706F7171717375757674757679797A7B7C7C7E7F807E80848584838483
86878886878488888A8A8B8C8B8C8E8E8E9192979597969B9A9C9FA2A2A4A4A4A4A9A7A9
ABAAADAFAEB3B5B5B8B9B6B7BCBDBEBFC0C1C5C6C5C2C9CCCBC9CDCAC8CECCCBCECCCDD1
D0CED0D0CFCDCECDCDCDCDCFCBCACBC9C9CAC9CAC9C9C5C7C5C5C7C7C8C8C5C4C5C6C7C7
C7C5C6C4C7C8C7C5C6C6C3C6C6C5C4C8C5C6C5C2C3C4C4C5C6C4C5C5CCC5C7CBC7C9C9C9
C7C9C8C9C9C7CCCDCECDCFD3D3D3D2D5D8D8D8D9D8D8D7DADADDDADDDADDDEDDE1E1E0E2
E0DEE1E2E0E1E1E3E5E3E3E2E3E1E2E0E4E0E1E0DFE0DCDEE2DEDEDBDCDCD9DAD9D8D7D8
D7D6D7D4D5D3D4D0D2D3CDCFCECBCAC9C9C5C5C5C3C0C2BFBEBEBCBDBAB9B7B6B2AFAEAA
A8A6A49F9D9B9792928E8B8986878382827D7C7B7978767471726F6D6F6C6A6868666665
64636262615E5D5D5B5B5B595A585654535352524F4F4D4D4B4A4745464242413F3C3B3A
38363432312F2E2D2C2B2B2A292929282828272727272727272726272726262626262726
2626262626262626
262626262626262626262726262626262626262626262726272626272727262627272727
272728282828282929292A2A2A2B2C2C2D2E2F31333436363739393A3C3D3E3F40424343
46474747494A4A4C4C4F5050525353545657595A595C5B5C5F6060636263656566656769
6A69696D6B6E6E706F6F71727373747675767975797A7A7A7D7E7E7F8080818181838583
84858986888585868888898B8B898B8B8E8F91929395959495999E9DA19EA2A3A4A5A8A8
A8ABACAAB0B0B1B0B4B4B3B5B7B9BDBFC2C0C0C1C2C6C6CACAC7CCC8CBCCCCCACECCCECE
CBD1CFCED0CFD2CFCFCBCECCCCCCCBCBCBC9C8C7C7C7C8C8C6C5C4C6C9C7C4C7C6C5C6C7
C8C7C9C6C3C4C7C6C7C5C6C5C4C8C7C8C5C4C8C4C3C4C5C2C4C5C6C1C4C7C6C5C7C7C8C9
CAC8C9C8CCC9CBCECFCECFCDD1D3D3D3D1D3D8D8D5D5D6D6DBDADCDCDCDAE1DEE0DBE2DB
DFDFE1E0E0E6E3E2E2DFE5E1E2E1DEDDE0DEDEE0DEDDDFDFDADCDEDADBDADBDBDADAD8DA
D5D4D7D4D3D0D4D0CDD2CECCCDCCCCC9C7C7C6C4C3C1C1BFC0BEBFBBBDBABCB7B7B5B4AE
ADA7A5A0A19B9896938F8C8C898A868683817D7C7A7778747371706F6D6B69696B676764
6364625F5E5F5D5C5C5959575756555553515150504E4C4B494847454442413F3E3C3A39
37363432312F2E2D2C2B2A2A292929282828282727272727262726272726272626262626
2726262626262626
262626262626262626262626262626272626262626262726262726272627272727272727
272727282828292829292A2A2B2C2C2C2D2E2F3133343636383A393A3B3D3E3F40414343
44464647484A4B4B4C4D4F505153535555565759595B5D5A5D5E60616363656465646668
6869676A6B6C6D6F6C706E717474757475767776797B787B7B7C7C7E7D7F818081838080
848586868684838785868889888C8C8E8E8D8E8F929294959397989B9B9FA0A2A3A3A4A6
A9A9A9AAACAEAEAFB2B1B4B5B6B8BABCBDBDBFC2C1C2C4C7C5C7C7CBC9CBCACCCECECED0
D0D0D0D1CED2CFD1CECBCFD1CECBCBCCC8C9CBCACBC8C9CAC5C7C9C7C8C5C5C7C7C7C4C6
C5C7C6C6C7C8C8C6C6C5C7C8C7C9C8C7C7C6C1C4C5C2C4C3C4C3C2C2C0C3C2C5C6C6C7C8
C8C9C7CAC8C8C8CECECCCCCFD1CECFD2D2D2D6D5D1D4D8D6D6D7D9DCDCDBDEDCDADDDEDC
DCDCDCE0E1DDE1E1E2DEE3DFDFE1DFDFDFE3E0E2DFDDDCDEE1DDDDDADDDEDBDCDCDCDCDA
D9D8D7D4D2D3D1CFD2D3CFD1CDCDCBCBCAC9C7C5C3C2C0C0BFBCBEBEBCBDB7B7B8B5B2AE
ACABA8A3A19E9C99959391908D8B88868483817E7C7B78777472726F706E6A6967656866
6461605E5E5D5D5B5959575856565553534F504F4E4D4C4A494746454242403F3D3B3A38
36353431302F2E2D2C2B2A2A292929282827282727272727262626272626272726262726
2626262727262626
262626262626262626262626262626272626262726272726262626272627262727282727
2727282828282828292A292A2B2B2C2D2E2D2F313235353637393A3A3B3C3D3F40414243
4446464749494A4B4E4D4E4E5051535656555758595A5C5D5D5E60616161646365666766
686968696B6A6C6D6E6E6E707172747274757577787A777A7B7B7A7B7E7E808083828080
8384878584858484858385878A8B8B8C8D8E8D8F8F91929095959996999C9C9EA0A2A3A5
A7A6A8A8A8ADB0ACB0B2AEB0B3B3B6B9B9BABFBFC2C2C3C5C7C4C4CBCBD0CDCED2CFCECE
CFCDCDCFCCD0CFD0CECFCFCFD0CCCECDCFCCCDC9C8C7C6C8C6C7C9C7C5C7C4C5C6C5CAC6
C6C2C4C4C7C6C6C8C6C6C8C6C6C6C7C3C5C4C3C5C3C2C4C7C2C2C3C0C2C3C4C3C9C7C8C4
C5C5C7C7CBC8CAC8C7CACCCCCFD0D4D2D0D1D0D2D3D3D2D3D4D5D4D8D9D6D9DADCDCD9D9
DDDCE0DFDEDDE1DFE0E1DFDEDCE2DFDFDFDFDDE2DDDDE3DCDFDFDBE1E0DADDDBDCD8DADA
DAD6D8D4D1D0D3D1CECFCFCECCCACDC9C7C7C3C6C1BFC1C3C3BFBCBDBDBAB8BAB6B4B5B1
AFABAAAAA49E9C98989592938F8D8B888685827D7B7B7A77757373716E6F6A6B69676765
6263605D5E5C5B5A595958555454525251514F4D4D4B4949484644444241403F3C3A3939
37353332302F2D2D2B2B2A2A292928282828272727272727272627262627272626262626
2626262626262626
262626262626262626262626262626262626262626272726262727262727272726272727
28272728272828292929292A2A2B2C2C2D2E2F30323434363739393A3B3C3E3F3F404142
4346474848494B4B4B4B4C4E5052515456565757575B5B5C5E5F5F606161616365666667
696869696B6C6B6C6B6D7070707174747473767476787879797A7C7D7D7E7E8081817F7F
8084838484848586868787868786888A8A8C8D8E8B8E8F9293929596969A9A9DA09FA2A1
A0A5A7A9A8AAABAEB0ACACAFB2B2B3B5B5BABBBBBDC3C5C4C1C7C6C7CBCCCECDCFD1D0D0
CFCDCDCBCDCDD1D3D0CFCCD0D0CCCDCDCDCFCDCECBCAC8C6C8C8C5C9CBC7C7C6C7C8C7C7
C6C4C6C6C7C9C5C6C8C9C7C6C6C5C7C6C7C6C3C3C2C4C2C6C3BEC3BEC0C0C3C2C3C6C6C4
C4C6C7C8C6CBC7C9C9C8C9CACECFD1CED0D0CED2D1D1D2D4D1D6D2D5D4D6D6D8D9DBDADF
DADADADCDDDDDEDDDDDCDDE1DFE0E0DEDEDEE0DFDCDEDFDEDDE0DADADEDCDBDCD6D9DDDA
D7D7D3D5D6D3CED1D1CDD0CECCCCCAC9C9C8C8C6C4C0C1C0C0BDBBBBBBBBB9BAB9B9B7B0
B1AEAFADA6A59F9B99999794908F8E8E888684827D7D7A78787773716E6C6C6C68676663
636261605E5B5B58595756555353535150504E4D4C4A48484846444342413E3D3D3A3A38
35353332302E2D2C2B2B2A2A292929282828272727272727272727272727262726262626
2626262626262626
262626262626262626262626262626272626262626272726262726272626262727272727
27272727272828292929292A2B2B2B2C2E2D2E30323335353738393A3B3D3D3E3F414142
444646474648494A4C4D4D4E4F5051545655565959595B5B5C5D5C606060626365646765
6768696B6B6A6B6B6C6C6E707170727374767375787877797879797B7A7C7D7D807E8281
827F83848386858688878587878A87888C8B8D8C908E8E8E9192929595979B999D9E9EA0
A1A3A6A6A7AAABABA9ADACADB2B1B1B4B3B6B9B7BDBEC1C0C2C3C6CACDCECFD0D0D1D3D1
CECECFCCCED0CED2CFD2CFCDCFCDD1CCD0CCCECECBC9CBC8C7C6C6C7C8C9C8C7C6C7C7C7
C7C6C4C6C9C7CAC5C7C6C7C4C7C6C8C6C7C4C4C4C4C4C4C4C1C0C0C1C3C4C2C1C2C2C3C6
C7C3C5C5C7C8C8C6C6C6C8CCCDCACECECDCDCECED0D0D0D4D2D0CFD3D6D4DAD9D7D9D7DB
D8DADED9DADADDE1DFDCDEDCDCDEDEE1DFDEE0DFDCDEDEDDDCDEDCD9DADCDBDAD9D9D6D8
D6DBD6D4D1D1D1D0CECECDCECDCECDCAC8C9C4C4C2C2C1BFC0BCBFBDBEBABAB9BBB7B6B5
B3B1AEABAAA4A5A09D9B969696938F8E8A888785817E7D7B787874726E6E6C6B69666765
6262605F5E5B5B595858565554525150504E4C4B494A48484544444241403E3D3C3A3937
353433312F2E2D2C2B2B2A2A292929282827272727272727272627272626262626262626
2626262626262626
262626262626262626262626262626262626262626262627272627272726262726262726
27272727282728282829292A2A2A2B2C2C2D2E30323435363738383A3B3B3D3E40404141
434444474749494A4A4C4C4E4F5051525556565857595A5B5C5C5C5F6161606363636667
6668686A6B6E6C6C6A6D6E6F6E6D6F7273747374757776777678787A7B7B7E7F7F807F7E
81828184848388888888878988878A86878B8B8D8B8E8E8F908F95959496989B9C9B9BA0
A0A3A1A5A5AAA7A7AAAAAAAEB0B0B3B5B4B6B8BABBB7B9BFC1C5C7C9CACDCACDCED0CDCF
D0D1CDCFCDCFD1D3D0D0D1D1CFD1CFD1CCCECBCCCBCBCBCBC7CBCAC7C6C9C5C7C7C7C7C5
C7C5C5C7C7C7C4C5C6C6C8C5C6C6C7C6C6C5C7C7C6C6C4C3C3C2C1C3C4C1C3C3C3C2C1C6
C2C6C3C5C6C7C6C5C7C6C9CACCCACACECACECECFCFD0CFD1D1CDD1D2D3D6D6D9D4D6DAD9
D8D8D8DADBDCDCDBDEDEDDDBDCE0E0DEDDDEDEDDDDDAE1DEDBDFDEDBDCDCDCDCD8D9D6D7
D6D5D6D4D7D4D3D3D1CECDCECDCCC9CBC7C9C7C5C4C1C0C1C0BFBFBFBBBCBCBBBCB9B4B5
B3B3B1ADACA8A4A5A19F9A9B9895928F8E8B878782817F7D7A7A7573716E6C6B69686866
6462605F5D5C5B5758595554535251504E4D4C4C49494846444343413F3F3E3C3C393836
353332312F2E2D2C2B2B2A29292929282728272727272627262726262726262726262626
2626262626262626
262626262626262626262626262626262726262626262727272626272726272727272727
27272728282828292929292A2A2B2B2C2C2E2E2F3133353537393A393A3B3D3F40414244
444445464848494A4C4C4B4C4E50515353555656585A5A5C5C5C5E5E5F60636163656466
66676A6A696A6B6D6D6C6D6D6F6E6F6F7373747374767676757579787A797C7D7C7F8080
7F838582848584868888878988898988898888898A8C8F8E8E918F93949698989D9A9B9C
9CA0A0A1A5A5A6A6ABA8AAAAAAADADB3B0B3B7BCB7BBBABBBFC2C4C5C8C8C9CACBCDCFCD
CDCACFCCD2CBD0CFD0D1D0D2D3D0CFCDCDCDCCCDD1CCCEC9CACDCCC8C8C8C8C9C7C5C6C6
C4C8C8C6CAC5C9C7C5C4C3C3C5C8C9C8C7C5C6C9C7C4C5C6C3C3C3C1C4C4C3C1C5C3C4C2
C5C0C5C2C6C5C4C6C6C6C6C6C7C7CACAC8CBCCCECFD1CDD0CECFCCD1CED2D5D4D3D7D7D5
DAD7DAD6D9D9DEDBDDDCDFDBDBDBDEDCE0DCDBDADDDFDDDCDDD9DADDDDDDDBD9D8D9D7D7
D9D9D9D7D5D3D2D1CDCCCCCDCACBCDCACBC5C6C5C4C2C1C0BEBDC1BDBABCBCBBB9B7B5B6
B8B1B1AFACADA8A8A4A49F9D9B9695908E8C898484827E7E7C7B78747271706D6A666865
6461605F5D5C5A58575555535250504E4E4D4B4A48464645434242413F3E3D3B3B383737
343232302F2D2D2B2B2A2929292828282727272727272727272727262726262627262626
2626262627262626
262626262626262626262626262626262626262626262626262627272727272727272627
27272727272828282829292A2A2B2B2B2D2D2E2F303335363739393A3A3D3E3F40404143
4245454647494A4B4B4B4B4E4E4F51515354555757595A595B5C5C5D5E60616163666467
6667676A696B6B6D6D6D6E6C6F6D6D70737274767475757675787678787B7D7C7C7E7D7D
7F818181838482868688858687878887888789898A8A8A8F8E9191929494929598999A9A
A0A0A0A2A2A1A4A3A8A8A8AAAAADAAAFB0B3B4B5B6B6B9BCBCC4C2C6C6C7C4C6C9C9C8CC
C9CECCD7D0CECFD4D2D7D2CFCECFD0D3CDCCCCCCCDCECCCBC9CCCACCCACBCAC5C9C8C9C5
C5C3C2C4C5C5C6C9C6C6C6C6C6C9C6C9C6C4C5C6C6C5C5C2C3C2C2C3C2C2C4C1C2C0C0C3
C0C3C4C4C3C2C3C5C3C6C4C3C6C5C6C8C8C8CACAC9CACEC9CDCDCDCECDD0D2D4D6D4D7D9
D6D8D4D7D9DAD9DBD9DCDDDCD9DFDDD8D8DBDBDBDBD9DADDDBDBD9D9DBDBD9D9D7DAD7D6
D5D6D7D5D1D4D2CFCFCFCECDCDCCC9C9C6C4C6C4C6C2BDC1BFBDBEBBBCBCBBBCBAB5B5B8
B4B4B0B1AEACA9AAA8A3A19C9C9A9594918F8A878583827E7D7B79767571716E6C696865
646361605E5C5A595757545252504E4F4D4C4A4949474644454241403F3E3C3B39383735
343332312E2D2C2B2B2A2A29292828282828272827272726272727272626262626262626
2626262626262626
262626262626262626262626262626262626272627262627262727262727262726272727
272727272827282829292A2A292B2B2B2D2D2E2E30313436383A393A3B3C3E3E3F424242
434345464747494A4A4C4A4D4E4E4F515153545556575A5B5A5B5C5C5C5F626163646464
666669686A686B6A6B6D6D6A706E7070717273757576767476767878797B7A7A7A7A7D7D
80818083818384848586888787888789878888888B8A8F8E8F8E8F8F8F9394949396989A
9C9D9E9E9FA0A2A3A3A6A9A9AAA8AEACACB2B3B1B5B5B7B8BEC1C4C3C2C4C3C3C3C5C8C8
CBCECCCFD0D0CDD0D0D2D1CFCFD1D2CED0D0CDCDCDCBD0CDCFCBC9C9CAC7CAC8CAC7C9C9
C8C5C5C6C8C7C7C4C5C4C6C3C8C5C3C3C5C2C2C1C6C6C4C0C0C3C0C0C2C4C1C0C0C5C0BF
BFC0C3C1C2C3C1C4C5C4C4C4C5C6C6C8C6C8C9C8CACBCDCCCBCBCBCDCCCFCFD0D2D3D3D3
D3D3D8D4D8D5D5D7D9D9DBDAD9DAD8D9DDD8D7DAD9DADAD9DCD9D9D9D8DADAD8D7D7D7D8
D6D4D8D4D2D3D1CCCECECECFCEC8C9C6C9C6C4C4C4C4C0C0C0BEBFBDB8BBBDB8B8B8B6B5
B7B5B2B1AFABAEA9A8A5A49FA19B989793908D8A898584817E7D7A777673716E6E6B6868
6562615F5E5C5B58575653535250504D4D4B4A484846464443423F403E3D3B3A3A383735
343130302E2D2C2B2B2A2929282828282727272727262727272727262726272726272626
2626262626262626
262626262626262626262626262626262626262626262626262627262626262727272727
27272728282828282929292A2A2A2B2C2C2E2D2F2F32343637383A3C3A3C3D4040414143
434446464647484A4A4C4C4D4D4E50514F52555454575858595A5B5C5D5E606262626464
6566656867696A6A6A6A6D6E6D6F70727073727472767476757778787978787B797A7B7C
7F8081808180828384848785868588878A8988868A8A898D8E8C8D8E9090929393949597
999A9B9B9C9DA1A2A4A5A7AAA9ABA8ABACADB1B3B3B4B4B8BABFC3C3C0C1C2C1C4C5C9C9
CACDCACBD1CFCECFD0CDD0CCD2D0CFCACFCED0CDCFD0CACECECDCCCBC9C8CAC7C5C7C8C8
C8C5C5C8C5C4C6C8C4C5C5C5C3C3C4C3C4C3C2C2C5C5C6C1C0BEC3C2C0C0BFC2BEBFBEBE
C0BFC0C3BFC1BFC1C5C4C4C2C7C4C7C3C5C4C6C7C6C7CAC8CACACCCECDCECED0CFD1D4D5
D7D5D3D7D5D7D5D8D7D7D9D9D8DAD6DBD8DAD8D9DBDADBD9DADBDBDCD9D9DDDAD7D5D6D7
D7D5D8D3D4D2D3D2D1CECACCCDCAC8CAC4C5C6C3C4C4C3C0BEBFBEBDBEB9BAB8BAB8B7B9
B6B3B4AFB0B0AEABA7A6A4A39F9C9A9A9692918E8B878482817D7B79767474706F706C68
6563625F5E5D5A595756545352514D4E4C4B4948474544434241403E3C3D3B3938373534
3332302F2E2D2C2B2A292929292827282827282727272727272726262627272627262626
2626262626272626
262626262626262626262626262626262626262626262626262627272626262727272727
27272727272727282829292A2A2A2A2B2C2D2E2E30313336383A3A3B3C3C3E3E40414142
43444646474747484A4B4B4C4D4F4F4F50515255565759595A5C5B5B5B5E5E6062636263
6567676768686B6B6B6B6C6C6D6D6F706F717172737376757677757778787B787A797D7C
7E7D7E7D7F808181848583858487858888888887898A8C8C8D8D8D8A8E8E909095929594
979A99989C9D9CA0A1A2A5A6A5A8AAABABAEAFAFB2B2B2B3B8B9BEC0BEC0BDBDC1C5CBCB
CACAC9CBCDCCCCCECFCDCECFCED1D1D4CED0D0D4CFD0CFD0CECECDCBCBC7CACACACAC9C6
C9C6C7C7C6C4C6C5C5C7C2C2C4C7C5C3C6C3BFC3C1C1C4C1C1C2C0C0C0BEC2BFBDBDBEBC
BFBFC0C1C2C0BDC0C1C1C6C4C4C3C5C5C5C5C5C6C7C5C4CBCBCCCDCBCBCCCBCFCECCCFD2
D3D1D1D3D1D5D7D6D8D7D7D6D9D8D8D6D6D9D8D5D8D7DBDADDDDDBD8D9D7D7D8D8D4D8D6
D3D2D2D2D4D2CFCFCECDCDCCC8C9C9CBC6C3C7C4C4C3C3C0BFBDBFBCBCBBBAB8B9B7B6B7
B7B3B2B3B1B1ADABACA9A6A4A1A09D9B9997918E8B898583807E7C7B777572726F6C6A68
66656161605E5B5957565453524F4F4D4B4B49474645444341413F3E3D3B3A3838363534
3331302F2E2C2B2B2A2A2929292828272728272727272727272627262727262626262626
2626262626262626
252626262626262626262626262627262626262626262726262627262626272727272727
272727272827282828282929292A2B2B2C2D2D2E303033363839393B3C3D3E3F3F414142
434344464748484A4A4C4B4D4D4D4F4F50525452555557595B5D5E5C5D5D5F6061626364
6666676769696C6B6A6B6C6B6E6D6E707070717172707375767776777877787A7879787C
7C7E7D7F807F8080838583868585868685878789898B8C8B8A8D8A8B8C8D8F9091939696
95969597989B9A9BA1A3A6A6A6A7A7A9ACADADADB0AEAEB3B7B7BBBDBBBCBABDC2C4C5C7
C7C7C8CBCBCBCBCBCECFCCCFCFD0D1D0CFD1D0D1D2D0CECECED0CCCDCACACACAC9C9C6C7
C7C9C7C5C6C7C2C3C5C3C4C0C2C3C2C2C3C4C3C3C0C0C3C2C0C1C0C1C0BDBDC0C0BBC0BF
BCBFBCBEBEBFC0BDC1C3C2C2C5C4C3C6C6C2C6C6C4C6C5C5C7C7C9C9CECDCCCCCDCED2CF
CFD2D3D1CFD4D5D3D3D6D7D7D6D4D4D7D3D6D7D8D6D9D5D8D8D7D8D8D6DBD6D8D7D4D1D3
D2D2D5D3D3D1CFCED2CDCAC9CACAC9C7C7C5C4C7C2C2C2BFBFBDBDBABAB8B9B7B6B7B6B4
B3B4B2B4B1B1AFABAAA9A3A4A1A29D9D9C9B97958E8B898682817D7B79767372706D6C69
666564615E5E5B5C56565453524F4F4C4C4948464645424242403E3D3C3C393937363433
3331302E2D2C2B2B2B2A2929292828282727272726272727272627272626262627262626
2626262626262626
252626262626262626262626262726262626262627262626272626272626272726272727
272727272728282828292929292B2B2B2C2D2D2E2F30323638393B3C3C3E3E3F3F414143
4345444647474849494A4D4C4C4E4E4F50505253565556585A5B5D5B5C5E616162616264
6466666867696A6B6C6B6D6C6C6D6E6D6F6F707074727374747676767677777577777B7A
7B7D7B7B7F8181818383828583828686888688888A898C8D8C8D8C8C8C8C8B9090919392
93969897989A9A9DA09FA1A4A5A3A4A6A7ACACABABAEB1B0B3B2B7B8BEBEBCBBBEC2C5C4
C4C2C4C7C9C7C5C8C7C9CECECFD0D3D2D1D1D0D2CFCFCECDCCCFCCCECDCCCBCBC8CBCCC8
CAC7C5C9C4C5C9C5C4C4C4C6C6C1C4C5C2C1C5C3C1C3C4C3C2BFBFC2C1C2BFBFBFBCBDBB
BCBDBFBFBEBEBDBCC0BFC3C4C3C1C0C3C3C4C5C3C5C4C2C2C5C7C9CBCACBCCCDCFCBCFCD
CFD0CED0D1D1CFCFD4D4D5D4D4D4D0D5D5D4D1D5D7D5D5D5D8D7D5D8D5D6D6D7D3D3D5D5
D3D6D3D3D2D0CFCBCBCFCACBCBCECAC8C6C4C5C5C2C1BEC0BFBFBCBDB9BAB8B8B8B7B7B5
B6AFB2B1AEADAEADAAAAA8A6A2A59F9E9D9C9997968E888784807F7B79787673716D6C6B
686764635F605C5B5858555452514E4D4B49494644444341413F3D3C3C39393737353433
31302F2E2D2C2B2B2A292928282828282828272727272726272726262627272626262726
2726262626262626
262626262626262626262627262626262626262626262626262727262626262727272727
2727272827272728292929292A2A2A2B2C2C2D2E2F303135383A3A3C3D3D3D3E40414143
4443464647484749494B4C4C4C4F4F4F515153545556575858595A5B5C5E5F5F615F6362
646466676669686B6A6B6B6C6B6F6E6F6E7171717170727372757474777577777779797B
7C7B7B7C7E7F81818182828384868685888587898A888C8B8C8E8A8B8C8E8F8E91929191
9295959696989A9C9EA0A2A2A3A4A5A8A9ABAAAEABACABAEB1B2B2B7B8BBB9BBBDBFBEC2
BEC3C2C6C6C6C5CAC9CCCCD0D0D0D0D0D1D0D0D1D1D0D1D0CFCECBCCCECDCCCBCCCACACD
C7C8C9C6C2C4C7C7C7C3C5C3C3C5C4C1C3C2C2BFC0C1C1C4C2C3C2C3C0C1BEBDBBC0BDBD
BCBBBEBEBFBEBDC1C0BEBDBDBFC0BFC3C1C3C2C1C5C6C3C5C7C6C4C7C8C8CCCACACECECC
CBD0CECFD2CED1D0D2D0D3D0D3D4D3D4D4D3D6D2D3D5D9D4D8D5D4D7D5D8D5D6D7D3D2D2
D2D3D1D3D0D1D0CECFCECECDCAC6C7C8C7C8C6C4C6C3C3C4BFBDBEB9B7B9B6B8B8B7B3B6
B3B4B3B1AEB0B0B0ADACA9A7A7A5A3A19E9C9C98938F8E898584817E7A77777471706E6D
6A666663625F5E5C5A57555451504E4D4C494846454442403E3F3E3D3B3A383736353433
31302F2E2C2B2B2B2A2A2929282828272727272727272727262627272626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262627262726272727
272727272728272828292829292A2B2B2C2D2D2E2E30313437393C3C3E3F3F3F40414343
44454645474748494A4A4B4C4F4D4E50505251535355575758585B5A5C5E5F6061626162
64636666676A68696A6A6D6D6E6D6F6D6D6F717071717174727376747476767876757879
797D7E7D7C807F80828583838383858686838787888A8B8A8B8B8E8A8A8D908F8E908F91
92949493979496989A9C9EA1A0A2A3A2A4A8A9A9A8ABADACB0B3B6B7B9B6B7BABABBBEBD
BDBFC5C4C4C5C6C4C8CBCDCBCDCFCECED0D1D2CFD1D2D0D1D0CECECCCECCCCCCC9CACCCB
CAC8C7C6C6C5C6C4C4C6C1C4C4C2C2C0C4C0C2C0C2C0C0C0C1C3C1BFC1C1C1C0C1BEBDBA
BBBCBFBDC0BFBEC0BBBCC0C1BEBFC1C3C4BFC1C0C4C5C6C3C3C5C2C4C8C7C8C9CCC5C8CB
CACBCBCECFD0D2D0D0CFCFCFD1D2D0D3D2D3CFD1D4D2D2D1D5D2D6D3D4D5D3D4D7D4D5D3
D2D1D4D0D1D1D0CDCECFCFD0C9CAC9CAC5C7C5C2C6C4C2C1BFBCBCBDBBBAB8BAB5B8B7B4
B1B4B2B3AFB0B1AEAEAAA9A9A6A4A4A2A4A09C999694908C898682827E7B76777372716D
6A68676461605F5C5B58565351514F4D4B494846454442413F3C3D3B3B39383735343332
312F2E2D2C2C2B2A2A292929282828282827272727272727262727262626272626262626
2626262626262626
252626262526262626262626262626262626262626262626262626262727262727272627
272727272727272828292929292A2A2B2B2C2D2E2E2F3133373A3C3D3E3F3F3E3F434243
44454545464748494A4B4A4B4D4F4D4E505152535555565657575A5B5B5C5D605F616162
636263656666686A69686B6B6D6D6E6E706E6E706F717170737375737577747676777679
7B797D7D7E7F837D7F8381848584848486848688898B8A8B898B898B8E8E8F8D8E8D908E
909194929596969797979B9EA2A1A0A5A4AAA7A7A8ABACAFADB1B3B3B5B8B5B8B7B8BBB9
BCBFBEC3C4C1C4C7C8CBCCCCCCCECBCDD1CECFD0D1D1D0D0D0CED0D0D1CECFCDCECDCCCC
CAC8C9C8CACACACAC4C3C3C3C2C3C5C5C1C4C0C2C3C1C1C2C0C2C0BFC0C3C3C2BABABABA
BBBCBDBFBBBCBBBCBDBCBCBDBEBFBEC1C0C3BEBFC0C5C2C2C2C2C4C5C3C7C2C7C9CAC8CC
C6CACBCCCDCDCBCFCECECFCECED0CDCFCFD2D1D3D0CFD2D3D0D0D0D1D3D5D1D3D5D3D1D5
D1D2D2D0D0D1CFD0CFD0CBCBCBCEC9C8C9C6C5C5C4C4C3C1C2BFBEBCBCBBB8BAB7B5B4B5
B3B3B3B1B0B1AFAFACADA9A9A7A6A3A2A2A19E9A979691918E8A868382807A7977737270
6C6A686763615F5E5A5955555251514E4B4A48464544413F3F3E3B3C3A3A383735343331
302F2E2D2C2C2A2A29292928282828272728272728272726272726262626262626262626
2726262626262626
262626262626262626262626262626262626262626262726262627272727262726272627
272727272727282828292929292A2A2B2C2C2C2D2E2F303234393B3D3E40414040414343
4445464646474A494A4B4B4D4C4E4F4E4F515151535554555758585A5B5C5C5E5E5F6260
616264656566666868686B6A6E6C6D6F6D706F6F6F6F6F71727274747376767778777779
787B7A7C7C7D807F7E818384828283868785868887898C8B8B8F8E8C8D8E91908F8F8E8E
908F8F91939598949497989B9F9D9EA0A0A6A7A5A8A9ABABADB2B1B2B3B5B5B6B4B8B9B9
B7B9BDBFC1C2C2C6C3CBC9CECBCCCCCCCECFCED2D0D1D1D0D1CFCED1D0CFD0CDCFCFCECE
CCCACAC9C9C7C8C6C5C7C5C4C5C1C2C3C4C1C0BFC1BFC0BFC0C0C1BDBDC2C1C0BDBBBBBC
BBBBBDBEBCBBBFBDBFBDBBBCC0BEBBC0BDBDBFC0C2C1C3C5BFC2C3C1C2C2C5C6C7C8CAC4
C7CACBC9CACCCCCACDCDCACDCECFCECED1CFCFCED0CDD1CECDD0D1CFD0D0D3D3D2D2D1D3
D2D0D1CFD3CDD0CFCFCCCCC9CAC8CBC8C8C7C8C3C4C1C1C0BFC1C2BBBDBCB9B8B4B7B4B3
B2B2B4B2B2AFAFACABABA9A8A6A5A4A2A29E9F9E9A999591908D8B8781817F7A79757371
706E6A676663605D5C5A5856545251514B4848474443423F3E3D3C3B3939373635343231
302F2E2D2C2B2A2A29292928282828272827272727272727272726262626272627262626
2627262626262626
252626262626262626262626262626272626262626262626262626262726272626272727
272727272728282828282829292A2A2A2B2C2C2D2E2F313234373A3D3D40404141424344
45464546464747494B4B4A4B4D4D4D505051515351545456555857595A5B5D5E5C5E6063
636363646467666969696B6B6A6D6A6E6D6E706F70717171737474757676787778777877
7879797C797C7D7E818284838183828282858386888A898B898C8C8C8F8E8E90918D8E8D
8D908E8F9293929892969599989B9C9E9FA4A3A6A8A8ABACAEADB1B1B3B1B4B5B4B3B8B7
B9BCC0C1C1C2C1C3C7C6CACACACBC9CDCBCFD2D0D1CECFCFCDD0D0D0D6D0D2D0CFCFCBCE
CCCBC8C8C8CAC9C8C6C5C3C6C3C3C3C7C1C3C2C0C1C1C2BEBEBCBCBFBEBEBFBEBEB9BCB8
BDBCBABDBEBFBEBEBDBDBCBDBEBBBDBCBFBEBDBFC0C4C1C1C1C4C0C0C5C3C5C4C5C4C5C8
C5C4C8CAC6CDCDCCC9CBCDCECDCDCECCCACFCDCECBD0CECDD0CECFCDD1D1CFD4D2D1D2D5
D1D0CFCED0D1D1CDCECBCACBCAC8C6C9CAC6C5C2BFC4C1C2BEBEBDBEBDBCB8BAB4B8B5B5
B5B0B3B1AFB1ACACACACA9A6A7A5A3A6A0A19F9D979A9794928F8A878684807D79797674
726F6C696766635E5E5C5A5654524E4D4C4A47474342413F3E3D3C3B3837363534333231
2F2F2D2C2C2B2A2929292828282828272727272726262727262626262626262626262626
2626262626272626
262626262626262626262526262626262626262626272627262726272626262627272727
27272728272728272729282929292A2A2B2C2C2D2E2F2F3133363A3C3D3F404141424245
46464746484848494A4A494B4B4D4E4F505051525455535654575657575A5C5C5D5E5F60
616263646565656568686969686A6D6D6D6D6F6E6F707171737376767777777877787777
76777B797A7E7D7E7D80837F8382828385878784888889898B8F8E8C8D8F8E8E8F8F8D8F
8C8D8E8F909094959593989898999A9D9E9DA2A1A3A6A7A9AAAEAFADB1B3B3B4B3B2B4B7
B8B9BEBFBEBEC5C0C4C6C6C9C9CCCBCCC9CBCFCFCFD0CED3CFD1D2D1D3D1CFCFD0D1CDCC
CECCCFCDCCC9CBCAC8C6C5C5C3C5C2C4C4C1C0C0BEBFBDC1BFBBBDBCBDC0BEBEBCBBB7B8
BFBCBBBFBEBCBDBCBBBABCBBBCBBB9BEBEBDBEBBBDBEBFBFC1C0BFBFC0BDC2C0C1C3C2C4
C5C5C8C7C6C9C8C8C9CAC9CCCCCACACACACBCCCECACBCCCECDCED1CFCFD0CFCFCFCECDCA
D0CECFCDCFCDCECECCCDCACBCAC9C6C5C9C4C7C2C4C0C1C0BDBCBEBCBBBBB9B7B7B8B3B2
B3B4B4B2B1AEADABABADA9A9A8A7A6A2A3A0A09F9C97959391908D8C888583817E797975
746F6E6B696563625F5C5A565451514D4C4848454542403F3D3D3B393937363533333230
2F2E2C2C2B2A2A2929292828282727282727272727272627272626262627262726262727
2626262626262626
262626262626262626262626262626262626262626262626262627262627272726272627
2727272727282728282828282929292A2B2B2D2D2E2F303133353A3D3E3E404242424444
4546474747484A494A4A4A4C4C4D4E4E4F5150525253535556575657595A5B5C5D5D5E60
6163646362666667676767696A6B6B6E6C6C6D6E716F707375757576767778787A797677
767779797A7B7A7C7E80808281808181818485878686898889888C8C8E8D8B8F8D8F8E8D
8C8F8E8D8F909395929694969797999D9B9D9EA2A2A6A7A6A9A9ADB0ADAFB2B3B2B3B2B5
B4B9BBBEBCBBC0C1BFC2C6C6C5C8C8CACCCBCECECDCECFCBCDD2CDCED0CFD1D1D0D1CECD
CDCBCCCCCCC9C7CBC7C7C5C4C4C5C6C2C2C4C2C0C0BFC0BDBCC0BCBDBCBCBEB9B7BBB8BB
BBBCBDBEBCBFBEC0BCBBBBB9B7BBBCBBBABDBBBFBBC2BDBFBDBDBEBDC0C0C2BEC2C2C1C4
C2C7C6C7C4C5C6C3C8C5C9C8C6C8CBCACACBC9C8CCCBCACACDCECCCCCECCCBCECBC9CBCD
CFCFD0D0CECFD0CFCDCBC8CAC5C9C8C8C8C7C8C4C2C4C3C1BEBDBEBEBDB9B7BAB9B6B5B6
B5B2B0B1B0AAADAAA8A9ACA9A8A6A5A3A0A3A29E9F9D959693928F8C8B8984827F7D7976
74716D6E696665625F5C5A575552514E4C4A47474442413F3E3C3B3A3837363532323230
2F2E2D2C2B2A2A2A29292828282828272727272727272727272726262626262626262626
2626262626262627
262626262626262626262626262626262626262626262726262726262726272627262726
26272727272727282828282929292A2A2B2C2C2D2D2E2F313134393B3D3F404141444346
47464847484749494A4B4C4D4B4D4E4E51505151545354555657585859595A5A5C5C5C5F
61626364646466666667696868696B6C6C6C6D6E717171717174767779777A7977777677
777778797B787C7C7C7C7E80808182828284858385878887868B8C8B8D8B8C8D8F8D8D8D
8D8E8C918E8D90909194949897999A9899989C9D9DA1A5A5A7AAABA7ADB0AEB1B1B1B2B0
B3B7BBB7BCBEBDBDC0C6C1C7C5C7C9C9C9CACCCCCBCCCDCBCFCCD3CFD2D0CFD2CECECFCE
D0CCCBCCCCCBC9C9CCC7C6C8C6C4C3C4C1C3C3C2C3BCBDC0BFC0BDBCC1BCC0BEB8B9B9B9
BABBBBBEC0BEBFBEBCB9BBBABBB9B9B9BEBEBCBCBEBABEBEC1BBC0BDC0BDBEBCBFC1C2C1
C1C1C0C0C1C5C3C4C6C6C8C4CAC8CBC8C9C6C8C8CACBC9CBC9C7CAC9CDCAC9C9CACBCCCA
CECCD0CDCCCDCCCBCBCAC9C8C9C6C8C6C6C4C7C5C4C1C2BFBEC0BDBCBCBABCB9B8B7B2B4
B1B2B2AEAFACA9AAAAACAAA7AAA7A5A6A4A1A09F9B9D97949392918F8B888783807F7A78
7674706E6B6964635F5C5A575652504D4D4B47464342423F3E3C3B3A3837353433323030
2F2E2C2C2B2A292A29282828282827272727272727272727262727262626262626262726
2626262626262626
252626262626262627262626262627262626262626262626262626262626272727272627
2726272727272728282828282929292A2B2C2C2D2E2E2F303234363A3C3E3F4143434545
4649484947484949494A4B4B4C4D4F4F50515153535454555655565859595A5A5B5D5D5E
5E62626263656567676669676A6A696B6C6D6C6F6D707072727375747778787877777676
7778777A7978787B7B7D7D7F807E7F808281828383858589868A8C8B8B8D8C8F8F8D8C8E
8D8D8C8F8F8E8E8F91949294949797989B9A9A9C9F9FA1A3A7A8A9A9AAAEB1B2B0B0B0B2
B3B4B4BAB6B9BABBBEBEC0BFC4C5C6C8C5CBCECDCACCCACDD0CFCDCFCCD0CFD2CFD0CDD0
D0CFCDCEC9CBC9CAC8C7C6C7C4C5C1C4C2C3C1C1C0C5BFC1BEBCBBBEBEBEBDBCBCBABABB
BCBFBDBFBDBFBCBDBCBDBDBBBBBBBBB7BBBDBAB8B8B9BABABBBFBCBDBDC0BEC0BFBFC0BF
BEC1C0C1C2C1C2C1C5C4C4C5C5CAC7C7C7C5C8C6CBC7CAC6C9C8CACCC8C8C7C8C8C7C9CC
C6C9CBC9C9C6CACACDCBC9C6C8C8C7C8C8C6C5C2C0C1C0BFBEBFBDBFBDBCB9B7B7B4B7B8
B4B3B3B1AFAFABACACABAAA8A8A6A7A2A2A19D9D9C9A97979493908E8C898785817E7C78
797371706D696764615D59585654504E4C4A4946444241403D3C3A393837363533323030
2E2D2C2B2B2A2A2929282828282827282727272727272627262626272626262726262626
2626262626262626
26272626262626262626262626262726262A262626262626262626272627262726272727
272727272727272727282828292929292B2B2C2D2D2E2F30313335393D3E404143434547
474847494A4A4A494A4A4C4D4C4D4E4F4E505152525454565557575858595A5A5B5B5D5E
5F60616463646265676667696A686B6A6B6C6D6B6E6F7070707274737476787779767574
777776777A79797878797B7B7F7E7E808282848184848684878B898B8C8B8C8D8D8B8E8D
8C908F91918D8F8E8F9193919596959696979C98999B9FA2A2A9AAA8AAACAEACB1B0B1B3
B4B4B4B4B3B6B7B8BDBBBEBFC1C2C7C5C6C9CBC9CCCCCBCDCCCECFD0CDCFCDCED1CDCECF
CFD1CDCDCDCBCCCBCBCBC6C8C7C7C7C3C5C1C2C3C0C3C0BFBEC1BDBCBCBFBBBCBCBCBCB9
BCBBBDBEBDBDBCBEBCBDBCBBBBBBBBBABBBDB8B9B9B9B8B8BBB9BCBCBABEBCBFBCBFBEC0
BDC0C1C0BDBDBFC0C3C1C1C2C4C5C5C4C4C7C6C5C6C6C5C5C7C5C9C6C9C6C9C9C5C4C8C7
C9C8CDCCC8CDC9CECBC9CCCBC7CAC8C5C9C7C6C6C4C2C4C2BFC0BEBCBCBABAB6B7B3B4B2
B6B4B2B0ADAEACAFACAAAAA8A6A5A6A19EA09F9D9C9A97959693908E8C8B888682827D7B
767572706E6B6965625F5D5A5652514F4D4C4846444241403E3B3B3A373635333232302F
2E2D2B2B2B2A292929282828282827272727272627262727262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626272626272627262726272727
27272727272727272828282929292A2A2A2B2C2D2D2E2F30313336383A3E404243434445
464948494A4A494C4A4A4C4B4D4D4E4F4E5051515354535455565758585959595A5C5B5D
5E5F605E6264656466666768676868696A6C6B6C6C6E6E6D716E71727475767577767573
7578787A787A787A7679797B7A7F7C7E83848282838384868787898A8A8B8B8C8C8F8D8D
91908F919090908F8E90919394959597989898999B9B9B9D9FA3A6A7AAAAABAEABAEB0B0
B0B3B1B7B4B7B6B9B6B9BCBEBFC1C0C5C5C5C5CACAC9C8C9CBC8CFCECCCECDD2D0D0CFCF
D0CDCDCDCDCACACAC8C9CBC9C5C7C5C3C2C4C1C5C2C0C0C0BEBEBDBEBFBDBABCBABBBCBC
BCBDBDBCBCBEBBBDBCBDBABBBCB8BAB9BDBBB9B8B8B7B9BCBCBDBCBCBBBBBDBCB9BCBEBF
BFBCBDBCBEBFC0BDC0C1C1BFC3C0C3C5C6C6C5C7C5C7C5C5C4C6C7C7C6C7C5C6C3C5C6C7
C8C7C7C9C7C6C6C8C9CAC8C8C6CBC8C8C7C6C7C5C0C0BFBBBDBEBEBFBCBBB8B7B7B3B6B5
B5B2AEAFAEAEAAABACABA9AAA8A4A4A4A1A09CA0999A99969794938E8B8B8987837E7D7B
777574706C6B6A6662605C5A5753514F4E4B4A47464442403E3B3A393736353332312F2F
2E2C2C2C2A2A292928282828272727272727272726262726272626262726262626262626
2626262626262726
262626262626262626262626262626262626262626262626262726262626262627272726
2626272727272727272828282829292A2B2B2C2C2D2D2E2F313234363A3E404144434545
464748494A4A4B4A4A4A4C4C4D4E4D4F4F50515051545455575857575959595A5B5B5B5C
5D5E5E5F6062646566666A676869696A6A6C6E6D6D6E6F6F6F7170727374757476747476
76767679767878797879777A7A7B7D7E8182848282828287838487878689898A8D8E8C8F
8E8D90908F90928F918F908E919194949696989898989C9C9EA1A2A4A7A9AAACADADAAAF
B0B2B0B1B3B7B7B4B5B5B8BBBEBFBEC1C3C4C6C8C7C6C7C8CAC9CFCCCECACFCDD1CED1D2
D0D1D0CDCDCEC8CBC9CAC7C9C7C6C7C6C4C4C6C4C2C0C0BCC0BCBFBCBABCBBBDBCBCBABB
BCB9BDBDBBBDBBBCBCBEBBBBB9BAB8B9B9B8BABAB7B8B5B8B8BABABBBBBABCBDBDBDBDBE
BFBBBCBCC0BBBEBDBEC0BFC3BDBFC0BFC1C1C3C3C3C4C4C3C5C4C4C1C3C2C4C5C6C4C4C6
C4C5C5C0C5C4C7C7CAC8C8CAC8C7C6C5C4C3C1C1C3C2C2BEBFBBBFBAB9BDB8B8B8B6B6B4
B3B4B1B0ADB0ADACADA9A9AAA6A6A4A6A1A19D9C9D9A99969491908D8D888984827F7D7B
797572716D6C696763605D5B5755534F4E4C4848464441403D3B3A38373734323230302F
2E2C2B2B2B2A292929282828272727272727272727272726272627262726262626262726
2627262626262626
262626262626262626262626262626262626262626262626262626272626262727272727
272627272727272727282728282929292A2B2B2C2C2E2E30303233353A3C3F4243444546
46484849494B4C4C4B4B4C4C4D4E4D4E504E4F52525353545554565658585A59595B5C5D
5D5E5E6062626162636466686868696A6C6B6D6B6B6E6D6D6F6E6E707172747372747474
7478797A777678787878797B7A7C7B7D81808184808383858586868584868787888C8C8E
8C8F8F908F928E929191908F909192929496959997989A9B9B9E9EA1A2A5A6A9ABADADB0
B0ADB0AFB1B3B4B6B5B5B6B8B9BBBFC1C2C4C5C4C5C5C7C8C8CBCCCBCCC9CFCECDCFCED0
CDCFCDCFCBCDC9CCC9C8CFC8C6C6C6C5C5C4C4C3C2BFC2BFC0C0BCBDBCBBBCBABBBABBBC
BDBABBBDBABEBBBDBDBABBB8BABBB8B9BBBAB7B7B8B5B7B6B6BAB9B7B9B9BAB8BBBCBDBD
BEB9BBBDBDBDBDBFC0C0BEBFBFBEBEC1C0C1C1C3C1C1C4C1C2C2C4C4C3C2C1C2C4C5C7C3
C6C2C1C1C3C3C5C5C7C8C5C7C8C7C5C2C5C3C1C1C1C2BFBEBABDBEBBB9B8BAB8B5B7B4B0
B2B5B0AFAFADADABADAAAAA7A7A5A4A3A1A19F9C999898969392908E8C89878681817E7B
797873706C6C6A6864615E5A59565251504D4B474644423F3D3C3A38383634333230302F
2D2C2B2A2A2A292928282828272727272727272727262726262627272726262726262626
2626262626272626
262626262626262626262626262626262626262626262626262626262626262627272727
272727272727272728282828282929292A2A2B2B2C2C2E2F30323335383B3F4142444445
4748484A494C4C4B4C4C4C4D4E4E4F504F4F51505252535355565657575859595A5B5C5E
5D5E5F605F6060616363636666686868696A6A6C6D6C6B6E6C6E6E707073727373737474
767576797876777778777A7978797B7D7C7F80807F81838486838686878684858C898B8A
8C8C8E8F918F8F8F9291929191919192949496939896979A9D9B9A9DA2A2A4A6A7AAAEAC
ACADAEAEAFB1B4B3B2B5B4B7B7BBBEBEBEC1BFC1C3C5C7C7C9C7C9C8CBCCCDC8CCCBCECF
D1CDCDCECECCCCCECBCBCACDCBC9C8C3C3C5C5C3C3BFC4C2BFC0BFBDBFC0BEBDB9BBB9BC
B8BCBCB9BEBBBBBABAB7BABDBBBCBABABAB7B8B8B6B4B6B7BAB7B8B8B6B7B9BBB7B9B8B9
B8BDB9BBBEB8BDBDBABBBCBBBDBABCBEBEC2BFC2C1C1C1C0C2C3BFC3C2BEC2C1C5C7C4C2
C1C1C0BFC1C3C2C5C2C2C3C4C7C4C6C2C5C3C2C1C2C1BEBCBDBDBDBBBBBAB7B5B6B3B5B3
B4B0B2AEACADAEADADACAAA6A7A5A4A3A09E9E9B989B97979493918D8B8A878482807D7A
797974716F6C6B6865635F5A58575450504C4B484644433F3D3B3938373634323230302D
2D2B2C2B2A29292929282828282727272727272727262726262627262627262727262626
2626262626262626
252626262626262626262626262626262626262626262626262627262726262726272726
272727272727272728282828282829292A2B2B2C2C2D2E2F30313234373A3D4042444646
474748494A4C4B4D4D4C4D4F4D4D4F4F4F5050515254535555575656585758595A5B5C5C
5C5D605E616060626262626363676567696A696B6C6B6D6F6E706D6F6F71707273737475
75747474767476777779797B797A7B7D7B7E7D7E7F818281858685888583848488898889
8A8B8D8E8F8D8E8F91928F9293939492939394969497989698999B9DA09FA2A7A6A8AAAC
ABACAFADADB0B1B2AFB4B3B6B5B5BABBBCBDBEC2C3C4C1C3C4C5C5C7C8CAC9CCCECCCCCA
CFCECECECACFCECFCECACAC9CACBC7C7C6C9C6C7C2C3C3C0C0C0C0BFBCBFBCBBBAB9B9B7
BCBABBBBBBB7BCBCB8B9B8BBBCB9BDBABAB7B8B7B7B8B6B5B8B7B8B8B7B5B6B6B6B7B7BC
BBB9B9B9BABDBBB9B9BBBDBBBCBEBDBDBDBEBEBEBCBCBCBEBEBFBDBEBCC0BEC1C1C3BEC0
C0C1C0C4C2C4C1C3C2C4C1C4C5C4C3C4C1C4C1C3C1BEBFBDBEBCBABBBAB8B6B8B6B4B2B1
B0B1B0AFADACACADA8AAA6A7A3A5A4A29EA09D9C999A979793928D8D898A868684827E7C
777675726F6D6A686763605C595553524F4C4B484744433F3E3C39393736343331302F2C
2C2C2B2B2A2A2A2928282827272727272727272627262627272626262626272626262626
2626262626262626
252626262626262626262626262626262626262626262626272627262626262626262727
27262727272727272727272828292929292A2B2C2C2D2E2F3030323434393C3F42454546
484948494A4C4C4D4C4D4D4D4F4F4F5050515052535255565555575658585859595B5C5B
5C5E5E5F60606161616262636565686968696669696B6C6C6D6D6D6E706E716F70727473
7473747475767778787B7B797B777979797A7C7E7D7E80838281848787868586888A8A89
898A8B8C8C8F8F8E9091909191949492949592959796949697989A9C9DA09EA4A1A5A5A7
AAA8ACADADB0ADB2B0B0B0B1B3B5B5B6BBBBBCBDC0BEC0C2C3C7C9C6C6C7C8C9CDCCCBCB
CCCBCECFD0CECCCFCECDCCC9CBCBCBC8CBC8C7C3C9C4C2BFC2C0C0BEBEBCBCBBBABAB9B7
B9B6BBB7BAB9B9BABBBBBABABCC1BDBCBBB7B6B6B5B4B6B8B7B7B6B4B6B8B4B8B6B6BAB8
B9BABABCBABABDBAB9B9B9BAB9BABEBBBFBCBDBFBCBCBFBDBCBDBEBEBBBDBCBEC2C0C1C2
C2C2C4C5C7C3C6C4C1C2C2C2C2C5C2C2C3BFC0C0C2BFBFBFBABCBABABBB9B6B6B5B2B2B0
B2B0B0ADABADAAA7A6A7A8A7A4A3A2A0A19E9E9B9A99979494908F8D8B8A888482807E7B
7A767571716F6A6866625F5C5A575453504E4A4A464443403E3C393736363432312F2F2D
2D2C2A2A2A29292929282828282727272727272627262727262726262627262726262626
2626262626262626
262626262626262626262626262626262626262626262626262626262727262726272626
272627272727272827282828282928292A2A2A2C2B2D2E2E2F30313334373B3F42444545
464748494A4B4C4C4E4D4D4E4F4F4F4F50505052535354555555555858575959585B5C5D
5B5F5D5E60626161616261646465656767676A6B69696C6B6D6D6D6E6F6F727070707172
727172727576757879777879797A7A787B787A7B7A7C7D7F80818483848684878887878B
86888B8B8E8D8C8E8F918F918F9192939494949794949594979697999B9C9EA0A2A1A4A6
A9A8AAAEACACAEAFB0B1B0AEB1B2B4B5B6BABCBCBDBEC1BEC2C5C3C5C7C5C7CACACAC9CC
CACECDCECBCFD1CECFCDCDC9CAC9CACDC9CBC8CAC6C6C1C3BFC0BFBEBDBEBABDB9BBBBB8
B8B8BBBBB7B8B8BABBBBBCBDBCC0BCBBBCBAB7B8B5B7B4B4B5B7B7B1B3B3B5B4B6B5B9BD
BCB8B6BCB8B8BAB9B8B7B9B8B9B8BCBBBCBBB8BABABABDBCBABCBBBDBBBBBBBCBBBCBFC0
C2C3C4C4C6C7C5C1C4BFC2C2C4C4C2C3C1BEC1BDBFBFBFBEBABCBAB8B7B7BAB8B6B2B0AF
B0B1ADAFAAA9A9AAA8A6A6A6A5A3A2A0A19F9D9A9898939590908E8B8B86878583837D7B
79787472716E6B676762625E5B585552514D4C49464443403E3C3A3836353332312F2E2D
2C2C2B2A292A292828282828272727272727272727272626272726262627272626262627
2626262626262626
252626262626262626262626262626262626262626262626262726262726262626262727
27272727272726272827272828282929292A2B2B2B2C2D2E302F31323336393E3F424547
4748494A4A4B4C4C4D4E4E504E4E4F50515252515353525355555656575758595C5A5D5D
5D5D5D5E5E60626262626260616568666667676868696B6A6A6D6D6E6E6E6E70706F7172
7172737174767677787876797A7978787B787A787C7C7E7C7E7F81818080838587898887
8888888C8A8B8D8F8E908D8F9091909194959596959898959597999A9A9B9C9FA1A2A2A4
A8A8A9A9ADACAEAEB0ADB3B0B1B1B4B5B6B7B7BEB9BCBEBEBDBEC2C2C5C9C6C8CBCCC8C7
CBCBCAC9CDCED0CDCCCCCCCDCBCEC9CCCAC7C9C7C7C4C7C3C2C3C0C1BFBEBCBFBBBBBAB7
BABBBCBABABCB9BBBABCBDBCBBBABBB8B8B8BABAB7B6B4B5B6B6B7B6B4B4B2B5B4B6B2B5
B7B6BAB7B8B8BAB8B7B6B7B9BAB8B8B7B9BABBBBB8B9B9BAB9B9B8BCBCB9B9BABEBEBFC0
C1C1C3C5C4C4C6C3C2C2C4C3C2C2C1BFC3C0BFBCBEBDBEBBC0B8B8B8B9BABCB6B7B2B4B0
B1B0ADABACABA9A8A7A7A7A5A7A3A19D9F9F9D9B9B979793928F8E8D8C8A8783817D7E79
787576726F6D6A696561605E5B5A5453514E4C4A484442403E3B3A3836343332302F2E2D
2C2B2A2A2929292928272828272727272727272727262627272626272626262626262627
2626262626262626
262626262626262626262625262626262626262626262626262626262626262727272626
2627272627272727272728282828292929292B2A2B2C2D2D2F2F30333335373C40424445
474849494B4A494D4B4F4D4E504F51505051525352545455555555565757585A5B5B5C5C
5D5E5D5E5E6060626161606263656767686768696968696A686C6C6D6C6F6D6F6F6D726F
737273747473757777767977787978767A79797A787B7B7E7D807E7E8182848583868887
888986888A8B8B8C8F8E8E8E9190939091949397989699979593989699999C9E9FA2A7A6
A6A8AAA9ABAAADB1B0B1AFB0B1B2B3B2B3B3B7B8B7B7B9BCBCBEC2C2C0C3C2C6C5C5C7CA
CBC8CACBCACACCCCCECDCACCC9CBCAC9CCC9C9C7C7C9C5C4C6C1C3C1C0C0C0BDBDBCBDBC
BCBAB8B7B6BABABDBEBDBAB9B9B7BABAB8B4BAB9B9B8B6B2AFB3B3B3B2B4B3B1B2B3B5B4
B4B5B4B6B7B6B7B7B9B8B6B9B9B7B7B8B7B8B8B9BAB8BABBB8B9B9B6B6B7B7B9BABCBEBD
BFC0C2C3C2C1C2BFC1C0BFBFC1C2C1C0BEBDC0BEBDBCBBBCBCBCB9B8B4B6B6B5B4B4B0B0
AFAFACADABAAA9A8A7A7A6A4A1A5A09F9B9B9D9998959794918F8B8C89888684827D7C7B
79787572706D6A6866635F5E5C585553514D4B49464442403D3B393835353331302E2D2C
2C2B2A292A29292828282728272727272727272727262726262626272626262626262626
2626272626262626
262626262626262626262626262626262626262626262626262627262626262627272726
262626272727272727272727282828282929292A2B2C2C2D2F2F30323234363A3E414345
464849484A4B4D4C4B4E4D50504F504F5152525252525554565857565758585A5B5B5D5E
5E5D5E5E5F5E606164626261616464676767686769686769696B6B6B6C6D6E6F6E6F6D70
727070737475767575737774797679777A7B79797B7A7C7C7B7D7F807F7F838386858886
8886898489898A8B8C908D8F908F8F9194919695989799989A95949697999A9EA0A2A2A6
A6A5A6A8ABABABABADADB2B0B1AFB1B3B3B3B3B3B5B7B5BABBBDBEBDC2C1C1C3C0C2C6C7
C5C7C7CBCBCBCAC9C8C8C9CBCDC9CBCACAC9C9C6C7C5C8C4C3C0C0BEC0BFC2BDBFBCBCBC
BBBABABBBAB9B8BBBBB9B8B7B8B7B7B6B8B8B8B9B9B9B7B7B4B0B3B0B3B1B2B2B1B3B1B3
B3B4B6B3B4B5B7B8BAB7B7B6B6B6B7B6B7B7B8B4B4B6B8B8B9B6B6B4B6B6B5B5BABEBDBD
BEBFBEC1BEBDBEC1C1BEC1BDBEC2BEC0BEBEBFBDBCBBBCB9BCBCB7B6B6B4B6B4B3B1B2B0
AFADABADA9ABA8A6A8A6A5A4A29FA19E9F9D9D9995979591908D8C898A878483807F7E7B
777575716E6E6A656562605F5C575753514F4B49464642403D3B3937363433312F2F2D2D
2B2B2A292929282828282727272727272726272726262626262627272626262626262626
2627262626262527
252626262626262626262626262626262626262626262626262626262726262626262726
2727272727272727272727272828282829292A2A2B2C2D2D2E2F2F31323435383C414445
464647484A4A4B4C4E4D4F4F4E504F50505252535355555655565657575758595A5C5E5E
5C5F5D5E5E5C61626263626362646468676568676969686969686A6B696C6A6D6D6C706E
716F717172747475747577767777787B79787A787A7B7A7B787D7C7F7F8082828486848A
878787868688878A898F908E8E8F8D9292949496979698989897969799999A9C9E9FA0A2
A3A5A7A8A8A8A6A8A7ACACAEADAEAFB0AEB2B3B2B2B5B5B3B7BBBBBBBEBDBFC1C2C3C6C6
C9C5C7C9C8CBC7C8CDCBCBCCC8CCC9C9CCC9C9C6C3CAC6C5C3C6C2C2C1C2C1C0BFBDBEBD
BDBCBBBCBABDBCBAB9B7B7B3B5B9B4B7B8B4B5B6B6B7B5B7B3B3B1B3B0B3B3B0B1B3B0B1
B2B1B4B4B1B5B5B4B6B5B6B6B4B5B6B6B7B7B6B6B6B5B4B5B8B7B6B8B9B6B8B9B8BBBDBE
B8B8B9BABBBBBFC0BFBEBEBFBFBFBCBFBCBABBBCBDBCB9BCBAB9B7B6B6B3B2B4B2B1AEB2
ABACADA9AAA8A6A6A5A5A1A2A0A09F9C9A9C9C9995959492908E8C8A888683847D7E7D79
767874706E6C6B6765625F5D5B5956534F4F4C484744413F3C3B383736333231302E2D2C
2B2B2A292A29292828282727272727272727272727272626272726262627262626262627
2626262626262626
262726262626262625262626262626262626262626262626262626262626262726262626
272727272627272727272728282828292829292A2B2B2D2D2E2F3030323235373C404244
454648474A4A4C4C4D4D4E4D504F5250505053535454575555565457585758585B5C5F5E
5D5F5F5E5E5F60606263626465646463666767666869666769686A6A6C6B6C6C6C6D6E6F
707271727172727274757475757778787A7979787A79797A7B7A7C7C7D7E7E8084838585
878488858887898B8A8C8C8E8E8F8F919394939698969898989798989899999D9D9D9FA2
A2A5A5A5A9A9A5A5A6A9A9ABAAADAEAEAFAFB3B1B1B1B1B4B4B7B6BCB9BBBDBDBDC0C0C4
C4C9C8C5C6C4C7C7C8C7CCCBCCCACACBCCCCC8CBC7C7C6C6C7C6C4C4C0BFC3C1BEC0BFBB
BDBABCBBBCC0BBBBBBB7B9B6B4B6B5B5B3B4B5B4B5B4B4B4B1B1B4B3B3AFAFAFB3B1B0B2
B2B0B1B4B1B1B4B3B6B7B7B4B8B5B5B8B6B4B5B6B6B7B7B6B8B5B6B7B7B7B8BAB9BABAB8
B8B8B8BAB9BCC1BEBDBABFBEBEBEC0BFBCBDBBBCB9B9BBB9B8B9B5B5B5B6B2B2B1B0AFB0
AEACACA9A9AAA8A7A7A3A5A2A29EA09A9C9B9897959494908D8E8B88868484817F7E7C78
787774726F6B6A666361605C5B595653504D4C484644413F3D3A3837353432302E2E2D2C
2B2A2A2A2929292828282727272727272726262727262726262727262726262626262626
2626262626262626
252626262626262626262626262626262626262726262626262627262726262726262627
2727272626272727272727282728282829292A2A2A2B2C2D2D2F2F30313234363A3E4143
454648474A4A4A4C4B4D4F505051505151535252535458565656575858585858595C5D5E
605F5E5F5E5F5E606061626262636466656564656868686769696A686A6A6C6E6C6D6E70
7070717172717075747478767575757877797A797A797A79797B7A7B7B7E7C8082808384
8386888984878785898B8C8B8F8F90919392949495979596979796969896999B9C9DA09D
9FA1A2A3A7A5A5A7A6A6ACACA8ADACADACADAFB1B1AEB1B1B2B3B5B6BAB9B8BCBBBFBFC1
C4C3C6C6C4C7C7C6C9C9CBCDC9CDCCCDCCCCC9C8C7C6C6C7C7C7C4C5C4C3BFC0C1BEBFBE
BDBFBEBCBABEBEBAB8BAB8B7B9B6B7B8B6B6B5B5B5B3B5B4B2B3B0B2B3B2B2B1B0B1B0B1
B0ADB0B2B1B3B2B4B3B0B5B2B3B2B5B6B6B6B5B5B6B7B2B6B5B6B1B6B4B4B7B7B8B7B7B7
B6B7B6BABABABCBEBABEC1BFB9BDBEBDBEC1BEBCB8BBB7B6B8B7B6B6B5B2B3B1AEB1AEAD
ABABAAA9A8A9A5A6A7A4A0A19F9E9C9A9A9A9896939692918D8B8B87868382807F7D7B7A
787572706D6D696764615E5C5C585554504C49484643423F3B3A3836363332302F2E2C2C
2B2A2A2A2928282828282727272727272727272726272726262626262627262626262626
2626262626262626
262626262626262626262626262626262626262627262726262626262626272626262627
2727262727262727272727272828282828292A2A2A2B2B2D2D2D2F2F31323334373D4043
454647484A4A4A4C4C4D4D4F4F5051505152525455555557575657575558585959595B5B
5D615F605C5F605E60616161626363626564656566676769676869696A69696B6D6D6D6F
70706F70736F73737475747476787778797A7A7779797A7A7C7A7A7A7C7B7C7F807F8282
83888785898689888A888B8A898B8E9090929795959696969795989796979B9C9D9B9D9D
9D9FA1A3A3A2A4A3A7A4A7AAABADABACACAFB2B0B1B0AEB2B2B3B7B4B4B7BAB9BDBABEBE
C0C1C2C2C0C7C5C5C8C9C8CDCAC8C9CCCBCDCBCBC8C8C7C6C7C8C8C4C4C5C2C2C2C0BFBF
BEBBBDBBB9BBBCB8BCB9B6BAB7B8B9B9B5B8B7B6B3B0B2B2B2B0B2B2B2B2B1B1B1AFAFAD
AEAFAFAEAFB1B2B2B0B3B3B4B3B3B2B4B6B4B1B4B2B6B6B3B3B2B3B3B5B4B5B6B7B8B8B5
B7B7B5B8BABABBBEBFC0BEBEBEBEBEBABEBCBCBABAB8B9B7B6B8B5B6B4B1B2B2AEAFB0AE
ACACACA8A8A3A5A4A2A3A1A2A0A09B9A999796959592928F8C8C8A878581837F7F7C7A78
7673746F6D6A6B6764605E5B5A5755524F4D4B474642403E3B3A3836343331302E2E2C2C
2B2A2A292928282828282827272727262727272726272626272726262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726272726
26262626272726272728272828272828282929292A2A2B2C2C2E2F2F31323335363A3F42
43464649484B4B4C4D4E4D4D50504F5253525352525556565556565858575758585A5B5C
5F5E5D5F5F5E5E5D5D5E606062616363616463656466676767686868686A6A6B6D6C6F6E
6E6E7071727172727473747676757877767877797A7A7A797C7B7C7D7B7C7E7F7F7F8182
838286858687878989898B8A8D8B8C8D8F9391929596949595969796959C9A9D9C9C9C9D
9C9EA0A4A1A3A2A0A3A5A6A7A6ABABADACADABACAFB0AEAFB2B3AFB5B3B2B5B9BBB8BBBC
BDBFBDC0C2C1C3C6C5C9C7CACACACDC8CDCACCCAC9C8C9C9C8C7C6C7C3BFC0C2C4C0C0BF
BDC0BDBDBCBCBDB9BABAB8B9B6B7B7B8B5B7B4B3B3B4B3B2B0B2B2B2B0B3AFAEAFADAEAB
AEAEB1ABADB1AFB1B0B1B0B2B3B2B4B3B3B4B2B0B3B3B5B1B2B1B3B0B5B3B4B5B5B5B5B6
B8B9B9BBB8BCBFBDBBB9BBBCBDBBBCBBBCBFBABAB7B5B6B4B4B5B7B4B5B1B0B3AFACACAE
ABAAABAAA6A5A5A4A5A2A19C9D9B9B999995959292908E8F8B8B8A87838582807D7C7976
757271726D6C676464615E5B595655514F4D4A474543403E3C3937353432312F2E2E2C2B
2A2A29292829282827272727272727272727272727262626262626262726272626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262727
27272626272726272727272728282828282928292A2A2A2B2C2E2E2F3032323436383C40
43454648494B4B4B4D4D4E4F50505052515152535355565557555657575958575859595A
5D5F5D5E5E5C5F5F5E5F606162616261626264656665666668696768696869696B6B6D6D
6B6D6D706E6F7172737372747574757576787778797B7A787B7B7A7A7D7A7C7D7D7E7E80
818283858587878588888A88898D8C8B8F8D9091949397969695949597979B9D9A9A9C9C
9C9F9EA2A0A2A2A4A4A2A6A4A7A5AAA9ACAAABAAACAFADAEAFAFB3B2B3B2B4B5B6B9B8B9
BABCBEBBC1C2C3C7C7C5C3C7C8C8CAC9C8C8C9C7CAC6C7C8C5CAC5C8C6C4C6C2C2C0C2C0
C0BFBDBEBDBBBDB9B8B8B9BAB8B7B7B7B7B7B3B0B2B2B1B1B3B3AFB3B3B2ADAEB0AEB0AD
AEACAEAEABACAFAEB2B0AFAEB1B5B1B1B2AFB0B0B2B6B4B1B2B3B2B2B1B0B2B5B3B3B4B6
B4B8B7BBBABCB8BCBCB7BDBBB9BBBABCBBB9B7B6B7B7B5B7B7B1B2B3B5B1AFB0ABAFAFAB
AAABA9A8A8A4A2A2A29FA19E9E989A9897949593908E8E8E8D8887848481817E7D7A7777
7472726F6D686665625F5D5C595755514F4C49464542413F3C3938353433312F2E2D2C2B
2A2A29292928292728282727272727272626272727262727272726262627262627262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
2627262727272727272827272727282828282929292A2B2B2C2D2F2F2F31333335373A3F
424546474949494B4C4D4F5050515052525353525456555455565657595857575858595B
5A5B5C5E5C5D5D5E5E5F606162616262636363646368666667676868686A686A686C6C6B
6D6C6C6C706F706F747172727674737775777779777879797A7A7B7C7A7A7B7B7C7F7E7D
7E8182848484868585868788898A8A8B8A8D8D8F92939292949394959699999B9B9C9C9D
9E9FA1A0A1A0A2A1A0A2A3A6A6A4A7A9AAABA8AAADAFAFADACB2AEB2B2AFB2B3B2B4B7B3
B7B7B7BBBFBEC0C3C2C3C4C5C5C7C5C4C9C9C6C6C7C9C8C8C8C6C5C5C4C6C5C6C3C3BFC3
C0BFBEBFBBBCBCBDBBBCBBB9BCB7B7B7B7B4B3B4B1B1B1B2B2B1B0B3B0AFB1ADAFABABAD
AFAFAFABACAEADB0AEB1B0AFB0AFB1B0AEB2B2B1B3B2B2B1B1B2B2B1AEB1AFAFB1B3B3B5
B6B6B9B9B9B8BBBAB7BAB7B9BBBCB6B7B8B9BAB9B5B5B6B7B4B5B5B5B2B2B1AFB1ADAAAA
AAA9A8A7A4A5A4A3A0A19C9D999C9B98969493928F8C8C8C8A89858682817E7E7C7B7776
73716F6E6B696763625F5C5A585753524D4B474642413E3D3A3936363332302E2D2D2C2B
2B2A29282828282828272727272727272626272726272626262727262626262626262726
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626272626
2727272727272727272727272727282828292929292A2B2B2C2D2E2E2F3131333536383C
41444447494A494C4C4D4E50505051505253525354545556575656575859575959585958
5A5A5B5B5C5C5E5D5D5E5F606060616161646364636466656666666967696867686A6B6B
6D6B6E6D6E707171707174747273747473757677777B79797B7A7C797B7A7A7B7D7D7C7C
807E7F838183838486898889878A898A8B8D8E8F92909091929094959598989A9C9E9D9B
9E9E9EA0A3A0A1A0A3A2A3A6A7A3A6A5A9A8A7A9A9AAABACACAFADB0AFAFAFB1B3B2B4B5
B6B4B8BABABCBFC1C1C4C2C4C9C5C7C4C5C6C4C8C7C8C7C8C5C5C7C7C6C4C4C5C1C2C1C1
C3C3BDBEBFBEBABDBABDBAB7B7B8B9B4B3B2B4B1B3B0B3AFB3B0B1ADAFADAFACADAEAEAB
ABACAAAAADAAABACAEAEAEADAFAFB1AFAEB1B1B0B2B1B4B1B2B4B0ADAEAFB0B1B0B1B3B6
B3B6B6B3B7B8B4B7B7B5B4B7B7B8B9B7BAB7B4B6B3B5B3B0B4B1B2AFB2AEAEAFACAAAEAD
A8AAA7A5A4A2A3A19F9C9E9D9A989598959592908F8F8E8B8886858381817D7B79787975
71716F6C6A676564615E5B5A5755514F4E4B484643403E3D3A3936343331302E2D2C2B2B
2A2929292928282827272727272727272727272626272726262627262626262626262626
2626262626262626
252725262626262625262626262626262626262626262626262626262626262627262627
262726262727272727272727272827282828282929292A2B2B2C2D2E2F30313234353739
3E43454649494B4C4B4F4E50515151515051535354545655565756565658585957585859
59585B5B5B5B5C5E5E5D5F5F5F616160626363636364656466656668666567686868696C
6D6C6D6D6E6E6E7070727273727373757577797877777A7A7A7B7A7B7C797C7E7D7E7C7D
7C7F7F7F7F818185868887888688888B8A888B8E8D908E918F919194959698989A9C9A9C
9E9EA2A1A0A0A1A19FA3A2A2A3A2A3A5A5A6A6A6A6A9ACABABAEACABABADACB0AEB0AFB3
B4B4B6B8BABCBFBAC0C1C1C1C3C4C3C5C5C9C8C6C6CAC9C6C8C7C6C7C6C8C6C6C4C4C3C2
C2C4BFC1C0BBBEBDBDBBBAB9B6B7B8B4B3B3B3B0B1B2B0B3B2B1B1ACADADA9ADABADAEAA
A8ABAAABABAFABADABADAEABACAEAFAFAFB0AFAFB1AFAFB1B0B1B1B1B2AEAEB0B0AEB2B3
B2B3B3B5B1B2B4B5B1B5B1B3B6B6B4B4B7B5B5B3B4B5B2B6B3B0AFB0B1AEAEACACA9A9AB
A7A7A7A6A4A2A1A39F9E9E9C9A9C97979491908F8F8D8A8C8986828482807C7C79787672
736E6E6C686764625F5E5B585653514F4D4A464642413F3D3A37363433302F2E2D2C2C2A
2A2929282828282827272727272727272726272727262627262626262626262726262626
2626262626262626
262626262626262626262626262626262626262526262626262626262626262627262626
272626262727272727262727272727272828282929292A2B2B2C2C2D2F2F313233343638
3C41444748494A4B4C4E4F50505151505152535154555555565657585958575A595B5858
585A5A5A5A5A5C5B5E5E5E605F6060616263636464636564666566676667696868696B6A
6B6D6E6E6D6F6E6F6E707372747474737576777678787C797978797A7E797C7C7C7B7D7E
7C7F80807F8281808484898A8889888A8989898D8C8F8E8E9092929194959998989A989D
9D9E9FA1A29F9F9DA19FA0A2A3A2A0A3A4A4A3A3A4A8A8AAA9ABABA9ABACABADB0ACAFB1
B1B4B6B9BCBABCBBBEBCBEBFC1BFC3C1C3C3C5C6C8C8C7C7C3C3C3C6C7C6C4C7C6C2C5C5
BFC0C1C1BDBFBFBDC0BBBBB6B6B5B4B2B2B2B1B2B1B0B3AFAEADADAFAEAEADA9ADA9ABAD
AAA9A9ACAAACACADAAAAABADACACAEABAEADADA9AEACB0AEB0AEB2B0AFAFAEAEB0B0B3AF
B2B2B2B1AEB0B1B0B2B2B1B2B5B3B5B4B4B4B2B3B3B4B2B1B2ADB1AFADACAAABADA8AAA8
A6A5A6A6A2A2A0A29D9F9C9B9A97979594928F8C8C8B898887868481807E7C7878787472
706E6D69696665615F5D5A585654504F4B49474442403E3B3937363332302F2D2D2C2B2A
2A2928292928282727282727272727272627272627262626262627262627262627262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
26262626272727262727272727272828282828292929292A2B2C2C2D2E2F303132343638
393F434447494A4B4D4F4F515150525352545352545556555557575759585958595A5857
59595A59595A5B5B5C5E5D5E5E606061606264646263636565656769656867696969696A
6C6C6B6D6E6F6D6D706F717171727275737775757676787A78777A7A7A797C7D7C7C7B7C
7D7E7E7F7F8280807F8485878688888789888B898A8C8D8F8E909292959394969697979A
9A9B9F9DA19F9E9F9D9D9FA29F9F9DA0A3A3A3A3A4A6A8A8A8ABA7A9ABACABADACAFABAE
AEAFB4B6B8B7B7B8BCBCBDBDBFBEC1C1C4C2C3C6C3C8C6C5C6C7C3C7C4C5C7C5C5C6C5C4
C3C2C2C2C0BEBEBEBDBCBDB8B5B7B4B5B4B3B4B3B1B0AFAFAEAEAEADACACACAAA9A9ABAA
AAAAA7ABABABABA9ABAAABAAAAACA9ACADADADACB1B0AFAEB0AEAFB0B0AEADAFACB0ADAF
B0AEACAFADADAEAFB2AFABAFB0B3B3B2B0B2B2B2B5B2B2AFB0B1ACACADADADAAA9A8AAA8
A4A7A3A3A3A3A09F9C9B9B99969795959290908F8D898A88878584807E7E7B7977757471
6F6D6D68676662615E5D59565552504D4A484543423F3D3A3837353331302E2C2C2B2A2A
2A2929282828282827272727272727272627272726272726262626272626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262727272726
26272726272727272627272727272727282728282928292A2A2C2C2D2D2F303032343536
383D414646484A4A4D4D4F50505153535354535355555555575957595859595959595859
5859595A5A5B5B5B5C5C5D5E605F5F5F636261616363646365676666656768676869696B
6A6A6C6C6E6D6E6E6F6F6F70727174737575757676777979777978797B797B7B7D7B7B7B
7B7D7D7D807F7F807F8083858685868888898A898B8C8C8C8E8E8F919293969595959798
999A9C9B9E9C9C9E9C9E9D9EA09E9F9FA1A2A2A2A8A6A6A8A9A7A8A9ABAAACADACAEABAE
ADACB1B6B5B8B5B7B9B8BCBCBBBFC0C1BEC0C0C1C3C6C4C7C4C3C6C4C5C8C7C6C3C3C6C5
C5C1C5C0C0BCBEBDBDBDBDB8B6B3B4B5B6B4B4B6B2B2B1AFAFADACAFAAADAAAAA7A8AAA7
A8A8A8A6A8A7A9A8A9A9ABAAABABABACABACACABAEA9ADAEAEAFB0B4B0B0B0ADAEAFAFAF
ABAEADA9AAABACAEAEAAABACADB2B1B0B0B3B3B3B3B3B0AEB4AEABAEACA9A7AAAAA9A8A6
A5A5A1A1A1A2A09C9B9C99999A96939291928C8E8E8A88858483817F7E79797A7674746F
6E6C6A68666361605C5C585453514E4B494846443F3E3C3B37363432302F2E2D2C2B2B2B
292A29282827282727272727272727272727262627262627272726262627262626262626
2626262626262626
262626252626262626262626262626262626262626262626272626262626262626262626
2626262627262727272726272727282728282828282929292B2B2C2D2D2E2F3131333436
373A3F434647484A4B4D4F4F5051505453555555565557565656585857585A59595A5A59
595A595A5A5A5B5C5C5C5D5E5F5E5F616160606262656263636465656666656867686A67
696B6C6B6B6C6C6D6E706F7070727273747575777775767878787A797B7A7A7B7C7C7D7D
7D7C7C7D7E7D7F7E8081808382868585898A8688888A8D8A8F8D91918F95929593939597
989A9B9C9C9A9E9A9D9E9B9A9FA0A0A1A3A39FA09FA7A2A5A5A6A8A8A8AAABABAAABAAAB
ABACB0B1B0B3B4B5B5B4B5BAB8B9B9BDBCBCC1C1C2C2C3C1C1C3C6C6C4C5C7C6C3C5C5C3
C6C4C5C3C0C0BDBEBFBEBABBB9B7B7B6B1B3B4B2B0B1B1B2AEB2ADADAAAAABA9AAA7A8A5
A8A7A8A8A8A7A7A7A8AAABABACA9A9ABAAACABABA8ABADABAFAEADB4B0AEAEAFAEADAFAD
ABACABABA7ACAFAEABABACAEABADAFB1AFB0B0AFB2AFB0ACAEADAAABACAAA7A8A5A6A5A4
A2A3A2A1A09F9C9D9C9A9A989696959192918E8D8C89888484817F807D7B78787674716F
6C6B6A686564605E5C5A5854524F4D4B4A4745423F3D3A3937353332302E2E2C2B2B2A2A
2A2928282828282827272727272727272727262726272727262626272627262627262626
2626262626262626
252626262626262626262626262626252626262626262626262626262626262726262726
2627262726272727262726272727272727272828282929292A2B2B2D2D2E2F3031323335
37393D4245484A4C4B4E4E5151515354545655555657565658575658585758585A595A59
595A5A595B5B5C5B5B5B5C5D5E5E5E605F62616163626265646565666566676668696869
68696B6B6C6D6D6E6E6D6F6F72727372757375777577767776777877797B7B7B7B7A7A7E
7C7D7A7C7B7D7E7E7E7F81828184848484898A8A8A8A8A8B8E8C8C909093929495949595
97999A9A9C989B999C9D9D9E9F9EA19FA1A09F9FA2A1A1A1A4A6A7A6A8ACA7A9AAA7A8AA
ACABAEAEAEAFB1B2B2B3B4B7B8BABCBBBDBDBDBEBEC0C0C3C2C3C3C2C3C1C5C4C4C5C3C6
C5C1C3C1C3C0C1BEC0C0BEB9BBBBB9B6B5B5B3B1B3AFAEB0AFAEABADACABAAA9A9A7A7A6
A8A7A6A8A6A5A6A4AAA7A9A8ABA9A9A8ABA9ABAAABACAAAAACADB0AFAFACADACAEABABA9
A8A9A9A9AAA7ACACABADAAABADADADB0B0B2AEAEADB0AEAFADADABABAAA7A8A7A5A5A5A6
A2A0A3A0A09B9E9B9C9A97969594938F908F8D8B8A878682827F807C7B7C787575736F6E
6E6A696564625E5E5B585855504F4E49494644423F3C3A38363433312F2E2D2D2C2B2B2A
292928282928272727272727272726262726262727262626262726272626272626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
2627262726262727272726272727272727272828282929292A2B2B2C2D2D2E2F30313334
36383B3E444E4B4C4D4D505051525354555457575756555555585757585856585859595B
5959595B5B5B5A5B5C5C5D5E5D5E5F606061606362626163636465666565656965666768
686A6A6B6C6B6C6D6C6E6F6E717172727574747374757476787776777A797B7A797D7D7A
7E7C7C7F7C7E7F807E7E7F7F8081848583888589878A8A8A8B8D8B8C8D8D939390959498
97979B999B9C9C9E9C9D9D9D9D9D9E9DA19EA1A19EA0A3A4A0A3A3A6A7A6A6A6A9A7A5AA
A8ABA9ACAAADADB0B0AFB1B3B3B4B6BBB9BBB8BDBDBFBDC0BEC0C1C1C2C3C2C3C4C5C5C7
C2C4C3C0C1C1BDBFBFC2BEBEBDBDBBBAB8B6B1B2B2B0B2ADB0AFABAAABABAAA8A6A5A3A7
A6A7A4A9A5A6A6A3A4A6A9A9A7A5A8A8AAA9A7A9AAAAAAAAAAADADADACADADACADAAAAAB
AAA7A9A8A7AAADAAACABABA9AAAAABABAEADABACABACABAEABABA8ABA7A8A6A7A2A3A3A2
A19FA19F9A9D9A9D99989796919190908E8B8C888687848180807C7D7B78767274706F6D
6B6A666562605E5B59585552504E4C49464441403D3A393736333230302E2D2C2B2A2A2A
292929292828272827272727272627272727272727272726262626262626262626262625
2626262626262626
252625262626262626262626262626262626262626262626262626262626262627272626
26262726262727272727272727272728272827282728292E292B2B2B2C2D2E2F30313334
3537393C414B49494C4D4F525253535556555656585857575659585857585A5959595859
5A5A595B5A5A5D5A5C5A5C5E5E5C5D5F6060626063636462626164666665676967676867
676869696A6C6E6C6E6F6E6D706F706F7272737474767976787778797777787A7A797B7C
7B7A7C7C7D7C7D7C7E7E80807F8084828584868988868A8C8C8C8D8A8C8C909091969494
9698989B9B9A9B9A9C9B989B9C9D9E9D9D9DA0A39FA0A1A2A3A1A2A4A2A6A8A9A6A6A8A6
ABA9AAA9ACABACAEAFAFAEB0B2B2B3B6B6B7B8BABCBDBDBDC0BFC0C0C2C3C2C0C1C3C4C3
C5C3C4C3C3C2C1BFC1C0BEBEBDBAB9BCB9B8B5B3B2B4B0AFB0B1ACAEABABA8A5A8A7A4A5
A5A3A7A6A7A6A8A6A3A4A7A8A6A9A6AAAAA7A7A7A9AAA8A9A9A7A8AAAEA8ACA8A9A8AAA8
AAACA9A9A9A8A5A8A8A6A7A8A8A9A8A9A8A9A8A8AAA8A8AAA7A9A7A9A8A4A6A2A4A3A2A1
9F9F9E9C9C9A9B98989996949493928E8D8B8B8786868381807E7C7B7A78757473716E6B
6B686563615F5E5A595553524E4E4A494643413E3D3A3837363331302E2E2D2C2B2A2A29
292928282828272727272727272727272726272627262626272626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262627
26262626272726272727272727272727272828292829282929292A2B2C2D2E2E30313134
3436383C3F43484A4C4F5051535354565457575858585857575857585859585959595A5A
595A595B5B5B5C5C5C5D5B5D5D5E5E60605F606061636362626362636565666768666569
676A6969696A6B6B6C6E6C6D6E6D6F72717272737674757774777A77777B7A7B7A7C7A7D
7A7B7D7D7C7C7D7E7B7D7D7F8080808183858487878A8788898A8C8C8D8E8D9393969192
93939598979C9B9A99989A9B9D9C9E9B9E9A9D9C9EA2A1A19E9FA1A0A1A3A4A5A7A4A6A8
A9A9A7A9A7ABABACABAEB0AEAFB3B2B1B2B5B7B9B6BBB9B9C1BEBDC2BFC1C1C3BFC3C1C4
C2C6C5C2C1C1C1BEBDBFBEBCBABCBBB8B8B6B8B5B4B2AFB2B1ADACAAAAAAA7A7A3A4A6A5
A2A4A5A2A4A6A6A7A6A7A5A9A5A6A5AAA9A9A7A7A8AAA8A7AAA8A7A9AAA9A9ABA9A9A8A6
A7A7A7A9A9A6A5A4A5A3A6A6A4A5A7A5A8A9A8A8A7AAA6A7A7A5A7A8A4A5A4A3A2A2A19F
9E9E9D9E9B9A9A979894969491918E8E8D8B86888684807F7E7D7A7877757373706D6E6A
68676461605D5B58565352514D4A4A4745423F3E3B3937363431312F2E2E2D2C2B2A2A29
292828282728282827272727272726262627272726262726262726262626262726262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262727272727262726272728272728282829282829292A2A2A2B2C2D2E2F313233
343636393C42484A4C4F5153545455565657595958575959595957585A585959595A5B5A
5A5A5B5B5A5B5D5B5C5C5D5C5D5E5E5E5F60616162616262626263646465656766686768
68676A6A6B6B6B6B6D6A6D6E6C706F6F6F72717274737474757876787878777979797979
7B7A7B7C7D7B7E7D7C7D7E7E80807F7E82828284858686888A8B8B888B8C8F9092919191
9293959497999A989898999C9C9F9E9D9B9C9C9E9C9C9E9EA19EA09FA1A2A4A4A6A5A2A5
A6A6A7AAA6ABA8A7AAAAADABADADAEB0B1B4B4B5B6B5B7BAB9BDBFBBC1C0C0BEC1BFC3C2
C3C2C4C5C2C1C1C2C0BEBCBEBCB8BCBAB8B9B9B7B8B4B3B2B1B0AEAEABAAABA5A7A5A8A4
A4A09EA4A2A5A4A6A6A6A6A5A5A6A8A4A6A8A8A7A8A7AAA7AAA9AAA6A9A9A7A9A8A7A8A8
AAA5A8A6A6A4A4A3A4A4A4A3A6A3A4A3A8A4A4A7A6A7A6A6A5A7A6A4A6A3A5A0A5A0A0A0
9F9E98999A9999979495929190918F8C8C8789848682827F7E7B7879777573726E6D6A6A
676562605E5C59585552504E4B49494644413E3D3B39373534312F2F2E2D2C2B2A2A2A29
292928282827272727272727272727262627272727262626272626262726262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262727262727
262627262626262727272727272727272727272828282829292A2A2B2B2C2D2D2F303132
343536393D3F464A4D5052535355555656595858595959595959595A585B5A5A5959595B
5A5A595B5C5C5B5B5C5D5C5D5B5C5E5E5F6061606162616361636265646366656667686A
66686B6A6B6A6A696A6C6C6D6F6C6E6F7072707371737474747576787978797977797979
77797A7B7C7B7C7D7C7D7D7E7E807F7F7F81818483848787878888878A8D8C8F8F8D8E90
8E929193939898979798979C9C999D9B999A9E9C9D9D9CA09C9E9EA09E9FA0A0A1A1A5A5
A4A4A7A4A5A4A6A9AAA9A9ABA9ADACACAEB2B0B1AFB2B7B7B9B8BABBBCBABDBDBFBFC3C1
BEC0C3C2C2C3C4C2BEBDBFBFBDBEBBBAB9BAB7B8B5B3B6B4B1B0B0ABAEACA7A6A8A4A5A5
A1A1A0A0A2A3A5A3A5A3A4A4A5A6A8A7A5A6A8A5A7AAAAA8A7A8A7A6A7A8A6A9A9A6A4A7
A6A6A4A5A4A4A3A2A4A3A2A6A2A2A1A3A2A3A4A5A4A5A4A5A5A3A4A3A7A1A2A29F9E9E9E
9B9C9C9B97999794959292918F908D8B8A87858481817F7F7C7A76767475716F6F6C6B67
6664615F5D5B59585453504D4B49474442413D3B3A3836343331302E2D2C2C2B2A2A2929
282828272728282827272727272726262726262626262626262726262726262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262627
2726262727262727272727272727272727272827282828282929292A2B2B2D2D2E303032
343537373B3E43494E51525456585757585A595A59595A5A5B595959595A5B5A59595A59
5A5B59595A5B5C5D5B5C5E5B5E5D5E605E60606161606163636462646464646764676868
6868686869696A6C6A6B6A6C6E6E6D6C6F71707272727275757676767678797778777877
7A797A7B7B7B7C7C7E7D7D7E7D7F807E7F81818284848485878688898A8A8D8C8E8E8B8D
8E8F8F91969796989896979A989B9B9B9C9B9D9A9D9B9D9D9E9D9B9F9E9FA09FA09FA09F
A4A4A4A4A5A6A7A7A8A6A6A9A7A8AAA9ABACAFAFAFB1B2B6B6B6B6B8BBBBBCBDC0C0C3BF
BFC0BFC1C0C1C0C2C2C2C0C1BEBCBCBBBABCB8B6B6B4B5B2B4AFB0B2ACACACA9A7A5A4A3
A49F9FA0A3A2A3A2A1A1A4A5A4A5A8A6A6A5A6A6A4A8A8A6A7A7A5A5A3A7A5A7A6A5A5A6
A5A5A6A4A4A2A2A2A0A2A1A2A1A0A1A0A0A39FA1A1A3A4A3A3A4A3A1A19D9F9D9C9F9C9B
9A989A979696959492938F8E8E8C8B8A8887858481807E7D7E797975747370716D686765
646362605C58575554514F4C49484643403F3E3A3837353432302F2D2D2C2C2B2A292929
292828282827272727272726272727272727262627262626262626262626262626262626
2626262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
26262626262726272726272727272727272727282828282928292A2A2B2C2C2D2E2F3031
33343538393E41484C50535557585858595A5A5D5B5C5A5A5B5A59585A595A59595A5A5A
5B5A5B5A5B5C5C5C5B5D5D5C5D5F5F5E5E5F605F60606262646462636362656565666766
6666686969696A69696D6B6D6C6D6E6E6D6F6F7171727171717274767776767777777879
787A797A797C7B7B7B7D7D7B7E7E7C827E80808281858384848487868689898C8C8B888A
8D8C8D909194949696949695999A9B9799999A9B9B9B9CA09B9D9C9E9D9D9E9E9FA19FA0
A1A0A1A2A4A6A5A7A5A6A7A8A8A8A9A7A7AAA9ADADAEB3B1B3B6B4B8BABABBBDBCBCC2C1
BDBDC1C1C0C2C1C4C2C1C0C1BCBCBCBDBDBCB7BAB8B4B6B5B0B2B0ADABAEACABA6A7A5A4
A1A19E9FA19FA1A1A1A4A4A4A8A6A5A4A4A4A7A4A4A8A7A6A6A6A4A4A6A5A3A5A4A3A5A4
A4A1A3A2A1A09DA1A0A1A2A1A19F9F9F9E9E9F9F9FA19FA2A1A2A1A09BA09F9C9B9B9C99
999898979596919292928E8E8B8E898B87868282827F7D7C7B77767474726F6E6A696666
6461605C5B595654514F4C4A49474442403D3C3A3835343331302F2D2C2C2B2A2A292929
282828282727272727272727272727272727262626262726262727262626262626272626
2626262626262626
262626262626262626262626262626262626262626262626262727262626262626262626
26262626262627262627272727272727272728272828282829292A2A2A2A2C2D2E2F3031
33333636393B3F444B51535558595A5B5A5B5B5D5D5E5B5C5C5C5B5A5C5A595A5B5A5B5C
5C5C5A5B5B5B5D5B5C5D5D5D5D5F5F6062605F5F61606262626262616464666565656567
66666667696869696A6A6B6C6D6D6D6C6E6F6F7270717270727173747675787777777777
77787879797A7A7A7B7E7B7C7B7D7B7D7F7F7F7F81808281838485858988878C88898788
8A888C8E92919491939293959698979799989A999A9D9D9D9D9A9B9C9B9F9C9D9D9A9FA0
9FA2A3A3A1A1A2A4A4A4A5A6A6A8A6A5A7A8ABACACAEADB3AFB3B3B6B7B8BAB7BBBCBFBC
BCBEBEBDBEC0C1C2C2C0C5C1C1BFBDBEBDBCB9B6B8B5B6B5B3B3B1B0B0ADABACACA9A6A2
A1A0A09E9FA0A1A0A4A3A1A3A4A7A4A4A5A5A4A2A4A4A3A6A6A6A8A7A1A6A1A1A4A1A4A3
A2A2A3A1A39FA29D9EA09E9E9E9E9E9C9D9D9F9D9F9F9E9EA09D9E9D9E9CA09C9A9B9998
9A9695979394919190918E8D8C888787868583807D7E7B7A79767673716E6E6B69696662
62615F5D58575553524E4C48474743413F3C3B3A37363332302F2E2D2C2C2B2A292A2929
282828272827282727272727272726272627272626262626262627262626262627262626
2626262626262626
262626262626262626262626262626262626262626262526262626262626262626262626
272626262726262627272627272727272727272827282728282929292A2B2C2D2D2F3031
31333436393A3D42494F5355585B5B5D5C5C5B5D5D5E5E5E5D5D5D5D5B5B5B5B5A5B5C5E
5C5B5B5A5B5B5B5A5E5D5F5E5F5E5F605F60606161626263616363636265646467656767
6767676768666A696B696C6C6D6D6C6E6E6E6F6E70707271727173727677767575777878
777877797B7A797B7A7B7E7C7B7D7D7C7E817E7F80838080807F8284848789898A89878A
8A898B8B8E908E8E8E8F9291959798969794989899999C9C9C999A9A9C9F9B9C9D9D9B9C
A1A1A1A2A1A3A0A3A4A2A2A4A6A5A8A8A4A7A6AAA9AAAAACB1B2B3B6B4B8B4B8B7BCB9BA
BABEBCBFBEBEBFC0BEC2C2BFBFBEBFBCC0BBBCBCB7BBB4B6B4B2B1B2AFAEACADACA8A5A3
A2A2A09F9FA0A1A2A2A2A0A3A5A4A5A4A4A2A4A4A5A4A4A6A4A5A5A3A2A3A1A3A2A2A2A2
9FA0A2A2A0A09B9E9E9D9C9C9D9D9C9E9A9A9B9C9B9E9D9B9D9E9C9B9A9B9B9998999797
98949393919390908F8E8C8A898B86858584817F7F7B7A7776757471716F6C6C6A676562
605F5D5A595652524E4C4A49464542403C3C3A3836343230302E2D2C2C2B2B2A29292929
282827272727272727272727272726272727272626262627262626262626262726262626
2726262626262626
252626252626262626262626262626262626252626262626262626262626262626262626
26272626272627272626272727272727272727272827282829292929292A2B2C2D2E3030
31323335383A3C3F444C52575A5A5C5D5E5D5D5E5F615F61605F5F5D5C5D5C5C5B5A5A5B
5B5D5D5C5B5C5C5D5D5D5D5C5F5F5F5F5E5F616061616262636264626563656566666666
66656867676767676C696A6C6D6B6E6B6D6D6F6F6F707070727073737573737377767777
77797879787B7A787C7A7B7C7C7D7E7E7E807E7E8180817F818282828385858786898989
8888898D8C8D8C8E8F8C8E90919396949697969897979A989C99999A9B9C9C9E9A9D9D9C
9D9B9C9CA1A09FA1A0A1A2A2A5A6A7A6A5A5A8A4A6A7ACADB0AEB2AFB2B6B6B3B7B5BABB
BEBABCBCBDBBBCBEBFBDBEC1C0C0BEC0BDBDBCB9BAB7B5B5B8B3AFAFAFAEAEAEADA9A6A7
A6A2A5A0A09FA3A0A2A1A4A4A2A1A2A2A1A5A6A2A2A0A5A6A3A4A3A3A2A0A4A2A29E9CA0
9F9D9DA09F9D9D9B9E9C9E9D9C9A9B9B9C99989C9B9A9C9A9B98999997959A9697979794
9594939092908D8C8D8C8A88878786848181807E7C797A7676747270706C6B6967656261
5F5D5C58575452504D4C4A464542403F3D3A3937353432302E2E2E2C2C2B2A2929282828
282728282727272727272727272626272727262626262626262726272626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262627262626262626262626
26272626262726272727272727272727272727272727282728282929292B2B2C2C2E2F30
3132333536393B3F42495257595B5D5F615F616061616363616261605E5D5D5E5D5D5C5C
5B5B5D5D5D5C5D5B5C5C5D5D5E5E5F5E5F5F5F6062626162626262636464636466646565
68686669676667686A676969696C6B6C6D6A6E6E6F70706F706F70717273737374767576
7777777779767779787A7B7B7B7B7B7D7C7E7F7E7E7F7F7F808181817F84838685878787
87898B898D8C8D8B8B8D918F9391929491959695989696999B999A99989B9B9C9D9A9A9C
999D9E9D9F9FA19EA19FA0A1A2A3A4A5A6A4A3A5A6A8A7ABADADAFACAFB1B2B1B6B4B9B8
B9BBBCBDBCBBBDBABDBEC0BEC0BDC1BDBFBBBCBCBBBBB9B6B6B4B5B0B1AEADADACAAAAA7
A7A7A5A4A3A0A29FA29FA3A1A2A3A3A4A3A3A7A6A4A4A1A2A4A1A1A4A3A2A3A1A2A1A09D
9E9EA09E9C9C9B9B9A9A9C9B989B96989699999698999696969796979695959795939191
929291908E8F8E8B8D8A89898582848382807F7D7B7879747374716F6C6B6A666664625F
5E5C5A565652514F4C49484644423F3D3B393635343231302F2C2D2B2B2B2A2929292828
282827272727272727272727272727262626262626262626262726262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
26262626272626272727272727272727272727282728272828282829292A2B2B2C2D2F2F
3031333537393C3E40474D545A5D5F61606262616161646565626362615F5E5D5D5D5C5E
5C5D5C5C5B5B5C5E5D5C5E5D5F5F5F5F5F5D60605F616362626363626464646565656565
66656668686668696768696B6A6B6A6C6C6E6D6E6E706D6E6F6F71737372757375747575
76747577777979787A787C787C7A7C7D7B7C7C7D7E7C7E7D838081818182828284848588
868988898988878C8B8B8D8F92939491959593959695979796979A9999969B989A9A9A99
9A999C9D9F9D9EA0A19E9EA0A1A3A5A7A0A3A5A4A6A6AAA9ACAAABABB2ACADAFB2B0B4B5
BABABCBABEBCBCBDBBBABFC0BDBEBCBCBDBCBABAB9BBBBB8B5B5B4B3B2B1AFAFACACAAA8
A4A7A4A5A4A1A1A3A0A3A2A0A2A0A2A0A4A4A4A1A5A6A2A3A2A0A4A2A4A0A3A2A19E9C9C
9F9C9D9C9A9B9C9A9A979A9A9B9696969794969A96969493949496939594959194929191
91908D908B8D8A8B8A8988868383847F807E7C7C7B76777472716D6D6C6967666363615F
5C59585454504F4D4C49474542413E3C3A3837363432312F2E2C2C2C2B2A292929282928
282828272727272727272726262726272627272626262726262627262727262626262626
2626262626262626
252625262626262626262626262626262626262626262626262626262626262626262626
2726262626262627272727272727272727272727272727282828292929292A2B2C2D2E2F
3031333437383A3B40424851595E61616364646363646765656564636361605F5F5F5C5D
5D5E5D5D5C5D5C5E5D5E5E5D5E5F5E5E605F606161636162646364626264666464636463
65666566676968686A69696B6B6B6A6B6C6C6C6C6E6D6E6E6F6E6F716F71737674747576
7576757777787779797A7978797B797B7D7C7C7C7D7C7D7E7E8281818081838184838384
868788878787868988898C8D8F918E8E939294949696949996999797979799999A999B9A
99999D989D9D9D9EA09D9E9FA0A2A49FA3A1A3A4A4A6A3A5A8A9ABAAA8ABAFAEB0B1AFB2
B8B8B9B8BAB8BABBBEBCBFC0C1BEBEBCBEBDBABCBDBAB8B7B8B7B6B6B3B1AEADB1ADACA7
A8A7A8A6A6A4A6A2A2A6A4A4A5A1A2A1A5A5A3A3A5A3A2A1A2A3A7A6A2A3A2A09F9F9D9D
9C9C9E9E9B9B99999C9697979897959594979494959491939392929394949390928F8E8F
8E8D8F8B8E89898B8B878584818280817E7E7A7B7879757371716E6C6B6C69656461605D
5B58565451514F4A49484543413E3C3C3938353333312F2E2D2C2C2B2B2A2A2929292828
282728272727272727272727272727262626262726262627262627262626262626262626
2626262626272626
252626252626262626262626262626262626262626262627262626262626262626262726
26262726272627272626272726272726272727272827282828282929292A2A2B2B2C2E2E
303132343537393B3D42464D565B616466676767666765686868676766666362605F5F5E
5E5D5D5D5F5D5D5D5C5D5C5E5D5F5E5F6160616162616163636264626464646464636365
6565666765666866676866696B696A6B6C6B6C6B6D6E6D6E6E6C6E707070717373737273
72727677797677777778787B7B7A7B7C7E7A7B7E7D7F7F7D7B7E7F7E80817D8182828285
8586878686878886898A89888A8C8E8F8D8F929293969597979598969997989899989A98
9B9B999A9B9B9C9A9D9D9B9C9E9EA0A0A2A1A3A1A2A1A0A3A4A5A6A6A8ACAAABADAEAFB0
B2B6B6B8B7B7B6BCBBBFBEBFBDBEBCBDBFBBBFBDBCBBBBB9B7B7B5B5B3B1B1B2AFADAFAA
A9A8A8A7A7A5A2A5A5A5A2A2A3A2A3A1A3A1A4A2A2A4A3A1A2A4A5A3A1A2A1A1A0A09C9D
9B9C9C9A9A999797989993949595939393939492939494918E8F8D8F91918F8F8F8C8D8E
8E8C8D8A8989888887858484827E837E7B7B797876757372706E6B6B6869666662605F5D
5A575653514F4C4A48454442403D3C3A3837343232312F2D2D2C2B2B2A2A292929292928
282827282828272727272627272727262726272726262627262626262626262626262626
2626262626262626
262626262526262626262626262626262626262626262626262626262626262626262626
2726262626262626262626262726272727272727272827282828282829292A2A2B2C2D2E
2F3132333536383B3D404449525A6164676769696968696A696A6A69676865656261605F
60605E5F5E5C5D5D5D5F5E5D605F616061616160635F6162616364636365666564656564
65666667686666676767686B6A6C6C6A6C6C6B6A6C6D706E706C6D706F71727174707173
73747677767678767877777A7879797B7C7C7B7D7F7C7C7B7C7D7C7C7E7E7F8080828082
838384848586888A8789888A8A8B8A8A8B8E8F9192929493939898959696999699989899
98999C99999997989A999C9D9B9E9FA09F9FA1A0A0A0A0A2A3A3A4A4A7A8A9A9ABACA9AC
AEB1AFB2B4B6B7B9B7B9B9BCBDBBBCBEBCBCBEBEBCB9BABBB9B8B6B3B2B0B1B0B0AFAEAB
ABACA8A7A7A6A7A5A6A4A4A5A5A3A3A1A4A1A2A2A2A1A2A2A6A5A3A3A1A2A19F9FA2A09D
9C9D9C989B969695959695969593939492939091918F908F8F8E8D908D8E8F8B8C8C8D8D
898B8B8A89878785868382827F7F7F7D7B79797677737270716B6A6968656461615F5B5A
58565553514D4B4B464442413E3C3B3937353333312E2E2D2C2B2C2A2A2A292929282828
272727272727272727272727272727272727262727262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262726262626
26262626262626262626272727272727272726272727272728282828292A292A2B2C2D2E
2F2F31333436383A3C3E43464C545F65686B6A6B6B6C6A696B6B6C6B6B6A68696463625F
5E5F5F5D5E5E5E5C5E60605E5D5F5E605F61636160606162646364636363656462646465
666566686666666868666868686B6B6B6B6B6B6B6D6E6D6E6E6E6E706F706F7171737273
72737374747676787778777679787A7B7C7B7C7A7D7E7E7E7D7C7D7E7C7F81807F818080
8182818386858586878888868889888C8D8E8F8E90909494949394939496969698999597
9797989798989A999A9A9C979C9B9A9B9C9D9FA1A1A0A3A0A1A2A3A3A4A3A8A7ABA9ABAA
AAADADB1B1B2B4B5B5B6B9B9B9BBBBBABCBBBEBABDB9BBB9B6B7B7B6B5B3AFB4B0AFB0B0
AEACACA8A8A8A6A8A5A4A6A3A4A5A6A5A5A3A3A2A4A4A1A4A2A2A1A2A1A0A19FA19E9E9C
9C9B9A999797979893949494949290909091918F8F8D8C8E8C8B8D8D8B8B898A8C898B89
88888A878786858485808080807F7E7A79777776747271706E6C6A6766656260605E5B59
565452504F4D4A484643423F3D3B3A3736353331302F2E2D2C2C2B2B2929292928282828
272728272727272727272727272726272627262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262627262626262626262627
26262726262626262627272627272727262627272727272828282828292929292B2C2C2D
2E303132353537393B3D414449515A61686E6D6E6E6A6C6D6D6B6D6C6D6C6A6868656262
6161615F615E615E5E5F5F5F605F5E605F60616160616161616464636563636464656465
64646664676867656767676A69676B696C6B6B6B6E6E6E6E6E6E6F6E6D6E707072707170
74717273757576777475757678777B78787779797E7E7D7D7E7C7E7D7E7F7C7F81807F7E
7F8282828282848585878885898888898C8D8C8E908F9392919395969596959695969796
9A97969597969697999C9B9C9D9C9C9D9E9BA09D9C9F9D9FA2A0A0A2A1A1A3A3A6A8A9A8
AAABAEACB0AFB1B2B3B5B6B2B6B8B8BABABABAB7B9BAB9BBBAB8B5B5B8B7B2B3B3B0AFB0
AEADABA8A8AAA4A7A6A5A4A4A6A6A6A5A4A4A4A3A4A4A5A3A2A2A1A0A1A0A2A09EA0A09C
9B9A999797969595939392949291918F8F8E8F8D8E8C8F8B8C8A8B8A8B8A888887868787
85858785858484838180807C7E7B7B7A7A75757272716E6D6B6A68666562605F5E595957
5554514F4C4949464543413E3B3A3837353332312F2E2D2C2C2C2B2A2A2A292829282827
282727272727272727272727272626262626262626262627272626262626262626262626
2626262627262626
262626262626262626262526262626262626262626262626262626262626262626262626
262626262627262727262727272627272726272727282727272828282929292A2A2A2B2D
2E2F3032333537383A3D4043474E5760666B7170706E6F716F706F6E6D6E6E6C6B6A6865
6260626162606061605F60605F605F616061615F62616161616363646363666565656465
6463636566686766666967686768696A6A6B6B6C6F6E6D6F6D6C6D6D6E706E706F6E706F
70727372767675747674767877767778797B797A7B7A7B7B7E7B7D7D7D7F7F7E7F80807F
7F8081818283818186878587878789898D8B8C8E8F909090929294939595979596999699
949699969698979698999A9B98999B9A9B9B9E9E9F9D9D9F9FA0A09EA2A0A2A1A4A3A7A5
A6A6AAABAEAEAFB1AEB0B4B4B3B5B6B6B9B8B9BAB7B9BAB9B9B7B6B7B6B4B4B1B2B5B0B0
AFB1ABADABABA9A7A6A5A7A7A6A4A4A4A5A6A6A1A4A3A6A3A3A4A49FA4A09F9E9F9E9D9B
9D9B9A97969593958F9291919090918F8D8D8D8D8D8B8B89888A8A888788868686878785
8383828480818281807D7C7C7D7B79777775747271706D6C6A68676464615F5C5C585954
5352514C4B4A484543403F3D3C3A3836343231312E2E2D2C2B2A2A292928282828282827
282727272727272727272627272726272727272626262626262626272626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
26262726262626272626262627272726272727272727272728282828292829292A2A2C2C
2D2F303233343638393C3E4147485059636C6F7374747172717171717170716F6C6A6967
666263636262626060606161616361606261616363606262626163636365666564656464
646563636467676769676767676969676A6A6D6B6E6C6F6F6C6C6D6F706D706F7070716F
71717273747573737675747577757777787978787B7B7C7B7D7C7B7C7F7F82807E817F81
828182808080828387858686858787888A898B8C8B8E8E8E8F8F91949492949393969497
9594979595959496969796979A9797999A9C9B9B9A9B9B9D9B9B9DA2A0A1A2A0A3A4A4A3
A5A6A6A7A7ACABADADAEB0B0B2B5B4B8B6B7B8BABAB9B9B9B8B7B6B8B5B6B5B0B4B0B1B1
B0B0AFAEABACA8A8A6A6A7A8A6A6A5A6A6A4A5A2A5A5A5A3A5A1A1A1A2A09FA09E9E9C9F
9A9C9A98989495939491908F8E908E8E8D8D8B898A878789898987868586828485828280
83818280837F7D7E7E7A7C7B7B797877767372716E6D6B6B6A676464605F5D5C59585554
524E4D4B4A484644423F3E3D3A3937353331302F2E2D2C2B2B2B2A292929282828282828
272727272727272727272726262726262726262727262626262726262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
2626262627262726262726272726272627272727272728272727282828292929292A2B2B
2D2E303033343537393C3E4144484C5660697175767376757373747270727270706E6D6C
696865666564616262626263616161626161616060616362626263646464656565646466
65656565666765666667686667666968696A6A6A6B6C6C6B6B6C6B6D6D6E6E6D6F6F7070
7071717071757373727374737575747777767977787A7A7B7A7B797D7E807E817F81807E
80818180808082818182838484868887898B8A8C8B8D8B8F8D9192919292919194929592
9596959793949894969594959895969798979A9B999C9A9B9C9EA19E9F9E9FA1A0A0A3A4
A3A5A7A7A9AAA9A8ABADAEAEB0B1B6B6B3B7B5B7B6B6B8B8B9B9B7B7B9B6B4B4B2B2B0B0
AFB0AEADAEAEADAAABA8A8A7A9A8ABA5A6A5A4A6A1A4A4A5A3A3A0A2A2A0A19F9F9E9F9B
9D9A9A9997969593949091908C8A8F8D8A898B8A8A8A8783868884858582828381808281
807E7D7E7F7E7B7B7A797A797876767573726E6E6D6B6B67666364605F5C5C5A58575552
50504E4A49484442403E3D3C3A37363332312F2F2D2C2C2B2B2A2A292928282828282828
272727272727272726272726272726262727262626262626262626262626262626262626
2627262626262626
252626262626262526262626262626262626262626262626262626262626262626262626
26262626272626262726272726262727272727272727272727282828282829292A2A2A2B
2C2D2F3032343536383A3C3F41464A505A656E7577787B7878757676737475747071726F
6D6A68666566666462636463646263646262616162636361626163626564656465646566
6566676666666867676869686867676869696A686A6D6D6C696E6D6C6D6D6D706E707271
706F72737271727374747574737676777576787778797A7B7C7A7C7C7E7E7E817E7E7F7E
817F7D7F7E7E8081818283848482858789878A8A8A8B8C8C908E90908F9090928E929393
95949590939392939494949495959797969899979A9A98999D9B9C9B9D9C9F9DA19FA1A2
A3A2A6A6A6A7A7A7A6ABACACAFB1B3B3B4B3B3B7B5B6B6B6B6B5B6B7B4B8B6B6B4B3B3B3
AFB0ACAFACADABACAAA9AAABA8A9AAA7A6A7A9A6A3A5A8A5A6A1A4A3A3A29FA09C9FA29D
9A9E9A989696949491918F8F8D8C8B8C8B87888787868684848385828181808180807E7E
7E7E7C7E7D7D7A7A7A7879787575757371706F6C6A696868666562605D5D5B5956555351
4F4C4A48464443423F3D3C3B3836353332302F2F2D2C2B2A2A2A29292929292827282728
282728272727272727272726272627262627262626262626272626262626262626262626
2626272626262626
252626262626262626262626262626262626262626262626262626262626262626262626
2626262626262726262727262626262727272727272627272728272828282829292A2A2B
2C2D2E2F31323437383A3B3E4043484D535F6B72767C7B7A777878797675757674727170
6D6C6B696866676664656464636461636063636161626263626364636665646366656465
6466636667666666656867656968676868696A696A6A6A6B6D6B6C6D6D6D6D6C6E6D6E6F
706C707172717274737374717375757575767679787778797B7B7C7B7D7E7E7B7E7E7D7C
7E7D7F807E7E7E7E7F8080848485858586848788878A8A8A8B8B8E8E8F90908F8F908F93
919292919293959295929195959594969699979795989B979A989B9E9A9B9C9C9D9D9EA0
A4A1A2A1A3A4A5A7A5A8A7ACAFAFB3B3B3B2B3B3B5B5B6B5B5B8B7B5B4B7B7B7B4B6B0B3
B1B1B1B1B0ADADAAABACACACA9A8AAAAABA8A7A8A8A6A6AAA9A4A5A5A2A2A3A19FA09D9C
9A9C98989999939492908E8E8B8C898A88898887858685818282827F81807F807E7E7F7C
7D7A7C7979777A7979757375747474706F6D6C68686865666361605F5D5A59585553524F
4D4B4948474241403D3D3B3837353332302F2E2D2C2C2B2A2A2929292828282728272827
272727272727272727272627272626262726262627262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262726262626262626262627272726272726272727272727282727272828282829292A2B
2C2C2D2F3132343537393B3C4043464A4F576570757A7C7F7E7E7A797B78787977757573
72716F6E6C6969676A686865666566626364626262616361656364646563656664636566
65656666676767656765666768676568686767676A6A6C6A6B6A6C6C6C6C6F6C6E6F6C6F
706F6F71717171717073747472747574757679777677777A7A7B7B7B7D7C7C7C7B7C7B7B
7F7E7D7D7E7B7C817F818281818283828384868686878786898A8B8A8E8D8E8E8F90908F
92919093919294949490919493949694959495989696949798999B999A9A989A999A9C9F
9DA09E9FA1A2A3A3A7A4A7A8ADAFAFB3B3B4B4B4B6B3B7B5B7B4B4B5B6B7B6B3B2B2B3B1
B0B1B1AFACB0B0ADACAFADADAAABACABADACA8ABAAA8A8A7A6A6A6A8A6A2A1A2A3A09F9D
9C9D9A97969594959392908D8C8B8A888988858483848483828180807E7E7D7C7C7B7B7B
7A7A7877777776767673747272726E6F6D6B6A686866646361605E5C5A5B56555450504D
4C4A48464542403F3C3C383735343231302F2D2D2C2C2B2A2A2929292928282828282727
272727272727272727272726262726272726262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262626252626262626262626
262626262627262626262626272626262727272727272727272727282727292829292A2A
2B2C2D2F3031333436373A3B3E4145474B525C6674787C7E807D7E7C7B7B7E7B7C797775
74737072706C6C6A6A6B6968656667656665646362626163626364636564626664626563
656567676565676766666766676766696667696A686B6A6B6A6B6B6B6B6A6D6D6E6D6E6E
6F6E6D706F6F7072717273737172727272757474777779787A787C777A7A7A7B797B7B7C
7D7B7D7C7C7C7D7D7D80817F818183848384858784848586878787888B8A8C8E908E8F8E
90909091939191939391929293939493929394959897969896969A9A9A9A9799999B9B9E
9C9E9E9F9FA2A3A7A3A5A5A8A8AEB1B2B1B3B4B6B4B8B3B4B3B2B4B3B5B5B2B3B1B2B5B5
B3AEADB2B0B0B1ABB2AEB1AEAEACAEACADAFABACACA8AAA8A9A9A7A4A8A3A3A1A3A2A09F
9E9B9B989795949391908E8C8B8987878686858283848181807F7E7E7E7D7C7B7A7A7B7A
797676767774747473737170706E6D6C6D6A686666626460605E5D5A5957555352514D4D
4A49474442413F3E3B3A3836343431302F2F2D2C2C2B2A2A292929282928282727272727
272727272627262727262727262727262626262626262626262626262626262626262625
2626262626262626
252626262626262626262626262526262626262626262626252626262626262626262726
262626262626272626262626272627272626272727272727272728282728282928292A2A
2B2B2D2E2F31323435373A3B3D3F4347484D555E6B767C81818182807D7F807D807D7D7A
787674727172706C6D6B6B696B6868666664656566646363646464656464636363656464
6565666765656567656765676465696769686A69696B696A6C6B6C6C6C6C6D6C6B6E6D6D
6C6D6E6F6F6F7070727071737373737573737275747579797878797B787978797A7D7B7B
7C7B7D7C7D7D7D7D7E7D7E7F7F7E80808483838385848584848587878B8A8C8A8C8C8D8D
8E8F9191929091928F939391919093919394929494949492959698999B9A99979B9A9DA0
9D9D9E9C9F9FA2A0A5A2A4A3AAADAFB0B3B4B4B3B6B5B4B3B4B4B1B1B2B2B2B1B3AFB4B1
B3B0B0B0B0AEB2B1B1B2AFADADB0AEB0ABAEADACAEAAAAA8AAA8A5A7A6A4A5A6A2A0AB9F
9C9A9A9B9B96959491918F8E8D8A898785848283808081807D7C7D7B7C7B7A7B7B787876
757775747273727270706F6E6E6D6B696A6967666663615F5F5B5B59565553524F4E4D4B
49474443413D3D3C393937353431312F2E2E2C2B2B2B2A29292928282828282727272727
272727272726262727272626262726262626262627262626262626262626262626262626
2626262626262626
252626262626252626262626262626262626262626262626262626262626262626262626
26262626262626262627262627272726272727272727272727272727272728282829292A
2A2B2C2D2F3032333535393A3C3E4244494B52596371787F83838584818281848285817E
7E7B7878777473716F6D6D6C6B6A6A696768686665656464646564646263626465636565
6564646465666466666366656567686869686A68696969696B6A6C6C6D6B6A6C6D6D706C
6D6D6D6D6D6E706F6F6F707272717072737375737476757979797677797878777A7B7B7B
7A7B7E7B7C7C7E7C7E7C7D807F7E7F80807F828283858582848586868889888C8A8C8A8D
8C8D8D8E908E908F8F918F8E8E908F9095929292929293959496979997979A97999B9F9F
9D9C9B9D9B9C9F9FA0A2A2A4A6A9ACB0B2B1B3B4B6B2B3B3B3B2B1B4B2B3B3B0B2B1AFAF
B1AFAFAEB0AEB1B0B0B1B1AFB1AEAEADAEAEACAEACACABAAACA7AAA6A8A4A3A5A3A2A19F
9D9B9A9A9A9795939190908C8D8A86858481808182827E7E7D7C7B7A7C787977787A7875
757573717271706E6D6D6D6D6A6A69676666656362605F5D5C5A5A57565451504E4E4B49
47454443413E3C3A3A37363432312F2F2F2E2C2B2B2A2A29292928282828282827272727
272727272727272727272727272626262726272626262626262626272626262626262626
2626262626262626
252626262626262626252626262626262626252626262626262626262626262626262626
262626262626262726262626272727262627272627272727272728272727282929292929
2A2A2C2C2D2F3032343537393B3E4042464A4E545C69747B808586888785858486848783
817D7B7B7778767472716F6F6D6C6D6B6868696968676667646466646463636263636365
64656464636465656766666364656568676868686967696869686A6A6C686B6B6C6E6E6D
6D6D6D6E6D6D6D6F6E6E716F6F7070737274737272747476787877757678787679797A7B
7C797B7D7C7C7B7C7C7C7E7E7D807F7F7C7E80808083838483848587868787868888898A
8B8D8A8D8C8C8E8D8F91919191908E90918C909092939493949297979795979A999A9C9B
9C9A9898989D9FA09FA0A1A0A2A5A8A7ADAFB0B1B0AFB1B0B1AEB0B0B2B0B0B0AFAFB0AD
AEAFADB0ADAFAEB0AEB0ACAFB1AFAFADAFAEACADABACACABA8ACA8A6A6A7A5A6A4A3A39F
9C9A9D9C9B98979492908F8D8C8A8985848182807F7F7C7B7B7979777778777878747573
7272727070716E6E6D6C6C696969676665646161605E5F5C5B5756545452524F4D4A4A49
4644423F3E3C3B3A3937353432302F2E2D2C2C2B2A2A2A29282928282828282827282727
262727272726272726272626262627262626272626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626252626262626262626262626
262626262626262626262627272626262727262626272727272727272828292829292929
292B2C2C2C2E2F31343437393A3D404346494B4F58626D78818086898888878788878886
8382807F7D79787774747371706F6C6A6E6A6B6B68676867686565666562646365636464
6563656564626464636665676465656666676868686868696A6A686A6A6A6A6C6D6C6F6E
6F6D6C6B6D6D6C706F706E6F717172727272737273727274757A7776787679787879787B
7B7C7A7B7D7B7B7E7D7E7A7E7C7D7D7C7D7E7B7F807F8282828585848585858687888687
8989888A898B8C8A8D8E908D8F8F8F8F928D90908E928F90929293969596949697989798
9B9A9998989A9B9EA09F9D9EA3A4A6A7AAABAEAFAEB2B0B0B1AEB1AFACADAFAEB0B0AEAE
ACB0ADAEB3B0B1ADB0B0AFAEB1B0B0AFB2B0B1ADABAEADAEACABADA7A6A7A6A3A5A5A3A2
9D9E9E9B9997959492918E8E8D8C88868481807E7E7E7C7A7A7876777675757474747472
717371706F6D6D6C696A6966666565646361625F5F5C5C5A5955555451514F4D4D4A4946
4442413F3D3C3A38373534332F302E2D2D2B2B2B2A292A29292928282828272727272727
272727272727272726272727262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262626262626262626262626262526262626262626262626
272626272626272626262626262626262726262727272727272727272827282828282929
292A2B2B2D2D2E30323435383A3B3E4043464A4C525A66717B8087898A8D8A8B898B8A89
8A8583817F7E7D7C797675727271726F6C6E6C6A6C6B696A676867686766646464636465
63656465666564656666676464646667666668666868676969686A69696A6B6A6A6A6C6F
6F6E6D6C6A6C6D6D6F716E6E6F6F70727273717373727273737677767876797677797878
787A7A7A7A797C7C7C7B7C7D7C7E7C7B797C7D7C7C7E7F82838181838081868784868784
888887888989888A878B8E8F8D8E8D8E8F8F8F8E918E9190909094939393949196969498
979699979798999B9F9A9D9EA1A1A3A2A7A9AAAEACADAFAEB0ADAFB1AFABAEAFAEADB0AD
AEAFADAEAFAFAFAEAFB0AEB0B1ADAFB2AFB0B2AFAFAFB1ADADACA9AAA7A7A6A7A4A2A3A2
A09F9E9B9A97969592908D8C8B8B888680837F7F7E7C7B7A7B7777777573747271716F70
706F6F6D6E6D6C6A68676865666363626260605E5C5B595756555352504F4E4C49484645
43403E3E3C3B393836343331302E2E2D2C2B2B2B2A2A2928292828282728272727272727
272727262727272727262627272626272626262727262626262626262626262626262626
2626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272726262626262626262626272727262626272727272727272727272728282728282929
292A2A2B2B2D2E2F31323436393A3D3F4244474A4F545C67737D81898B8C8D8A8E8C8D8D
8C8C88858181817F7C7A797677747272726D706E6D6C6B6A676768696665656566636365
65636464646663666467656565646766666768666A68686968696B6969696B6A6B6B6B6E
6C6D6D6C6D6C6D6D6E6F706E6F6F70707071757573727273747574757679767978787878
797878797A7A7A7D7B7C7A7B7D7B7B7D7C7C7B7B7D7B7E7E808180828081818482838285
8886888685868887888A8B8B8D898A8B8C8C8E8D918E8F8E8F9291919491919493959696
9797989696999B9B9C9C9A9C9D9EA1A4A2A5A7A7AAACAFAEADABACAEAAA9ADAAAEACADAF
AEAEAFAEB2AEADADAEAEAFB0B2B3B2B4B2B5B6B2AFB1B2ADAFAEABA8ADAAA9A8A4A3A1A0
A19DA09D9C9995959492918C8C8A89858380807D7D7B7A797875757373717171726F6D6F
6F6D6D6A6C6A696968666665646262625F5E5C5B5A585855555453514E4E4B4A47464543
41403D3D3B393736353331302F2E2D2C2C2B2B2A2A292929282828282828272727272727
272726262726262727272626262626262626262626262726262626262626272626262626
2626262626262626
252626262526262626262526262626262626262626262626262626262626262626262626
262626262626272626272626262726272627262627272727272727272727272828282829
292A2A2A2B2C2D2F30323336373A3C3D404245494D5157606B777F878C8D8D90908F9090
8F908D8B8A8783807F7E7C7B7A797775757171706E6E6B6D6C6C6A6A6867686666666566
66646263636464656563646664656764666767676868666869676969686A6B696A6A6A6B
6A6D6B6C6D6C6C6C6D6D6F706C6C6D6F6E6F727675757272727473757776787575787878
7675777979787B797A7C7D7D7C7B7D7B797A7C7B7D7A7D7F7F7E7D818181828282828383
838486858686878685888A8B8B8A888C8C8D8D8E8F8D8C8F8D90918F92918F8F92949293
9395959597989697999B989C9E9C9F9EA0A3A2A6A8A8AAADACABABABABACABAEAEADACAC
ADACADAEAFAFB0B0B1B0AFB2B3B1B3B4B5B5B8B7B5B6B3B3B1B0B3B1ADADABAAA6A7A5A1
A3A1A09C9B9896959590908D8D89888683817F7B7B7A79777775727271707071706D6F6C
6C6C6B6A696868666664636264605F5E5F5C5C595957555452514F504C4B494846454341
403F3E3B39383735333230302E2D2C2C2C2B2A2A29292929282827272727272727272727
272727262727262727262626262626262626262626262626262626262626262626262626
2626252626262626
252626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262627272727272727272727272727272727272828282828
29292A2B2B2B2D2E2F30333336383A3C3F4144464A4D5359646F7C848A8D8F9092969592
9394918E8B8987858283817E7C7A7A7778767472736F6F6D6C6B6C6A6B69676968656666
6464646464646465636564666766676666666768666866686969686869696A6A6B6B696A
6A6B6A6A6A6C6D6C6B6D706E6D6D6D6C6F6E6F7172757573757172747377747778787776
7778777779787979797A797A7B7B7B7A797B7B7B797D7C7B7D7D7E807F807F817F7F8081
8182848586868488878A8B86898A888B8A898C8C8C8E8D8D8D8E8F8D8F8F8D8E8E919393
9494969596969898969798989C9E9B9D9DA1A2A3A3A7A8AAA9ACA7ABAAA9A8A9AAACA9AA
AEAFAEADADAFAFB0AEB0B4B6B4B5BAB8B7B9BAB8B5B8B7B8B8B6B4B1B3AFADABA7A6A59F
A0A09F9C9A97989694928F8D8B89888584817F7D7A78797574737371716F6F6E6D6D6C6C
6B6968686866666564616161605E5D5D5C5B595756545352514E4E4C4B4A484646424040
3E3C3B393736343432312F2E2D2D2C2B2B2B2A2A29292828282828272827272727272727
272727272626272727262726262626262626262626262626262626262626262626262626
2626262626262626
252626262626262625262626262626262626262626262626262625262626262626262626
272626262626272626262626262626262627272727272726262727272727272728282828
2829292A2A2B2C2E2E3031333537393B3D4143464A4B50535C667580888C918E92969696
9595959293918D8A898481817E7D7C7F7979757275737170706C6B6A6A6A686768656465
6566646464656463646464666663646666656867676869686866686967676A6A6B6A6C6A
6B6A6C6B6A6C6A6A6D6D6F6E6F6C6C6D6C6D6F6D70707272717273717674757576757678
757777787877787779787B7A797E7A7A7A7B7A7A797C7D7C7C7B7C7C7E8081807F7F7F7D
8080847F8282848586868788878887888A8A8B8B888B8C8D8C8D918F8F8D8D8F8F8D8F90
909192949497959495929797999A989A9A9D9EA0A1A1A4A7A8A6A7A9A5ABAAA9A9AAABAA
ADABACAEADACAEB2AFB6B8B6B9BAB8B8B9BABABCBBB8B9B7B9B7B9B8B3B4AFAFAEA9A6A9
A3A19D9C999798959491908D8C8B8684807F7E7B7A797675757371706F6D6E6A6D6A6968
68686566666564636262615E5F5C5C5B5A5757565350514F4F4D4C4B484846454342403F
3D3C3A393637343332312F2F2D2C2B2B2B2A292A29292928282827272727272727272727
272727272726262726262626262626272626262627272626262626262626262626262626
2626262626262626
252626262626252626262626262626262626262626262626262626262626262626262626
262626262726262626262626262626262626262627272727272727272628272727282828
292929292A2A2C2C2E2F30323336383A3C3F4143474A4E51565F697781878C9293949596
97979A9A979292908C8987848482807F7C7B787875757473716E6D6C6C68696968676666
6463656566636465636365656465646765656667676769676869686A68686B6A6969696A
696A6C6A6A6A6C6C6C6D6D6D6D6C6D6F6D6D6E6C6D706F72717372727275747672757474
7778787877797777787779797B79797A7A7A7A7B7A7A797978797B7E7B7E7E7F807D7E7D
7E7D7F8182838283848685868888848A8989898B8A8A8A8A8B8D8F8A8D8C8D8B8D8E8E8E
8F8F909090949693939492969897999A98999C9F9C9FA3A2A5A4A6A6A5A7A7A6A9A7A7A9
ABA7ABACACADB0B0B4B6B9B7BCBABABBBCBBBEB9BBBBBBBCBAB7B9B5B8B3B2B1AFACAAA8
A7A39D9A9B98979695928F8C8C888784827E7D7B78757671747170706C6D6C6C6A696B67
6765656565646361605F5F5B5C5C5959575756545451504E4D4A4B494745444242403F3D
3C39393736343332302F2E2D2C2C2B2B2A29292928292828282728272727272727272727
262626262627272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626252626262625262626262626262526262626262626262626262625262626
262626262626262726262626272626262626262727272727272627272727272727282828
282929292A2B2B2C2C2E2F313335363A3B3D3F4146474B505359606D7B82899091929697
9A9A9B9A9B98999391908C8788868683807C7A797876757372726F6E6C6C696A6A686966
676766646565646565656465646565636567666566666969696A6A6A686B6B696A6A6A6A
6A6A6A6C6B6B6A6A6B6A6B6B6D6C6B6C6D6D6E6C6E707071707072727272747373747575
7577777879777777767678777A7A797B7A7A7A7A7878787978797C7A7B7D7D7D7C7D7D7E
7C7D7E7E817F7F80828280828485858A87868987878789888C888A8B8E8B8B8B8D8D8C8D
8D8F8F928F9191949191929495959697989A99989B9FA09FA4A2A1A3A5A5A5A6A9A4A6A6
A7A9AAA9ACADAFB2B3B4B7B9BCBDBDBCBBBCBCBFBDBDBFBAC0BCBCBAB8B3B3B0B3B1ACAB
A9A3A1A1999B999693938E8E888A8783827F7C7A7876767472716E6C6C6D6A6969696768
6565626363615F60605D5D5C5A5A58585653525252504E4C4B49484745444341403E3D3B
3A39383634333230302E2D2D2C2B2B2A292A292A28282828282728272727272727272727
272727262727272626272626262726262626262726262626262626262626262626262626
2626262626262626
262625262526262625262626262626252626262626262626262626262626262626262626
262626262626262626272626262627262726262726272727272727272727272727282728
282929292A2A2A2C2C2D2E30313335373A3B3E404345484D50555A626F7E869091939699
989C9C9C9D9C9D9C989490908D8C898684827E7C7B7978767574726E6F6C6D6A6A686A69
676666646564636464656666646565646366676665676668696867686969696968696A6A
6B6A6A6B6C6B696A6B6A6C6C6A6B6E6C6C6E6C6C6C6C6C6E6E7070707172737373737274
747676767678757776777877797978787778787A7A797976797979787A7C7E7C7B7B7B79
7C7C7F7E7D7F7E7F7F81808183828485858886858687888889898A8A89898E8B8C8D8E8D
8C8C8D8E8D8F8E90929293959494949594989997999A9F9D9E9DA0A0A1A4A2A3A4A4A6A4
A8A9AAAAADB0B1B3B6B8B9B9BCBCBDBBBDBBBDC0BDBFC0BDBDB9BDBAB9B7B5B1B3B2AEAB
AAA7A2A09B9A9A959491918D8A868681827F7D7B76757371706F6D6C6C6A6A6868676665
6463626361605F5E5E5D5B595857555554525251504F4C4B494746454442403F3E3D3C3B
383836343432302F2F2D2D2C2B2B2A2A2929292928282828272827272727272727272727
262727272726272627262626262626262726262626262626262626262626262626262626
2626262626262626
262626252626252626252626262525262626262626262626262626252626262626262726
262626262626262626262626262626272626262626272727272727272727272727282728
282929292A2A2A2B2C2C2D2F30323435383A3C3E4144474A4E51575A647281898F919597
9A989A9D9E9E9E9D999A969693928F898887837F807C7A7878757471716F6D6C6A6B6969
676965666564636464656466656665656665656565666667696666676869696768696A69
6868696A6D696B6B6B686B696D6A6A6C6C6C6A6E6D6C6E6D6E706F727173737372727571
7376767675757676767778777976777779777679787B777978787A787B797C7C7D7B7B7A
797C7B7B7B7C7B7E7F7E7D808281828483848485878787888A8788878B8A8B8A898D8E8A
8E8D8C8B8D8B8E8D8F8F9292939493959696969797979B9A9D9D9F9E9FA0A4A1A2A2A4A5
A6A6AAA9ABB0B1B5B7B6BABCBABCBEBCC0BCBFBCBEBEBCBCBABBBCBCBAB7B6B4B2B1B1B0
ABA6A3A1A09C9A9794938F8E8B868781807D7D7978757272716D6C6C6B6A676768656462
6361625F5F5E5E5C5B5B5A58585654545352504E4E4D4C49494645434242403E3E3B3A39
383735343230302F2E2D2C2C2B2B2A2A2929292929282828282727272727272726272627
272626262626262727272626262626262626262626262626262626262626262626262626
2626262626262526
252626262626262626262626262526262626252626262626262626262626262626262626
252626262626262626262626262727262626262626262627272727272727272727272827
282829292A292A2A2B2C2C2D2F31323437393A3C3F4345494C4F54575F67747F888F9396
969B9C9F9D9F9EA09E9C9E99999595928E8A8885827F807C797874767172716F6C696B6A
68686665656667656564656464646567686765646566656667676665656867696968696A
69696C6C696B6A6B69696A6C6A6C6B6C6C6B6D6C6B6A6D6B6D6E70707172747174747371
7372767475757475757679777878787876777877797879787A777778787A797B7A7A7B7A
7B7A7B787A7B7A7A7C7D7A7F81828181828481848487878588888786898989888989898A
8A888B8A8A8C8B8F8D908D8F9190939292929694969897999A989A9A9C9F9E9FA1A3A3A2
A3A4A7ACAEAFB2B3B4B5B9BABBBABEB9BEBDBCBFBEBEC0BFBFB9BAB9BAB8B7B3B3B3B1B0
ACAAA8A4A09B9B9794908E8E88898783807F7D77757171706F6B6C6B6867686565666462
62605E605E5C5B5C5A5959575755535352504F4C4D49484747444342413F3E3D3C3A3938
3636333230302F2D2D2C2B2B2B2A2A292929292928282828282727272727272727272727
272727272726262626272626262626262627262626262626262626262626262626262626
2626262626262626
252626262626262525262626262626262526262626252626262626262626262626262626
262626262627262626262626262726262626262627272727272727272727272727272728
2828292829292A2A2A2B2C2D2E2F31333437393B3E404345484C5153585F6A77858C9194
999C9C9F9FA19DA2A0A3A09F9E9B9A9A95918E89888682817F7D7A78767372736F6D6C6C
6A6968686665656665656464656466676767666565666667646666666767686868696868
696A6A68696A696B6A69696A6B6C6A6B6D6A6A6B6C6C6C6B6B6B6D6E7070737073747272
6F727575757276747677767574787575757676777979797879777877777A79797A7A797B
7C7A797979787A7B7A7B7C7B7E7F81817F80828283838485858585858586858485878787
8A888A8987898A878B8C8D8D8F9091919090949291919694949A979798999B9DA09CA0A0
A3A6A8A9ACAEB2B1B5B5BCB9B9BBBCBCBBBCBCBEBBBDBEBABCB9BBB8B8B8B6B6B2B2B0AE
AFABA7A5A39E9A9994938C8E8A8686837F7C7A7675786F6E6E6D6B696866656664616261
605F5D5C5C5B5A5958575755545452514F4D4C4C4A4A4746444342413F3D3C3B39393736
34343232302F2E2D2C2C2A2B2B2929292828282828282727272727272727262727272727
262726272627272626272626262626262626262626262626262626262626262626262626
2626262626262625
252626262525262525262626252626262626262626262626262626262626262626262626
262626262626262626262626262626262726262727272726272727272727272727272728
2828282828292A2A2B2B2C2C2D2E30313436383A3C3F4144474B4E4F5659616D79869194
989B9F9E9FA0A3A1A2A0A2A3A2A19F9D9897938D8F888883817F7B797876747171716F6B
6A6A69666768676766666565646462676568676665676768656566666766656869676969
6969696A686A6A696968696A6B696A6B6A6D6D6C6D6D6D6B6C6B6D6D6F6F6E6E6F737374
74727272747374747375767577757475767474777876767977767676777775777A787978
7B777B7978797B7A7C7B7B7C7C7D7D7F8180828283838383848585858784868486868585
858787878889878A888A8B8B8C8D8E8D8E9193949290929396959394949599989C9D9DA0
9EA2A4AAACAFACB0B2B2B8B7B6BABAB9BABCBABFBBBBBABABABBB7B7B9B4B7B2B7B3B1AE
ADABABA9A2A09F9995918F8C89868582807B79797473706F6C6968676666656363626061
5D5D5E5B5B59595856555454525250504D4B4C4A4847464442423F3F3D3C3C3939383635
343331302F2E2D2C2C2C2B2A2A2A29292929282828272827272727272727272727272726
272726262726262627262627262626262626262626262626262626262626262626262625
2626262626262626
252626262626262626262526252626252626262626262626262626262626262626262626
262626262626262626262626262626262627262627262726272727272727272727272827
272827282928292A2A2A2B2C2D2D2F30313435383A3D3F4145474C4F52565B626E7D8791
95979B9D9E9E9EA1A3A6A4A4A3A29F9E9D9F9B98938F8D8784817E7F797878747172706E
6C6C6B686766666865666465656565666667676565666766686667666665656668686769
6B68696A696769696B68696A6B686A686A6A6B6B6D6D6D6D6C6A6A6B6D6F6E6F71707172
737274707272747473757477757573747675777475747675777674767877777876777777
7777767A7977797679797A797A7C7E7E7D7D7F7E80838282848482858585868483858687
8485868B88868886878A898B8B8C8E8F8D8D8F90908E8E9190949496939598989A9C9B9C
A0A1A2A6ABADAEAFB1B1B3B4B6B7B8B7B8BCBBB9B9B9B7B7B8BAB8B7B7B7B5B4B5B2B0AE
AFABA7A8A4A39D9B96938D8B898785817F7C79777572706F6C69686566656562605F605E
5C5C5B595A59585555535452514E4F4D4C4B48484646444341403F3E3D3C3B3937363634
3432302F2F2D2C2C2C2B2A2A2A2929292828282828272727272727272727272627262627
262626272726262626262626272626262626262626262726262626262626262626262626
2626262626262626
262626252626262626262525262626262626262626262526262626262626262626262626
262626262626262627262627262626262626262627262626262727272727272727272727
2828282728292829292A2A2B2C2D2E2F30333537393A3D3F4245484B4F52585B626D7D88
8F93989C9EA09FA3A4A6A5A4A4A5A7A3A1A19E9C9B968F8D8A84807F7D7B7A797572736F
6D6B6B6A68676966666565656466656664646665646768666A6768676566666865686769
6968676A69696A69696869686A696A6A68696B6C6C6E6C6B6D6B6B6C6E6B6E6D6F6E7271
717472707272717273737473747472757476757673747576747574757776777977777777
777779797877777778777978797B7B7C7C7B7E7E7E808382838484838484858584848484
8586848488868686878986868B898A8D8D8C8A8E8E8C8E91919291919292939698979B9B
9DA1A1A7A6ABACB1AFB1B2B5B4B7B7B6B7B9BAB9B7B6B7B5B4B5B8B7B4B6B4B5B2B1B1AE
ADADA8A7A8A19E989790908D8987857F7E7C797774726E6D6C69676764636362605E5E5B
5D5A595958575653545250504F4E4D4C4B49494644434342403F3E3D3B3A383737353433
32312F2F2D2D2C2C2B2B2B2A292928292828282828272827272727272727272727272627
272627262626262627262627262626262626262626262626262626262626262626262626
2626262626262626
252526262526262626262626262626262626262626262626262626262626262626262626
262626262626262626262626272626262726262627272726272727272727272727272728
272828282829292929292A2B2C2C2D2E3031333537383B3D414346494C5054585D656F7D
8A8F96999D9CA2A3A1A5A3A6A6A4A4A4A4A1A29F9E9A96928D8886827E807B7976757371
726E6D6C6B68686765666666656566636464646666656666676865686667676666676766
6868686A68686968696867696A686A6B6A676B696A6D6C6B6C6D6C6C6D6C6C6A6C6E6E71
6F7070717072717171707272727271747474727471727173727576767778787778777677
767577767576767777767678777678787A797B7C7C7D817E7F8082808484838281848685
85848387858787868787888687878988898C8B8C8B8A8A8E8E8E908F8E908F9393979A99
9C9EA0A3A7A8ADADAEB0B2B3B4B3B3B4B7B9B7B5B6B6B1B7B4B7B6B4B6B3AFB1B1ADB0AC
AFAAA8A6A4A29F999893908A8985837F7B7C767673716E6A69686564616161605F5D5C5B
5A5A5858565454535151504E4F4D4C4B49474745434241413F3D3C3B3A38373636353332
31302F2E2D2C2C2B2B2A2A2A292929282828282727272727272727272627272626272727
262627262627262626262626262727272626262626262626262626262626262626262626
2626262626252626
252626262626262626262626262626262626262626262626252625262626262626262626
262626262626262626262626262626272626262727262626272627272626272727272727
272828282828282929292A2A2B2C2D2E2E30313435373A3C3E4044474A4D51555A5E666F
7D869096999C9DA1A4A5A5A4A6A6A4A9A4A7A2A19F9E9997938E8C8783807F7B7B767675
72716F6F6B6A686868656669676565646563656264646365676667656665666769656567
6867686568676768666969676A686A6869686A696A6C6C6D6C6C6C6B6B6D6C6B6C6D6F6C
706F716F6E6F71717270707170707273727472716F717373747376777777787979797877
75767576777475747575737475777876787778797B7D7E7E7F7F80818282828181818183
8383868386858484868788858687868789898A8A87888A8A8D8E8E8D8E8E909090959698
9A99A0A0A5A5A8AAAFAAAFB1B2B3B7B6B8B4B7B5B5B4B0B3B3B5B3B0B1B3B0AFADAEB0AC
AEAAA7A6A4A09E9C9891918C8887827E7C7B797672706D6A696765646260605F5D5C5B59
5A58575554535251504E4F4E4D4B4948484645434340403F3F3C3B3A3837353534333230
2F2F2E2D2C2B2B2B2A2A2A29292928282828272828272727272727262727272726272726
272726262627262726262726262626262626262626262626262626262626262626262626
2626262626252626
262626262526262626262626262626262626262626262626262626262626262626262626
262626262626262626272626262626262626262626262627272726272726272727272727
2727282728282929292A2A2A2B2B2C2D2D2E2F323336383A3D3E4245474A4D5354595F65
72818B9097999CA0A4A4A5A6A8A8A8A3A8A7A9A0A4A19D9C97958E89878382807C7A7775
767173706F6C696B67676865666565646465646265636564666566656667666566656767
6866676765676768676868696969686967676A6A6A6B6B6C6C6A6B6C6C6B6E6B6D6C6D6C
6D6E6E70716D7071706F6F6F6F70727272717270726F7172737475757779777A79797B78
7777757474747474737373737674757675777678787A7B7B7C7D7C80808281807F808080
8181828583828483858585848386838487878987878987888A8B8A8B8D8A8A8C8E909393
96989DA0A1A4A5A8AAADAFB0B1AFB4B5B4B3B2B5AFAFB1B0B2B1B1B0AEB0ADACADACAEAB
ABA8A6A7A39E9F9A9895918C8784827E7C797773716F6E6A6764636361605F5C5C5A5A59
57565655535251504F4E4D4C4B4A47474645444241403E3D3D3D3A39383735343231302F
2E2E2C2C2C2B2B2A2A292929292828282828282727272727272727272727272727262727
262727262626262626262626272626262726262626262626262626262626262626262626
2626262626262625
252625262526252626252626262625262626262626262626262626262626262626262626
262626262626262626262626262726262626262627262626262727262627272727272727
27282727282828282829292A2A2B2B2C2D2E2F30313437393A3D3F4146484B4F5256595F
6673828A91969A9E9EA0A2A5A8A5AAA6A8A8A6A6A5A2A39F9B9993928C8784827F7D7A79
77747373736F6D6B69686867676767666464636364636464656564656465646467636766
696666676665676768676867686969696969696869696B6969696B6A6B6B6D6D6B6B6D6C
6D6F6F6D6E6F6F6E6E70706F6E6F7070737171706E70707172737675777778787A7A7977
737472737274737272717373747574757375777777777A787A7A7B7B7D7E7E7E81807F7F
80838080818282808483828483818584868583878982878789878A8A8A8A8989898D8F92
939697A09FA0A5A8AAADB1AFAEAFADAFB1AFAFB1AFAFAFAFAEAEAEAEAEABACABA8ABABAB
A9A7A5A4A19D9C9A9692908B8A847F7E7A79757170706969656462615E5D5D5B5A595857
555455535251504F4E4D4D494848474444434241403F3D3D3C3A39383736343332312F2F
2E2D2D2C2B2B2A2A2A292929292828282728272827272727272727272627262627262626
262626262727262626262627262626262626262626262626262625262626262626262626
2626262626262626
252626252625262526262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262627262626262726272626272727272727272727
2728272728272728282829292A2A2A2B2C2D2E2F30323436393B3C414345474C4F53565C
606A76828B95979A9F9FA4A5A5A5A9AAA9A9A6A7A9A5A3A5A09F9993928C8A85827D7E79
7979787473716E6C6B6A6967676868656565656566656664636464646364656564636466
65666565676667676767676867676967686969686867696A69686B696A6C6E6D6C6B6C6D
6D6D6C6D6C6C6B706F7070706D6E6F6E7070706E6E6F6E70717073747376787879767677
7474717370727172757173717671747474747576767775787976797C7B7D7E7E7E807F81
80828183818183818180828281818281838484838384838384868687868687878A898B8E
9092989A9DA0A2A1A6A7A8ACACAEA9AEACAAACB0ACADAFADACADAAABABA9ACAAA9A8AAA7
A5A5A69F9F9F9C989994908C86847F7D7D777573706C6A686763615F5E5C5B5A5A5A5755
5454525351504F4D4C4B4B48474746444343413F3F3D3C3A3939363735353332312F2F2E
2D2C2C2B2B2A2A2929292928282828282727272727272727262727272726272727262627
262726262627262626262626262626262626262627262626262626262626262626262626
2626262626262625
252626262625252626262526262626262526262626262626262626262626262626262626
262626262626262626262626262627262626262626262627262727272726272726272727
2727272727272828282829292A292A2B2B2D2D2E2F313234363A3B3E404245484B505356
5C616A75838A91999C9FA0A5A5A6A6AAA9A8AAA7A4A8A7A4A5A09F9A99908C8A87848280
7B7C77777574726E6B6C6C6A686967656666666866676563656564646364656464666564
6566656566676666676667666868676669676868676A6A6A696A6B6A6B6C6C6E6D6A6C6F
6E6D6A6C6C6E6F6E6F70706F6E6D6E6E6E6F6E6F6E6E6F6F706E72707174747577777575
74717372727170707070717171727173727374757477757877777B7A7B7C7C7C7D7D7E7D
7E7F7F7E81828181808181808281807F828482838383838384848583858785878587898A
8F9093989A9C9E9EA3A2ABAAACAAACAAABACABACADACADAAA8A7ABA8A8A9AAA9A8ABA9A9
A5A4A1A19F9D9C9694918E8A86827F7A79767572706C69666564605E5D5B5A5958565654
535251504F4C4D4B4A4A49484545434342413F3F3D3B39393837363433333230302F2E2D
2C2C2B2B2B2A292A29292928282827282828272727272627272726272727272627272627
262626262726262626262626262626262626262626262626262627262626262626262626
2626262626262626
252626262526252626262625262626262626262626262625262626262626262626262626
262626262626262626262626262626262626262626272626272627272727272727272727
272727272728272828282829292A2A2A2B2B2C2E2F30313435383A3B3F404445494D4F53
555B616975828C939A9B9EA3A4A5A8A9A9ABA9AAA7A6A7A8A4A3A19D9997948F8B898480
827C7D78767672706E6D6C6B6B6A6A676666676567666664636464646464656365646463
65656564656564656766666666666765676768686768696A6A686A6B6A6D6C6D6B6A6A6D
6D6C6D6C6B6A6D6D6E6F716F6E6C6C6D6C6D6E6E6E6E6D6F6F6D706E7070727275737273
72726E7172716F6F6F7170717170717270717172737472767678787576777A7B7C7B7C7C
7F7D7E7F7F7F8081817E80807E7F8080818080818381828181827F838283838386848989
8B8B8F9498999C9F9EA4A6AAA9A7A6A5A7A6A7AAAAA9AAA7A5A6A8A8A8A7A6A7A5A8A4A6
A6A29F9F9F9B999893918E8A857F7E7A797574716F6C68676360605E5C5A585757545454
524F4E4E4D4D4C4A4A484847454442403F3F3E3D3B3A393836363433333231302F2E2D2C
2C2B2A2A2A2A292929282828282728272727272727272727262627272727272626272727
262626262627262626262626262626262626262626262626262626262626262626262626
2626262626262626
262626262526262626262526252625262626262626262626262626262626252626262626
262626262626262626262626262626262626262626262626262627272727262727272727
2727272727272827282828292929292A2B2B2B2D2D2F30313336373A3B3E414346484D4F
52575C616975828C90989B9DA0A4A6A7A8A8AAA7A7A6A9A7A5A6A1A49F999895938D8A84
80817E7C7B7976737271706D6D6C69686969676869686664656565636363656564646464
646666636465656464656566656566676766676866696869696A6968686A6A6A6C6B6A6B
6D6C6D6E6A6A6C6C6D6D6D6E6D6C6C6B6C6D6C6D6D6E6E6C6D6D6D6F6F706F7172727071
707071716F706E6F6F6F706F6F72706F6F7071716F73737474757577767877797B7A7B7B
7D7D7D7C7E7D7E7F7F7F7F7E7F817F7D7F7F7F827F7F7F7E817E7E7F807F7F8184838584
878B8D909295979A9D9FA2A5A9A7A5A3A4A6A6A7ABAAAAA4A6A2A4A6A6A7A6A1A3A1A1A1
A29FA19D9B999895938F8A8785807D7A7674726F6D6A686663615E5C5B5A585655535352
524F4D4C4B4B4948484645444241403F3E3D3D3B3B393737363533333231302F2E2D2C2C
2B2B2B2A2A29292928292828282727272728282727272727272727272627272626262626
262627262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262625262626252526262626262626262626262626262626252626262626
262626262626262626262626262626262626262627262626262727262627262727272727
2727272727272727282828282829292A2A2B2B2C2D2E2F30313436383A3B3F404648494C
4F54585B616A75818C9497999F9FA5A4A9A7A7A8A9A7AAA8A7A5A7A6A0A29E9A96948F8A
8781807E7C797A777674726F6E6C6D6B6B69696867666464646566666564646365646362
636364666566646563656464666665656766686768666867686869696A67696B6A6B6A6A
6B6B6B6A6A6A6A6C6C6D6D6A6D6A6B6A6E6D6D6C6C6E6D6D6E6D6E6D6E6C6D706F6F6E6F
6E6E6E6F6F706D6C6F6E6F6E6E6F6F6E6F6F6E706F6F717273757675757476767778797A
7B7C7A7A7C7B7D7E7E7D7E7D7D7C7E7C807E7E7C7C7D7D7D7D7D7E7D7C7D7E7F7F818382
85858B8E8E939498999B9EA1A2A4A39FA1A3A4A3A7A8A4A5A2A2A5A4A2A0A1A29E9F9D9F
A19F9E9A9A9795908F8B8A88817F7B787574736F6C69676562615D5C5957555555525250
4F4E4C4C4B494947454544424240403E3D3C3A3A393837363433323130312F2E2D2C2C2C
2C2B2A292929292929282828282828272727272727272727272727262627262626272626
272626262726262626262626262627262626262626262626262626262626262626262626
2626262626262626
252626262626262525262526262626262525262626262626262626262625262626262626
262626262626262526262626262626262626262627262626262626272727262727272727
272727272727282828282828282929292A2A2B2B2D2D2E303132343538393C3F4244474B
4E5154575B616A75828E94959DA1A3A5A7A7A7A9A9AAA9AAA8A7A6A6A2A4A19E9D979592
8B858380807D7B7A77757470706E6C6B6B6E686969686767656666656764646564626262
63646464636366646466656468656767666565686768666669686A6A6A696A696869686B
6B6C6A696C686A69696A6D6A6B6A6A6B6C6B6B6B6B6C6C6C6C6B6C6C6C6D6F6C6D6D6D6D
6C6E6D6F6D6D6F6D6D6E6E6E6D6E6E706D6D6D6C71717170717274747574757575767979
797A7A787A7B7A7D7C7B7C7A7C7D7C7F7B7C7B7A7A797B7A7C7C7E7D7A7C7B7B7B7D8080
8386878A8D8B919294979B9D9F9E9F9F9EA0A1A2A3A5A3A09EA0A1A2A0A09E9D9E9C9D9B
9B9C9B99969795908E8B8A85827B787675716F6E6C686663615E5D5A5956565553515150
4F4D4C4A4948464744444242403F3E3D3C3B393A383736343432323030302E2D2D2C2C2B
2B2A2A292929282828282827272827272727272727272726272726272726262726262627
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262526262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262627272726272726272727
272727272827282728272828282828292A2A2A2B2B2C2D2E2F30323436383A3C40414446
4A4E4F53595C616876818B939899A0A1A2A2A8A4A8A7A9A9ABA6A6A7A6A4A3A39E9E9893
928C8984837E7D7D7A7A757372706F6F6F6F6D6B6C6A6867646565666564656364646562
636665636364636465646564666667656567666668656667686869676968696867686967
696A68686A68696A6969696B6A6B6B6969696A696B6B6A6B6B6B6D6B6D6D6C6C6A6D6D6D
6D6B6D6C6D6D6D6C6B6D6D6C6F6E6D6D6E6E6F6D6E6D6F70716F70717171737474757776
7778777A7B7A7A7B7A7A7B78797A7C7C7C7A7A7A7B7978797A797A797B79767B7B7C7E7D
7E81828589898B8F9394989B9C999A9B9C9D9EA0A3A4A0A19E9E9E9D9E9B9D9D9B9A999A
989A9A969693918E8C8986827F7A7975736F6E6D69676662605D5C5A57565552524F4F4E
4C4C4A4847464543434140403F3E3D3C3B3A383837363534333230302F2E2D2D2C2B2B2B
2A2A29292929282828282827272827272727272727262727272726272627262726272626
262626262726272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262626262626262626252626262626262626262626262626262626262626
262626262626262626262627262626262626262626262626262626262727272727262727
2727272727272727272828272828282929292A2A2B2B2C2D2E2F31323435373A3D404245
47494D4F54565B626974818992969B9DA3A3A3A7A5A8A8A9ABA7AAA7A4A6A6A4A3A19C98
96928E8B868484807C7B7A777673727370706F6C6D6B696A686765666865656464636364
6264626463646363646465656665646667656565656667676769686A6867696869686767
686869686667686A69696A6A6B6968686A69696A6B69696A6A6C6B6C6A696B6C6C6C6B6B
6B6C6B6B6C6B6C6C6C6C6D6C6D6D6C6D6C6D6B6C6F6D6F70707070727071727273717374
75767576767B79797A797A797A787A7C7A79777977777878787677767877777678797A7B
7C7C7E80848589898B9094979696979C9A9B9C9B9DA09F9C999C9C9B9A9B999A9A9B9897
9797959093918F8D8A8684807F78767472706C6A69686461615F5A585654535250504E4B
4C4A4847464545444240413F3E3D3B3A3938373736353432323030302E2E2D2C2B2B2B2A
2A2929292928282827282727272727272727272727262727272726262626262726262726
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626252526
252626262626262526262626262626262626262626262626262626262626262626252626
262626262626262626262626262627262626262626262726262627272626272627262727
272727272727272727272828282828282829292A2A2B2B2C2E2E3030333436383A3D3F41
44464A4D5153575B6167707F8B9296999D9EA3A3A7AAA9A9ABABA8A8AAA7AAA4A6A6A1A0
9E97928E8D898784817F7C7B787976767372726F6D6D6C6B6B6869696766646463636564
64636463646464626263636665636565656467656667666767686A666767676869686768
6868676767666868696769676767676867676A69696A69696A6B6B6B6A6A6D6B6B6D6B6B
6B6B6B6B6B696A6C6B6B6C6D6C6C6B6B6D6B6C6C6C6E6D6D6E6F6E707170707171737374
757377777877787879787877777877787877787677787777767675767573747576767778
797A7B7D7F8285888B8D8E919395979698979699999B9C97969798969899989898989493
92949492918E8D888784817E7A7872726F6E6B69676562615E5C5957555452514E4C4D4A
4A49464644444242403F3E3D3C3C3A39383736353434323331302F2F2E2D2C2B2B2A2B2A
2A2929292828282827282727272727272727272727272626272627262627262726262726
272626262626262626262726262626262626262626262626262626262626262626262626
2626262626262625
262625262626262626262626252626262625262626262626262625262626262626262626
262626262626262626272626262626262626262627262626262626262627272726272727
2727272627272727272727272827282829292A2A2A2A2B2C2C2E2E3030323536383B3D40
4145464A4D4F53575C6068707E8B93979A9D9DA3A4A6A8A8A9A8A9A9A9A8A6A7A7A4A2A2
9E9B9A94978E8D8A84827E817C797A767975757270706E6B6C6C69686765656464646563
636264646464656364616364636665656665646564656665676666676867666868676869
686568666867686667686767666667676668686867696A696A6969686A6B69696A6C6B6B
6B6B6B6B696A6B6B6A6A6A6A6C6C6B6A6B6B6C6B6B6D6C6D6D6F6F6F6D6F6F7071707070
707373757476777578767777787678787777757675757575747373737172717371717575
7778797C7E7D7F83868B8B8F8E90949294959495989A9895949397979698979694949390
90928E8D8E8C898886807D7B7774746E6E6C69676563625F5E5C5955535352504E4D4B49
4846464544434141403E3C3B3C3A393836373534333231312F2F2E2D2D2C2C2A2A2B2A29
282929282928282828272827272727272727282727262727272726262726262626272727
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626252626262626262626262526262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262626272626272627272727
2626272727272827272727272728282828292929292A2A2B2C2D2E2E2F31333536373A3D
3F4244474A4C4E51565A6065707C888F95979D9FA3A5A5A6A8A7A9ABABA7A8A9A5A6A4A4
A1A49C9E9996938D88858583807E7E79777674737371706D6F6D6C686868656566656563
646363646363636463646262636465646465646565656766656866666669686767686968
6965676666676767676766656666666668676666666667686666696A6969686968696B6A
6A6A6968696A6B6A6B6B6A6B6B6A6B6A6C6A6A6A6A6B6A6B6B6A6C6B6D6B706D6E6F6F71
7170717273737274757675767676757776757775757475767372706F6F6E6F7073717474
75747679797B7E7F828287898B8C8D8E8F92939392939694929294939193949193938F8F
8E8E898B8B878583807D7D767472706E6E6A68666462605E5D5A575754514F4F4C4B4B49
484445454241403F3F3D3C3A3A393736363535333232302F2F2D2D2C2C2B2B2B2B2A292A
292929282828282827272727272727272627272727272726272626262627262626262627
262626272626262627262626272626262626262626262626262626262626262626262626
2626262626262626
252625262526262526262525262625262626262626262626262625262626262625262626
262626262626262626262626262626262626262626262627262626262627272727262726
2627272727272727272727282828272828282829292A2A2A2B2C2D2D2E2F31323536383A
3D404244474A4B4F5257595E666F7B868E94979BA0A3A6A6A9A5AAACA8A9ABA8A8A6A6A5
A4A5A4A09F9997938E8B868686827F7C7C777776757373716F6E6D6A6968676768666765
646363656364616463626263646464646565646364656465656567676867676567676666
686766666766666766656665656563666567676566656866686766676669686668686A68
69666B69686A696869686A686A68686A6A6B6A6A6A6A6B6A6A6C6A6C6C6C6C6C6D6D6D6F
707070717270727073747375747574737373747775747173716F6E6E6D6D6D6E6D6F7173
717574767578787D7E7E808386898B8B8E8C8E8E8F908F91919393919292929091918E8E
8D8A8988888584817E797774736F6E6D6B6A68656461605E5A59565453524E4E4C4A4846
45454442413F3F3E3D3C3B39383836353533333231302F2F2E2D2D2C2C2B2A2A2A292928
282928282828282727272727272727272727272726272626262627262627262626262626
262626262626262626262626262626262626262626262626262526262626262626262627
2626262626262626
262625262626262626252626262626262525262625292626262626262626252626262626
262626262626262626262626262626262626262626262626272626262626262726272727
27272726272726272727272827272828282829292929292A2B2B2C2D2D2E2F3132353738
3A3C3F424447494C4F53565A5F656D7C848E94979B9FA3A3A5A8ABA9AAAAACA9A7ABA7A7
A6A5A79EA29D9A9695908E8D888984817E7C7B787975757471716E6D6968686867666765
646363646363636463626263626565656464656563626564656565666666656767676866
656566676666676566656565646465676567666665656565656867676666676768696768
6868696868686968696A6968696A6A6A6A6969696A6A6B6A696B68696A6C6C6C6C6C6D6E
6E6F6F6F6E6E6E70727371727375717173717476737473706F6D6E6D6B6B6B6C6C6D6E6E
6F716F7274747678797B7B808182858587888A8C8B8D8E908E8D8D8E8E8D8E8F8E8B8A8A
8A8786858382807D7B7874726F6E6B6A6867666461625F5D5A58565652504F4C4A4A4745
464343403F3E3E3D3B3A38383736363534333231312F2E2E2D2C2D2C2B2A2A2929282928
282828282727272727282727272727272727272627262726272627262727272726262627
262626262626262626262626262626262626262626262626262526262626262626262626
2626262626262626
252625262626262626262626262626262626262626282626262626262626262625262626
262626262626262626262626262626262626262626262626262626262627262626272627
27272727272727272727272727272828282828282929292A2A2B2B2B2D2D2E3031323436
383A3C3F414345484B4F5154585E646D77818B8F989A9FA0A5A7A5A7A8A9A9A8ABAAA9A8
A8A5A7A7A09E9E9997989692908C8A86847E7D7F7B7A77777473706E6D6B6A6A69676867
646563646463646364636063636262636363636363646464666665666564666567666765
686666656667656465656364666565656465656665666565666665666667676767686666
666866696966686869696869686968696A69696A6869676A69696A6A696A6B696A686C6B
6D6C6E6D6D6E6E6F6F71737071706F6F707373747271716E706E6C6A6A696A696A6B6A6B
6D6E6F6F71727273757679797C8081818685868789898A8B8B8A8D8C8C8B898888898A88
878582827E7C7B787675716F6C6A696866656460605E5E5C5A585453504E4D4B4A484645
444240403E3E3D3C3A39383836353433333231312F2E2E2D2D2B2C2B2A2A2A292A282829
282828272827282727272727272727272627272627272626262726262626272626262626
262626262626272626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262626262626262626262526262626262625262626252626262526262626262626
262626262626262626252626262626262625262626262626272626262626262627262626
27272727262727282727272727272727272828282928292A2A2A2B2B2B2C2E2E30313234
3638393B3E414346484B4E5053585C636B7380899494999D9FA1A4A4A9A9A7A7A9ADA8AB
A9A7A7A6A4A4A19F9D9A999794938F8A878481817E7E797977747271706B6B6968686967
656565646362646363646363626361626363636365646464656565656566666665656565
666465646365676365646364646563636465646666636464646666636666666666666666
676768656767696768676766696667676867696A696868686869696869686A696A6A696A
6D6C6B6C6C6D6C6E6E6D6D6F706E6E6F6E7073727071716F6D6D6C69696868676A676A68
6A6B6B6D6F6F72717072747577797C7C7F80818484838384858787868786868486828482
84827F7B7B79777272706D6B6B6869666463625F5F5C5B59585554524F4E4D4C49474644
4342403E3D3C3B3A3938373635343333323130302E2E2D2C2C2B2B2A2A2A292928282828
282828282827272727272727272727272727272727262626262626262626272626262626
272626272727262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262525252625262625262626262625252526262626262626262526252626262626
262626262626262626262626262626262626262626262626262626272626262626262727
26272727272727272827272727272727282828292828292A2A292A2B2B2C2C2D2E2F3132
343637393B3E404345474A4E4F53585C6168737E878E95999D9DA3A4A7A6AAA9AAA8ACA8
ACA9A7A7A3A4A1A4A3A09E9B9B97968F8E8B8A8382807E7B79777473736F6F6B6B686966
676665646362626365636362606362626161626464646464646464646464646463646565
676365656662636363656664636362636463636362656264646465646565666464666667
666566656866666667676867656568666767686A6768686968676766686767686A696A6A
6A6B6A6C6B6B6E6C6E6D6F6C6B696D6D6E71716F6E6D6D6D6D6D6B696A66676866666766
6B68686A6C6B6E6E6F6F707271747777797C7E7E817E7E7F81838482838381817F7E7E7E
7C7B79787674736F6E6C6C6A686664646461605E5E5C5B59575452514E4D4C4A48464544
42403F3F3C3B3A39373736353433323130302F2F2E2C2D2C2B2B2A2A2A292A2929292828
282728272827272727272727272727262627262727272627272626262626262627262626
262626262626262626262626262626262626262626262626262626262626252625262626
2626262625262626
252625262626262626262525262526262626262626262626262626262526262626262626
262626262626262626262626262626262626262626262626262627262626262626262726
27272627272726272727282727272728272728282828282929292A2A2A2A2C2C2E2E2F31
32343538393D3D404245474B4D4F54555C5F66717A848E959A9A9DA1A5A7A8ABA9ABAAAB
AAA6ABA8A8A7A6A6A5A2A29F9E9B989992908D8B8886837E7E7A797473736F6D6B6A6767
686665646564646363636262636162606164626464636565646365646465626262626563
656464646563626363636262636165616363626363636264636464646564656564656567
666666666566676567656867676667666767686967666967676767676868676767686769
686967686968696A6B6A6D6C6C6B6C6C6E6D6E6D6B6D6C6C6B6D696A6967676564666665
65666868686A6C6A6C6C6D6E6F7072737472747778797C787B7C7F7F7D7D7E7E7C7B7C77
7778767372736D6C6B6A6A686664646360605E5D5A595958555452504E4B4A4846464241
413F3F3D3B3939383735353434323231302F2E2D2D2C2C2B2A2A2A2A2929292929282828
282827272727272726272726272727272627272727262727262727262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626252625252526262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626272626262627262626262626272626
2626262727272727272727272727282827282728282828282929292A2A2A2B2B2C2E2E30
30323335373A3C3D40434546494C5052555B5F656D79848D94989B9EA0A3A8A9A8A9AAAB
A9ABA8A7A8A9A9A8A4A6A3A0A09F9B99999794928E8B8984837F7A777673706F6E6C6D6A
6A6867666565676565646362626262626163636261646163636462636364636463646463
656461626462626364646262616163626362616261626162636264646563636365636263
646563646464656464666466656567666766666865676766656868686767686566676867
666868686768686968696A686B6A6A6A6C6D6B6A6A6A696869696A6A6967666363636464
65636665666567696B6A6B6A6C6B6E6E6F6D717273727576787878787878797977767675
7373716F706C6C6A6868676564635F5F5F5D5D5B5A5957545452504F4B4A484645444240
3E3D3D3B3A393736363533333231312F2F2E2E2C2C2C2B2B2A2A29292929292928282828
272728282727272727272727272727262626272627262626272627262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625252526252526262626252526262525262626252626262626262626262626262626
262626262626262626262626262626262626262626262627262626262626262626262627
262726272726262727272727272727272727272828282828292929292A2A2B2A2B2D2D2E
303131333538393B3D3F434546484E4F5255595C626A76818B8E95979DA1A7A5A9A8ADAC
ADABAAAAAAA7A9A9A7A4A5A3A29F9E9F9E9C9893928D8D8A86827F7C7977767471716E6B
6B6B68666567656465646362626261626262636263636362636263626064636261626263
656364626464636364626261626062616262616162636062616162616263626362646664
656564646362636064646565666564666665666568666467676666676866656566656765
66686667656868676869686768686A696A6769696866686768696A6A6767656464626262
636464646364666766676869696A696B6B6D6C6D6E6F717272707273757574727272716E
6F6C6D6B6A6969686866646363605F5D5D5D5A5A5856565452514F4D4B4A48474442413F
3E3C3B3A38393736343333323130302F2E2D2D2C2B2B2B2A2A2A29292928292828282828
282727272727272727272626272727262627272726262726262727272726262626262726
262626262626262626262626262626262626262626262626262625262626262626262626
2626262626262626
252626262526252626252526262626262626262526262626252625262526252626262626
262626262626262626262626262626262626262626262626262726262626262626262627
2727272727262727272727272727272727272728282728282928292929292B2B2B2C2D2D
2E2F2F323334363A3C3D3F414446484C4D4F54575B62677680888F93999CA0A1A5A6A7A8
A8ACABA9AAAAAAABA6A9A5A2A5A5A3A2A19E9B999694918E8A86837F7A7B787675747371
6E6C6C686867676466626563626262626262626563606161636263616263626261616063
6263636263646260616060615F616062616261636261625F60615F616163636162616264
626363646464626161626265646565666666666664636566656667666665646465656566
666665646565666668686768676667676868686666686868686869696867656363616161
626263616161616464656566656668686668696A6A6A6A6A6D6D6C6E6E6D6E6B6D6B6B6B
6A6968676867696564626163605D5C5C5A5959575754525250504E4A4A4847454442403E
3C3B3A393837363534323130312F302E2D2C2C2C2B2B2B2A2A2929292928282828282728
272727272727272727272727272726262726272727262627262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
2626262626262626
252625262525262625262626262626262626262625262626262626262626262626262625
262626262626262626262626262626262626262626262626262626262626262627262626
262727262727272727272727272727272727282727282828282829292929292A2A2C2C2C
2E2E2F3031333537393A3D3F424346494B4D4E53565961666F7D878D93949D9FA1A3A5A6
AAA8AAADABA9A9AAA9A5A7A3A4A5A5A49E9F9E9A999793918D8C8783807D7A7878777473
716D6D6B6A6A676865646565656462626361626262626163606162616163636261606363
626162636262626162606161605F60616060626061636160606060636161606163616463
626362616261626361616264626464646464636465656664656565666764646463646463
656563636462666467656867676665676667666566656668686766666565656562626061
5F5E605E5F60606060626366656466656565666564656868696B6C6A696968696A676A66
66666564636463636062605D5E5D5A5A595957555452514F4E4D4C4A4947454442423F3C
3A3A3A3837363433323232302F2F2E2D2C2C2C2B2B2A2A2A2A2929292828282828272727
272827272727272727272727272727272727262726262627262626262726262726262626
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626262625
252626262626262626252626252626262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262727
262726262626262727272727272727272827272727272828282929292829292A2A2A2B2B
2C2D2E2F3031333536383B3C3F404345474A4C4F5256585F646D7B838D93979A9CA2A1A4
A5AAA9ABAEADAAACAAA8A8A6A7A6A7A3A2A19F9C9E9B9A94938F8B878783807F7C777775
7172706F6C6C69676566656665636362636162626261636162625F606061626161636061
6261636263626161626363636261615F606160616161615F605F616062606062615F6161
616161626261636262626161626163646462636463656364656564636264636464646463
636464636263636462656665656465656364646365666664666566666562636363626261
605E5E5F5F5F5E5E5F606264646361636163636363646665656666656364666666666364
646362616161615F615E5D5C5C5A5A57575655545152504F4D4B4A494946444241403D3D
3B3A3737363434343231302F2E2E2D2C2C2B2B2A2A2A2A29292828282828282828272727
272727272627272727272627262726272626272726262626262626262626262626262626
262626262626262626262626262626252626262726262626262626262626262626262626
2626262626252625
252625252626262626262626252526262626252626262625262626262626262625252626
262626262626262626262626262626262626262626262626262626262627272726262626
26272627262627272627272727272727272727272727272828282828292929292A2A2A2B
2C2C2D2E2F303132353538393C3D404344474A4D4F5155595D646B7782868F969C9D9FA3
A3A7A8A8A9ACADAAAAA8ABA8A5A9A7A7A3A3A19F9F9D9C9A9894928F8B8882827F7C7877
7373736F6F6F6B6A67676667656466636262626262616162616161606160626061616062
626161626161616063616363626060605E605F5E5E5E625F5F5E5F606160606260606060
626061616162605E625F6163616262636261636362626263646465626365636365626263
626362636362616363626264656463636464656464636463636464636262636162616160
605E5E5E5D5E5D5E5E5F5F605F6360626161626261626163626261626162616163616161
605F605E5E5E5D5E5B5A5A5A5958575755545352514F4C4C4B4B4A4746454241413F3D3B
3A39363735333332312F2F2E2E2D2C2B2B2B2A2A2A2A2929292828282828272827272727
272727272727272727272727262726272627262627262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252625252626252626252626262626262626252626262626262626262626252626252626
262626262626262526262626262626272626262626262626262626262626272726262626
27262626272627272727272725272727272727272727272827272828282929292A292A2A
2B2B2C2D2E2F303132343637393A3E3F414446484A4E5053565C6166707B888E959B9D9F
A3A3A5A9A7AAABAAAAAAAAA9ABACA8A7A6A6A0A2A3A09F9C9B9694928C8C8786827E7B7A
7875747172726D6C6A6868676666656664636261616163616262616262626161615F6061
616260626160615F5E6061615F6160605F5E5E5E5E6060605F5F5E5F5F5F5F5E5E606160
6161605F61616060606061615F5F61606161606362626162626362636262626162646365
636362616061605F6161606061616363636563626162636462626262626162616162605E
5F5E5E5E5D5D5E5D5E5F5F5F5F5F5F5F60605F5F605F5E5F605F5E5C5E5E5E5D5E5C5D5D
5B5D5C5B5C5B5B595856585856565553525151504F4E4C4A49484746454242403F3C3C3A
3938373634333231302F2F2E2D2D2B2B2B2A2A2A2A292928282828282828282727272827
272727272727272627272626272727262627262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262525262626262625262626252526262626262626262526262626252626262626
262626262626262626262626262626262726262626262626262626262626262626262626
27272626272627272726272726272727272727272728272727282828282829292829292A
2A2B2B2C2D2E2E2F3231343637393A3C3F414345484A4E5154565A5E666B79878C919798
9C9FA1A2A7A7A7A9A9AAABABA8AAA8A7A6A6A5A5A2A4A29F9C9A989394918D8A8584807B
7B7575737372706D6D6B6969676666646664626261626261626161616060606061605F61
5F6062616060626160605F5F5F5F5F5E5F5E5D5D5E5E5F61605F5D5F61605E5E5E605F5E
616160605F5E605F5E60615F5F615F6061615F6161606162626461616161616261626261
616262615F60605F60605F60615F6161626263626163616262636261616060605F5E605F
5F615E5E5D5C5D5E5E5D5E5D5C5D5D5E5C5D5E5E5D5D5D5C5D5C5C5B5D5D5B5A5C5B5C59
5B5A59575858565755545555545452515050504E4C4C4A49484646444342413F3E3B3B38
38363634333331302F2E2E2D2C2C2B2B2B2B2A2929292929282828272728272727272727
272727272727272727272726272626272627272626262626262627262626262626262626
262626262626262626262626262626262626262626252626262626262626262626252626
2626262626262526
252626262626252626262526262526262526262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
262726272726262727272727262627272727272727272728282828282828282829292929
2A2A2B2C2C2D2D2F303032343537393A3D3E424246474A4D5053575A5E626B747F899091
989C9EA1A5A5A6A8A7A8AAABA9A9ADA9A8A6A6A4A5A5A5A2A29D9B9A9995938E8B858480
7F79787474737172706E6D6B6A686967646564636264636161616060605F615F5F605E5F
61626060605F606060605F5F605D5F5D605E605E5F5E62605E605E5D5E5D5D5E5D5E5E60
61605F5F5E5F5F5D5D5E605F605F5F5E5F6060605F606160616061616060616160616161
616061606060605E5E5E5D5D5D5E5D606162606160605F605F5F605F5E615E5E5F5E5E5F
605C5E5D5C5D5B5D5D5C5B5B5B5A5B5B5A5B5C5B5A595B5C5B5B5A5A5B5C5A595A575857
585655565453545452535352515150514F4E4C4D4B494948474544424040403D3B3A3937
363534333231312F2E2E2D2C2C2B2B2A2A2A292929292828282827282728272727272727
272627272727272727272727262626262627262727262626262726262626272626262626
262626262626262626262626262626262626262626262526252626262626262626262626
2626262626262626
252626252625252626262626252626262626262626252626262626262626252626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262726262627262727262727262726272727272727272727272727282828272929292929
2A2A2A2B2A2C2C2D2E2F2F32333537393A3C3E3F434546484A4E5154595A5E67707C868B
92979B9CA2A4A4A7A8ABA8A9A9A8A9ABA9A8A7A7A6A4A4A4A3A0A29D9C989592908B8786
827E7B7A787674716F716E6D6B6B696967676464646262626161615F62605F5F60615F5E
5E60605E5E60605E5F5E5E5E5F5F5D5D5C5E5F6060605F5E5F5D5D5D5E5F5F5F5E615E5E
5F5F5F5E5E5E5C5D5D5D5F5F5E5D5E5E5E5E5F5E605F6060615F5F5F5F5F605F5F5F605F
60605F5F5E5E5F5E5F5D5D5E5E5D5E5D5F5E5E5F5E5F5F60605F5F605F5E5E5C5D5D5D5C
5D5C5D5C5C5B5B5A5B5A5C5A59595A59595A595959595759595759595958585757565656
55545554535351515150504E4E4F4E4F4D4B4B4A4948474544424240403F3D3C3B393836
3534333231302F2E2D2D2D2C2B2B2A2A2A29282928282828282828272727272727272727
272627272727272627272726262626262726272626262626262627262626262626262626
262626262626272626262526262626262626262626262626262626262626262626262626
2626262626262626
252625252625262626262526252526262626262526252626252626262526262626262626
262626262626262626262626262526262626262626262626262726262626262626272626
262626272726262627272726272727272727272727272728272727282827282828282929
2A292A2B2B2C2B2C2D2F2E3031333336393A3C3E40424345484B4D5155575A5D666D7880
8B8F96979E9DA0A3A7A6A9A7A7AAACA7AAA9ABA7A9A5A5A3A4A2A09EA09C9997918F8B8B
86827F7B7B7977747372706E6E6B6B6A696868676363636361615F606062615F5F5E605E
5F5F5F5E5F5F5F5E5F5D5E5F5D605E5B5E5E5F5E5E5D5F5F5F605F5E5D5D5D5D5F5E5E5F
5E5C5E5D5E5C5D5C5D5C5E5C5E5E5D5D5E5D5D5E5E5E5E60605E605D605F5E5D5E5D5E5D
5E5E5F5E5D5F5E5E5D5D5E5C5C5C5D5E5D5D5E5C5C5E5E5E5E5D5E5D5D5C5E5C5C5D5D5C
5C5D5D5B5B5B5C5B5A5A5958585957585856565658575656575557575556565454545353
51525251504F4E504F4D4F4D4D4D4C4B4C494847474645434341413E3E3D3B3A39373635
3533323130302E2D2D2C2B2C2B2A2A292929282928282828282827282727272727272727
272727272727262726262726262726262626262626262626262626262627262626262626
262626262626262626262627262626262626262626262626262626262626262626262526
2626262525262626
252625252626262626252625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626272726262626
262626272627262627272727262627272727272727272727272727272828272828282829
28292A2A2A2B2B2C2C2D2D2E303132343537393B3D3F414343464A4E4E5255565D626B72
7C868E94959A9FA3A0A3A6A9A8A8A9A8ADACA9AAABA9A6A2A6A3A4A3A19E9E999794908F
8C8784837C7C7777757273716F6F6C6D6A6867666666646363626263615F60615F616060
615E5F5E5E5E605E5D5F5C5D5F5F5D5E605E5D5E5D5D5F5D5D5F5D5D5D5D5E5D5B5D5C5C
5B5F5D5C5C5A5A5C5D5C5C5E5D5C5E5C5D5C5D5B5A5D5E5D5D5E5D605E5F5D5F5F5E5D5D
5F5E5D5C5D5D5C5E5C5D5D5C5C5C5C5C5D5D5D5B5C5B5B5C5E5C5C5D5B5B5C5B5A5B5A5A
5B5B5B5B585A595958595A58585757575756565655565454555353545555535453525151
5050514F4E4E4C4D4D4C4B4B4B4A4949474846464644424141403E3E3D3B3B3837373535
333231302F2E2D2D2C2B2B2A2A2A29292929292929282827282727272827272727272727
272727272727272727262626262626262626272626262626262626262626262626262627
262626262626262626262626262626262626262626262626252626262626262626262626
2626262626262626
252626252625262526252526262626262525252626262526262625262626262625262625
262626262526262626252626262625262626262626262626262626262626262626262626
262626262626262627262727272727272727272727272727272828282728282828282929
29292A292A2A2A2B2C2C2D2E2F2F3032353537393A3C3F41434347494D4E5053575C6267
6F76838A8F95989A9FA1A4A6A7A7A6A9AAAAAAA8AAA8A9A8A5A6A6A4A0A09C9D9B979795
918C8985837F7D7B79767472726F706E6D6B696968656665636462606263605F605F5F61
60605F5E5F5F605F5D5D5D5E5C5E5E5E5E5E5E5E5D5D5E5E5D5D5D5C5E5E5D5B5C5D5C5D
5D5C5D5B5B5B5B5D5B5B5B5B5B5B5C5D5D5C5D5B5D5B5D5C5D5D5E5C5D5C5D5E5D5E5D5E
5D5D5C5C5C5C5C5C5D5B5C5A5C5B5B5A5A5A5A5C5B5B5B5C5D5C5A5B5B5B5A5D5B5B5B58
595A5857585759585758575755565655545455535455545453525252525152515151504E
4F4D4E4F4D4C4B4B49494A494948464745464544434341403F3E3D3C3A3A383736363333
3231302F2E2D2C2C2B2B2A2A2A2A29292928282828282828272727272727272727272726
272627272726262727272627262626262626272626262626272626262626262626262627
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625262525252626252526262526262626252626252626262626262626262626252625
252626262526262526252626262626262626262626262626262626262626262626262626
272626262726262726272726272726272727272727272727272727272828272828282828
2828292929292A2A2B2B2C2C2D2E2F3032323536383A3C3E40414446484A4E4F5256595E
6067727E888C9195999FA0A2A6A8A6A9A8A7ABA8A9A7A8A8A8A7A7A6A4A1A29F9D9B9B97
96928D8B87837F7E797977777373706F6E6B6A6A696967666565646265636062605E6161
60605F5E5E605E5E5D5F5C5D5D5F5D5E5F5D5E5D5C5B5C5B5D5C5D5B5C5C5C5C5B5C5D5B
5B5B5B5C5A5A5B5B5B5B5A5D5C5A5C5B5D5B5C5B5B5B5B5B5C5B5C5C5D5D5B5C5C5D5D5C
5D5B5B5C595D5C5B5A5A595A5A5A59595859585A5959595A5B5A59595A585A5959585859
5857565757575856575556565556545355535352535253515150515150504F4F4F4D4D4D
4D4C4C4B4A4B4A49484848464545454543424242433F40403D3C3B3A3838373635353332
312F2E2E2D2C2C2B2B2A2A2B292929282929282827282728272727272727262727272727
272627272627272726262627272626262726262626272626262627262626262626262626
262626262626262526262626262626262626262626262626262526262726262626262626
2625262626262626
252625252626262625262526262625262626262626262626252626262626262626252626
262625262626262626262626262626262626262626262626252626272626262626262626
262626262727262727272627262727272727272727272727272727272727282827282828
282929292929292A2A2B2C2C2C2D2E2F303133343537393B3D40404245474A4B4E515559
595F666F7880898F95979C9DA0A1A4A7A5A7A8A8A6A8A8A6A8A9A6A5A2A4A3A1A1A09D9D
9A98958D8C898382817F7C787574737270706B6D6B6A67666565656464636162615E5F5F
5F5E605C5D5F5F5E5E5D5D5D5C5D5E5D5E5E5D5C5C5C5D5C5C5D5E5D5C5B5B5B5B5C5C5A
5A5C5B5A5A5A5C5B5B5B5B5B5C5A5B5A5C5A5B595A5B5C5C5A5A5C5B5C5C5B5B5D5D5C5B
5B5B5B5B5C5A5B5B5B595A5B5A5859595858585756575A57585958595858585857585857
555756565555565456555554535352535153515152515050504F4F4E4E4E4E4C4D4C4C4B
4C4B4A49494848484645444444434342414140403F3D3D3C3C3B3A393737353534333230
2F2E2E2D2D2C2C2B2B2A292A2A2928292829282827282828272727272727272726272627
262727262626272726262626272627262626262626262626262626262626262626262626
262626262626262626262526262626262626262626252626262626262626262626262626
2626262625262626
262625262626262525262526262626262526262626252626262626262626262626252626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626272727272626272726272727272727262727272727272728282828282728
28282828292929292A2B2A2B2C2C2E2E2E2F3132333537393A3C3E40424346484C4D5053
55595C6268717D858C9294979C9FA2A4A4A5A9A7A4A7A8A9A6A7A6A7A5A4A5A4A1A1A19E
9D989795908D878683827C7C7A77757373726E6F6D6D6B69686765646562636361605F60
5F5F605E5C5E5E5E5E5E5E5D5D5C5E5E5E5E5E5B5C5C5D5D5D5E5E5E5C5B5D5B5A5A5A5A
5959595A5A5A5A595A5959585A5A595A5A5A59595A5A5A5B595C595A5A595A5B5B5C595B
5C5C5959595A595A595A5758585857575656575457575657575656555655545757575655
5456555455555454545254535253514F4F514D504F4E4E4D4D4D4E4C4B4C4C4B4A4A4A49
49474748474645474543424241424041403E3F3E3D3C3D3B3A3938373635343332313130
2F2E2D2C2D2B2B2A2A2A2929292929282828282828272727272727272727262727272727
272627272727272727272727262627262726262626262626262626262626262626262626
262626262626262626262626262626262626262626262625262626262626262626262626
2626262526262625
252626262526252626262625262626262626262626262626262626262526262626262626
262626262626262626262626262626262626272626262626262626262626262626262626
262626262626262727262727262627272727272727272627272727272727272727272728
282828282929292929292A2B2B2B2D2C2D2F30303233343638393B3E3E424445484A4D50
5054585A60656E7781888D92949A9EA1A1A4A7A5A4A4A6A6A8A7A8A6A8A6A8A6A4A5A2A0
9F9C9C9997918F8D888586817E7C7775777170706F6C6C6A696869676563636161616160
6060605E5E5C5E5D5E5E5E5D5D5E5D5E5F5D5D5B5C5D5E5B5D5E5E5C5D5D5A5C5B5C5B59
5A5B5A5A5959585958585759585958575958595B5A585A5959585858585B59595B5A5959
5959595A5959595856595757585757585655555654555655555552545654545455545454
555454555353525253525150514F504F4F504E4F4F4F4D4E4C4C4C4B4A4A494A49494948
474646454545454444424240403F3F3E3E3E3D3C3C3B3938373736363534333231302F2D
2D2D2D2B2B2B2B2A2B2A2929292828282828272827272827272727272727272726272727
272727272726272626262626262727262626262626262626262626272626262626262626
262626262626262626262626262726262626262526262626262626252626262626262626
2626262626262626
252625262626262626252525252626262626262526262626262626252625262626262626
262526252526262626262626262626262626262626262626262626262626262626262626
262626262627262626262626272727272627272627272727272727272727272727272728
27282828282828282929292B2A2B2C2C2D2E2E2F303132343637393B3C3F414246474949
4C4E52555A5E616A717C858D9293999D9CA19FA3A6A4A6A7A5A8A1A5A8A6A5A7A4A3A0A0
9EA19E9E999995928D8C8784827F7F7A77767372716E6E6C6B6B68666664636563626260
61605F5F5E5E5D5E5D5D5C5C5E5D5E5C5D5C5D5B5C5B5C5E5C5D5C5C5B5A5B595B5B5959
595959595A59595958585758585957585758575857595858595959585858585A58595958
575957585758595858575657575655575756555454535453535253545353545255525353
5353515152505052515151505150504E4F4E4D4D4C4C4B4C4C484A484948474747474745
45454445434342424141413F3E3E3D3C3C3B3B3B3A3939383736363434333231302E2E2E
2D2D2B2B2B2B2A2A29292928282828282828282727282727272727272727272627272627
272626272726262626262626272726272626262726272626272626262626262626262627
262626262626262626262626262626262626262626252626262626262626262626262626
2626262526262626
252526252525252626262626262625262626252625262626262626262626262626262526
262626262626262626252626262626262625262626262626262726262626262627262626
262726272626262626262726262726272726262727272727272627272727272827282728
27282828282829292929292A2A2B2A2B2C2D2D2E2E2F3232343536383A3D3D4042444647
4A4B4E5253555A60656C757F878B93959999A09EA0A1A6A3A6A4A6A7A6A6A6A6A8A6A6A3
A5A4A1A09E9D9896928F8D8B8585807D7D7875727372716E6D6C6B686666656463626260
605E5F5E5D5D5C5D5D5E5C5C5C5C5D5E5C5D5D5C5A5C5D5C5D5C5B5C5B5B595B59595958
5959595A5858595857565756585757595757565656575857585757575758595658585856
585758575758575657555756565656565655555452545455515251515352525152525353
515253505050504F504D4F4F4E4D4F4D4D4B4B4B4C4C4B4B494A48484746464545444545
44424441424143403F403D3E3C3C3D3B3A393A3838373736353434333231312F2F2E2D2D
2C2B2B2B2B2A292A29292928282828272827272728272727272727272727272727272727
262626262626262726262626272627272626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262526252626262626
2626262626262625
252625262526262525252626262526262526262625262626262525262625262626262626
262626262626252626262626262626262626262626262626262626262626262626262626
272626262626262726262626262627272626272726272726272727272727272727272827
2827282828282829292929292A2A2A2B2B2C2C2D2E2E2F323133343637383B3C3E3F4344
47494C4D4E5254575C60666F7881878F9197999B9D9F9EA4A3A4A3A7A3A5A5A6A5A6A8A7
A5A5A7A19F9E9C9C979693908C888482817E7A79747673706E6E6E6A6968676463626262
62625E605E5E5D5D5C5D5C5B5B5B5C5C5C5B5D5C5B5B5B5B5C5C5C5B595A5A595A585858
59595958595B585958585656575757575455565656565656575755575755555657565755
565556575755575755565555535654565554555452535250525151515151515051515052
504F504F4F4F4E4D4E4E4E4D4E4D4C4C4B4C4B4B4A494949484747454445454443434342
4241423F3F40403F3D3D3C3C3C3A3A3939383737363535343533333230302E2E2D2D2D2C
2B2B2B2B2A2A2A2928292928282828282828272727272727272727272727272727262626
272626272626262626262626262626262626272626262626262626262726262626262626
262626262626262626252626262626262626262626262626262626262626262626262626
2626262626252626
252626262526262626262626262626262626262625262626262526262625262626262526
262726262626262626262626262626262626262626262626262626262526262626262626
262626262627272626272626262626272727272727272727262727272727272727272727
282727282828282828292829292A29292B2B2B2C2D2D2E2F303132353537383A3C3E3F42
4446494A4C4D4F5156595C6168707C828A8F96989D9B9E9BA2A3A7A3A5A3A4A5A6A7A6A5
A6A8A5A4A5A19D9E9E9A98969390898A84817E7C7A777573736F6C6C6C69696664646364
616161615F5F5E5E5E5C5C5C5B5B5B5C5C5D5B5A5D5B5B5A5B5C5A5A5959595858585858
595958585959595757565655565754555556535556555555555555555554535555555556
5556565556545453545555545453545353535352525251504F50504F4F4E504E4F504F4F
514F4E4E4D4E4D4E4E4C4B4C4B4A4B4C4A4A4A4948474747464646454344444242424140
40403F3E3E3E3E3C3C3C3C3B3A3939383936373535343433333131302E2E2E2D2D2D2C2B
2B2A2B2A2A29292928292828282828282828272727272727272727272626272626272727
272627262627262626262727262726262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626252626
252625252526252625262626262525252526262626262626262626262626262626262526
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262627272626262626272626262626272727272627272727272727272727
272827282828282828282828282929292A2A2A2B2C2D2D2E2E303132333538383A3B3C3F
404245474A4A4D50515558585E646A757C848B9193989B9B9EA0A2A2A3A2A2A3A5A4A5A5
A5A8A6A6A5A3A19F9F9F9C9B9893928E8A8684817E7A797775726F6D6D6C696867666664
63606261605E5E5E5E5E5C5D5B5D5B5B5A5C5C5C5B5A5B5B5A5B5A595859595958585958
5A5757575758585556565656555655535555555454545454545553535454555455545454
545453535254555354555353535252535251525150515150514F4F4E4D4E4E4C4E4E4C4D
4C4E4D4C4B4C4D4C4C4C4B4B4A4A4A494A49494748464646454444444243414241413F40
3F3F3E3D3C3D3B3A3B3A3A393938373736353534343333323130302F2E2D2D2C2D2C2C2B
2A2A2A2A2929292928282828282827272727272827272727272727262727262626262726
262626262626272626272626262626262627262626262726262626262626262626262626
262626262626262626262626262626262626262626262626262726262626262626262626
2526262626262626
252625262526262626252526262525262626262626262525252625262626262626252626
262626252626262625262626262626262626262626262626262626262726262626262726
262626262626262727262626262627272727272626272627272627272727272727272727
2727272828272728282829282929292A292A2A2A2B2C2C2D2E2F2F303233353637393B3D
3E40424347484A4C4E515354585B5F656C757E868E9296969C9B9FA2A0A2A4A2A2A2A5A4
A3A4A7A6A4A6A4A2A29E9F9C9A9896948E8B888783807B7A7576726F6F6D6D6968666564
65636162605F5D5E5F5D5C5C5C5B5A5A5A5A5B5A5A5A595A5A5A5B5A5A59575757575657
575557575656565656565654545554545554535556535355565554535354545354535252
5252525351535353535352525251515250515050515051504F4E4F4E4D4D4C4D4B4B4A4C
4B4C4C4B4C4A4C4B4B4B4A49484A48484847464846454644444342414240403F3F3F3E3D
3D3B3D3B3C3B3A3939383837373736353435333333323131302F2F2E2D2C2C2C2C2B2B2B
2A2A2A292929282828282827282728272727272727272727272727272726262727272727
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262626262626272626262626262626262626262626262626262626262626
2626262626262626
252626252625262526262626262526262526262525262625262626262625262626262526
252526262526262626262526262626262526262626262626262626262626262626262626
262726262626262626262626262627262727262626272627262727262727272727272727
2727272727282828282828282828292929292A2A2A2A2B2B2D2D2E2F303233343537383A
3A3C3E40424346494B4C4D515355585E61676F7980888D9193999B9B9B9EA1A1A3A3A1A2
A6A6A5A6A5A6A5A3A3A2A19C9B9E9A9893948E8B88847F7F7C78767370706D6C6C686765
6463636262625E605F5D5C5D5C5C5B5B5B595B5A5A5A5A5A595A595A5757585856565556
555656555656555454555654545553545353535454545552535352525251525151525252
52505151505052505250515250514F50505151504E4F50504E4D4D4D4B4C4C4C4B494949
4A4948494B494A4B49494948474746474646464645454343424241413F3F3E3E3D3D3C3C
3C3B3A3A3939383838373736363534343433333231312F2F2E2E2D2E2D2C2C2B2A2A2A2A
2A2A29292828282928282827272727272727272727272727262727272626272626272626
262626262726262626262626262626262626262626262626272626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262525
2626262626262626
252626252526252526262526252625262525262626252625262626262626262626252626
262626262626262625262626262626262626252626262626262626262626262626262626
262626272626272626262726262726262627262726272726272727272727272727272727
27272727282727282828282828282828292929292A2A2B2C2C2C2D2E2F30313133353638
383A3C3D404043454748494C4E535256595D6369717B81888E939899999C9EA0A2A1A0A1
A5A3A3A3A5A4A4A3A1A2A29F9F9E9D98959493908B888582817B7A767772716E6C6A6968
66656463626160605F5C5C5C5D5B5B5A5B5A595A5A5A595A5A595A595957585657575556
555655555556555454535354545253525452525351525152535151505051505052515250
50514E504F515051504F4E4F4F4F4F4D4F4E4F4E4C4E4E4C4C4C4B4B4A4A49494A49484A
48484948484748494746474647464546454446444342414141403F403F3E3E3D3D3C3B3B
393B393939373737363636353534333333323030302F2F2E2E2D2D2C2C2C2B2A2B2A2A29
292929292928282827282827272727272727272727272727262727272626272727272626
262626262626272726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262526262626262526262626262626262626262526
2626262625262626
252626252525262625252625262625252525262526252626252525262625262626262626
262626262625262626262626262626262626262626262626262626262626262626262626
262626262626262626262626272627262626272627262726272727272727272727272727
2727272727272728272829282828282928292929292A2A2B2A2C2C2D2D2F302F31323436
3738393B3B3D3F41444448494B4D505254595B5F6569737A82898F91959A9B9A9EA1A1A1
A1A3A5A3A4A3A4A2A4A39EA3A09F9D9C9B999593908F87878281807B7B7674716D6E6B6B
68666465636262615F5E5E605D5D5C5C5D5B5A5A5A5A5A5A595A59585757575755555554
555456525353555354525454525353515151515052514F50505151504E4F4F505051504F
504D4F504F504D4F4F4E4F4E4C4D4F4E4D4C4C4C4D4C4C4A4C4B4A4B49494A4847484747
48484647464846464645464644444344434342424242413F3F3F3D3D3D3E3D3B3C3A3A39
3A3838373737363635343434333231313130302F2F2E2E2D2C2C2C2B2B2A2B2A2A292A2A
292929282828282828282727272727262727272627272727272727272627262626262626
272626272626272626262626262626262726262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262526
2626262626262626
252525262626262625252626262625262625262626262625262626252625252625262625
262626262626262626262626252626262626262626262626262626262626262626262626
262626262626262626262626262627262627262626272727272627272727272727272727
272727272727272727272728272828282829282929292A2A2A2B2B2C2C2D2E2E2F303232
33363839393B3D3F41424446484A4C4F505455575A60656B747D858A8E919699999D9EA0
A1A2A5A1A1A2A6A3A4A3A2A1A09D9CA09F9A989896908E8B8683827E7B797674706D6D6B
69686766636262616160605E5D5D5C5B5C5B5B5B5A5B5A59595857565958565657565555
545553545554535254525253525351525251514F50504F4F5050504E4E4F4E4E4F4F4E4E
4F4F4E4E4E4D4D4D4D4D4D4B4C4B4C4C4D4B4C4C4B4A4A4B4A494A494949484848464646
4546464645454545454443444248434242414140403E403E3E3C3C3D3C3C3B3A3A3A3937
38373736363435343333333232313130302F2E2E2D2D2D2C2C2C2B2A2B2A2A2A2A292929
292828282828272728272727272727272727272727272727272726262727262727262726
262727262626272626272626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
2525262625262626
252625262526252526252626252526252626252625252526262626252526252626252626
262526262625262626262626262625262626262626262626262626262626262626262626
262626272626262626262726262626262626262626262627272727272727272727272727
27272727272727272727282728282828282828282929292A2A2A2B2B2B2D2D2E2F2F3031
3334353638393B3C3D4041444448484A4D4F505356595C61666C747E828B8D9296999B9E
9EA09EA2A1A1A2A3A2A4A1A1A09FA09D9E9D9B999696938E8C878481807C7A7673706F6D
6A6B69676564636160605F5F5E5F5B5C5C5D5B5B5B5A5A5B595759585757565655555555
53545453535353535352525150515151505050504F51504E4E4F4E4F4E4D4D4E4E4D4F4E
4D4E4C4B4D4D4C4C4B4C4B4C4C4B4A4B494A4A4A4A4A4B484A4948494648464646464546
45454444454243434344424342414141403F3F3F3E3D3D3D3C3C3C3A3A3A3A3B38383736
36363535343333333232313131302F2F2F2E2D2D2C2C2C2B2C2B2B2A2A2A2A2A29292929
282828282827282828272827272727272727272727272627262626262627272726262626
262627262626262626262626262626252626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262526262625252625252626252626262626262626262626262626252626262626
262626262626262526262526262626262625252626262526262626262626262626262626
262626262626262626262626262626262726272627262626272627272726272627272727
272627272727272728272728272728282828282829292929292A2A2B2A2C2C2C2E2D2F2F
31323435353838393A3D3F4041434648484B4D4F4F5356585C62666C747D858A8E919598
9B9A9D9FA3A0A2A3A3A2A2A1A29F9EA09F9D9C9B9A9796948E8C898382827B7A7572716F
6D6C68686866626162615F615F5E5E5E5C5C5A5B5A5B5B5A595757575756555857545654
5354545354535453525253515251515150504E4F4D4D4E4D4F4D4E4E4C4D4C4C4D4C4C4B
4B4C4D4D4C4B4B4C4A4A494B49494A4A4A49494A494A4848474747474646454545464544
4444434443424242434142424040413F3F3E3E3E3E3D3D3D3A3A393A3939383838383636
3535343333323231323030302F2F2E2E2E2D2C2D2C2C2C2B2B2B2A2A2A2A2A2929282928
282828282828272727272727272727262727262727272726272726272626262626262627
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252625252526262525252526262625262625262626252626262626262526252626262626
262626262526262626262526262626262626262626262625262626262626262626262626
262626262626262626262626262626262626262626272626262727272727272726272727
27272727282727272827272728272728282828282828282928292A2A2A2B2B2C2D2D2E2E
302F303233343637393A3B3D3F4042434547494B4B4F5153575A5D60676E757D838A8E91
9399999B9B9FA0A1A1A0A1A1A0A19E9F9D9B9D9B98989897918D8B8A85827F7C77797373
72706B696A666663616261605F5E5D5D5D5C5B5A5A595B59585856585756575757545555
56535353545352525151515151515150504F4F4F4F4E4E4D4C4D4D4D4C4A4B4B4B4B4B4B
4C4B4B4A4A4B4A4A4A494948484A49484848484848474746474646464648464443434343
4442424241404140404040403F3D3E3E3D3E3D3C3C3C3A3B3B3B39393838373635363435
33333332323232313030302E2F2F2D2D2C2C2C2C2B2B2B2A2A2A29292929292928282828
282828272728272727272727272727272727272727262627272626272726262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626262626262626262626262626262526262626262526262625252626262626
2626262526262526
262626262526262625252525252526252525262626262526252626262626252626262526
262626262626262526262626252626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262727262627272627272727272627
2727272727272727272727272827282727282828282828292929292A292A2B2B2C2C2D2D
2D2F3030323335363637393B3C3E3E4142444645494C4D4E525357585C62676C737C8389
8D909395969A9B9B9B9D9FA0A09F9F9F9D9C9D9D999A9799969290898886827F7B797A75
72716E6B6967686564636260605E5F5D5E5D5A5B5A5A5A58585857575855565455555554
55555452525353545152505051504F4E4F4D4E4D4D4C4D4D4C4B4B4B4B4C4C4A49494949
4A4949494948494848484847474847474746464646464646464544454345434443444443
4142414040403F40403F3D3E3D3D3E3C3D3C3B3B3A3B3A39393737383636353535343333
33323232313130302F2E2E2E2C2C2C2C2C2B2B2A2B2B2A2A2A29292A2928282828282828
282828282827272727272727272727272727272727262726272626272626262626262626
262627262726262626262626262626262626262626262726262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262525262626262526262626252526262625252526262625262626262626262626
262526252625262626262526262626262626262626262626262626262626262626262626
262626262626262726272626262626262626262626262626262627272726272726272727
2727272728272727272727272727272828282828282828292929292A29292A2A2B2C2C2C
2D2E2E2F2F30333334353638393B3C3E404142454647494B4D4F515357595E61666C737A
82878B8F9297969B9B9A989D9D9C9E9D9D9F9C9F9B9A9996969591908B8886817D7E7A78
75746F6D6B6A696964646362605F5F5E5C5C5A5B5B5B5A59595957565757575556545555
5454555353525252505251504F4F4F4F4D4D4E4D4D4C4B4C4B4B4A4A4A4A484949494949
4A4949474847474847484747464746454645454544454544454344444243424242434341
3F3F3F40403E3D3E3E3C3B3C3C3C3B3B3B3A3A3A39393837373737363635353434333332
3131313031302F2F2E2E2D2D2C2C2C2B2B2B2B2B2A2A2A29292929292928292828282828
282728282727272727272727272727262726272727262626262727262726262626262626
262627262626262626262626272626262626262626262626262626262626262526262626
262626262626262626262626262526262626262525262626262526262626262625262626
2626262525262626
252625262625262626262625262526262525252525252626252526262626262626262626
262626262626252626262626262626252626262626262626262626262626262626262626
262626262626262626262626262626262726262626262626262726272727262726272727
272627272727272727272727272827282728282828282828292928292929292A2A2B2B2B
2C2D2D2E2E2E3031333334363738393C3D3F3F41424446474A4C4E4E4F53565A5C60646B
727983868C8E9394959A9A999A9B9B9B9D9C999A9A9A9998969693908C898884837E7C7A
767471706D6A6A6969666562615F5E5F5D5C5C5C5C5B5958575858575756555654535554
5455545453515151515050504E4E4D4F4E4E4D4D4C4C4C4A4B4A4A494949494749474848
484647464646464647464645454645444444444445454442434343434341414140414040
3F3E3F3E3E3D3D3D3C3C3C3B3A3A3A3A393A393837383637363635343534343333323230
313030302F2E2E2D2D2C2D2C2B2B2B2A2A2A2A2A2A2A2929292928282828292828272727
282827272727272727272726272727272627262726272627262626262727262626262626
262626262726262626262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262526262625262626262626262626262626262626
2626262626262626
252626262626262625252626252625262526252626262526262626262526262626262526
262626262626262626262626262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262627272627262727262627262727272727
27272727272727272727272727272728272727272728282828282929292929292A2A2A2B
2B2C2C2D2E2E2F2F30313234353737383A3B3C3E3F4144444747494B4D4E525455585A5E
626A717980858A8C909494979998979B9A9B9B98989B9897979896938F8D8A8886817D79
797774716F6E6B696865656361616160605E5C5C5B5A5959585858585557575555545454
535453505251515150504F504E504C4D4D4D4D4A4C4B4B4A4A4948494848484846484648
464746454646454645454444444443434343444344434242434242414142413F4040403E
3E3D3D3D3C3D3C3C3B3B3B39383939393839373737353635353434333333323231323030
2F2F2F2E2E2D2D2C2C2C2B2B2B2B2A2A2A2A2A2929292929282828282828282828282728
272727272726272727262627272727272627262726262626262626262626262726262626
262626262626262626262627262626262626262626262626262626262626262626262626
262626262625262626262626262626262626262626262626262626262626262626262626
2626262626262626
252626262625252625252626252526262626262625252525252626262626252626262626
262626252626262626252626252626252626262626262626262626262626262726262626
252626262626262626262626272626272626262726262626272626272727262627262727
2627272626272727272727272727272728272727272828282828282829292929292A2A2A
2A2B2B2C2C2D2E2F2E3030313333343638393B3C3D3D404243454647484B4D4E52555559
596062686E767C83888A8F909292949697999898989999989A98969590918F8889838080
7C787574716E6D6A69696665636161605F5E5D5C5B5C5A5A595A56575757555354535352
535151505150515151504F4F4E4F4D4E4C4B4C4C494B4A48494949484747464645464646
464545454344454444444444434343434342414242434141414040413F3F3F3F3F3D3E3D
3D3D3B3B3C3B3B3B3A3A3939393838373737363636353535333332333232313130302F2F
2F2E2D2D2D2C2C2C2B2C2B2B2A2B2A292A29292929292928282828282828282827272727
272727272727272627272727272727272627262627262726262726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262526262626262626262626252626262626262526262626262626
2526262625262626
252625262626252626262526262625262625262625252626262625262626252626262526
262626252625262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262726262726272726
272727272727272727272727272827272727272727272827282828282829282929292A2A
2A2A2A2B2C2C2D2D2D2E2F2F30313234353538393B3C3D40404143444648494B4B4F5053
5658595F62666C737A8187888B8D8F92949493959699989697989698968F8E8B89878481
7F7A797774726F6C696868676664626060605D5D5B5C5A59585857575654555554535253
5352525151504F4F50504E4E4D4D4C4C4B4A4B4A4B494949494848474745454646464546
4444444344434242424243424142424140424140404140404040403F3E3F3E3D3D3D3D3D
3D3B3B3A3A3A393938383837373736353535353535353332323332313230302F302E2E2E
2E2D2C2D2C2C2C2B2B2A2A2A2A2A2A292929292928282729282828282727282827272727
272727272726272727272727272726272726272726272727262626272626262626272626
262627262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262626252626262626262626262626262626262626262626262626
2625252625252526
252626252626252525252526252526262626252626262625262625252626262625262626
262526262626262626262526262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262626262627272726
272727272727272727272727272727272727272827272728272828282828282828292929
29292A2B2B2C2B2D2C2D2D2E2F3030313334353637393A3C3D3E404143444447494B4C4E
4F5154565A5C60656A737A7C82848B8D8E8F909193929695959496949293908F8D8A8685
817F7D777775736F6D6B696966666262615F5F5C5C5B5C5A595658575755555554535351
525250515050504F4F4E4F4D4E4D4D4E4B494A4A494A4948474747474644444544444545
4444444443424342424141414041404140403F403F3F3F3E3F3E3D3E3E3C3C3C3C3C3B3B
3B3A3B3A3A393837383637373635353535343434333433323131313130302F2E2E2E2D2D
2C2C2C2B2B2B2B2A2B2A2A2A2A2929292929292929292828272727282727282827272727
272727272727272727272727272627272727262726262626262627272626262626262626
262626262626262626262626262626272626262626262626262626262626262626262626
262626262625252526262625262626262626262626262626262625262626262626262626
2626262626252525
252526262626262526262525262626262525262625262625262626262626262626252525
262526262526262526262526262626262626262625262626262626262626262526262626
262626262626262626262626262626262626262626262626262626272626262626262626
272727272726272626272727262727272727282827272727272828282828282828282929
29292A2A2A2B2B2C2B2D2C2D2F2E2F3031333234363638393B3C3D3E3F40434446474849
4C4E4F515456585B5E63696C7478808386898B8B8E908E939291939192918F8F8A8A8A84
85817F7D787873726D6E6B6967656563625F5E5C5E5B5A5B5A5858575555555454535351
51504F515050504F4E4F4F4E4D4C4E4C4B4B4A494A484947464847464545444443434343
43434342434241404240413F4040403F3F3F3F403E3E3D3D3D3D3D3C3D3C3B3C3B393A3A
393939383837373736363635363434343433333231323131303030302F2E2E2D2E2C2C2C
2C2B2B2B2B2A2A2A292A2929292929282928282828282828282828282727272728272727
272727272626262627272627262627262627262627262626262626262626262626272726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262526262626262626262626262626262626262626262526262626
2626262626262626
252625262626252625262625262625252626262526252626262626262626262625262626
262626262526262626262526262626262626252626262626262626262625262626262626
262626262626262626262626262626262626262626262626272726262627272726262726
272626262726272727272726272727272727272728272727272727282728282828282828
29292929292A2A2A2A2C2B2D2C2D2E2E2F30323233353637383A3A3B3E3F3F4142444446
484A4C4D4E505255565A5B5F63686C73787E8083868B8B8E8E928F928F8F8D8E8E8E8B88
8886817E7E7B7674716F6E6E6B68676562605F5F5D5D5D5B595A58575654555453525151
5251505050504F504D4E4C4D4E4C4C4B4A4A484949474846464646454544444344434242
4241404040403F403F3F403F3F3E3E3D3D3E3D3E3E3D3C3B3C3B3B3C3B3A3B3A3A393938
3938383839363735353535343434333332323232313130302F2F2F2E2E2E2D2D2D2C2C2B
2B2B2B2A2A2A2A2A29292929292928282828292828282728282727272727282727272727
272727272727272727272727262727272727262726262626262626262726262626262626
262726262626262626262626262626262626262626262626262626262626262626262626
262626262626252526262626262626262626262526262526262626262626262625262626
2626262626262626
252625262626252625252625252626262626262526252526252525262626252625262626
262626262526262626262525262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262726262626262626262626262627
272727272627272727272727272727272727272727272727272728272828282828282829
29282829292A2A2A2A2A2B2C2C2C2C2D2E2F303031323333353639393A3B3D3E40414243
464648494A4B4E50505354565A5D60646B6D72797D81868788898B8C8B8A8E8D8E8C8A8B
888585837F7C7A7574716F6D6D696A666462615E5E5C5C5B5B5959575755565354525252
5050504F4E4F4D4D4E4D4B4C4C4C4B4A4A4A4A4848474747464545444444434244424141
40403F3F3F3F3F3F3E3E3E3D3E3C3C3D3C3D3C3C3B3C3B3B3A3A393A3A3A383838383737
37363736363535343434333333313232323131312F302F2E2E2E2E2D2D2D2C2C2B2B2B2A
2A2A2A2A2A2A292929292829292928282828282828272727272727272727272727272727
272627262627272726272727262726262726272626262727272726262726262626262627
262726262626262626262626262626262626262626272626262625262626262626262626
262626262626252426262626262626262626262625262625262626262625252626252626
2626252626262625
252625252526262525262625252526262525252626262526252526252526252626262626
262526262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262627262627262626262626
272726262727272727272727272727272727272727272727272727282727282728282828
2828282929292A292A292A2A2B2C2C2C2D2D2E2F2F3031323335353738393B3C3D3E4141
4244444647484A4A4C4E4F525454575A5D5F64686C73787B80838487868A898A89898888
88848583817E7C7976736F6F6E6B69696564605F5E5E5C5C5B5A58575556555353505250
504F504E4F4C4D4D4D4D4C4C4C4B4B4A4A49474747464645464545434244424141414140
403F3E3D3E3E3E3D3E3D3D3D3C3C3D3B3B3B3B3B3B3B3A3A393939383839373737373736
363636353535343433323232313230313130302F2F2E2E2D2D2D2C2C2B2B2B2B2B2B2B2A
2A2A2A292929292929282828282828282828282828272727272827272727272727272727
272727272726272727262726262726262726272627262626262727272626262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262626262626252526262626262626262626262626262626252626262626262526252526
2626262626262526
262525262526252525262625252626252526262526262626252526252625262525262626
252625262626262626262626252626262625262626262626262626262626262626262626
262626262626262626262626262626262627262626262627262626262626262626262626
262727272726272726272727262727272727272727272727272827272727272728282828
282828282929292A292A2A2A2B2A2B2B2C2C2D2D2E2F30303132333435363738393A3D3D
3F41424444454648494A4B4C4E4F52525559595C5F64696C6F767A7C8182868788848583
83848483807D7D7A7A787671706C6B69676462625F5D5F5C5C595B585757555554535252
514F504E4E4D4C4C4C4C4A4A4A4A4A494948474746464545454442444241414140403F3F
3E3E3F3E3D3D3D3C3C3B3B3B3B3A3A3A3B393A393A393938383838383836363636363536
3535353534333333323232313031303030302E2E2E2D2D2C2D2C2C2B2B2C2B2A2A2A2A2A
292A29292928292829282828282828282728282727272727272727272727272727262727
272727262626272627272626262727262727262627262626262626262626262626262626
262626262626262726262626262626262626262626262625262626262626262625262626
262626262625242426262626262626262626262626262626262626262626262626262526
2626262626262626
252625262526252525252625262526252626252626262526262525252526262626262626
262626262626262626262625262626262626262626262626262626252626262626262626
262626262626262626262626262626262626272626262626262626262626262626262626
262626262726272627262727272727272727262727272727272727272727272727282828
2827282828282929292A2A2A2A2A2A2B2A2B2D2D2D2D2E2F30313032343535363739393B
3D3D3E4041434244454648494A4C4C4E5252535558595E5F62686B6F73787C7E80817F7F
7F808180817F7D7C7A7675736E6E6A6967656361615E5B5B5B5B59565855565353505051
50504E4E4E4D4D4B4C4B4A4B4B494A4749484746474645454443434141413F403F3F3F3D
3D3C3D3C3D3D3C3B3C3B3B3A393A39393938393839393738373638373636363535343534
343434343332323231313030302F2F2E2E2D2D2D2C2D2C2B2B2B2B2B2A2B2A2A2A2A2A2A
292929292828282928282828282727282728272728272727272727272727272727262727
262727262726272726272727272626272626262627262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262625
262626262626242426262626262626262626262625262626262626262626262526262626
2626262626262625
252626252526252525252526252626252525262626252625262526262626262625262626
262626262626252626252626262525262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626272626262627262626272626
262627262726262727272627272627272727272727272727272727272727272728272728
28282828282828282929292A292A2A2A2A2A2B2C2B2D2D2E2E2F30313233333535363839
393A3C3D3E3F41414243464647484A4B4A4D4E505053545658595E6265666C717477777B
7C7D7C7E7F7C7C78797673706D6D6C6966646463605F5E5B595959565455555353525150
4E4F4F4E4D4C4B4B4A4949494849484847464645444544444342434140403F3E3E3D3E3D
3D3B3D3C3B3A3B3A3A393A39393838383837373837373636363635353534353434333434
33333231323132313030302F2F2E2E2D2D2D2D2C2C2B2B2B2B2B2A2A2A2A2A2A29292929
292929282928282828282828282827272728272727272727272727272727272727272727
272727272626272627262626262627262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262625252526262626262526262526262626262626262626262526252626252625
2526262525262626
252526262626252625252526262526252626252525252625262526262626262625262525
252526262626252526262626262526262626262626262626262526262626262626262526
262626262626262626262626262626262626262626262626262627262626262626262627
262726272726272726272727262727272726272727262727272727272727272728272727
2827282828282828292829292A292A2A2A2A2A2B2B2B2C2D2D2D2E2E3031323333333536
3738393A3B3C3E3D404141434444474748494A4C4E4E505153525657595A5C6163686B6E
71737576787A77777574726F6E6B6C6A69656563615F5E5D595958565655545452505150
504F4E4C4E4C4C4B4B4A484947484846464645454544434341424041403F3E3E3D3D3D3C
3B3C3A3B3A3A3A3739383838383837383736373636363636353535353434343333333332
3132313130303030302F2E2E2D2D2C2C2C2C2B2B2B2B2A2A2A2A2A2A2A29292929292928
282828292828282828282827272727272727272727272727272727272726262726262727
272626272727272626262726272627272626262626272626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242526262626262626262626262625262626262626262626262626262626
2626262625262625
252625252626252525262525262625252525252625262525252626262626252626252626
262626252626262626262626262626262626262626262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272627272626262627272626272727272727272727272727262727272727282727272827
272727272828282829282829292929292A2A2A2A2A2B2B2C2C2D2D2E2E2F303031333334
3435373838393A3C3D3C3D3F4142424445454847484A4B4B4D4E4F5150515556585A5D61
6167696C6D7170717170716F6E6B6A6966656462625E5D5B5A595855565453535150504F
4F4E4D4D4C4B4B494B4B4A4847474646454543444341424241414040403E3C3D3D3D3C3B
3B3A3A3A3939373838383736363536363637353535353434343434333332323332323131
3131302F302F2F2E2E2E2D2D2C2C2C2B2B2B2A2B2A2A2A2A2A292A292929292929292928
282828282828272828272727272727272727272727272727272626272727272727272727
262726272727262726272626262727262627262626272626262626272626262726262626
262626262626262626262626262626262626262626262625262626262626262526262626
262626262625242426262626262626262525262626262625252625262626262626262626
2626262626262526
252526252526252525252626262626262625262525252626262626262626252626262526
262525262626262625262526262626262626262626262626262626262626262526262626
262626262626262626262626262626262626262626262626262626262626262626262726
262627262626262626272627272627262627272727272727272727272727272727272727
28272728282727282828282829292929292A292A2A2A2B2B2B2B2C2C2D2E2E2E30303132
33333335353838383B3A3C3C3E403F4142424345434847494A4A4B4C4C4D4C4F4F525254
56585B5D5E626567696B6A6B6B6B6968666463615F5D5B5B5A59585655545351514F504F
4D4E4C4C4A4A4B49494A474847474545444543434242424141403F3E3E3E3E3E3B3A3A3B
3A3A38393838383737373634353536343534343434333332343332323132313131313031
2F2F2F2E2E2E2D2D2D2D2C2C2B2B2B2B2B2B2A2A2A2A2A29292928292929292829282828
282828272827282728282827272727272727272727272727272727272626262727272727
272627262627262627272726262626272727262626262626272726262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
262626262626252526252626262626262625262626262626262626262626262526262626
2626262626262626
252625252526252626252625252525252625252625252525262525252626252626262625
262526252626262526262626262625252526262626252626262626262626262526262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262627272627262626262627262726272727272727272727262727272727272727
2727272827282728282828282829282929292A292A292A2A2B2A2B2B2B2C2D2D2E2E2F30
303132333435363638393A3B3B3C3D3E3F3F404243424445454647484A474A4A4A4C4C4E
4F4E5052545457595B5D5E61646462646260605D5E5B5B5958585855535252514F4F4F4E
4F4C4C4C4B4A4A49484748484646444543434342424141403F3F3F3F3E3C3C3C3B3A3A39
3838383737373635353535353434343333333433333332333231323230303130302F2F2E
2E2E2E2D2D2D2D2C2B2C2B2B2B2B2B2A2B2A292A292A292A292929292829282828282828
282727272827272827272727272727272727272727272726272726272626262626262726
272626272627272626272626272627262726262626262626262626262626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626252426262626262626262626262526262626262625262626252526262526
2525262626262626
252625252526252526252526252526262525262525252626252525262626262625252626
262626252626262626262625262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262627262626262626
262626262627262726272626272627272627272727262726272727272727272727272727
2728272728272827282828282828282828292929292A292A2A2A2A2B2B2B2C2C2C2D2E2E
2F2F303131333334353637373839393B3C3D3D3E3F3F4142424243434745454747474747
49494A4C4C4E4F4E505053545658575858585959595A59585756565654535151504F4F4E
4C4D4C4A4A4A49484648474546454544434242424140403F3E3E3E3D3C3C3C3B3A3A3938
383738373636353435353534333333333332323232323131303130302F2F2F2E2E2E2D2D
2C2D2D2D2B2C2C2C2B2B2B2B2A2B2A2A2A2A292929282929292928282828282828282728
282728282727272727272727272727272727272727272627262727272726272727272727
272726262726262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626252426262626262626262626262625262626262626262526252626262625
2626262626252626
252625262526252626262625262526252525252625262626262525252526262625252626
262626262625262626262626262625252526262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262726262626262626262626
262726262626262727262726272627262626262727272727272727272727272727282727
272828272728272728282828282828282829292A292829292A292A2A2A2B2B2B2C2C2C2D
2D2E2F2F2F31313133333435363838383A3A3B3C3D3D3E453F4040404242434343444544
454646474747484749494A4B4C4B4C4D4D4F4F52515353545252535351504F51504E4E4D
4C4B494A49474948474745454544434342414041403F3F3E3E3D3C3C3C3B3B3B3A393837
3737363635353434333333333232323231323031312F30302F2F2E2F2E2E2E2E2C2D2C2C
2C2C2B2B2B2B2B2B2B2A2A2A2A292A292929292929292929282828292828282828282727
272727272727272727262727272726272727272627272626272627272727272726272626
272726262626262726272626262626262626262626262626262627262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262526262626242426262526262526262625262625262626252525252626262625262626
2626262626262626
252625262625252625252625252526252626252625262626262525262626262525262625
252625262626252626262626262526262626262626262626262626262626262626262626
262626262626252626262626262626262626262626262626262626262626262626262626
262726262626262627272626262627262726262627272627272726272727272727272727
2727272728272727272728282828272828292828292928292929292A2A2A2A2B2B2B2C2C
2C2C2E2D2D2F2F2F3031313333343436373738393A3A3B3B3D3E3D3E3E403F4041414242
42434444434443444444444547444546474847484A4A4A4949494A4B4C4B4D4C4E4B4D4C
4A4A494847464547454644434242414140413F403F3E3E3D3C3C3B3B3A393A3939393737
35353534343334343332323231313130313030302E2F2E2E2E2E2D2D2C2D2D2D2C2B2C2B
2B2B2B2B2B2B2A2A29292A2A29292A292929282829282828282828282828282727282828
272727272727272727272727272727272727272726272726272726262726272627272627
262726262626262726272626262627262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626242426262625262526252625262626262526262626252625252526262626
2626262625262526
252625262625252525252625262626262526262625262526252626262626262625262626
262526262626252626262526262626262626262626262626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262727262626262626262727272727272627262626272627262727272727272727272727
272726272727272727272828282828282827282928282929292929292929292A2B2A2B2B
2B2B2C2D2C2D2D2E2F2F30313132333334353537373838393B3A3A3B3D3C3E3D3E3E403F
413F42404141404042414141434242414241424243434343434141434343444545454547
46454545434343434443424240403E3E3F3E3D3E3D3C3C3B3A3B3A3A3939383837363634
35343333333331313130313030302F2E2E2E2E2D302E2E2C2C2D2C2C2B2C2B2C2B2B2B2B
2B2A2A2A2A2A2A2A2A2A2929292929292829282828282828282828282828272827272727
272727272727272726272727262726262727272726262627272726262626262727272626
262626272726262626262626262626272626272626262626262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262526
262626262626242426262626262626262625262525262626262626262526262626262525
2626262526252626
252625262626262626262526262525252625262525252526252625262625262626262625
252625262626252626262526262626252626262626262625262626262626262626252626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262726262626272726262626262726272627272727262727262727272727
272727272727272727272728272A2B282828272828282928282829292929292A2A2A2A2B
2B2B2B2C2C2C2B2D2E2D2E2E2F2F303133333434353536373738393A393B3C3C3C3C3D3C
3D3D3D3D3E3D3E3D3E3E3E3E3E3F3D3D3D3D3E3E3F3D3E3D3E3E3E3D3E3E3D3E3F3F3F3E
3F3F3F3E3E3E3F3E3D3D3E3D3C3B3B3A3A3B3A3A39393938373837363737353534343433
323231303030302F2F2E2D2E2E2E2E2D2D2D2D2D2D2B2C2C2C2C2C2B2B2A2B2A2A2B2B2B
2A2A2A2A292A2A2A292A2929292929292828282828282828282728272727272727272727
272727272727262726272727272727262727262626272627262726272627272626272626
262626262626262626262626262726262626262626262626262626262626262626262626
262626262726262626262626262626262626262626262626262626262626262626262626
262626262626242425262626262626262626262626262526252626262626262526262626
2625262626262526
252625252526262626252525252625252525252625262626252626252626252526262625
262626252626252626262526262626262626252626252626252626262526262626262626
262626262626262626262626262626262626262626262626262626262626262626272626
262626272626262626262626262626262727272726262627272727272627262727272727
2626272727272727272727272828282828272828272828282828292828292929292A292A
2A2A2B2A2B2B2C2C2B2C2E2E2E2F2F2F30303132323334353636363837383938393A3A3A
3A3A3A3B3B3B3C3B3B3C3C3C3C3C3C3C3B3A3B3A3B3B3B3A3C3A3B3B3B3B39393A3A3A3A
3A3939393939393939383837373837373637373736353535353434333433323232323130
312F2F302E2E2E2E2E2E2D2D2D2D2C2C2D2C2B2C2B2C2B2B2B2B2B2B2A2B2A2B2A2A292A
2A2A29292A29292929282928282828282828282828272828272727272727272727272727
272727272727272726272726272627272727262627272626262626262726262626262726
262626262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242426262626262625262625262626262626262625262626262626262626
2626262626262626
252625252525262525252526262526262525252526252626252625262626252626262526
252526262526262626262626262626262626262626262526262625262526262625262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262726262627262626262626262626272727272627272727272727272727272726
272727272727272727272727272727272727272728282828282828282829282829292929
2A2A2A2A2A2B2B2B2C2C2C2C2D2D2D2E2F2E303030313132313233353536363637373838
3938383939393A3A3A3A39393939393939393A3939373838373838383839393837373737
373736373735363536363536353434343434333433333333323232313131303030302F2F
2E2F2F2D2D2D2D2D2D2D2C2D2C2B2C2B2C2B2B2B2B2B2B2B2B2A2A2A2A2B2A2A2A2A2A2A
2A2929292929292828282928282828282827282827282728272727272727262727272727
272727272727272726272627262727262626272727272626262726272726272626262626
262626262727262626272626272626262626262626262626262626262626262626262626
262626262626262726262626262526262625252626262626262626262626262626262626
262626262626242426262626262625252625252626262626262626252626262626262626
2626252525262625
252625262525252525252526252525252626262625262526262525252525262626252625
252626262526262525262526262526262626262626252626262626262626262625262626
262626262626262626262626262626262626262626262625262626262726262626262626
262626262626262626262626262726272627262727272726272726262727272626272727
272727272727272727272727272727272727272727282828282828282828282928282928
29292A2A292A2A2B2A2B2B2B2B2C2D2C2D2D2E2F2F2F3030313132323333333435363535
373837373736373737373738373737373737363737363636373636363636353535353535
3435363534343433333333333332333232323232323131313230302F302F2F2F2F2E2D2D
2E2D2D2D2D2C2D2C2C2C2B2C2B2B2B2B2B2B2B2A2A2A2A2B2A2A2A292A29292929292A29
292929292829282829282828282828282728282828272827272727272727272727262627
272727272727272727272726262727262626262726262626262726262626262626272726
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626252626262626262626
262626262626242426262625262625262626262626262626262626262626262526262626
2525262625262525
252626252525252525262526262626262526252526262525252626262626252626252626
252625262526262625262525252626262526262626262626262626262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262726262626272626272726272726272727
272727272727272727272727272727272728272727272728282828282828282828282929
2829292929292A2A292A2A2B2B2B2B2C2C2C2D2D2E2E2E2F2E2F31303030323332333434
333435353535363535363536353637363636363636353635353535353434343434333434
3434333334343332323232313131323230303030302F2F302F2F2F2E2F2E2E2E2E2D2D2D
2D2C2C2C2C2C2C2C2C2B2B2B2B2B2B2A2A2A2A2A2A2A2A2A2A2929292929292929292829
292928282929282828282828272828282727272727272727272727272727272727272626
272727272726262626272727272627272626272727262626272726262626262626262726
262626262626262626272626262626262626262626262626262627262626262626262626
262626262626262626262626262526262626262526262626262626262626252626262626
262626262626242426262626262626252626262626262626262626262625252626262526
2625252525262526
252626252626252525252526252525262526262625262526252526252526262626252626
252626262626262626262526262525262626262626262625262526252626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262626272626262726262626262626272626272626272626262727262727272727262727
262727272727272627272727272727272827272727282728272828282827282828282828
282929282829292A292A2A2A2A2A2B2B2B2B2C2C2B2C2C2D2D2E2E2E2F302F3031313131
323232333334333334343334333334343334343334343433333333333433323233323232
32323232323130313130303030303030302F2F2F302F2E2E2F2E2E2E2E2D2D2D2D2D2D2C
2C2B2C2C2B2B2B2B2B2A2A2A2A2A2A2A2A2A29292A2A292A292929292929292928282828
282928282828282828272828282728272727272727272727272727272727262727272726
272626262726262727262726262626262627262627272727262626272626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626262626262626262626262626262626262626262526262626262625262626262626
262626262626242426252526262626262626262626262626252626262526262626262526
2626262626262526
252525252526262525262525252525262526252626262626252626262526252625262526
252625262525262526262626252625262626262626262626262626262626262626262625
262626262626262526262626262626262626262626262626262626262626262626262626
26262627262F262626262626262626262627262626262726262627272627272626272727
272727272727272726262727272727272727262727272727272728282828282727282828
2828282928292929292A29292A292A2A2B2B2A2B2B2B2C2C2C2C2D2E2E2E2E2E2E2F2F30
303030303031313231323232323232323132313232323131313231313133313131313130
31313030303030302F2F2F2F2F2F2E2E2E2F2E2E2E2E2E2E2D2D2D2D2C2C2C2C2C2C2C2C
2C2B2B2B2B2B2B2A2A2A2A2A2A2A2A2A292A292929292929292928292828292828282828
282828282728282728272727282727272727272727272627272727272727272726272727
272627262726272726272627262626272726262627272726272626262626272626262626
262626272626262626262626262626262626262626262626262626262626262626262626
262626262626262625262626262626262626262526262626252626262626262626262626
262625262626242426262626262626262625262526262626262526262626262526262626
2625262526262626
252726252526252625262625252525262525252626262526252626262625252525262626
262626262526262526262626262625262626262526262526262626262625262526262626
262626262626252626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262627272726262627262626272727272727272627
272727262627272627272727262727272727272727282727282727272828282727282728
2828282828292928282929292929292A292A2A2B2B2B2A2B2C2B2C2C2D2D2C2D2E2D2E2E
2E2F2F2F2F302F3030303031303031313030313030303031302F30313030303030303030
2F2F302F2F2F302F2E2E2F2E2E2E2F2E2D2D2E2D2D2D2D2D2D2C2C2C2B2C2C2B2B2B2B2B
2B2B2B2A2A2A2A2A2A29292A29292A292929292929282929282828292828282828282828
282828282727282727282827272727272727272727272727272727272727272627272727
272726272727272727272727262626262627262626262626262627262626272626262627
262626272626262627262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262626262626262625262626262626262626
262625262625242526262526262626262526262626262625262626262526252626262626
2625262526252626
252626262525252525252526262525262525262525252625262526252625252625262626
262526252626262626262626262626262626252626262625262526262626262626262626
252626262626262626262626262626262626262626252626262626262626262626262626
262627262626262626262626262626262626262626262626272626272727262626262726
262627272727272727272727272727272727272727272727272727272727282828282828
28282828282828292929292929282929292A29292A2A2B2A2A2B2B2B2B2B2C2C2D2C2C2D
2D2E2D2D2E2E2D2E2E2F2E2E2F302F2F2F2F2F2F2F2F302F2F2F2F2E2F2F2F2E2E2F2E2E
2E2E2E2E2F2E2E2E2E2D2D2D2E2D2D2C2D2C2C2D2C2C2C2C2C2B2B2B2B2C2B2B2B2B2B2B
2B2A2A2A2A2A2A29292A2929292929282929292829292928282828282828282827282728
282828282827272827272727272727272727272727272726272727272727272627272727
272627262726262627262726262626262726272726262627262626272726272626262627
262626262626262626262626262626262626262626262626262626262626262626262526
262526262626262626262626262626262626262626262626262626262626262626252626
262625262625242426262626252625262626262526252526262625262526262625262526
2626262626252625
252626262626252525252525252625252525262625252625252625262626262526262525
262626262525262626262526252626262625252625262625262626262626262626262626
262626262525262526262626262626262626262526262626262626262626262626262626
262626262626262626262626262626272626262727262626272626262626262627262626
262727262726272727272727272727272626272727272727272727282728282728282727
2728282828282828282829282829292929292929292A292A2A2A2A2B2B2B2B2B2B2B2B2C
2C2D2C2C2C2D2D2D2D2D2D2D2E2D2D2D2E2E2E2E2F2E2E2E2E2E2E2D2D2E2E2E2D2E2F2E
2D2D2E2D2C2D2D2D2D2D2D2D2D2C2D2C2C2C2C2C2B2B2B2B2B2B2A2B2B2A2B2A2B2B2A2A
292A2A292929292929292929282828282828282928282828282728282827282728282728
272827272727272727272727272727272726272727272627272726272726272726262626
262626262626262627262626262726262626262626262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626242425262626252626252526262626262626262626252526262626252526
2525252526262526
252526262526252525262525262526262626252625262525262625262526252625252626
262626262526252526262626262626262626262626262626262626262525262626262626
262626262626262526262526252626262626262625262626262626262626262626262626
262626262626262626262626262626262626262627272626262626272726262627272726
262627272627262627262726272727272627272726272727272727272727272827272827
2827272728282828282728282828292928292829292929292929292A2A2A2A2A2A2A2B2B
2B2B2B2B2B2C2C2C2C2D2C2C2C2C2D2C2D2D2D2D2D2C2D2E2D2D2D2C2C2C2D2D2D2C2C2C
2C2D2D2C2C2C2C2C2C2C2C2C2B2C2B2C2B2B2B2B2B2B2A2B2B2B2B2A2B292A2A2A292929
292929292929292928292928292828292828282828282828282827272728272827272827
272727282828272727272727272727272726272727262727272727272627272726272626
262627262726262726262626262727262626262627262626262727262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262526262626242425262626262625262626262526262626252626252625262526262625
2626252626262526
252525252526262525252525252626262625252626262526262525252526262625262526
252526252626252526262526262526262626252626262626252626262626262626262626
262626262626262625262626262626262626262626262626262626262626262626262626
262626262626262726262626262626262626262627262626262726262627262626262626
272626272626272727272727272727272726272727272727272727272727272727272727
272727272827282728282828282829282828292829292829292929292A2A2A2A292A2A2A
2B2B2A2B2B2B2B2B2B2C2B2B2C2B2B2B2B2C2C2C2C2C2D2C2C2B2C2C2C2C2C2C2C2B2C2C
2C2C2B2B2B2B2B2B2B2B2B2A2B2B2B2A2B2A2B2A2A2B2A2A2A2A2A2A2A2A2A2929292929
292929282829282828282828282828282828282728272828282727282728272728272727
272727272727272727272727272726262626272726262727272626272627272626272626
262626272726262626262627262626262626262627262626262626262626262626272626
262626262626262626262626262726262626262626262626262626262626262626262626
262626262626262626262625262626262626262626262626262626262626262626262626
262626252626242526262526262626252626262626262625262626262625262626262626
2626262626252626
252525252525262525252625252625262525252625262626262525262525252526252625
262526252526262626262626262625262626262626262625262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262726272726262726262727272727272727262727272727262727272727272727272727
2727272827282728272827282828282828282829282828292829292828292929292A292A
292A2A2A2A2A2B2B2A2B2A2B2A2B2A2B2B2A2B2A2B2B2B2B2B2B2C2B2B2C2B2B2A2B2B2A
2B2B2B2B2B2A2A2B2B2A2B2A2A2A2A2A2A2A292A2A292A2A2A29292A2929292829292829
292929292828282828282828282828282827272827272727272827282727272827272728
272727272727272727262727272726262727272727272727262727262726262727262726
262627262627262626262726262626262626262626262627262627262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252526
262626252526242426252626262526262626262626252626262526262626252626262626
2626262626252626
252625252525252526252525252525252526252525252526252525262625252626262625
252625262625262626252525252526262626262626252625262626262626262626262626
262626262626262626262626262625262626262626262626262626262526262626262626
262626262626262626262626262626262626262626272626262626262626262626262626
262626262727262726262627262727272727272727272727272727272727272727272727
272727272728272827272727272727282827282828282829282828292829292929292A29
29292A2A2A2A292A292A2A2A2A2A2A2A2A2A2A2A2A2B2B2A2B2A2A2A2A2A2A2A2A2A2A2A
2A2A2A2A2A2A2A2A292A2A2A2A2A2A2A292A2A2929292929292929292929292828282828
292828282828282828272828272727272728272727282727272727272727272727272727
272627272727272727272627262727272626262726272626272627272727262626262626
272626262626262626262626262627262626272626262626262626262626262626262626
262626262626262626262626262626262626272726262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626242426262526262526262626262626262525262625262626252626262525
2625262525262625
252525252525252626262525252526252525252626252526252625262525262526262525
252626262626252626252626252626262625262626252626252626262626262625262626
262626262625262626262526262625262625262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262627262626262627
262727272627262626262726272626272727262727272626262727272627272627272727
272727272727272727272727272827272728282827282828282828282828282929282929
2929292929292929292929292929292A2A29292929292A2A2A2A2A2A2A292A292A292A2A
2A2A2929292A2A2929292929292929292929292929292929292928282829282928282828
282828282828272728272728282827272727272727272727272727272727272727272727
272726262727272626272627272627262726262727272726272626262626262626262626
262626262627262627262626262726262626272626272626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262626262626242426252625262626262626262526262625262626262526262625262526
2625262626262626
252626262525262525252625252525252626262525252625262626252525252625262626
262526252626262526262625252625262625262526262626262626262526262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626262726262626262626262626262626262626262626262627262626
262626272727262627262627262627272627262727262727272727272626272727272726
272727272727272727272827272727272727272828272828282728282827282828282828
29292928292928292929292929292929292A292829292929292929292929292928292929
2929292A2929292929292929292928292829292828282829282828292828282828282828
282728282728272827272727272827272727272727272727272727272727272626272727
272626272727272727262626262727272627272626272627262626262627272626262626
262627262626262626262626262626262626262626262726262626262626262726262626
272626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262625262626262626262626262626262626262626262625
262626262626242426262626262625262626252625262526262626262625262526262626
2526252626262626
252625252526252525252526252526262625252526252526252525252525262626252525
262526262625262625262626262626262626262625262626262626262626252626262626
262626262525262626262526262626262525262626262626262626262626262626262626
262626262626262626262626262626262626272626262626262627262626262626262626
262626262626272626272727272727262726272727272727272727262726272727272727
272627272727272727272727272727272728272727272827282827282728272828282828
292828282928282829292829292929292828282829282929282829282929292929282929
282828292928282929292828282828282828292828282828282828282828282828272828
282727272727272728272727272727272727272727272727272727272727272727272627
272726272627272726272627272627262626262626272626262626262626262626262626
262726262626262626262626272626262626262626262626262626262626262626262627
262626262626262626262626262626252626262626262626262626262626262626262626
262626262626252626262626262626262626262626252626262626262626262626262626
262626262626252426262626262626262626252525262626252626262625252625262626
2626252526262626
252525252526252525252625252525252625252625262525262625252526252626262526
262526262526252625262625252626252626252625262626252625262626252625262626
252626262626262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626262627262626262626262626262626262627
262626262626272727262726262627272726262627272727262626272727272727272727
272727272627272727272727272727282727272827272827282728282728272727282828
282828282828282827282828282828282928282828282928282828282828282828282828
282928282828282828282828282828282828282828282828282827282827282827272827
272827272727272727272727272726272727272727272727272727272727272627262727
272727272726272727262727262726262626272727262627262626262726262626262626
272627272726262626262627262626262626262626262626262626262626262626262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262526262626262626262626262626262626
262626262625242425262526262526262626262626262626262625262625262525262626
2626252626262526
252625262525262525252625252525262625252626252525262625252626252525252626
252526262526252525262626252626262525262525262625252525262526262626262526
252625262626262626262626262626262626262626262625262626252626262626262626
262626262626262726262626262626262626262626262627262626272626262626262626
262626262626272626262627262727262626262626272726272626272727272627272627
272727272727272727272727272727272727272727272727272727272727282728272828
282728282828282828282828282828282827282828282728282828282828282728282828
282827282728282828282828272828282828282728282827272827282727272727272727
282727272727272727272727272727272727272727272727272726262726272627272627
262626262726262627262626262626262626262726272626262626262627262627262726
262626262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626262625262626262626262626262626262626262626262626252626262626262626
262626262526252426262526262625262625262626252626252626252626252626262526
2625262625262526
252626252525252625252525252626252625262526252626262626262525262525252525
252526252525262626252625252525252626262625252625252626252626262626262525
262626252525262626262526262626262625262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262727262627272626272627272726262726272627272627272627
272727272727262727272727272727272727272727272728272727282727272727272827
272727272727272728282827282828282828282828282828282828272827282828282828
282827272828282728282827282827282728272727282728272727272727272727282727
272727272727272727272727272726272727272726272627272727262726272726262626
262627272726272626262626262626262626262726272626262626262626262626262626
262626262626262626262726272626262626272626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262625262626
262626262626262626262626262626262626262626262626262626262626262626252625
262626262526252426262626252626252626262625262626252625262625262526262526
2526252625262626
252625262525252626262525252625252625252525252526262525252526252626262626
252626252626262525262526262625252526262626262626262625262626262625262626
262625252526262526262626262626262626262626262526262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
272626262627262626262626262627272727272626272627262727262627262727272626
272626272726272727272727272727272727272727272727272727272727272728282727
272827282727272828282727282827282728282728272727282827272727282727282827
272727272827272727272727282727272727282727272627272727272827272727272727
272727272727272727272627262726272627272727272727272626262726272627272626
262727262627262727272627262626262626272626262626262626262626262626262726
262626262626262626262626262626262626262626262627262626262626262626262626
262626262526262626262626262626262626262626262626262625262626262626262626
262626262626262625262626262626262626262626262626262626262626262626252626
262626262626252426262626262626262526262626252526262626252525262626262526
2626252625262626
252625252525252525262526252626252526252625252625262525262525252625262525
262625252625262525262626262526252625252626262526262626262626262625262625
252626262525262626262626262626262626262626262626262626262526262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
262727262626262626262626262626262626272626262726262727272626272626272627
262626272727272727272727272727272727272727272727272727272727272727272727
272727282828272727272728282727272727282727272727282728272727272827272827
272728272727282727272727272727272727272727272727272727272727272727272727
272727272727272727262727262727262727272727262727272726262726272726262626
262828262626262626272727262627262626262626262627262626262726262626272626
262626262627262626262627262626272626262626262626262626262626262626262626
262626262626262626262626262526262626262626262626262626262626262626262626
262626262626262626262626262626262626252626262526262626262626262625262626
262626262626242426252626262625262626262625252626252626252625262526252625
2526262625262526
252626252526252525262625252625252526252626252526262526252525262625262526
262625252525252625262625262526262525262626262625252625262626252626262625
262626262526262626262626262526262626262625262626262626262626262626262626
262626262626262625262626262626262626262626262627262626262626272626262626
262626262626262726262626262626262727262626262626272626272727262627272726
272727262727262727272727272727272627272727272727272727272726272727272727
272727272727272727272727272727282827272727272727272727272727272827272728
272727272727272727272727272727272727272727272727272727272727272727272627
272727272726272727262726262627272727272726262726272627262726262726272627
262726272627262626262627262626262626262626262626272626262627262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262626262626262626262626262626262626262626262626262526262626262626262626
262626262626262626262626262626262526262626262626262626252625262626252526
262626262526242525262626262625262626252626262625252526262626262626262526
2625252525262626
252525252525252626252525262525252525252526252526252625252526252625262526
262625252625262526262625262625252625262625252526252526252626262626262626
262626262626262625262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626262626262626262626262626262726
262626262626262627262726262627262626262626272627272626262726262627262626
262727272627262726272727262727272727262727272726272727272727272727272727
272727272727272727272727272727272827272727272727272727272727272727272727
272727272727272727272727272727262727272727272727272727272727262726262727
262727272727262727272727262727272727262626262727272627262627272726262626
262727262726262626262626262626262626262626262626262626272626262626262626
262626262626262626262626272626262626262626262626262626262626262626262626
262626262626262626262625262726262626262626262626262626262626262626262626
262526262626262626262626262626262626262626262626262626262626262625262626
262626262626242425262626262626252626262625262626252626262526262525252625
2626262526252625
252525252525262525252526252625252625252626262625252625252525262525252526
262626252526262626252525262625252626252626252525262626262526252526262626
262625252625252625262526262626262626262526262626262626262626262626262526
262626262626262626262626262626262626262626262626262626262626262626262626
262627262626262627262627262626262726262726272726272726272627272627272726
272626262727272727262727272727272727262626272627262727272727272727272727
272727272727272727272727272727272727272727272727272727272727272727272727
272727272727272727272727272727272727272627272727272726262627272727272727
272727262727262626262727262727272626262727262726262626272627262626272626
272626262726262626262727262726272727262626272626262626262626262626262627
262626262626262627262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626252626262626262626262626262626262626262626
262626252626242525262625252626262625262526262626262625262626262625262526
2626262525262625
252625252526252525262526252525252526252525252525262526262625252526262525
252525252526252626252526262525252525262525262625252625262625262625262626
262625252626252626262626262626262626252626262626262626252626262626262526
252626262626262626262626262626262626262626262626262726262626262626262626
262626262626262626262626262626262627262626262626272626262726262727262726
262727262627272727272727272727262727272727272627262727272727272727262727
272727272727272727272627272727272727272727272727272726272727272727272727
272727272727272727272727272626272727272727262727272727262627272727272727
272627272727272727262627272626262726262626272727272726262726262726262627
262626262626262627262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262726262626
262626262726262626262626262626262626262626262626262626262626262626252626
262626262626252626262626262526262626262626262626252626262626262625262626
262626262526242426252626262626262625262626262526262525262525262626262526
2526262626262526
252625252526262525252525252625262525262626262525262525252525252525252625
262525262525252626262625262525262626252525262626262526252626262626262526
252626262626262625262626252526252626262626262625252626262626262625252625
262626262626262626262626262626262626262626262626262626262726262626262626
262626262626262626262626262627262626262626262726272626262626262726262626
262726272626272626262726262627272626272727272727262727272726272727272727
272727272726262727272727272727272727272727272727272727272727272727272727
272627272726272727272727272627272627272626262726272627272726272727272727
272727272727272627262727272727272626272727262626262626262626262627272627
262627262526262626262626262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626252626262626262625262626262626262525262626262626252626
262626252626242425262626252626262526262526252526252626262626252626252625
2625252625262625
252625252525252525252525262526262526252525262625252625262526262625262526
252526262625252626262526252626252626252626262626262626252526262626252625
262626262526262526262626262625262626262526262626262626262626262626262526
262626262526262625262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262726262627262626262726
272627272627262626272627272727262727272726262727262727272727272727272727
272727272727272727272727272727272627272727272727272727272727272727272626
262627272727272727272726272727272727262727262727262726272627272727272727
262627272627272726262726262626262727262626262626272626262627262626272626
262726262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262625262626262626262626262626262626262626
262626262526262626262626262626262626262626262626262626262626262626252626
262626262526242426252526252626262626262625262626262626252526252626262626
2625252525262526
252625252525252626252525262525252526252525252525252626252526252626252625
262625252526262625252626262626252626262526262526262626262526262626252526
252626252526252626262625262626262626262625262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262727262626272626262626262726
262726272627262626272626262727262726272727262627262627272727272627272727
262627272627272727272727272727272727262727272727272727272726272627272727
272727272727272727272726272627262727262626262727262727272727262726272626
262627272627272627262726262627262626262726272626262626262626262626262626
272626262626272627272626262626262626262626262626262626262626262626262626
262726262626262626262626262626262626262626262626262626262726262626262626
262626262626262626262625262626262626262626262626262626262526262626262626
262626262626262626262626262626262626262625262626262626262626262626252626
252626252626242526262626262626252626262626262626262625262626252626262626
2625262625262626
252626252526262525252525252525252525252525252626252625252525252626252626
262525262526262525252525262625262626262626262626262625252625262526262525
262626262626262626252625262626252626262526262526262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262726262626272626272626262626
272626262627262627262626262726262727272727262627262927272727272726272626
272627262627262727272627272626272726272726262727272726272727262627272726
272726262726272626272727272726262626272727272726262626272626262626272627
262627262627262727262626262627262626262726262626262626262626262626262626
262626262726262626262626262626262626262626262626262626262626262626262726
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626252626
262626262626262626262625252626262626252626262626262626262626262626262626
252625252626242425252625262526262626262625262625262626262526262626262526
2525252625252526
252625262526262526252525252525262525252526262526252525252626252625262525
252626252526262626262526252526262626252626262626262626262626252626262526
262626262625262626262626252626262626252626252626262626262626262626262626
262626262626262626262626262626252626262626262626262526262626262626262626
262626262627262626262626262626262626262626272626262626262727262626262726
262626272626262727262726272626262726262626262627262E27272627262626262726
272626262626272626262726272726272727272727272626262727272727262726272627
272727272627262626272626262626262726272626262627262626262626262626272727
262726262626262626262626262626262626272626262626262626272626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626272626262626262625262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626252626262625262626262626262626252526262625262625262626262526262626
252626262525242526262625252626262625252525262625252526262626262626262625
2525262625262526
252625252525252525262525252525262625252525252526252525252625252625262526
252626262525252525262625262626262626262526252626252626262625262526262626
262625252626262626252626262625262525262626262626262625252526262626262625
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262627272626272727272626262626272727262726262726262627
272627272726262626272627262727272727262727262626262627262726262726272627
272727262626262727272726262727272726262726272627272626262726262626262626
272626262727272626272626262726262626262726272626262726262626272727262627
262626262626262626262626262626262626262626272626262626262626262626262626
262626262626262626262626262626262626262626262526262626262626262626262626
262626262626272626262626262626262626252626262626262626262626262626262626
262626262626262626262625262626262626262525262625252626262626262626262625
252526252625242426262526262626252626252625252526252525262626252525262625
2626252626262626
252625252525252525262625252625262626252525252525262525252525252626252526
252525252526252625262526252525262526262525262626262626252625252626252625
252626252626262626262626262526262626252626262626262526262626262626262626
252626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262726262626262626262626262626
262627262626262626272626262627262726272627262627262727272626272726272626
272726262627262726262627262626262626262726262727272726272626272627272627
272726272727272626262726262626272627262626272726262726262626262726262626
262626262627262726262626262626262726262726262727262626262726262626262626
262626262626262626262626262626262626262726262626262626262626262626262626
262727262626262626262726262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262625262626262626262626262626262626
262626262626262626262626262625262626252626262626262626262626262626262526
262626262626242426262526262626262626262626262526262626262525262626252626
2526252525252625
252625252526252525252525252526252525252525252526262526252625252525252626
252525252626252625252626252626252625252625252525262626262625262626262625
262626262625262626262625262526262626262526262626252626262626262626262626
262526262626262626262626262626262626262626262626262626262625262626262626
262626262626262626272626262726262626262626262726262626262626272626272726
272626262626262626262626262626262726262626262626262626272626272626272726
262627262627262726262726262726262627272627262726272626272626272726262626
262726262627272726272726262627262626272626272626262626262626262726262627
262727262627262726262627262626262626262626262626262626262626262626262627
262626262626272626262626262626262626262626262626262626272627262626262626
262626262626262726262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262526262626
262625262626262626262525262626262626262626262626262626262626262526262526
262626262626252526262525262626262525262626262626252625262625262525252626
2525262626252626
252525252525252525252525252525252625262525262525252525262525252525262525
252625252526252526252625252525262525252626262626252626252525252626252526
252625252526252625262526262626262526262526262625262626262626252526262626
262626262626262526262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262627262626262626262626262626262626262626
262626262726262627272626262626262626262626272626262627262627262626262627
272626262626262626262626272727262626272727262626262726262726272726262726
272627262726262627262726262727262626262726262626262627262626262627262626
262627262626262626262626262627262626262627262626262627272627262626262627
262626272626262626262626262626262626262626262626262626262626272626262626
262626262626262626262626262626262626262626262626262626262626262626262626
252626262626262626252626262626262626262626262626262626262526262626262626
262626252526262625262626262625262625262626262526262625262626262526262626
252626252626242425262625252525262526252525262525262526262525262625262625
2526252625262625
252625252525252525252525262526252525252526262525252525252525252626252625
252626262625252625262526252525252526252626262625262626252526262626262526
262625262626252626262626252626262626262626262626262626252526262626262626
262626252626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262627262626262627262626262626262626262626262726262626272626262626
272626262626262626262626262727262626262626262626272627272626262626262726
262726262626262727272626262626262727262726262626262626262626262627262726
262627262626272626262626262626262626262626262626272626262626262626262626
262626262627262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626262626252626262626252626262626262625262526252626262625252626262626
252626252526242426262625262625262626262525262625252625262626252526262625
2526252625262526
252626252526252526252525262525252525252625262625252525252626252625252526
252526262525252626252526252626252525252626262626252626262625262625252525
262625252626262526262526262626262625262626262526252626262625262526262626
262626262626262626252626262626262526262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262627262626
262626262626262626262626272626272626272626262627262626262626262626262726
262626262626262626262726262626272626262626262727272626272626262626262626
262626262626262727262627262727262626262626262726262627262626262626262626
262626262626262627262626262626262626262627262626262627262626262626262626
262626262626262626262626262626262626262626262626262726262626262627262626
262626262625262626262626262626262627262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262526262626262626262626
262626262526262626262526262626252626262626262626262626252626252626262625
262626262626242426252626262626262525262625252526262626262626252626252626
2525252525262625
252525252526252525252525252525252526252525262525252525252525252525252625
252625252526252626252526262525262626252625262626262626252526262626262626
252625262626252626262626262525252625262626262626262626262526262626262626
262625262526262626262625262626262626262626262626262626262626262626262626
262626262626262626262726262626262626262626262626262626262626262627262626
262626262627272626262726262626262626262626262627262626272626262626262626
262726272626262626272626262626262627262626272627262626262626262726262626
262726272626262626272726262626262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262526262626
262626262626262626262626262625262626262625262626262526262626262526262626
262626262626252526252626262526262525262626262526262525262626262626252526
2626252625252525
252625252525252525252525262525252626252525252525252526252626252625262526
262525252525252525252525252625252626252625262526252525252626262525262625
262626262525252626262625262526262625262626262526262626262626252626262626
262626262626252626262626262626262626262626262626262626252626262625262626
262626262626262626262626262626262626262626262626262626272626262626272626
262626262626262626272626262726262626262726262626262626262626262626262626
262627262727262626262726262626262626262626262626262626262626262626272726
262626262626262626262626262627262626262626262626262626262626262726262726
262626262626262626262626272626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262625262626262626
262626262626262626262626262626262626262626252626252626262626262626262626
262626262626262626262626262626262626262626262626262526262526262625262625
262525262626242426252526262626262626262625262626252526262626262525262625
2625252526262626
252625252525252525252625252525252525252525252625252525252525252626252525
262525262625252625252626252525252625262626262525262626262625262526262626
252626262526252526262625262626262626262626252626252626262625252626262626
262625262626262526262626262829262626262625262626262625262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262627
262626262627272626262626262626262626262626272627262627262626262626262726
262626272627262626262726262626262626262626272626262726262626262726262626
262626262726262626262626262626262626262626262626262726262626262626262626
262626272626262626272626262626262626262626262626262626272626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262626262626
262625262626262626262626262626262626262626262626262625262626262626262626
252525262626262526262626262626252626262626262625262625262626262626252625
262626262626242426262526262625262526252526262625262625262626252526262525
2625262625252626
252625252526262525252525252526262525252525262626262525262525252526252625
252625262525252526252625252526262625262625262626252625262525262626262625
252626262526262526252625252526262626262625262626262626262626262626262626
262626262626262626262626262627262626262626262626262626262626262626252626
262626262626262626262626262626262626262626262626262626272626262626262626
262626262626262626262627262626262626262626262626262626262626262626262626
262626262626262726262626262626262626272626262626262626262626272627262626
272626262626272626262626262626262626262627262627262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626252626262626252626
262626262626262626262626262626262626262626262625262626252626262626262525
252626252626242425262526262625262625252626252626262626262626252626252625
2626252525262625
252525252525252525262525252525252625252525252525262525252525252525262526
252626252625262526262526252525252526262526262625262625262525262625262626
252625262625252526262526262626252626262626262526262626262626262626262625
262626262626262626262625262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262627262626262626262627262626262626262626262626
262626262626262626262626262627262626262626262627262626262626272626262626
272626262727262626262726262626262626262627262626262626272626262626262626
262626272626262626262626272626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262625
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262625262526262625262625
262526252526242425252626262626262526262625262626262526252626252626252626
2526252526252526
252525252525252525252525252625252525252525252525252526252525252526262526
252625262525262525252525262525252526262526262626262525262525262525262526
262626252525252626262626262626262626262626262626252626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262727262626262626262626262626262626262626262626262626262626
262626262626272626262626262727262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262625262626262626262626262626262626262626262626262626262626262526262625
262626252625262626262626262626262626262526262626262625262626262626262626
262626262526252626262626262626252626262526262626262626262626262625262626
262626252526242425262526262526262526262625262625252526252526262526262625
2526252626252526
252526252526252525262526252526252525252625252525252526252525252625252526
252525252526252525252625262625262626252526252525252626252526262625262626
252525252626262626262625262526262626262626262625262526262626262626262625
262626262626262626262625262626262626262626262525262626262526252626262626
262626262625262626262626262626262626262626262626262626262626262627262626
262626262626262626262626262626262626262626262627262627262626262626262626
262626262626262626262626262626262626262626262626262627262626262626262626
262626272726262626272726262626262626262627262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262626262626262626262626262626262626262626262626262626262626262626
262626262526262626262626262626262626262626252626262626262626262526262626
262626262626262626262626262626262526262626262626262626262626262626262626
262526262526262626262625262626262626262626262625252625262626252625262626
262626252625242426262626252525262626252626262526252625252625262525262726
2525252526262625
pop
P
% End of image
1 1 1 r
.5 Mabswid
[ .05 .03 ] 0 setdash
.10007 .10193 m
.89993 .10193 L
.89993 .89807 L
.10007 .89807 L
.10007 .10193 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=Z@D09BDU0`0V9RH01P0U9BD09RHV02HV9P0V
9RH09BDU02HV9P<09BDU0`0V9RH00`0U9BD09RHV02HV9P0302HV9P0302DU9@0V9RH09BDU00D09RHV
00D09BDU02HV9P0V9RH09RHV02DU9@0J02HV9P0502LW9`0V9RH09RHV02HV9P0W9bL0200V9RH00`0W
9bL09RHV02HV9P0J02HV9P0302DU9@0V9RH09BDU00@09RHV00<09BDU02HV9P0V9RH00`0U9BD00`0V
9RH09BDU02DU9@0402HV9P<09BDU00<09RHV02DU9@0V9RH00P0U9BD00`0V9RH09BDU0=7=Z@030=7=
Z@000`3AcJT402DU9@<09RHV0`0U9BD00`0V9RH09BDU02DU9@0402DU9Ah09RHV00<09bLW02HV9P0V
9RH0100V9RH00`0W9bL09RHV02HV9P0302HV9P0302LW9`0V9RH09RHV00@09RHV00<09bLW02HV9P0W
9bL00P0V9RH202LW9`@09RHV0P0W9bL00`0V9RH09bLW02HV9P0N02HV9P809BDU00<09RHV02DU9@0U
9BD00`0V9RH01P0U9BD09RHV02HV9P0U9BD09RHV02DU9@<09RHV00<09BDU02HV9P0U9BD0100U9BD4
0=7=Z@000`3AcJT00`0V9RH09BDU02DU9@0202HV9P<09BDU0`0V9RH01@0U9BD09RHV02HV9P0V9RH0
9BDU00<09RHV00<09BDU02HV9P0U9BD00P0V9RH00`0U9BD09RHV02HV9P0M02HV9P809bLW0P0V9RH0
0`0W9bL09RHV02LW9`0402HV9P809bLW00<09RHV02LW9`0V9RH01@0V9RH202LW9`P09RHV00<09bLW
02HV9P0V9RH00`0V9RH00`0W9bL09RHV02HV9P0<02HV9P0302DU9@0V9RH09RHV00D09RHV00<09BDU
02HV9P0V9RH00P0U9BD302HV9PD09BDU00<09RHV02DU9@0U9BD00P0U9BD00`0V9RH09BDU02DU9@04
0=7=Z@000`3AcJT202DU9@809RHV00<09BDU02HV9P0U9BD0100V9RH202DU9@@09RHV0P0U9BD00`0V
9RH09BDU02HV9P0?02HV9P0302`/;00V9RH09RHV00D09RHV00D09bLW02HV9P0W9bL09RHV02LW9`03
02HV9P0402LW9`0V9RH09RHV02LW9`<09RHV00<09bLW02HV9P0W9bL00P0W9bL00`0V9RH09bLW02LW
9`0402LW9`809RHV100W9bL0100V9RH09bLW02HV9P0V9RH402LW9`0302HV9P0W9bL09RHV01809RHV
00<09BDU02HV9P0V9RH00P0V9RH00`0U9BD09RHV02HV9P0302HV9P809BDU0P0V9RH01@0U9BD09RHV
02HV9P0V9RH09BDU00809RHV00<09BDU02HV9P0V9RH00`0U9BD202HV9P@0dLfY00030=7=Z@@09BDU
00D09RHV02DU9@0U9BD09RHV02DU9@0402HV9P809BDU1P0V9RH00`0U9BD09RHV02DU9@0A02HV9P03
02LW9`0V9RH09RHV00D09RHV100W9bL0100V9RH09bLW02LW9`0W9bL202HV9P0302LW9`0V9RH09RHV
01009bLW00<09RHV02LW9`0W9bL01@0W9bL00`0V9RH09bLW02LW9`0J02HV9P0302DU9@0V9RH09BDU
00809RHV00<09BDU02HV9P0V9RH0100V9RH00`0U9BD09RHV02HV9P0702DU9@@0dLfY00030=7=Z@80
9RHV0P0U9BD302HV9P0302DU9@0V9RH09RHV00<09RHV00<09BDU02HV9P0V9RH07@0V9RH202LW9`80
9RHV00<09bLW02HV9P0W9bL00`0W9bL202HV9Q809bLW00<0:2PX02LW9`0W9bL02P0W9bL202HV9P80
9bLW00<09RHV02LW9`0V9RH0600V9RH0100U9BD09RHV02HV9P0V9RH302DU9@0302HV9P0U9BD09RHV
00809RHV00<09BDU02HV9P0U9BD00P0U9BD00`0V9RH0dLfY0=7=Z@020=7=Z@000`3AcJT0100V9RH0
9BDU02DU9@0V9RH202DU9@809RHV0P0U9BD402HV9P0302DU9@0V9RH09RHV00@09RHV00<09BDU02HV
9P0V9RH0200V9RH00`0U9BD09RHV02HV9P0>02HV9Ph09bLW0P0X:2P402LW9`0402PX:00W9bL09bLW
02PX:0809bLW1@0X:2P402LW9`0502PX:00W9bL09bLW02LW9`0V9RH00`0W9bLK02HV9P0302DU9@0V
9RH09RHV00<09RHV0P0U9BD01P0V9RH09BDU02DU9@0V9RH09BDU02HV9P@09BDU103AcJT000<0dLfY
0P0U9BD602HV9P0302DU9@0V9RH09BDU00D09RHV00<09BDU02HV9P0V9RH04@0V9RH00`0W9bL09RHV
02LW9`0202HV9P0302LW9`0V9RH09RHV00l09bLW200X:2P0200W9bL0:2PX02PX:00Y:BT0:2PX02TY
:@0X:2P0:BTY1`0X:2P902LW9`809RHV0`0W9bL902HV9P0302DU9@0V9RH09RHV00d09RHV00<09BDU
02HV9P0V9RH00P0V9RH0100U9BD09RHV02HV9P0U9BD402HV9P809BDU00<09RHV0=7=Z@3AcJT00P3A
cJT000<0dLfY0P0V9RH0100U9BD09RHV02HV9P0V9RH202DU9@809RHV00<09BDU02HV9P0V9RH0300V
9RH00`0W9bL09RHV02HV9P0502HV9P0402LW9`0V9RH09RHV02HV9P809bLW00<09RHV02LW9`0V9RH0
2@0W9bL;02PX:0H0:BTY00<0:RXZ02TY:@0Y:BT00`0Y:BT0100Z:RX0:BTY02TY:@0Y:BT202PX:003
02TY:@0X:2P0:2PX0080:2PX00<09bLW02PX:00W9bL01`0W9bL00`0V9RH09bLW02HV9P0D02HV9P03
02DU9@0V9RH09RHV00@09RHV00L09BDU02HV9P0V9RH09BDU02HV9P0U9BD09RHV00809BDU00<09RHV
02DU9@0U9BD0103AcJT000<0dLfY0P0U9BD00`0V9RH09BDU02HV9P0202DU9@809RHV0P0U9BDE02HV
9P809bLW100V9RH00`0W9bL09RHV02LW9`0202LW9`0502HV9P0W9bL09bLW02PX:00W9bL00P0X:2P3
02LW9`@0:2PX100Y:BT302XZ:PD0:b/[1@0/;2`302/[:`80:RXZ00<0:BTY02XZ:P0Y:BT00`0Y:BT4
02PX:0L09bLW00<09RHV02LW9`0V9RH00`0V9RH00`0W9bL09RHV02HV9P0902HV9P0302DU9@0V9RH0
9RHV00@09RHV00<09BDU02HV9P0V9RH0100V9RH01@0U9BD09RHV02HV9P0V9RH09BDU00809RHV0P0U
9BD40=7=Z@000`3AcJT00`0U9BD09RHV02DU9@0302DU9@809RHV00<09BDU02HV9P0V9RH0203oool3
02HV9PP0oooo00@09RHV02LW9`0W9bL09RHV203oool302LW9`P0oooo00@0:BTY02XZ:P0Z:RX0:RXZ
203oool00`0^;Rh0;bl_030`<0080?ooo`0302d];@0^;Rh0;Bd]00T0oooo0P0X:2P00`0W9bL0oooo
0?ooo`060?ooo`809bLW00<09RHV0?ooo`3oool01P3oool402HV9PP0oooo00@09BDU02HV9P0V9RH0
oooo0P0V9RH202DU9@0302HV9P0U9BD09BDU00<09RHV00<09BDU0=7=Z@3AcJT00P3AcJT000<0dLfY
00<09BDU02HV9P0V9RH0500V9RH00`0U9BD09RHV02HV9P0202HV9P0302LW9`0V9RH09bLW00809RHV
0P0W9bL00`0V9RH09bLW02LW9`0602LW9`H0:2PX0P0Y:BT0100Z:RX0:b/[02XZ:P0[:b/302`/;080
;Rh^00L0;bl_030`<00`<300<C4a038b<P0c<c<0<S8b0080=3@d0P0e=CD303@d=00403<c<`0b<S80
<S8b034a<@80;bl_00@0;Bd]02`/;00];Bd0:b/[0P0Z:RX00`0Y:BT0:2PX02TY:@0302PX:0809bLW
00P0:2PX02LW9`0W9bL09bLW02HV9P0W9bL09RHV02LW9aH09RHV00L0oooo02HV9P0V9RH09BDU02HV
9P0U9BD09RHV00809BDU00<09RHV02DU9@0V9RH0103AcJT000<0dLfY00<09BDU02HV9P0V9RH01@0V
9RH00`0U9BD09RHV02HV9P0?02HV9P0402LW9`0V9RH09RHV02HV9Ph09bLW100X:2P00`0Y:BT0:RXZ
02XZ:P0202/[:`80;Bd]0P0_;bl2030`<003034a<@0c<c<0<c<c0080=SHf0P0i>CT01@0k>c/0?Cdm
03dm?@0m?Cd0>c/k00<0?Cdm00<0?3`l03Xj>P0k>c/00P0i>CT01@0f=SH0=CDe03<c<`0a<C40<30`
0080;Rh^00@0;2`/02/[:`0[:b/0:RXZ0P0Y:BT402PX:0L09bLW00<09RHV02LW9`0W9bL02@0V9RH0
100U9BD09RHV02HV9P0U9BD602HV9P050?ooo`0V9RH09RHV02DU9@0V9RH00`0U9BD302HV9P0302DU
9@3AcJT0dLfY0080dLfY00030=7=Z@809BDU00<09RHV02DU9@0U9BD00`0V9RH0100U9BD09RHV02HV
9P3oool;02HV9P0302LW9`0V9RH09RHV00<09RHV1@0W9bL01@0V9RH09bLW02LW9`0X:2P09bLW00@0
:2PX100Y:BT04@0Z:RX0:b/[02`/;00/;2`0;Rh^02l_;`0`<300<C4a03<c<`0e=CD0=cLg03Ph>00l
?3`0?clo0410@014A4@0BDU90080CDe=01T0DE5A05ADE01GEeL0EUIF05UIF@1HF5P0EeMG05=CD`1@
D500C4a<04];B`17AdL0A4A40410@00n?Sh0?3`l03Ti>@0f=SH0=CDe038b<P0`<300;Rh^02d];@0/
;2`0:b/[0080:RXZ0P0Y:BT202PX:0H09bLW00D09RHV02LW9`0W9bL09RHV02LW9`0A02HV9P030?oo
o`0V9RH09BDU00@09RHV0P0U9BD00`0V9RH09BDU02HV9P040=7=Z@000`3AcJT902HV9P0402DU9@0V
9RH0oooo02DU9@L09RHV00<09bLW02HV9P0V9RH00P0W9bL402HV9P0302LW9`0V9RH09bLW00H09bLW
0`0X:2P202TY:@80:RXZ0P0[:b/02@0/;2`0;Bd]02l_;`0_;bl0<S8b03<c<`0h>3P0>c/k03hn?P02
0451@@0B04A4A015ADD0BDU904U9B@1=CDd0C4a<04m?C`1ADE40EEEE05MGE`1HF5P0Fe]K05mOG`1P
H600IfMW06QXJ01[Jf/0K6a/0P1YJFT03`1UIFD0GUiN05=CD`1:BTX0ATI60451@@0n?Sh0>c/k03Ph
>00e=CD0<S8b034a<@0^;Rh0;Bd]02/[:`0202XZ:P80:BTY0`0X:2P502LW9`0302HV9P0W9bL09RHV
01409RHV00<0oooo02HV9P0V9RH00`0V9RH00`0U9BD09RHV02DU9@0302HV9P@0dLfY00030=7=Z@80
9BDU1`0V9RH00`0U9BD09RHV0?ooo`0B02HV9PH09bLW1@0X:2P0500Y:BT0:RXZ02XZ:P0[:b/0;2`/
02d];@0^;Rh0;bl_038b<P0c<c<0>3Ph03/k>`10@400@D5104=3@`15ADD0ATI604Q8B019BDT0Bd];
0P1=CDd01`1?Cdl0DE5A05=CD`1FEUH0FEUI05YJFP1LG5`00P1OGel01@1TI6@0JFUY06YZJP1`L700
KVi^0080LG5a0100L71`06e]K@1XJ6P0GUiN055AD@1:BTX0A4A403lo?`0k>c/0>CTi03Hf=P0c<c<0
<C4a02h^;P0/;2`0:b/[0P0Z:RX0100Y:BT0:2PX02LW9`0X:2P402LW9`@09RHV00<09bLW02HV9P0V
9RH01`0V9RH00`0U9BD09RHV02HV9P0302HV9P040?ooo`0V9RH09RHV02DU9@@09RHV00@09BDU02HV
9P0U9BD09BDU103AcJT000<0dLfY0`0V9RH00`0U9BD09RHV02HV9P0502HV9P030?ooo`0V9RH09RHV
00L09RHV00<09bLW02HV9P0V9RH0100W9bL00`0V9RH09bLW02LW9`0202LW9`0302PX:00W9bL0:2PX
00<0:2PX00@0:BTY02XZ:P0Z:RX0;2`/0P0];Bd02`0^;Rh0<C4a038b<P0f=SH0>CTi03/k>`0m?Cd0
@T9204I6AP18B4P0BDU90080Bd];00L0CTi>051@D01@D500DU9B05ADE01CDe<0EEEE0080F5QH01h0
FUYJ05eMG@1PH600H61P06=SH`1VIVH0IfMW06YZJP1_Kfl0L71`079bLP1dM7@0LW9b07EeM@1cLg<0
LG5a06m_K`1]KFd0Hf=S05EEE@1;Bd/0ATI60410@00l?3`0>3Ph03De=@0a<C40;Rh^02d];@0/;2`2
02XZ:P0502TY:@0X:2P0:2PX02LW9`0X:2P0100W9bL00`0V9RH09bLW02HV9P0>02HV9P030?ooo`0V
9RH09RHV00809BDU0P0V9RH01@0U9BD09RHV02HV9P0V9RH09BDU00@0dLfY00030=7=Z@<09RHV00D0
9BDU02HV9P0V9RH09RHV02DU9@0302HV9P030?ooo`0V9RH09RHV00d09RHV100W9bL00`0X:2P09bLW
02LW9`0302PX:00B02TY:@0Z:RX0:RXZ02/[:`0];Bd0;Rh^02l_;`0b<S80=CDe03Ph>00j>SX0?Cdm
03hn?P11@D40A4A404U9B@1<C4`0CTi>0P1@D5001P1ADE40EEEE05EEE@1EEED0EUIF05QHF080EeMG
00l0F5QH05]KF`1LG5`0GEeM05iNGP1PH600HV9R06=SH`1WIfL0JVYZ06e]K@1^KVh0Lg=c07EeM@1f
MWH00P1hN7P04`1dM7@0MWIf07MgM`1cLg<0LW9b06][J`1TI6@0EEEE04Q8B012@T80?Cdm03Ti>@0d
=3@0<S8b02l_;`0];Bd0:b/[02XZ:P0Y:BT0100X:2P402LW9a009RHV00D0oooo02HV9P0V9RH09RHV
02DU9@0502HV9P0302DU9@0V9RH0dLfY00<0dLfY00030=7=Z@809BDU2@0V9RH00`3oool09RHV02HV
9P0802HV9P0302LW9`0V9RH09bLW00P09bLW0P0X:2P0500Y:BT0:RXZ02/[:`0/;2`0;Bd]02h^;P0`
<300<c<c03De=@0h>3P0?3`l03hn?P10@400@d=304I6AP18B4P0Bd];04i>CP1@D500De=C0P1DE5@0
3`1GEeL0FEUI05MGE`1HF5P0FUYJ05]KF`1LG5`0GEeM05aLG01MGEd0FUYJ05]KF`1MGEd0GemO061P
H00206EUI@0506IVIP1XJ6P0Jf][06e]K@1`L7000P1fMWH01P1iNGT0N7Qh07UiN@1kNg/0N7Qh07Ui
N@80MGEe00d0LG5a06][J`1OGel0Cdm?04A4A00o?cl0>SXj03Hf=P0a<C40;Rh^02`/;00[:b/0:BTY
00<0:2PX1P0W9bL00`0V9RH09bLW02HV9P0;02HV9P0502LW9`0U9BD09RHV02HV9P0U9BD00`0V9RH2
02DU9@0302HV9P0U9BD0dLfY00<0dLfY00030=7=Z@0302HV9P0U9BD09RHV00809RHV00<09BDU02HV
9P0V9RH00`0V9RH0103oool09bLW02HV9P0W9bL402HV9P0302LW9`0V9RH09RHV00809RHV100W9bL0
0`0X:2P09bLW02PX:00202PX:00H02TY:@0Z:RX0:RXZ02/[:`0/;2`0;Rh^030`<00c<c<0=CDe03Ti
>@0l?3`0?clo0451@@15ADD0ATI604Y:BP1>CTh0D51@05=CD`1EEED0EUIF05MGE`1IFET0FUYJ0P1L
G5`01`1NGUh0GemO05iNGP1OGel0H61P05mOG`1QHF400P1MGEd04P1NGUh0GEeM05iNGP1OGel0HF5Q
061PH01SHf<0IFEU06MWI`1YJFT0Kfm_075aL@1cLg<0MGEe07UiN@1lO7`0N7Qh07alO080Ng]k00l0
NGUi07MgM`1eMGD0M7Ad071`L01TI6@0CTi>04M7A`0o?cl0>CTi03De=@0a<C40;Rh^02`/;00Z:RX0
0P0Y:BT202PX:0D09bLW300V9RH01`0U9BD09RHV02HV9P0V9RH09BDU02HV9P0U9BD0100V9RH00`0U
9BD09RHV0=7=Z@030=7=Z@000`3AcJT;02HV9P040?ooo`0V9RH09RHV02LW9`H09RHV00<09bLW02HV
9P0W9bL0100W9bL00`0X:2P09bLW02PX:00202TY:@0C02XZ:P0[:b/0;2`/02d];@0^;Rh0<C4a03@d
=00f=SH0>SXj03`l?00o?cl0@d=304M7A`18B4P0Bd];051@D01BDU80E5AD05QHF00205YJFP80Fe]K
0180GemO061PH01QHF40HV9R06=SH`1QHF40H61P06=SH`1PH600HF5Q05mOG`1PH600GEeM05mOG`1P
H600GemO065QH@1RHV8206ATI080IfMW00P0JVYZ06a/K01_Kfl0LG5a07=cL`1hN7P0Ng]k07UiN@<0
NWYj0P1iNGT207MgM`0;07EeM@1[Jf/0GEeM04i>CP11@D40?3`l03Lg=`0b<S80;Bd]02`/;00[:b/0
0P0Y:BT202PX:0H09bLW400V9RH202DU9@D09RHV103AcJT000<0dLfY00<09BDU02HV9P0V9RH0400V
9RH302LW9`0302HV9P0W9bL09bLW00<09bLW0`0X:2P04P0Y:BT0:RXZ02/[:`0];Bd0;Rh^034a<@0d
=3@0=SHf03Ti>@0l?3`0?clo04A4A015ADD0BTY:04a<C01@D500E5AD05IFEP80FUYJ00<0G5aL061P
H01RHV800`1SHf<206IVIP0306MWI`1YJFT0IVIV0080IfMW0P1UIFD0101TI6@0HV9R06=SH`1SHf<3
061PH00:069RHP1SHf<0H61P06=SH`1UIFD0J6QX06YZJP1[Jf/0KFe]06m_K`80Lg=c0P1gMgL0101h
N7P0Ng]k07YjNP1kNg/207YjNP0>07]kN`1gMgL0M7Ad06i^KP1HF5P0B4Q80451@@0i>CT0=3@d02l_
;`0];Bd0:b/[02XZ:P0Y:BT302PX:0<09bLW00<09RHV02LW9`0W9bL04P0V9RH202DU9@0302HV9P3A
cJT0dLfY0080dLfY00030=7=ZA809RHV0P0W9bL00`0V9RH09bLW02LW9`0302LW9`<0:2PX0P0Y:BT0
4P0Z:RX0;2`/02h^;P0`<300<S8b03Hf=P0k>c/0?Cdm0410@011@D40ADE504U9B@1<C4`0CTi>055A
D@1EEED0F5QH05]KF`80H61P00L0Hf=S06MWI`1WIfL0IfMW06QXJ01ZJVX0Jf][0080JVYZ00@0Jf][
06a/K01/K6`0KFe]0P1[Jf/00`1YJFT0J6QX06IVIP0206IVIP03069RHP1SHf<0Hf=S0080Hf=S01d0
HV9R06=SH`1VIVH0IfMW06QXJ01ZJVX0K6a/06i^KP1`L700Lg=c07AdM01eMGD0MWIf07QhN01jNWX0
O7al07YjNP1kNg/0NWYj07]kN`1fMWH0LG5a06MWI`1FEUH0ADE503`l?00f=SH0<S8b02h^;P0202/[
:`0402TY:@0X:2P0:2PX02PX:0D09bLW2@0V9RH00`3oool09RHV02HV9P0902HV9P@0dLfY00030=7=
ZA809RHV1`0W9bL00`0X:2P09bLW02PX:00202TY:@0G02/[:`0];Bd0;bl_034a<@0d=3@0>CTi03dm
?@11@D40ADE504M7A`19BDT0C4a<04i>CP1BDU80EEEE05QHF01JFUX0G5aL061PH01SHf<0IfMW06UY
J@1[Jf/00P1/K6`0101]KFd0KVi^079bLP1_Kfl2071`L004075aL@1`L700Lg=c079bLP80L71`0P1/
K6`00`1ZJVX0J6QX06IVIP0206ATI00606IVIP1UIFD0Hf=S06ATI01VIVH0IfMW0P1VIVH206QXJ004
06UYJ@1^KVh0Kfm_07=cL`80MgMg01<0N7Qh07YjNP1jNWX0OGem07]kN`1mOGd0Ng]k07UiN@1dM7@0
L71`069RHP1<C4`0?clo03/k>`0d=3@0;bl_02d];@0[:b/0:BTY0080:2PX100W9bL:02HV9P030?oo
o`0V9RH09RHV00D09RHV00@09BDU02HV9P0V9RH09RHV103AcJT000<0dLfY3P0V9RH01@0W9bL09RHV
02LW9`0W9bL09RHV00D09bLW0`0X:2P03`0Y:BT0:RXZ02/[:`0];Bd0;bl_038b<P0g=cL0>SXj03hn
?P14A4@0BDU904e=C@1?Cdl0DE5A05EEE@0205QHF00M05YJFP1NGUh0GemO06=SH`1TI6@0IfMW06UY
J@1]KFd0LG5a07=cL`1dM7@0MWIf07AdM01fMWH0MGEe07IfMP1iNGT0MGEe07IfMP1dM7@0Lg=c07If
MP1dM7@0MGEe06m_K`1`L700KVi^06e]K@1/K6`00P1ZJVX0101WIfL0J6QX06IVIP1TI6@206EUI@03
06ATI01XJ6P0J6QX0080JVYZ00<0KFe]06m_K`1`L7000P1dM7@0101gMgL0NWYj07]kN`1jNWX307al
O00;07YjNP1gMgL0M7Ad06][J`1CDe<0AdM703dm?@0f=SH0<S8b02d];@0[:b/00P0Y:BT00`0W9bL0
:2PX02LW9`0302LW9`809RHV00<09bLW02HV9P0V9RH00`0V9RH00`3oool09RHV02HV9P0502HV9P04
02DU9@0V9RH09RHV02DU9@@0dLfY00030=7=Z@809RHV00<09BDU02HV9P0V9RH01P0V9RH00`3oool0
9RHV02HV9P0202LW9`0302HV9P0W9bL09bLW00@09bLW0P0X:2P202TY:@0[02XZ:P0[:b/0;Bd]02h^
;P0b<S80=SHf03Xj>P0o?cl0@d=304U9B@1>CTh0DU9B05EEE@1HF5P0Fe]K05iNGP1OGel0GUiN069R
HP1TI6@0IVIV06MWI`1[Jf/0Kfm_075aL@1cLg<0M7Ad07QhN01lO7`0Ng]k07emO@1lO7`0NWYj07]k
N`1hN7P0NGUi07QhN01fMWH0N7Qh07IfMP1eMGD0MWIf07=cL`02075aL@80KVi^00H0KFe]06][J`1Z
JVX0J6QX06IVIP1WIfL206EUI@0N06ATI01WIfL0J6QX06UYJ@1[Jf/0KFe]06m_K`1aLG40LW9b07Ee
M@1fMWH0N7Qh07MgM`1jNWX0O7al07]kN`1mOGd0O7al07UiN@1dM7@0Jf][05]KF`18B4P0?3`l03Ph
>00a<C40;Bd]02/[:`0Z:RX0:BTY0P0X:2P402LW9`809RHV00<09bLW02HV9P0V9RH00P0V9RH00`3o
ool09RHV02HV9P0902HV9P@0dLfY00030=7=Z@<09RHV00<09BDU02HV9P0V9RH01@0V9RH00`3oool0
9RHV02LW9`0202HV9P@09bLW00D0:2PX02LW9`0W9bL0:2PX02TY:@0202XZ:P0A02/[:`0];Bd0<30`
03@d=00g=cL0>SXj03lo?`16ATH0BDU904m?C`1DE5@0FEUI05YJFP1PH600HV9R06IVIP1UIFD00P1W
IfL01`1YJFT0JVYZ06e]K@1`L700LG5a07IfMP1gMgL00P1kNg/01@1oOgl0OWin07moO`21PH40P820
0080Ogmo00T0Ng]k07inOP1nOWh0OWin07emO@1iNGT0O7al07YjNP1gMgL00`1dM7@00`1aLG40KVi^
06i^KP0306][J`0606QXJ01YJFT0IfMW06IVIP1XJ6P0JFUY0`1[Jf/00`1_Kfl0L71`075aL@0207Ee
M@80MgMg00@0NWYj07UiN@1kNg/0OGem0P1jNWX02P1eMGD0Kfm_069RHP1;Bd/0@D5103Ph>00b<S80
;Rh^02/[:`0Z:RX202PX:0@09bLW0`0V9RH202LW9`809RHV00<0oooo02HV9P0V9RH02@0V9RH40=7=
Z@000`3AcJT00`0U9BD09RHV02HV9P0802HV9P040?ooo`0W9bL09bLW02HV9PD09bLW0P0X:2P302TY
:@0C02/[:`0/;2`0;Rh^030`<00c<c<0=cLg03dm?@0o?cl0ATI604a<C01@D500E5AD05UIF@1MGEd0
HV9R06EUI@1YJFT0Jf][06a/K004075aL@80M7Ad00L0MgMg07UiN@1kNg/0OGem07inOP20P800Ogmo
00<0Q8B400D0Ph>308F5Q@20P800PX:207moO`020820P00307moO`1nOWh0OWin0080NWYj0P1iNGT2
07AdM00607=cL`1aLG40L71`06m_K`1]KFd0K6a/1@1ZJVX02@1[Jf/0K6a/06i^KP1/K6`0KFe]071`
L01aLG40M7Ad07EeM@0207IfMP0?07UiN@1kNg/0Ng]k07YjNP1iNGT0MWIf071`L01XJ6P0EEEE04=3
@`0j>SX0<c<c02l_;`0[:b/0:RXZ0080:2PX1`0W9bL302HV9P030?ooo`0V9RH09RHV00T09RHV103A
cJT000<0dLfY2`0V9RH00`3oool09RHV02HV9P0502LW9`@0:2PX01@0:BTY02/[:`0/;2`0;Rh^034a
<@0e=CD0>SXj03dm?@12@T80AdM704a<C01ADE40E5AD05YJFP1LG5`0H61P06IVIP1YJFT0KFe]079b
LP80Lg=c00<0NWYj07]kN`1hN7P00P1iNGT03`1hN7P0NWYj07emO@20P800PX:208>3P`25QHD0QXJ6
08F5Q@27QhL0RHV908N7Q`28R8P0QhN708F5Q@0208B4Q00608>3P`21PH40PH610820P01oOgl0P820
0P1kNg/00`1iNGT0MgMg07QhN00207=cL`03075aL@1_Kfl0KFe]0080Jf][00@0KFe]06][J`1[Jf/0
K6a/0P1]KFd05P1^KVh0KFe]071`L01aLG40Lg=c079bLP1dM7@0MWIf07UiN@1gMgL0NGUi07alO01i
NGT0MWIf079bLP1]KFd0EeMG04E5A@0j>SX0=CDe02l_;`0[:b/202TY:@<0:2PX0`0W9bL402HV9P03
0?ooo`0V9RH09RHV00P09RHV00<09BDU0=7=Z@3AcJT00P3AcJT000<0dLfY2P0V9RH0100W9bL0oooo
02HV9P0V9RH502LW9`80:2PX0280:BTY02XZ:P0Z:RX0;2`/02d];@0a<C40=CDe03Ph>00n?Sh0@d=3
04Q8B01;Bd/0Cdm?05IFEP1GEeL0G5aL061PH01UIFD0J6QX06][J`1`L700MWIf07MgM`1hN7P0O7al
0820P01nOWh0P82007moO`1nOWh0P8200861P@23Ph<0Q8B40P27QhL03@29RHT0QXJ608Z:RP28R8P0
Rh^;08V9R@28R8P0RHV908R8R026QXH0QHF508J6QP23Ph<00P22PX820861P@0=0820P01nOWh0Ng]k
07UiN@1gMgL0MWIf07=cL`1aLG40KFe]06i^KP1]KFd0K6a/06YZJP0206a/K00306][J`1]KFd0Kfm_
00<0KVi^01@0L71`079bLP1bLW80LG5a07AdM01fMWH0MgMg07UiN@1jNWX0N7Qh07IfMP1cLg<0J6QX
059BDP11@D40>SXj03<c<`0^;Rh0:RXZ02TY:@80:2PX1@0W9bL302HV9P030?ooo`0V9RH09RHV00L0
9RHV00<09BDU02HV9P3AcJT00`3AcJT000<0dLfY2`0V9RH00`3oool09RHV02HV9P0402LW9`<0:2PX
01X0:RXZ02/[:`0];Bd0;Rh^038b<P0f=SH0>c/k03lo?`17AdL0BTY:04m?C`1CDe<0EUIF05aLG01N
GUh0HF5Q06ATI01VIVH0JVYZ06a/K01bLW80MGEe07UiN@1nOWh0PX:208F5Q@80QXJ600P0R8R808F5
Q@26QXH0QHF508N7Q`26QXH0RXZ:08N7Q`80RHV900P0Rh^;08b<S02;Rh/0SXj>08n?S`2>SXh0SHf=
08n?S`80RXZ:00@0RHV908J6QP25QHD0QXJ60P24Q8@01P23Ph<0P8200820P01iNGT0NWYj07IfMP80
MGEe00H0L71`06m_K`1/K6`0K6a/06e]K@1ZJVX206a/K00606][J`1^KVh0K6a/06e]K@1[Jf/0L71`
0P1_Kfl01P1bLW80L71`07=cL`1cLg<0MgMg07QhN080MWIf00T0LG5a06YZJP1CDe<0AdM703Ti>@0c
<c<0;Bd]02/[:`0Y:BT00`0X:2P01P0W9bL09RHV02HV9P0W9bL09RHV02LW9`/09RHV00<09BDU0=7=
Z@3AcJT00P3AcJT000<0dLfY200V9RH0100W9bL09RHV02HV9P3oool602LW9`0K02PX:00Y:BT0:BTY
02/[:`0];Bd0;bl_034a<@0g=cL0?Cdm04A4A018B4P0Cdm?05=CD`1HF5P0G5aL05iNGP1PH600HV9R
06EUI@1VIVH0JVYZ06a/K01^KVh0LW9b07MgM`1jNWX0PH610080QHF500P0RHV908b<S02=SHd0SHf=
08n?S`2:RXX0Rh^;08Z:RP80RHV900D0RXZ:08b<S02;Rh/0RXZ:08b<S002092@T00408n?S`2=SHd0
T92@092@T080S8b<00<0SHf=08b<S027QhL00P27QhL02`26QXH0Q8B408:2PP24Q8@0Ogmo07emO@1i
NGT0MGEe079bLP1`L700KVi^00@0K6a/00<0JVYZ06][J`1YJFT00P1/K6`206][J`0306a/K01_Kfl0
Kfm_0080L71`00l0LW9b07=cL`1bLW80N7Qh07UiN@1fMWH0Lg=c06YZJP1IFET0A4A403Xj>P0b<S80
;Rh^02/[:`0Y:BT00`0X:2P302LW9`T09RHV00<09BDU02HV9P0V9RH00P0V9RH40=7=Z@000`3AcJT;
02HV9P030?ooo`0W9bL09bLW00<09bLW0180:2PX02TY:@0Y:BT0:RXZ02/[:`0^;Rh0<S8b03Hf=P0l
?3`0ADE504a<C01BDU80F5QH05iNGP1TI6@0IVIV06QXJ01YJFT206YZJP0=06][J`1/K6`0KFe]06m_
K`1cLg<0N7Qh07]kN`20P800QhN708Z:RP2>SXh0S8b<092@T00209>CT`80TY:B00T0TI6A08n?S`2=
SHd0SXj>092@T02?Shl0TI6A09:BTP2ATI400P2BTY82096AT@0409>CT`2@T900TI6A08j>SP80Shn?
00@0Rh^;08V9R@28R8P0QXJ60`27QhL208>3P`0407emO@1jNWX0NGUi07EeM@<0KVi^00D0KFe]06i^
KP1[Jf/0Jf][06YZJP0206UYJ@80JVYZ00L0K6a/06e]K@1^KVh0KVi^071`L01^KVh0L71`0080M7Ad
00`0MWIf07EeM@1`L700JVYZ05]KF`13@d<0>3Ph03<c<`0^;Rh0:RXZ02TY:@0X:2P302LW9`l09RHV
103AcJT000<0dLfY2P0V9RH302LW9`0302PX:00W9bL09bLW0080:2PX0100:BTY02XZ:P0[:b/0;Rh^
030`<00f=SH0?3`l04E5A@1<C4`0EUIF05UIF@1TI6@0JFUY06i^KP1aLG40LW9b0P1cLg<05@1dM7@0
LW9b07=cL`1bLW80M7Ad07EeM@1hN7P0OWin08:2PP28R8P0RXZ:08^;R`2?Shl0T92@09NGU`2DU9@0
VIVI09^KV`2HV9P0VIVI09>CT`03092@T006096AT@2DU9@0Ti>C09JFUP2DU9@0Ti>C102FUYH209BD
U00309>CT`2BTY80TI6A0080SHf=00d0R8R808V9R@29RHT0Q8B408F5Q@22PX80OGem07alO01jNWX0
LW9b071`L01^KVh0KFe]00<0Jf][0P1YJFT0101ZJVX0JFUY06YZJP1YJFT206][J`0C06a/K01]KFd0
K6a/06i^KP1_Kfl0LG5a07IfMP1dM7@0L71`06m_K`1ZJVX0De=C0451@@0i>CT0<C4a02d];@0Z:RX0
:BTY02PX:00402LW9`0302HV9P3oool09RHV00X09RHV103AcJT000<0dLfY2@0V9RH602LW9`<0:2PX
00l0:BTY02XZ:P0];Bd0;bl_03@d=00k>c/0?clo04Y:BP1BDU80FEUI05mOG`1[Jf/0L71`07=cL`1f
MWH00`1jNWX207UiN@80N7Qh00@0MGEe07IfMP1iNGT0OGem0P26QXH01@29RHT0SHf=09:BTP2ATI40
Ti>C0080V9RH0P2JVYX02`2LW9`0Vi^K09NGU`2HV9P0UYJF09BDU02EUID0UYJF09NGU`2EUID0Ti>C
0080UIFE00H0V9RH09NGU`2MWId0V9RH09NGU`2CTi<3092@T00608j>SP2;Rh/0RHV908R8R029RHT0
QXJ60P22PX80501mOGd0Ng]k07EeM@1cLg<0KVi^06e]K@1/K6`0JVYZ06UYJ@1ZJVX0JFUY06a/K01Z
JVX0JFUY06QXJ01YJFT0Jf][06e]K@1ZJVX0Jf][0P1]KFd206m_K`09071`L01^KVh0KFe]06IVIP1;
Bd/0?Shn03Hf=P0_;bl0;2`/0080:BTY0P0X:2P302LW9`030?ooo`0V9RH09RHV00T09RHV103AcJT0
00<0dLfY2@0V9RH602LW9`0C02PX:00Y:BT0:BTY02XZ:P0/;2`0;Rh^038b<P0h>3P0@D5104I6AP1@
D500FEUI069RHP1XJ6P0L71`07QhN01nOWh0P82008:2PP0208B4Q080Ph>30P21PH400`1oOgl0P820
07moO`0208:2PP0:08N7Q`2:RXX0Rh^;08Z:RP2CTi<0TI6A09JFUP2JVYX0W9bL09fMW@80WYjN00P0
WIfM09bLW02KVi/0UiNG09JFUP2GUiL0VIVI09RHV080VIVI00T0V9RH09ZJVP2FUYH0Vi^K09fMW@2H
V9P0UiNG09JFUP2DU9@00P2BTY804P2?Shl0SXj>08j>SP29RHT0RXZ:08V9R@28R8P0QHF50820P01l
O7`0MgMg07AdM01cLg<0LW9b06m_K`1/K6`0KFe]06][J`<0JVYZ00<0Jf][06QXJ01XJ6P00P1[Jf/0
0`1YJFT0Jf][06YZJP0406e]K@0906][J`1YJFT0HF5Q04Y:BP0l?3`0=3@d02l_;`0[:b/0:BTY0080
:2PX0`0W9bL00`3oool09bLW02HV9P0902HV9P@0dLfY00030=7=Z@L09RHV00D09bLW02HV9P0V9RH0
9bLW0?ooo`0202LW9`<0:2PX01H0:RXZ02`/;00];Bd0<30`03Hf=P0m?Cd0ADE504a<C01FEUH0GemO
06YZJP1]KFd0MGEe07inOP24Q8@0R8R808^;R`2:RXX0Shn?08f=S@2<S8`0Rh^;0P2:RXX00`29RHT0
QXJ608J6QP0208N7Q`<0R8R800l0RXZ:092@T02DU9@0U9BD09JFUP2KVi/0XJ6Q0:2PX02VYZH0XJ6Q
0:2PX02NWYh0X:2P09^KV`2HV9P0102KVi/01@2JVYX0Vi^K09VIV@2MWId0WYjN0080VYZJ00<0V9RH
09NGU`2DU9@00P2BTY8208n?S`<0S8b<00X0RHV908F5Q@23Ph<0OGem07UiN@1gMgL0Lg=c079bLP1c
Lg<0Jf][0P1/K6`00`1[Jf/0JVYZ06YZJP0206UYJ@0306QXJ01YJFT0J6QX0080J6QX00d0JVYZ06a/
K01]KFd0KFe]06a/K01ZJVX0J6QX05mOG`15ADD0>SXj03@d=00];Bd0:b/[0080:2PX0`0W9bL00`3o
ool09bLW02HV9P0902HV9P@0dLfY00030=7=Z@<09RHV00<09bLW02HV9P0V9RH00P0V9RH302LW9`0U
0?ooo`0X:2P09bLW02LW9`0X:2P0:BTY02XZ:P0];Bd0<30`03@d=00k>c/0@T9204a<C01CDe<0Fe]K
06IVIP1`L700M7Ad07moO`24Q8@0RXZ:08f=S@2BTY80U9BD09JFUP2JVYX0UiNG09RHV02GUiL0TY:B
096AT@2@T900S8b<08V9R@2:RXX0RHV908N7Q`0208R8R00J08f=S@2>SXh0TY:B09RHV02KVi/0WYjN
09nOW`2TY:@0Zj^[0:RXZ02TY:@0YZJV0::RXP2QXJ40W9bL09fMW@2KVi/0W9bL09nOW`2MWId0Vi^K
09fMW@2KVi/0WinO09ZJVP2KVi/209VIV@0N09NGU`2EUID0U9BD09:BTP2=SHd0Shn?08^;R`2<S8`0
RHV908R8R025QHD0PH6107inOP1iNGT0MgMg07IfMP1aLG40LW9b06e]K@1^KVh0JVYZ06UYJ@1ZJVX0
JFUY06YZJP1YJFT0IfMW06IVIP1UIFD0JFUY0P1XJ6P02`1/K6`0Jf][06YZJP1VIVH0IFEU05]KF`13
@d<0>CTi034a<@0/;2`0:BTY0080:2PX0P0W9bL00`3oool09bLW02LW9`0902HV9P@0dLfY00030=7=
Z@0302DU9@0V9RH09RHV00@09RHV100W9bL05@3oool0:2PX02PX:00W9bL0:BTY02XZ:P0[:b/0;Rh^
038b<P0h>3P0@41004Q8B01BDU80FUYJ06ATI01]KFd0Lg=c07YjNP21PH40RHV9092@T00209FEU@06
09ZJVP2KVi/0XJ6Q0:BTY02RXZ80XJ6Q0P2MWId0102IVIT0UYJF09>CT`2>SXh208f=S@0<08Z:RP29
RHT0Rh^;08f=S@2@T900UYJF09VIV@2OWil0XZ:R0:BTY02WYjL0ZZZZ0`2XZ:P0502WYjL0Xj>S0:2P
X02OWil0WIfM09^KV`2LW9`0X:2P09fMW@2OWil0X:2P09fMW@2OWil0WYjN09fMW@2JVYX0W9bL09RH
V02CTi<0U9BD0P2ATI402`2<S8`0Shn?08V9R@2:RXX0QhN708>3P`20P800O7al07YjNP1fMWH0MgMg
0080LG5a01L0KVi^06a/K01YJFT0JVYZ06][J`1XJ6P0IfMW06=SH`1VIVH0I6AT06QXJ01WIfL0JFUY
06e]K@1/K6`0JFUY06QXJ01SHf<0DU9B0410@00f=SH0;bl_02/[:`0202TY:@809bLW00<0oooo02LW
9`0V9RH02@0V9RH40=7=Z@000`3AcJT502HV9P0302LW9`0V9RH09RHV00809bLW00<09RHV0?ooo`0W
9bL00P0X:2P06@0Y:BT0:RXZ02`/;00`<300=CDe03/k>`13@d<0CDe=05ADE01NGUh0J6QX075aL@1i
NGT0OWin08F5Q@2<S8`0Shn?09FEU@2IVIT0WinO0:6QX@2TY:@0YJFU0:NWY`2ZZZX00P2UYJD0202S
Xj<0WIfM09ZJVP2IVIT0UYJF09:BTP2>SXh0Rh^;0P2>SXh01P2=SHd0TY:B09ZJVP2MWId0X:2P0:FU
Y@80YZJV01@0ZZZZ0:^[Z`2ZZZX0Zj^[0:ZZZP2WYjL0XZ:R0:6QX@2OWil0X:2P09fMW@2QXJ40WinO
09jNWP2KVi/0WIfM0:JVYP2RXZ80X:2P09ZJVP<0UiNG00D0U9BD09:BTP2CTi<0Shn?092@T00208b<
S080QXJ600@0Ph>307inOP1jNWX0N7Qh0P1cLg<00`1/K6`0KVi^06a/K00306][J`0606EUI@1VIVH0
IVIV06IVIP1TI6@0IfMW0P1XJ6P02P1ZJVX0JFUY06QXJ01UIFD0GEeM04Y:BP0j>SX0<c<c02d];@0Z
:RX202PX:00402LW9`3oool09bLW02LW9`T09RHV103AcJT000<0dLfY200V9RH302LW9`0d0?ooo`0W
9bL0:2PX02TY:@0Z:RX0:b/[02h^;P0b<S80>SXj03lo?`17AdL0DE5A05aLG01TI6@0Jf][07=cL`1n
OWh0Q8B408^;R`2ATI40U9BD09fMW@2OWil0XJ6Q0:JVYP2WYjL0[Jf]0:j^[P2_[jl0[Zj^0;2`/02[
Zj/0ZZZZ0:>SX`2OWil0WIfM09VIV@2DU9@0UIFE09BDU02?Shl0Ti>C096AT@2EUID0V9RH09nOW`2S
Xj<0Y:BT0:RXZ02[Zj/0ZZZZ0:^[Z`80[Zj^00@0[:b/0:VYZ@2VYZH0YJFU0P2RXZ820:2PX00309jN
WP2QXJ40WYjN0080X:2P00X0WYjN09fMW@2MWId0W9bL09RHV02FUYH0VIVI09NGU`2DU9@0TI6A0P2?
Shl02P2:RXX0R8R808V9R@26QXH0P82007alO01iNGT0MgMg07AdM01_Kfl206e]K@0306a/K01ZJVX0
IfMW0080IFEU01<0IVIV06ATI01UIFD0JFUY06QXJ01[Jf/0JFUY06MWI`1VIVH0H61P05UIF@11@D40
=SHf02l_;`0/;2`0:BTY02PX:00W9bL0oooo00809bLW2@0V9RH40=7=Z@000`3AcJT602HV9P0302LW
9`0V9RH09RHV00809bLW01d0oooo02PX:00X:2P0:BTY02/[:`0];Bd0<30`03De=@0l?3`0A4A404a<
C01EEED0GemO06IVIP1aLG40Ng]k08B4Q028R8P0T92@09FEU@2KVi/0X:2P0::RXP2[Zj/0[Jf]0:j^
[P2a/K40/;2`0;>c/`020;Fe]@0:0;>c/`2d];@0[jn_0:b/[02XZ:P0YJFU0:6QX@2MWId0Vi^K09FE
U@80UYJF00<0Ti>C09NGU`2JVYX00P2PX:001@2UYJD0YjNW0:VYZ@2[Zj/0[Zj^0080/;2`00D0[Zj^
0:ZZZP2YZJT0YZJV0:FUY@020::RXP0309fMW@2PX:00WIfM0080XZ:R00D0X:2P0:6QX@2MWId0WinO
0:2PX00209fMW@0?09^KV`2HV9P0UiNG09:BTP2?Shl0TI6A08j>SP29RHT0R8R808F5Q@22PX80Ogmo
07YjNP1gMgL0MGEe0080LW9b00H0Jf][06a/K01XJ6P0IVIV06=SH`1TI6@306IVIP0<06MWI`1VIVH0
J6QX06IVIP1UIFD0Hf=S05iNGP1?Cdl0?3`l03<c<`0^;Rh0:RXZ0P0X:2P302LW9`T09RHV103AcJT0
00<0dLfY0P0V9RH01@0W9bL09RHV02HV9P0W9bL09RHV00@09bLW01`0oooo02PX:00X:2P0:BTY02/[
:`0^;Rh0<S8b03Ph>011@D40ATI6055AD@1IFET0Hf=S06][J`1cLg<0O7al08B4Q02:RXX0Ti>C09bL
W02MWId0XZ:R0:ZZZP2/[:`0[Zj^0;>c/`2e]KD0][Jf0P2g]kL01P2j^[X0^KVi0;Zj^P2k^k/0]kNg
0;2`/080[jn_00@0Y:BT0:2PX02NWYh0VIVI0P2HV9P07P2IVIT0Vi^K09bLW02NWYh0WinO0:BTY02V
YZH0Zj^[0:j^[P2][Jd0[Zj^0;:b/P2f][H0[Jf]0:b/[02ZZZX0YjNW0:>SX`2QXJ40WYjN0::RXP2P
X:00XZ:R09nOW`2QXJ40X:2P0::RXP2MWId0X:2P0::RXP80WIfM01<0W9bL09RHV02EUID0Ti>C092@
T02;Rh/0T92@08^;R`25QHD0PX:207moO`1kNg/0MgMg07AdM01cLg<0LG5a06e]K@1[Jf/0IfMW0080
IVIV0140IFEU06MWI`1TI6@0IVIV06EUI@1VIVH0I6AT06EUI@1TI6@0H61P05YJFP15ADD0=cLg038b
<P0/;2`0:RXZ02PX:00402LW9`0302HV9P0W9bL09RHV00@09RHV00<09BDU0=7=Z@3AcJT00P3AcJT0
00<0dLfY1P0V9RH01P0W9bL09RHV02LW9`0W9bL0:2PX0?ooo`80:2PX01L0:RXZ02`/;00`<300=3@d
03/k>`14A4@0BTY:05=CD`1LG5`0IFEU06][J`1dM7@0OWin08N7Q`2<S8`0UYJF09fMW@2SXj<0YjNW
0:f][@2^[Zh0][Jf0;Rh^0020;bl_00S0;Rh^02k^k/0_;bl0;no_`2n_[h0^k^k0;bl_02k^k/0^KVi
0;>c/`2^[Zh0ZZZZ0:JVYP2RXZ80WinO09bLW02KVi/0VIVI09^KV`2JVYX0WIfM09nOW`2PX:00YZJV
0:^[Z`2_[jl0/[:b0;6a/@2e]KD0/K6a0;:b/P2`/;00Zj^[0:NWY`2RXZ800`2QXJ400`2OWil0Y:BT
09nOW`030::RXP0F0:BTY02UYJD0XJ6Q0:6QX@2KVi/0VIVI09NGU`2EUID0U9BD08n?S`2@T900S8b<
08Z:RP26QXH0PX:207inOP1jNWX0MgMg07EeM@1bLW80L71`06][J`80JVYZ00<0IfMW06=SH`1VIVH0
0`1TI6@03@1RHV80I6AT06ATI01UIFD0HF5Q05eMG@1@D500?3`l03De=@0^;Rh0:RXZ02TY:@0X:2P0
0P0W9bL902HV9P@0dLfY00030=7=Z@@09RHV0`0W9bL0100V9RH09bLW02LW9`0W9bL202PX:00[02TY
:@0Z:RX0;Bd]038b<P0f=SH0?Shn04I6AP1>CTh0E5AD05mOG`1WIfL0L71`07QhN01oOgl0RHV9092@
T02EUID0WYjN0:BTY02XZ:P0/;2`0;Fe]@2f][H0^KVi0;fm_@2n_[h0_;bl0;^k^`2o_kl0`<300;no
_`32`/80a<C40;jn_P2m_Kd0_[jn0;Zj^P2i^KT0/[:b0:b/[02XZ:P0Y:BT0:6QX@0209^KV`0>09VI
V@2HV9P0Vi^K09nOW`2SXj<0YJFU0:b/[02^[Zh0/k>c0;:b/P2g]kL0]KFe0;Bd]02_[jl20:^[Z`0@
0:JVYP2UYJD0YZJV0:6QX@2PX:00Y:BT0::RXP2OWil0Xj>S0:BTY02OWil0YZJV0:>SX`2PX:00WIfM
09ZJVP80UiNG01@0UYJF09BDU02>SXh0SXj>08Z:RP29RHT0Ph>30820P01mOGd0N7Qh07IfMP1cLg<0
Kfm_06i^KP1/K6`0IfMW06IVIP1UIFD0Hf=S065QH@<0HV9R00/0I6AT069RHP1RHV80GUiN05UIF@13
@d<0>3Ph034a<@0/;2`0:BTY0?ooo`0302LW9`P09RHV103AcJT000<0dLfY1`0V9RH402LW9`80:2PX
01P0:BTY02/[:`0^;Rh0<c<c03Ph>010@400B4Q8051@D01IFET0HV9R06a/K01cLg<0NWYj08F5Q@28
R8P0T92@09VIV@2NWYh0YZJV0:ZZZP2`/;00]KFe0;bl_02n_[h20;fm_@040<71`@32`/80`L710<71
`@80`/;20P35aLD07036a/H0aLG50<K6aP32`/80`<300;Zj^P2f][H0[jn_0:ZZZP2UYJD0XJ6Q0:2P
X02LW9`0WIfM09jNWP2PX:00XJ6Q0:JVYP2YZJT0[Jf]0;2`/02^[Zh0/;2`0;6a/@2c/k<0/;2`0:n_
[`2a/K420:VYZ@0?0:FUY@2VYZH0XZ:R0:>SX`2QXJ40XZ:R0:2PX02SXj<0Y:BT0:6QX@2TY:@0XJ6Q
09^KV`2JVYX0Vi^K0080U9BD00h0TY:B096AT@2=SHd0RXZ:08J6QP25QHD0PX:207inOP1iNGT0MWIf
07=cL`1bLW80L71`06YZJP80IFEU0100Hf=S069RHP1QHF40H61P065QH@1PH600HV9R061PH01OGel0
Fe]K051@D00o?cl0=3@d02h^;P0Z:RX0oooo0`0W9bL802HV9P@0dLfY00030=7=Z@L09RHV100W9bL2
02PX:00H02XZ:P0/;2`0<30`03Hf=P0j>SX0@D5104];B`1?Cdl0FUYJ06=SH`1/K6`0Lg=c07emO@23
Ph<0SHf=096AT@2HV9P0Vi^K0:JVYP2/[:`0/K6a0;Jf]P2k^k/0_kno0P30`<006033`l<0`<300<;2
`P37alL0`/;20<30`03;bl/0b/[:0<W9b@3:b/X0bl_;0<c<c039bLT0a/K60<71`@2j^[X0^;Rh0;2`
/02YZJT0YJFU0:>SX`2QXJ40WinO09jNWP80XJ6Q00P0Xj>S0:RXZ02XZ:P0Zj^[0:j^[P2a/K40/;2`
0:j^[P80];Bd00X0]KFe0:b/[02YZJT0YjNW0:BTY02UYJD0XZ:R0:JVYP2RXZ80X:2P0`2RXZ804@2Q
XJ40WinO09fMW@2LW9`0VIVI09JFUP2@T900TI6A08n?S`29RHT0RXZ:08N7Q`23Ph<0PH6107inOP1k
Ng/0N7Qh0080MGEe00@0KVi^06UYJ@1WIfL0I6AT0P1SHf<03P1RHV80GemO061PH01OGel0GUiN05mO
G`1MGEd0EUIF04U9B@0h>3P0<C4a02/[:`3oool0:2PX0P0W9bL0100V9RH09bLW02HV9P0W9bL402HV
9P@0dLfY00030=7=Z@D09RHV1P0W9bL07@0X:2P0:BTY02XZ:P0];Bd0<C4a03Lg=`0l?3`0@d=304e=
C@1CDe<0FUYJ06=SH`1]KFd0M7Ad07emO@24Q8@0Rh^;09>CT`2IVIT0WinO0:BTY02][Jd0[jn_0;Fe
]@2k^k/0_kno0<71`@37alL0aLG50080a<C400D0a/K60<[:bP3;bl/0b/[:0=3@d0020=;BdP0C0=7A
d@3Fe]H0e]KF0=WIf@3=cLd0bl_;0<K6aP2o_kl0]kNg0;>c/`2][Jd0YjNW0:>SX`2QXJ40WinO0:>S
X`2QXJ40Y:BT0:>SX`020:NWY`0:0:VYZ@2^[Zh0[Zj^0;:b/P2c/k<0][Jf0;Fe]@2b/[80[Zj^0:ZZ
ZP80YjNW00<0YJFU0:BTY02OWil00P2OWil06@2RXZ80XJ6Q0:6QX@2PX:00WinO09fMW@2HV9P0UIFE
09BDU02@T900SHf=08^;R`28R8P0QXJ608B4Q025QHD0QXJ607emO@1iNGT0MWIf075aL@1^KVh0JVYZ
06QXJ01TI6@00P1RHV8505mOG`0:05iNGP1IFET0DE5A03dm?@0d=3@0;Bd]0?ooo`0Y:BT09bLW02HV
9P@09bLW100V9RH40=7=Z@000`3AcJT502HV9PD09bLW01h0:2PX0?ooo`0Z:RX0:b/[02h^;P0a<C40
=cLg03dm?@13@d<0CDe=05=CD`1MGEd0Hf=S06YZJP1aLG40N7Qh08B4Q027QhL0SXj>09JFUP2OWil0
YJFU0:ZZZP2`/;00][Jf0;Zj^P2k^k/0`l?30<K6aP37alL30<S8b00A0<c<c03>c/h0c/k>0=7Ad@3E
eMD0d];B0<k>cP3De=@0e]KF0=cLg03De=@0d];B0<g=c@3:b/X0`L710;^k^`2h^;P00P2_[jl03`2X
Z:P0YJFU0::RXP2NWYh0WinO09jNWP2OWil0XJ6Q0:FUY@2XZ:P0[:b/0:j^[P2e]KD0^;Rh0;Vi^@02
0;Bd]0030:j^[P2/[:`0ZZZZ0080YJFU0140X:2P0:6QX@2RXZ80XJ6Q09nOW`2SXj<0XJ6Q0::RXP2O
Wil0WYjN09VIV@2EUID0TY:B092@T02?Shl0S8b<08Z:RP0308F5Q@0807moO`1kNg/0NGUi07AdM01_
Kfl0Jf][06YZJP1WIfL2069RHP03065QH@1MGEd0GemO0080GUiN0P1KFe/01`1FEUH0@d=303De=@0_
;bl0oooo02TY:@0X:2P00`0W9bL602HV9P@0dLfY00030=7=Z@@09RHV1P0W9bL0700X:2P0oooo02XZ
:P0/;2`0;bl_03@d=00j>SX0?clo04E5A@1=CDd0EEEE05eMG@1TI6@0KFe]07=cL`1kNg/0PX:208V9
R@2?Shl0UYJF09fMW@2SXj<0ZJVY0;2`/02f][H0_;bl0;fm_@30`<020<G5a@0K0<k>cP3<c<`0c<c<
0<k>cP3?cll0e=CD0=?Cd`3EeMD0dm?C0=OGe`3Jf]X0gMgM0>;RhP3Shn<0g=cL0=[JfP3Fe]H0d=3@
0<c<c033`l<0_[jn0;Zj^P2e]KD0[:b/0:JVYP2QXJ40WinO0080W9bL00P0Vi^K09fMW@2MWId0Y:BT
0:RXZ02^[Zh0]KFe0;Ng]`80^KVi00d0][Jf0;Bd]02^[Zh0Zj^[0:FUY@2TY:@0Xj>S09nOW`2RXZ80
X:2P0:>SX`2RXZ80Xj>S0080WIfM01T0WinO09^KV`2FUYH0TI6A08j>SP2@T900Rh^;08R8R025QHD0
Ph>307moO`20P800O7al07UiN@1`L700KFe]06][J`1ZJVX0IVIV065QH@1PH600GEeM05]KF`1LG5`0
Fe]K0080FUYJ00L0EUIF04a<C00j>SX0<C4a0?ooo`0Y:BT0:2PX00<09bLW1P0V9RH40=7=Z@000`3A
cJT602HV9P@09bLW01L0:2PX0?ooo`0[:b/0;Bd]030`<00f=SH0>c/k0410@018B4P0Cdm?05ADE01L
G5`0IVIV06a/K01aLG40N7Qh0861P@25QHD0S8b<09FEU@2MWId0X:2P0:FUY@020:j^[P0:0;>c/`2k
^k/0_kno0<;2`P37alL0c<c<0<g=c@3@d=00e=CD0=?Cd`80eMGE01P0emOG0=;BdP3IfMT0e]KF0>?S
h`3Ti>@0h^;R0>CTi03Ogml0gMgM0=[JfP3Fe]H0d=3@0<c<c037alL0_;bl0;>c/`2ZZZX0YjNW0:BT
Y02OWil0VYZJ09^KV`2NWYh209nOW`0509fMW@2VYZH0Zj^[0;6a/@2e]KD00P2i^KT01@2k^k/0^KVi
0;>c/`2[Zj/0ZZZZ0080YJFU0140Xj>S0:6QX@2QXJ40WinO0:2PX02QXJ40WinO09^KV`2LW9`0V9RH
09JFUP2ATI40T92@08n?S`2<S8`0RXZ:08F5Q@020861P@0<07inOP1kNg/0MgMg079bLP1`L700JVYZ
06QXJ01TI6@0H61P05iNGP1MGEd0G5aL0P1IFET0201GEeL0EUIF04i>CP0m?Cd0<S8b0?ooo`0Z:RX0
:2PX0P0W9bL702HV9P@0dLfY00030=7=Z@D09RHV00<09bLW02HV9P0W9bL00P0W9bL0800X:2P0oooo
02/[:`0^;Rh0<S8b03Ph>00m?Cd0@d=304Y:BP1@D500EEEE05YJFP1TI6@0JVYZ075aL@1hN7P0Ogmo
08B4Q02;Rh/0T92@09ZJVP2PX:00Xj>S0:NWY`2_[jl0/k>c0;Ng]`2m_Kd0alO70<?3``39bLT0c/k>
0P3Bd]80203GemL0f][J0=KFeP3Jf]X0fMWI0=_Kf`3MgMd0hn?S0P3UiND0403Xj>P0iNGU0>GUi@3Q
hN40h>3P0=gMg@3EeMD0dm?C0<W9b@2m_Kd0]kNg0:n_[`2YZJT0Y:BT09nOW`2NWYh209^KV`0>09bL
W02MWId0XJ6Q0:JVYP2YZJT0/K6a0;Jf]P2k^k/0_;bl0;^k^`2j^[X0];Bd0:n_[`2[Zj/20:JVYP03
0:BTY02PX:00WYjN0080WinO00@0W9bL09nOW`2LW9`0V9RH0`2DU9@0702>SXh0S8b<08Z:RP26QXH0
Q8B408:2PP21PH40OWin07YjNP1hN7P0Lg=c06i^KP1[Jf/0J6QX06EUI@1OGel0GEeM05YJFP1IFET0
EeMG05ADE01EEED0CDe=04I6AP0d=3@0oooo02`/;00Y:BT402LW9`D09RHV103AcJT000<0dLfY0`0V
9RH0100W9bL09RHV02HV9P0V9RH302LW9`0Y02TY:@3oool0;Bd]02l_;`0c<c<0>SXj0410@014A4@0
Bd];055AD@1GEeL0G5aL06=SH`1ZJVX0Kfm_07MgM`1lO7`0Ph>308N7Q`2>SXh0UIFE09bLW02OWil0
Xj>S0:f][@2_[jl0]KFe0;bl_033`l<0a<C40<c<c03>c/h0d];B0=CDe03Fe]H0fm_K0=cLg03Ng]h0
h>3P0=oOg`3Ph>000P3Ti>@04@3[jn/0i^KV0>KViP3Xj>P0jn_[0>WYj@3Shn<0f][J0=SHf03AdM40
b<S80;jn_P2j^[X0[jn_0:ZZZP2XZ:P0Xj>S0080W9bL0P2JVYX01`2LW9`0XZ:R0:BTY02][Jd0][Jf
0;^k^`2m_Kd00P2k^k/20;Zj^P0=0;Bd]02`/;00ZJVY0:NWY`2RXZ80WinO0:2PX02OWil0WYjN09fM
W@2NWYh0Vi^K09NGU`0209BDU00M08n?S`2<S8`0RXZ:08V9R@26QXH0QHF508B4Q020P800Ng]k07Qh
N01gMgL0LG5a06e]K@1YJFT0IFEU069RHP1PH600GEeM05QHF01FEUH0De=C059BDP1<C4`0BDU903Ti
>@3oool0;Bd]02TY:@0X:2P00P0W9bL602HV9P@0dLfY00030=7=Z@H09RHV0`0W9bL07`0X:2P0:BTY
0?ooo`0];Bd0<30`03Lg=`0m?Cd0@T9204M7A`1>CTh0De=C05QHF01NGUh0I6AT06][J`1_Kfl0MGEe
07moO`24Q8@0QXJ608j>SP2ATI40V9RH09jNWP2SXj<0Z:RX0:VYZ@2a/K40^KVi0<71`@33`l<00P3<
c<`00`3@d=00e]KF0=OGe`020=gMg@090=kNgP3Ogml0hn?S0>CTi03Vi^H0iNGU0>[ZjP3Ti>@0j^[Z
0080jNWY01H0k>c/0>KViP3QhN40fm_K0=WIf@3;bl/0a<C40<;2`P2k^k/0/k>c0:^[Z`2WYjL0Y:BT
09nOW`2KVi/0W9bL09ZJVP2RXZ80YZJV0:RXZ02b/[80][Jf0`2k^k/01P2j^[X0_Kfm0;Rh^02d];@0
/K6a0:f][@80YJFU01d0X:2P09jNWP2NWYh0WIfM09bLW02IVIT0UiNG09ZJVP2EUID0Ti>C092@T02;
Rh/0RHV908N7Q`25QHD0PX:207moO`1lO7`0NWYj07IfMP1bLW80KFe]06][J`1VIVH0HV9R05eMG@1L
G5`0F5QH05IFEP02059BDP0704i>CP1;Bd/0?3`l03<c<`0^;Rh0:RXZ02TY:@0202LW9`H09RHV103A
cJT000<0dLfY100V9RH402LW9`80:2PX0300:BTY0?ooo`0];Bd0<S8b03Ti>@10@400AdM704a<C01B
DU80F5QH05YJFP1NGUh0IFEU06][J`1_Kfl0MgMg07alO022PX80QHF508^;R`2ATI40U9BD09fMW@2O
Wil0Z:RX0:VYZ@2`/;00];Bd0;Vi^@2o_kl0alO70=3@d03Bd]80e=CD0=_Kf`3GemL0fm_K0>3Ph03Q
hN40i>CT0>7Qh@3Ti>@0inOW0>[ZjP3YjNT0kNg]0>_[j`3]kNd20>k^kP150>WYj@3WinL0h>3P0=?C
d`3@d=00b/[:0<?3``30`<00^;Rh0;Bd]02/[:`0YjNW0:6QX@2OWil0WIfM09nOW`2PX:00YjNW0:ZZ
ZP2_[jl0]KFe0;Ng]`2l_;`0^k^k0;Zj^P2l_;`0^k^k0;Jf]P2c/k<0[:b/0:JVYP2TY:@0WYjN0:2P
X02MWId0Vi^K09fMW@2GUiL0UYJF09FEU@2CTi<0TI6A08n?S`2;Rh/0R8R808B4Q022PX80Ogmo07em
O@1iNGT0MgMg07EeM@1_Kfl0Jf][06UYJ@1VIVH0H61P05iNGP1IFET0EUIF05EEE@1BDU80CDe=04Y:
BP13@d<0=CDe02l_;`0[:b/0:2PX00@09bLW100V9RH40=7=Z@000`3AcJT502HV9P@09bLW02X0:2PX
02TY:@3oool0;bl_03@d=00k>c/0@T9204];B`1@D500EUIF05]KF`1NGUh0HV9R06MWI`1[Jf/0LG5a
07EeM@1lO7`0PH6108B4Q028R8P0Shn?09BDU02JVYX0WYjN0:6QX@2VYZH0[:b/0;Fe]@2f][H0_;bl
0<71`@39bLT0d=3@0=CDe03Fe]H0f][J0=SHf03MgMd0g]kN0>CTi03Ph>020>SXj00N0>WYj@3WinL0
j>SX0>WYj@3Zj^X0l?3`0>o_k`3^k^h0jn_[0=oOg`3Lg=`0fMWI0=[JfP3Cdm<0cLg=0<G5a@31`L40
^;Rh0;:b/P2ZZZX0YZJV0:BTY02QXJ40X:2P0:FUY@2WYjL0Z:RX0:j^[P2c/k<0^KVi0P2k^k/0202i
^KT0^k^k0;Ng]`2f][H0]KFe0:f][@2XZ:P0YJFU0P2OWil209fMW@80VIVI0P2DU9@01@2BTY80SXj>
08f=S@2:RXX0QhN70080PX:201@0OGem07YjNP1hN7P0M7Ad079bLP1^KVh0K6a/06IVIP1SHf<0H61P
05aLG01HF5P0E5AD05=CD`1?Cdl0BDU904E5A@0g=cL0;bl_02`/;080:2PX0P0W9bL502HV9P@0dLfY
00030=7=Z@@09RHV0`0W9bL202PX:00Y02TY:@0Z:RX0;2`/02l_;`0e=CD0?Cdm04E5A@1=CDd0De=C
05YJFP1QHF40I6AT06QXJ01[Jf/0KVi^07=cL`1iNGT0O7al0820P022PX80QhN708b<S02CTi<0UYJF
09^KV`2NWYh0Xj>S0:RXZ02a/K40];Bd0;Vi^@2m_Kd0`L710<O7a`3;bl/0dM7A0=?Cd`3Kfm/0fMWI
0=cLg03Rh^800`3UiND20>OWi`040>g]k@3Vi^H0j^[Z0>c/k080kno_00h0j^[Z0>SXj03Rh^80gmoO
0>;RhP3MgMd0f=SH0=3@d03<c<`0`L710;jn_P2b/[80/;2`0:VYZ@80YZJV03P0XJ6Q0:>SX`2UYJD0
ZJVY0:NWY`2b/[80/K6a0;Jf]P2e]KD0^;Rh0;Vi^@2j^[X0^KVi0;Bd]02a/K40ZZZZ0:FUY@2PX:00
WIfM09^KV`2HV9P0UiNG09FEU@2BTY80T92@096AT@2>SXh0Rh^;08V9R@27QhL0PX:20820P01jNWX0
NGUi07EeM@1cLg<0KVi^06a/K01ZJVX0IVIV069RHP1NGUh0FEUI05EEE@1ADE40DU9B04a<C012@T80
oooo030`<00/;2`0:BTY02PX:00W9bL09RHV02LW9`@09RHV103AcJT000<0dLfY0`0V9RH00`0W9bL0
9RHV02HV9P0302LW9`0F02TY:@0Z:RX0;2`/030`<00f=SH0?Cdm04I6AP1>CTh0E5AD05iNGP1UIFD0
J6QX06e]K@1`L700M7Ad07MgM`1iNGT0Ogmo08F5Q@26QXH0R8R808n?S`80Ti>C01@0VYZJ09jNWP2R
XZ80Z:RX0:^[Z`2`/;00][Jf0;^k^`2o_kl0a/K60<S8b03<c<`0c/k>0=7Ad@3Cdm<0fm_K0>3Ph03S
hn<0i>CT0>OWi`80i^KV00D0k>c/0>SXj03YjNT0j^[Z0>k^kP020>g]k@80jNWY0380inOW0>SXj03W
inL0h^;R0=SHf03De=@0c/k>0<K6aP2n_[h0^[Zj0;:b/P2][Jd0ZZZZ0:VYZ@2SXj<0XJ6Q0:>SX`2X
Z:P0YjNW0:^[Z`2_[jl0/k>c0;Fe]@2f][H0^;Rh0;Zj^P2g]kL0][Jf0;6a/@2[Zj/0YZJV0:6QX@2O
Wil0WIfM09RHV02EUID0U9BD09>CT`2?Shl0S8b<08Z:RP2;Rh/0R8R808B4Q021PH40OGem07inOP1i
NGT0LW9b06m_K`80JVYZ00h0IFEU06ATI01PH600FEUI05EEE@1ADE40CDe=04Q8B012@T80oooo034a
<@0];Bd0:RXZ02PX:0809bLW1@0V9RH40=7=Z@000`3AcJT402HV9P@09bLW0P0X:2P0<@0Z:RX0;2`/
030`<00f=SH0?Shn04I6AP1?Cdl0EEEE05mOG`1VIVH0K6a/075aL@1fMWH0N7Qh07]kN`1nOWh0P820
08>3P`26QXH0RXZ:08j>SP2?Shl0Ti>C09JFUP2NWYh0XZ:R0:JVYP2[Zj/0[Zj^0;6a/@2g]kL0_;bl
0<?3``32`/80b<S80<c<c03?cll0dm?C0=SHf03MgMd0hN7Q0>3Ph03Shn<0j>SX0>WYj@3^k^h0kno_
0?3`l03Zj^X00P3/k>`20>g]k@0@0>_[j`3Xj>P0jn_[0>c/k03Ti>@0gMgM0=[JfP3Bd]80bl_;0<C4
a02n_[h0^[Zj0;:b/P2^[Zh0[:b/0:NWY`<0Y:BT00L0YZJV0:NWY`2XZ:P0[Jf]0;Bd]02c/k<0];Bd
0080][Jf00H0]kNg0;Fe]@2`/;00ZZZZ0:BTY02PX:0209^KV`0409VIV@2DU9@0TY:B092@T080Rh^;
01T0RXZ:08N7Q`24Q8@0PH610820P01nOWh0N7Qh07AdM01aLG40KFe]06][J`1VIVH0Hf=S061PH01J
FUX0EEEE059BDP1=CDd0AdM70492@P3oool0<C4a02`/;00Z:RX0:2PX00D09bLW0P0V9RH40=7=Z@00
0`3AcJT01P0V9RH09bLW02HV9P0V9RH09bLW02HV9P809bLW02/0:2PX02TY:@0Z:RX0oooo034a<@0f
=SH0?Cdm04E5A@1?Cdl0EEEE05iNGP1WIfL0JVYZ079bLP1hN7P0Ogmo0820P023Ph<0QHF508V9R@2:
RXX0S8b<092@T02CTi<0U9BD09ZJVP2MWId0XJ6Q0:JVYP2XZ:P0[:b/0;2`/02b/[80]KFe0;bl_02o
_kl0`L710<K6aP37alL0d];B0=CDe03Kfm/0g=cL0080iNGU0`3WinL06P3]kNd0kno_0>o_k`3`l?00
jn_[0>k^kP3]kNd0j^[Z0>_[j`3/k>`0kNg]0>WYj@3WinL0h>3P0=_Kf`3Bd]80cLg=0<W9b@32`/80
^k^k0;Vi^@2a/K40[Zj^0:ZZZP2UYJD0Y:BT0P2RXZ804@2WYjL0Z:RX0:n_[`2a/K40/[:b0;Fe]@2g
]kL0^KVi0;Ng]`2e]KD0/;2`0:j^[P2XZ:P0X:2P09fMW@2HV9P0VIVI0080TI6A00@0Shn?08b<S028
R8P0QXJ60P24Q8@05P20P800OWin07alO01gMgL0M7Ad075aL@1YJFT0IVIV06=SH`1NGUh0FUYJ05IF
EP1CDe<0CDe=04M7A`13@d<0oooo03<c<`0];Bd0:RXZ02TY:@0X:2P202LW9`@09RHV103AcJT000<0
dLfY0P0V9RH202LW9`0E02HV9P0W9bL09bLW02LW9`0X:2P0:BTY02XZ:P3oool0<S8b03De=@0l?3`0
ATI604e=C@1CDe<0Fe]K06IVIP1[Jf/0MGEe07QhN020P800QHF50080RXZ:00H0S8b<08n?S`2@T900
Ti>C09BDU02EUID209^KV`0D09bLW02TY:@0YjNW0:VYZ@2[Zj/0/;2`0;Ng]`2h^;P0_;bl0;no_`34
a<@0b/[:0<71`@3:b/X0d];B0=[JfP3Ogml0hN7Q0>OWi`3Vi^H20>WYj@0N0>o_k`3^k^h0k>c/0?3`
l03Zj^X0k^k^0>WYj@3/k>`0jNWY0>k^kP3Zj^X0i>CT0>OWi`3Ogml0fm_K0=KFeP3;bl/0c<c<0<G5
a@32`/80^[Zj0;Rh^02^[Zh0ZZZZ0:JVYP2UYJD0WinO0:6QX@2PX:00XZ:R0P2XZ:P04P2_[jl0/[:b
0;Bd]02b/[80];Bd0;>c/`2d];@0[Jf]0:JVYP2TY:@0WYjN09ZJVP2EUID0TI6A092@T02=SHd0RHV9
08^;R`<0Ph>301/0PH6107alO01iNGT0M7Ad06m_K`1]KFd0J6QX06=SH`1NGUh0FUYJ05QHF01CDe<0
CDe=04U9B@13@d<0oooo03De=@0^;Rh0:RXZ02TY:@0X:2P09bLW02HV9P0W9bL09RHV02LW9`0V9RH0
103AcJT000<0dLfY100V9RH00`0W9bL09RHV02LW9`0202LW9`0C02PX:00Z:RX0oooo034a<@0f=SH0
?3`l04=3@`1;Bd/0DE5A05YJFP1QHF40J6QX075aL@1jNWX0PH6108B4Q02:RXX0U9BD09:BTP0209>C
T`0=09RHV02FUYH0UiNG09RHV02NWYh0WinO0:2PX02UYJD0YjNW0:^[Z`2`/;00/K6a0;Jf]P020;^k
^`0=0;no_`35aLD0a<C40<W9b@3<c<`0dm?C0=WIf@3Lg=`0gmoO0>GUi@3Vi^H0jNWY0>g]k@020>c/
k0030>k^kP3`l?00jn_[0080k^k^01<0kNg]0>k^kP3[jn/0k>c/0>WYj@3WinL0hn?S0>7Qh@3Kfm/0
d];B0=7Ad@3=cLd0b/[:0;no_`2g]kL0[jn_0:^[Z`2XZ:P0YZJV0080XJ6Q00@0X:2P09nOW`2RXZ80
YJFU0P2][Jd20:n_[`0?0;:b/P2^[Zh0[Zj^0:f][@2WYjL0XZ:R09jNWP2GUiL0TI6A09:BTP2?Shl0
SXj>08f=S@26QXH0QHF50080P8200P1jNWX04@1gMgL0M7Ad06i^KP1YJFT0IfMW065QH@1KFe/0F5QH
05=CD`1=CDd0BDU90492@P3oool0=cLg02h^;P0[:b/0:BTY00809bLW00D09RHV02LW9`0V9RH09RHV
02LW9`040=7=Z@000`3AcJT402HV9PD09bLW01`0:BTY02XZ:P3oool0<S8b03De=@0m?Cd0@d=304Y:
BP1@D500EeMG05mOG`1VIVH0Kfm_07IfMP20P800QHF508^;R`2?Shl0Ti>C09RHV02LW9`0Vi^K09VI
V@2KVi/0W9bL09fMW@2PX:00XJ6Q0P2TY:@01`2[Zj/0/K6a0;:b/P2c/k<0][Jf0;Rh^02k^k/00P32
`/802@37alL0bl_;0<g=c@3De=@0e]KF0=gMg@3Ph>00j>SX0>_[j`020>[ZjP0A0>_[j`3^k^h0k>c/
0?3`l03^k^h0l?3`0>_[j`3Zj^X0kno_0>_[j`3WinL0jn_[0>OWi`3Vi^H0hN7Q0=SHf03Fe]H00P3G
emL01@3@d=00`/;20;^k^`2a/K40Zj^[0080ZJVY00/0Xj>S0:6QX@2OWil0WinO0::RXP2UYJD0ZJVY
0:b/[02a/K40/;2`0;6a/@020:j^[P0=0:VYZ@2UYJD0Xj>S09bLW02GUiL0UIFE08j>SP2=SHd0RXZ:
08V9R@25QHD0P82007inOP0207UiN@0A07MgM`1eMGD0LW9b06YZJP1XJ6P0HF5Q05eMG@1IFET0E5AD
04m?C`18B4P0A4A40?ooo`0g=cL0;Rh^02/[:`0Y:BT0100W9bL302HV9P@0dLfY00030=7=Z@H09RHV
0`0W9bL05@0Y:BT0:RXZ0?ooo`0a<C40=SHf03/k>`13@d<0Bd];04e=C@1EEED0G5aL06=SH`1/K6`0
MGEe07]kN`22PX80QhN7096AT@2EUID0UiNG09^KV`020:2PX00A09nOW`2PX:00XZ:R09jNWP2SXj<0
YJFU0:RXZ02ZZZX0Zj^[0;6a/@2`/;00][Jf0;jn_P2j^[X0_;bl0<?3``36a/H00P3:b/X0203;bl/0
d];B0=GEe@3Jf]X0g]kN0>CTi03WinL0j^[Z0P3/k>`20?3`l080kno_00<0jn_[0?3`l03_knl00P3/
k>`0503]kNd0jn_[0>g]k@3Zj^X0j>SX0>7Qh@3Ph>00hn?S0>3Ph03De=@0c<c<0<71`@2e]KD0[Jf]
0:^[Z`2UYJD0Y:BT0:6QX@2OWil0WIfM0P2OWil20:NWY`0U0:^[Z`2^[Zh0[Jf]0:j^[P2][Jd0Zj^[
0:ZZZP2SXj<0Vi^K09RHV02?Shl0SXj>08b<S029RHT0QHF508N7Q`23Ph<0O7al07UiN@1fMWH0M7Ad
07=cL`1^KVh0J6QX06ATI01MGEd0F5QH05ADE01?Cdl0BDU904A4A03oool0=cLg02l_;`0[:b/0:RXZ
02PX:00202LW9`@09RHV103AcJT000<0dLfY1@0V9RH302LW9`80:2PX01T0:RXZ0?ooo`0a<C40=CDe
03/k>`12@T80Bd];04i>CP1CDe<0FUYJ061PH01WIfL0Kfm_07IfMP1lO7`0Q8B408b<S02CTi<0UiNG
09^KV`2QXJ40Y:BT0:JVYP2WYjL0Z:RX0080YJFU00<0ZZZZ0:RXZ02ZZZX00P2[Zj/0202_[jl0];Bd
0;Rh^02h^;P0^[Zj0;jn_P31`L40aLG50P37alL02@3:b/X0clo?0=;BdP3IfMT0gMgM0>;RhP3YjNT0
kNg]0>c/k0020>o_k`030?3`l03_knl0lO7a0080kno_0200kNg]0>k^kP3^k^h0kNg]0>k^kP3[jn/0
lO7a0>c/k03]kNd0j>SX0>GUi@3Rh^80gMgM0<o?c`35aLD0^k^k0;Bd]02YZJT0Z:RX0:BTY02PX:00
WinO09fMW@2LW9`0WYjN09nOW`2SXj<0YJFU0:VYZ@2_[jl0[:b/0:VYZ@80Zj^[01d0XZ:R09nOW`2F
UYH0TI6A08n?S`2;Rh/0QXJ608>3P`21PH40OWin07]kN`1eMGD0M7Ad079bLP1[Jf/0JVYZ06IVIP1O
Gel0FEUI05EEE@1@D500BTY:04=3@`0n?Sh0=cLg030`<00[:b/0:BTY02PX:00202LW9`@09RHV103A
cJT000<0dLfY1@0V9RH302LW9`0I02PX:00Y:BT0:b/[0?ooo`0b<S80=SHf03/k>`13@d<0BTY:04m?
C`1BDU80Fe]K061PH01UIFD0JFUY075aL@1eMGD0PH6108J6QP2>SXh0TI6A09^KV`2PX:00YJFU0:RX
Z0020:^[Z`040:ZZZP2[Zj/0ZJVY0:VYZ@80[:b/00P0Zj^[0:j^[P2`/;00/k>c0;Jf]P2k^k/0_kno
0<30`080`l?300h0aLG50<[:bP3;bl/0cLg=0=?Cd`3IfMT0h>3P0>7Qh@3Ti>@0k>c/0>k^kP3/k>`0
kNg]0?3`l080kno_00@0kNg]0>o_k`3clo<0kno_0P3`l?003P3clo<0mOGe0?Cdm03`l?00l_;b0>WY
j@3Xj>P0iNGU0=kNgP3AdM40b/[:0<;2`P2k^k/0/K6a0P2ZZZX0302RXZ80WYjN09fMW@2NWYh0W9bL
09jNWP2OWil0Y:BT0:FUY@2/[:`0ZJVY0:JVYP80Y:BT00L0Xj>S09^KV`2HV9P0TI6A08f=S@26QXH0
Ph>30080Ogmo01<0O7al07MgM`1eMGD0LW9b06a/K01ZJVX0I6AT065QH@1JFUX0EUIF051@D019BDT0
@T9203`l?00g=cL0;bl_02/[:`0Y:BT0:2PX00<09bLW0`0V9RH40=7=Z@000`3AcJT502HV9P<09bLW
01X0:2PX02TY:@0Z:RX0oooo034a<@0f=SH0?Cdm04=3@`1;Bd/0De=C05EEE@1IFET0GEeM06EUI@1X
J6P0L71`07AdM01iNGT0P82008J6QP2?Shl0UiNG09bLW02SXj<0YjNW0:ZZZP80/;2`00D0/[:b0;>c
/`2`/;00/;2`0;:b/P020;2`/0070;:b/P2c/k<0][Jf0;Zj^P2m_Kd0_;bl0<;2`P020<71`@0<0<O7
a`3:b/X0bl_;0=7Ad@3@d=00dm?C0=gMg@3Ph>00inOW0>KViP3/k>`0kno_0P3^k^h0103`l?00kno_
0>k^kP3alO420?3`l080m?Cd00L0moOg0?Gem@3emOD0lO7a0>o_k`3]kNd0j>SX0080gmoO00X0dM7A
0<c<c036a/H0^KVi0:n_[`2/[:`0Z:RX0:>SX`2NWYh0VYZJ0P2IVIT0902KVi/0WIfM0:6QX@2SXj<0
YJFU0:b/[02UYJD0Y:BT0:NWY`2QXJ40W9bL09NGU`2ATI40RXZ:08J6QP22PX80OWin07]kN`1jNWX0
MWIf079bLP1]KFd0JFUY06IVIP1RHV80FUYJ05EEE@1@D500BTY:0492@P0m?Cd0=cLg02l_;`0[:b/0
:BTY02PX:0809bLW0P0V9RH00`0W9bL09RHV0=7=Z@030=7=Z@000`3AcJT302HV9P0302LW9`0V9RH0
9bLW00809bLW0P0X:2P0700Z:RX0;2`/034a<@0f=SH0>c/k0492@P1;Bd/0EEEE05MGE`1IFET0G5aL
069RHP1WIfL0K6a/07AdM01gMgL0Ng]k08B4Q027QhL0TI6A09RHV02NWYh0YJFU0:VYZ@2][Jd0];Bd
0;6a/@2b/[820;Fe]@0@0;Bd]02f][H0/[:b0;:b/P2d];@0]kNg0;Vi^@2l_;`0_Kfm0;no_`30`<00
bLW90<71`@37alL0b/[:0<o?c`80dm?C02X0f=SH0=[JfP3Rh^80inOW0>SXj03YjNT0k>c/0?7al@3]
kNd0k^k^0?;blP3fm_H0l_;b0?Gem@3fm_H0m?Cd0?Shn03dm?@0no_k0?Ogm`3^k^h0kNg]0>[ZjP3W
inL0g]kN0=OGe`3Fe]H0c/k>0<G5a@2i^KT0];Bd0:ZZZP2WYjL0Y:BT0:6QX@2KVi/0VIVI09ZJVP2L
W9`0WYjN0:2PX02SXj<30:BTY080XZ:R01X0WYjN09^KV`2FUYH0TI6A08N7Q`26QXH0Ogmo07alO01h
N7P0Lg=c075aL@1^KVh0JVYZ06ATI01PH600Fe]K05QHF01@D500BDU90492@P3oool0=SHf030`<00[
:b/0:RXZ02PX:0809bLW100V9RH40=7=Z@000`3AcJT602HV9P809bLW0240:2PX02TY:@0Y:BT0;2`/
034a<@0e=CD0>c/k0451@@19BDT0E5AD05QHF01JFUX0GEeM069RHP1UIFD0Jf][06i^KP1eMGD0Ng]k
0861P@24Q8@0R8R808n?S`2HV9P0WYjN0:RXZ02ZZZX0[jn_0;>c/`2h^;P0^k^k0;Vi^@2e]KD00`2g
]kL0602i^KT0]kNg0;Jf]P2i^KT0^k^k0;jn_P2o_kl0`/;20<?3``31`L40alO70<k>cP3=cLd0c<c<
0<o?c`3Fe]H0f=SH0=gMg@3QhN40i^KV0>WYj@3Zj^X0kNg]0>c/k0<0kNg]01l0m?Cd0?Win@3fm_H0
moOg0?[jnP3clo<0l?3`0?Ogm`3_knl0k>c/0>[ZjP3Shn<0g=cL0=kNgP3De=@0dm?C0<[:bP34a<@0
][Jf0;:b/P2[Zj/0YjNW0::RXP2MWId0Vi^K09jNWP2PX:00Vi^K09fMW@2PX:00YJFU0080XZ:R01X0
X:2P09bLW02KVi/0VYZJ09:BTP2ATI40S8b<08>3P`1oOgl0MWIf07AdM01aLG40KVi^06UYJ@1TI6@0
GUiN05]KF`1FEUH0D51@04Y:BP12@T80oooo03Lg=`0`<300:b/[02TY:@<09bLW00@09RHV02LW9`0V
9RH09RHV103AcJT000<0dLfY0`0V9RH202LW9`809RHV0P0W9bL202TY:@0J02`/;00`<300=3@d03Xj
>P0o?cl0ADE504m?C`1EEED0EUIF05]KF`1NGUh0Hf=S06a/K01]KFd0LW9b07QhN01lO7`0P82008B4
Q02:RXX0Ti>C09RHV02MWId0YjNW0:b/[02`/;020;Jf]P070;fm_@2k^k/0_Kfm0;Zj^P2h^;P0^k^k
0;Zj^P030;^k^`0A0;Zj^P2m_Kd0`/;20<30`034a<@0a/K60<W9b@3;bl/0dM7A0<g=c@3AdM40dm?C
0=[JfP3IfMT0gMgM0=oOg`3Vi^H00`3Xj>P0203^k^h0kNg]0?Cdm03alO40m_Kf0?Cdm03gmoL0n?Sh
0P3bl_80103[jn/0k>c/0>WYj@3UiND20>?Sh`0C0=oOg`3Hf=P0e]KF0=?Cd`39bLT0_kno0;Zj^P2c
/k<0[:b/0:JVYP2OWil0W9bL09^KV`2MWId0VYZJ09fMW@2OWil0WYjN0:6QX@0209bLW00I09^KV`2I
VIT0UIFE096AT@2=SHd0QhN708:2PP1kNg/0MGEe075aL@1]KFd0Jf][06ATI01OGel0FEUI05MGE`1?
Cdl0BDU90492@P3oool0=SHf030`<00[:b/0:BTY02PX:00202LW9`@09RHV103AcJT000<0dLfY100V
9RH0100W9bL09RHV02HV9P0W9bL202PX:00P02TY:@3oool0;bl_03<c<`0i>CT0?Shn04A4A019BDT0
D51@05ADE01HF5P0GemO06=SH`1WIfL0Jf][071`L01cLg<0NGUi07alO023Ph<0RHV908n?S`2CTi<0
VIVI0:2PX02VYZH0[Zj^0;Fe]@2i^KT0^[Zj0;jn_P30`<020;no_`80_Kfm00P0_;bl0;^k^`2n_[h0
_Kfm0<;2`P2o_kl0_[jn0<?3``80b<S800h0bl_;0<[:bP3;bl/0dM7A0=3@d03EeMD0d];B0=KFeP3H
f=P0f][J0=cLg03Rh^80hN7Q0>SXj080k>c/0P3`l?002P3clo<0m?Cd0?Ogm`3dm?@0l?3`0>g]k@3[
jn/0j^[Z0>SXj03UiND20>?Sh`0=0>3Ph03Ng]h0e]KF0=CDe03=cLd0bl_;0<;2`P2n_[h0]KFe0:^[
Z`2RXZ80WYjN09fMW@0209ZJVP0N09^KV`2JVYX0Vi^K09bLW02KVi/0UiNG09FEU@2CTi<0TY:B08j>
SP28R8P0QHF507moO`1jNWX0Lg=c06i^KP1ZJVX0Hf=S05mOG`1HF5P0EEEE051@D01:BTX0@d=30?oo
o`0f=SH0<C4a02/[:`0Y:BT0:2PX0`0W9bL302HV9P@0dLfY00030=7=Z@<09RHV00<09bLW02HV9P0W
9bL00P0W9bL202PX:00U02TY:@3oool0;bl_03<c<`0h>3P0?Shn04=3@`17AdL0CTi>059BDP1FEUH0
Fe]K065QH@1VIVH0JVYZ06m_K`1cLg<0MgMg07YjNP20P800Ph>308R8R02<S8`0U9BD09ZJVP2OWil0
Z:RX0:n_[`2c/k<0]KFe0;^k^`31`L40`l?30<;2`P34a<@0`/;20<?3``020;no_`0:0<;2`P30`<00
_[jn0<71`@33`l<0`/;20<O7a`38b<P0bLW90<[:bP80cLg=00h0d];B0=?Cd`3?cll0clo?0=?Cd`3H
f=P0f][J0=oOg`3Shn<0j>SX0>KViP3/k>`0j^[Z0>o_k`80lo?c00@0l?3`0>o_k`3_knl0jNWY0P3V
i^H05`3Ti>@0iNGU0>CTi03UiND0i>CT0=kNgP3IfMT0dm?C0=7Ad@3?cll0aLG50;fm_@2i^KT0]KFe
0:ZZZP2SXj<0WinO09^KV`2HV9P0UiNG09RHV02FUYH0UIFE0080Ti>C01L0TI6A092@T02?Shl0RXZ:
08F5Q@24Q8@0OWin07IfMP1_Kfl0Jf][06ATI01OGel0F5QH05ADE01>CTh0AdM70451@@3oool0=SHf
030`<00[:b/0:BTY02PX:00402LW9`809RHV103AcJT000<0dLfY00H09BDU02HV9P0V9RH09RHV02LW
9`0V9RH302LW9`0`02PX:00Y:BT0oooo02l_;`0b<S80>3Ph03dm?@10@400ATI604a<C01ADE40EEEE
05QHF01QHF40Hf=S06EUI@1ZJVX0L71`07AdM01gMgL0Ogmo0820P026QXH0RXZ:096AT@2FUYH0VYZJ
0::RXP2YZJT0/K6a0;Jf]P2k^k/0`<300<?3``34a<@0`l?30<C4a032`/80`L710<;2`P30`<00`/;2
0<30`032`/80`L710<30`035aLD0cLg=0P3;bl/01`3@d=00c<c<0<g=c@3Cdm<0clo?0<g=c@3@d=00
0P3Bd]80103IfMT0g=cL0=oOg`3UiND20>WYj@030>k^kP3/k>`0jn_[00<0k^k^00/0k>c/0>[ZjP3Z
j^X0h^;R0>CTi03WinL0i^KV0>;RhP3Ph>00fm_K0=OGe`020=?Cd`090=3@d034a<@0^[Zj0;Rh^02]
[Jd0ZZZZ0:NWY`2OWil0VIVI0080U9BD0P2BTY806@2ATI40T92@08j>SP2;Rh/0SHf=08Z:RP27QhL0
Ph>307moO`1hN7P0Lg=c06i^KP1VIVH0GUiN05UIF@1CDe<0Cdm?04M7A`12@T80oooo03Hf=P0`<300
:b/[02TY:@0X:2P00P0W9bL402HV9P@0dLfY00030=7=Z@L09RHV0P0W9bL0>P0X:2P0:BTY0?ooo`0^
;Rh0<S8b03Lg=`0k>c/0?clo04E5A@19BDT0Cdm?059BDP1GEeL0G5aL065QH@1VIVH0JVYZ06i^KP1e
MGD0MgMg07UiN@1nOWh0P82008:2PP28R8P0S8b<09NGU`2JVYX0XZ:R0:BTY02/[:`0]KFe0;Rh^030
`<00a<C40<G5a@3:b/X0a/K60<G5a@34a<@0aLG50<K6aP31`L40`/;20<C4a031`L40aLG50<W9b@37
alL0b<S80<_;b`3:b/X0alO70<W9b@3=cLd0c/k>0<[:bP3;bl/20=3@d0050=OGe`3Hf=P0gMgM0>CT
i03WinL00`3YjNT0203Vi^H0jn_[0>o_k`3YjNT0k>c/0>SXj03Vi^H0j>SX0P3Zj^X00`3Ti>@0iNGU
0=kNgP020=SHf00@0=GEe@3De=@0b/[:0<?3``30`<00^[Zj0;Jf]P2][Jd0YJFU09nOW`2HV9P0TI6A
08n?S`2<S8`0Rh^;08Z:RP80Rh^;01D0RHV908N7Q`26QXH0PX:20861P@1kNg/0MGEe071`L01WIfL0
GemO05QHF01DE5@0CDe=04I6AP0o?cl0oooo03De=@0`<300:b/[02TY:@0X:2P00P0W9bL302HV9P03
02LW9`3AcJT0dLfY0080dLfY00030=7=Z@D09RHV0P0W9bL0900V9RH09bLW02PX:00Y:BT0oooo02d]
;@0a<C40=SHf03Xj>P0o?cl0@T9204M7A`1<C4`0D51@05EEE@1JFUX0GUiN06=SH`1YJFT0KFe]07Ee
M@1mOGd0N7Qh07YjNP1hN7P0OWin08>3P`2:RXX0Shn?09JFUP2IVIT0WYjN0:BTY02ZZZX0/[:b0;Zj
^P80_[jn00@0aLG50<O7a`37alL0b/[:0P36a/H20<C4a00=0<;2`P33`l<0a/K60<K6aP3>c/h0b<S8
0<[:bP3>c/h0alO70<K6aP37alL0b<S80<[:bP030<c<c0060<o?c`3De=@0e]KF0=kNgP3Ph>00hn?S
0P3WinL01`3Vi^H0j^[Z0>WYj@3/k>`0i^KV0>WYj@3Vi^H00P3UiND20>CTi00F0>;RhP3Ng]h0g]kN
0=_Kf`3Hf=P0e=CD0=7Ad@3:b/X0a<C40;Zj^P2f][H0/;2`0:VYZ@2QXJ40Vi^K09JFUP2<S8`0RXZ:
08N7Q`25QHD0Ph>308B4Q080Ph>301@0PH610820P01nOWh0Ng]k07EeM@1cLg<0JFUY065QH@1JFUX0
EEEE04i>CP16ATH0@4100?ooo`0e=CD0;bl_02/[:`0Y:BT09bLW02PX:0809bLW0`0V9RH40=7=Z@00
0`3AcJT402HV9P0K02LW9`0V9RH09bLW02HV9P0W9bL0:2PX02TY:@3oool0;2`/030`<00e=CD0>CTi
03lo?`12@T80ATI604a<C01?Cdl0De=C05QHF01MGEd0HF5Q06EUI@1ZJVX0L71`079bLP1fMWH0N7Qh
0080Ng]k01L0OWin0861P@28R8P0S8b<09NGU`2LW9`0XJ6Q0:FUY@2YZJT0/k>c0;Ng]`2k^k/0`/;2
0<K6aP37alL0b<S80<[:bP38b<P0c<c<0<O7a`36a/H0aLG50<;2`P020<C4a0030<G5a@38b<P0bl_;
0080b/[:00T0a<C40<S8b038b<P0b<S80<W9b@3>c/h0c<c<0<k>cP3Bd]800P3Fe]H04@3Kfm/0gmoO
0=gMg@3QhN40i^KV0>SXj03WinL0j>SX0>KViP3Xj>P0i>CT0>OWi`3Vi^H0iNGU0=oOg`3Ti>@0gMgM
0080fm_K0180e]KF0=CDe03Cdm<0b/[:0<C4a033`l<0^;Rh0;Bd]02XZ:P0WinO09VIV@2CTi<0S8b<
08N7Q`21PH40Ogmo07emO@1nOWh307alO080NGUi00l0MgMg079bLP1[Jf/0I6AT05eMG@1EEED0CDe=
04I6AP10@400>SXj03@d=00^;Rh0:RXZ02TY:@0X:2P00P0W9bL402HV9P@0dLfY00030=7=Z@0302HV
9P0W9bL09RHV00809RHV100W9bL06@0X:2P0:BTY0?ooo`0/;2`0<30`03@d=00h>3P0?3`l0410@015
ADD0C4a<04i>CP1DE5@0FEUI05eMG@1OGel0Hf=S06QXJ01ZJVX0KVi^07=cL`1gMgL0O7al07]kN`1m
OGd00P21PH402P27QhL0SXj>09FEU@2HV9P0WinO0:NWY`2ZZZX0/k>c0;Rh^02l_;`20<;2`P070<G5
a@39bLT0c<c<0<g=c@39bLT0b<S80<[:bP020<W9b@040<S8b035aLD0bLW90<K6aP80b/[:00<0a<C4
0<S8b039bLT00P37alL0403:b/X0c/k>0<c<c03=cLd0clo?0=7Ad@3De=@0gMgM0=_Kf`3QhN40h^;R
0>KViP3UiND0inOW0>KViP3Zj^X20>SXj0070>GUi@3Ti>@0hn?S0>7Qh@3Shn<0gMgM0=kNgP020=GE
e@0A0=3@d03<c<`0bLW90<K6aP33`l<0^[Zj0:f][@2VYZH0VYZJ09BDU02=SHd0RXZ:08:2PP1mOGd0
O7al07UiN@1kNg/00P1iNGT04@1hN7P0MWIf07=cL`1_Kfl0JFUY06ATI01OGel0FEUI04m?C`18B4P0
?clo03Xj>P0d=3@0;Rh^02XZ:P0Y:BT0:2PX00@09bLW0P0V9RH40=7=Z@000`3AcJT602HV9P<09bLW
0P0X:2P05@3oool0;2`/02h^;P0d=3@0=cLg03/k>`10@400ADE504U9B@1>CTh0DE5A05MGE`1JFUX0
GEeM065QH@1TI6@0KVi^06a/K01_Kfl0LW9b07AdM00207alO00A07inOP21PH40PX:208N7Q`2=SHd0
TI6A09^KV`2QXJ40Xj>S0:JVYP2ZZZX0/k>c0;Vi^@2n_[h0a/K60<S8b037alL00P3>c/h03@3<c<`0
cLg=0<W9b@37alL0bLW90<O7a`35aLD0bLW90<[:bP39bLT0a/K60<S8b039bLT00P3:b/X05`36a/H0
b/[:0<_;b`3;bl/0b/[:0<_;b`3?cll0dm?C0=WIf@3Jf]X0gMgM0=cLg03Ph>00hN7Q0>?Sh`3UiND0
j>SX0>KViP3UiND0hn?S0>;RhP3UiND0hn?S0080h^;R02H0g]kN0=WIf@3De=@0clo?0<c<c037alL0
`l?30<30`02g]kL0[jn_0:NWY`2LW9`0TY:B08^;R`27QhL0P82007UiN@1hN7P0MGEe07MgM`1dM7@0
LW9b071`L01_Kfl0K6a/06MWI`1QHF40G5aL05MGE`1ADE40BDU90451@@0i>CT0<c<c02h^;P0Z:RX0
:BTY02PX:0809bLW100V9RH40=7=Z@000`3AcJT702HV9P<09bLW01@0:2PX0?ooo`0[:b/0;Rh^03<c
<`0g=cL0?3`l0410@012@T80BDU904];B`1>CTh0E5AD05UIF@1LG5`0GUiN069RHP1^KVh0Jf][06m_
K`80LW9b0100MgMg07UiN@21PH40PH6107inOP24Q8@0QHF508R8R02ATI40UIFE09jNWP2RXZ80YZJV
0:VYZ@2b/[80_Kfm0P34a<@01@36a/H0bl_;0<_;b`3<c<`0cLg=0080c/k>00@0alO70<W9b@3:b/X0
cLg=0P35aLD20<S8b0080<[:bP35aLD0a<C40<C4a035aLD0alO70<c<c03=cLd20<c<c080clo?00L0
e=CD0=[JfP3MgMd0gmoO0=cLg03UiND0hN7Q0080i^KV01X0i>CT0>GUi@3YjNT0hn?S0=oOg`3Ph>00
g=cL0>7Qh@3Hf=P0fMWI0=KFeP3>c/h0b/[:0<W9b@33`l<0`/;20;Vi^@2a/K40Y:BT09^KV`2CTi<0
RXZ:0861P@1oOgl0NGUi079bLP80L71`0180KVi^06e]K@1YJFT0IfMW06=SH`1OGel0FUYJ05=CD`1@
D500B4Q80410@00j>SX0<c<c02d];@0Z:RX0:BTY02PX:00W9bL502HV9P@0dLfY00030=7=Z@D09RHV
00<09bLW02HV9P0V9RH00P0W9bL06P0X:2P0:BTY02XZ:P0];Bd0<S8b03Hf=P0j>SX0?Shn04=3@`17
AdL0Bd];04m?C`1EEED0EeMG05YJFP1OGel0HV9R06IVIP1WIfL0K6a/071`L01eMGD0Lg=c07YjNP1n
OWh0O7al0P22PX806024Q8@0QHF508^;R`2@T900TY:B09NGU`2RXZ80Y:BT0:ZZZP2a/K40];Bd0;jn
_P31`L40`l?30<K6aP3:b/X0cLg=0<_;b`3=cLd0bLW90<[:bP3<c<`0b/[:0<S8b080b/[:01h0bLW9
0<C4a034a<@0aLG50<O7a`34a<@0b<S80<G5a@37alL0b<S80<[:bP38b<P0bl_;0<g=c@3?cll0emOG
0=[JfP3Lg=`0h>3P0>7Qh@3Rh^80h>3P0>CTi03Shn<0h^;R0>?Sh`3QhN40h>3P0=oOg`3Lg=`20=SH
f00Q0=GEe@3Bd]80c/k>0<_;b`37alL0`L710;bl_02i^KT0[Jf]0:FUY@2KVi/0TY:B08R8R022PX80
OGem07IfMP1bLW80KFe]06YZJP1WIfL0I6AT069RHP1OGel0FEUI05IFEP1CDe<0C4a<04E5A@0o?cl0
oooo034a<@0/;2`0:BTY0080:2PX00<09RHV02LW9`0V9RH00`0V9RH40=7=Z@000`3AcJT602HV9P@0
9bLW0P0X:2P0500Z:RX0;2`/034a<@0f=SH0>SXj03dm?@13@d<0ADE504U9B@1=CDd0DU9B05ADE01H
F5P0GUiN065QH@1UIFD0IVIV06][J`1`L700LG5a0P1eMGD0101jNWX0O7al07inOP24Q8@208J6QP0E
08R8R02<S8`0SXj>09:BTP2FUYH0WinO0:BTY02YZJT0ZZZZ0;>c/`2h^;P0_;bl0<30`035aLD0c<c<
0<[:bP3;bl/0dM7A0=3@d03>c/h0cLg=0080b/[:00@0bLW90<G5a@38b<P0aLG50P37alL01`35aLD0
a/K60<S8b032`/80a<C40<G5a@37alL00P39bLT00`37alL0cLg=0=?Cd`020=SHf0030=[JfP3MgMd0
gMgM0080h^;R00<0hN7Q0>?Sh`3Rh^800P3Ph>009@3Ng]h0g=cL0=WIf@3GemL0eMGE0=;BdP3?cll0
bLW90<G5a@2o_kl0_;bl0;Ng]`2^[Zh0YZJV09^KV`2>SXh0QhN708:2PP1iNGT0LG5a06m_K`1XJ6P0
IFEU069RHP1MGEd0Fe]K05IFEP1BDU80Cdm?04Y:BP12@T80?3`l0?ooo`0a<C40;2`/02TY:@0X:2P0
0P0W9bL202HV9P0302LW9`0V9RH09RHV00@0dLfY00030=7=Z@P09RHV0P0W9bL202PX:00I02XZ:P0/
;2`0;bl_03De=@0j>SX0?3`l0451@@16ATH0BDU904i>CP1@D500EUIF05QHF01MGEd0HF5Q06=SH`1W
IfL0J6QX06a/K01^KVh0LW9b07EeM@1jNWX0Ng]k07inOP0208>3P`0A08F5Q@24Q8@0QhN708b<S02=
SHd0TY:B09VIV@2LW9`0XZ:R0:JVYP2][Jd0/;2`0;>c/`2i^KT0`/;20<G5a@3;bl/00P3>c/h00`3=
cLd0clo?0<o?c`020<c<c080alO701P0aLG50<K6aP36a/H0alO70<S8b036a/H0`l?30<G5a@34a<@0
`l?30<C4a037alL0aLG50<S8b03:b/X0clo?0=3@d03Cdm<0e=CD0=SHf03Jf]X0fMWI0=oOg`3QhN43
0=oOg`060=gMg@3Ogml0f][J0=cLg03Jf]X0dM7A0P3>c/h07P39bLT0a/K60<?3``2l_;`0^;Rh0;Fe
]@2[Zj/0WYjN09FEU@2=SHd0QXJ607]kN`1eMGD0KVi^06][J`1UIFD0GEeM05]KF`1HF5P0DU9B04m?
C`1;Bd/0ATI60451@@0j>SX0oooo030`<00[:b/0:BTY02PX:0@09bLW0`0V9RH40=7=Z@000`3AcJT6
02HV9P@09bLW0200:2PX0?ooo`0Z:RX0:b/[02h^;P0e=CD0>SXj03/k>`11@D40A4A404Q8B01<C4`0
CTi>05=CD`1FEUH0G5aL05iNGP1QHF40I6AT06YZJP1[Jf/0KFe]06i^KP1cLg<0MWIf07EeM@1jNWX0
O7al07moO`22PX80QXJ608V9R@80R8R80P2?Shl03@2HV9P0VYZJ0:2PX02UYJD0Zj^[0:ZZZP2`/;00
]kNg0;^k^`35aLD0b/[:0<g=c@3?cll00`3@d=00303=cLd0c<c<0<g=c@38b<P0alO70<C4a03:b/X0
alO70<?3``38b<P0bLW90<G5a@<0`l?301D0`<300<G5a@36a/H0alO70<S8b03?cll0c/k>0=7Ad@3D
e=@0eMGE0=KFeP3Ng]h0gmoO0=kNgP3Lg=`0gmoO0=WIf@3MgMd0f=SH0=WIf@3EeMD00P3=cLd07P3:
b/X0aLG50<30`031`L40_;bl0;Fe]@2a/K40[Jf]0:BTY02FUYH0SXj>08B4Q01lO7`0LW9b06e]K@1U
IFD0GemO05YJFP1EEED0D51@04];B`16ATH0@T9203hn?P0h>3P0oooo02l_;`0[:b/0:BTY02PX:0<0
9bLW100V9RH40=7=Z@000`3AcJT802HV9P<09bLW01l0oooo02XZ:P0Z:RX0;Rh^03<c<`0j>SX0?3`l
0451@@14A4@0AdM704Y:BP1=CDd0D51@05EEE@1IFET0Fe]K061PH01RHV80IfMW06][J`1/K6`0KFe]
075aL@1cLg<0MWIf07QhN01jNWX0OWin07emO@21PH40QHF50080R8R80180S8b<08f=S@2@T900TY:B
09ZJVP2MWId0XJ6Q0:FUY@2[Zj/0/[:b0;>c/`30`<00_Kfm0<_;b`39bLT0c<c<0<k>cP3AdM420=3@
d0070<k>cP3;bl/0b/[:0<W9b@36a/H0aLG50<;2`P020<?3``0:0<C4a030`<00`/;20;fm_@2o_kl0
`<300<71`@34a<@0aLG50<O7a`80bl_;00<0clo?0=;BdP3Cdm<00P3GemL09`3Hf=P0fMWI0=OGe`3M
gMd0emOG0=SHf03Cdm<0e=CD0<k>cP3<c<`0bl_;0<C4a030`<00_kno0;Zj^P2f][H0/k>c0;6a/@2Y
ZJT0X:2P09VIV@2;Rh/0P82007MgM`1bLW80J6QX065QH@1KFe/0E5AD04m?C`19BDT0ADE50451@@0k
>c/0=SHf0?ooo`0^;Rh0:RXZ02TY:@0402LW9`@09RHV103AcJT000<0dLfY2@0V9RH202LW9`0D0?oo
o`0Y:BT0:b/[02d];@0a<C40?3`l03lo?`11@D40ADE504M7A`1:BTX0Cdm?051@D01CDe<0EeMG05YJ
FP1PH600HF5Q06IVIP1XJ6P206e]K@0=06m_K`1aLG40LW9b07AdM01fMWH0NGUi07emO@20P800Ph>3
08J6QP27QhL0Rh^;08j>SP02092@T080U9BD00h0VYZJ0:2PX02TY:@0Z:RX0:b/[02g]kL0^[Zj0;fm
_@35aLD0a/K60<g=c@3?cll0dM7A0=;BdP80c/k>00<0bLW90<[:bP36a/H00P34a<@30<30`080`L71
00D0_[jn0;bl_02o_kl0_;bl0;jn_P020<C4a0090<?3``34a<@0bLW90<_;b`3>c/h0d];B0<o?c`3@
d=00dm?C0080d];B00l0eMGE0=OGe`3Bd]80dM7A0<k>cP3@d=00b/[:0<;2`P31`L40_;bl0;Rh^02g
]kL0];Bd0;2`/02ZZZX00P2TY:@04@2FUYH0RHV907inOP1gMgL0KFe]06ATI01OGel0EUIF04m?C`18
B4P0A4A403`l?00i>CT0=3@d0?ooo`0/;2`0:RXZ0080:2PX100W9bL302HV9P@0dLfY00030=7=Z@P0
9RHV0P0W9bL06P0X:2P0oooo02TY:@0Z:RX0;2`/02l_;`0j>SX0?clo0492@P16ATH0B4Q804Y:BP1;
Bd/0D51@059BDP1FEUH0EeMG05aLG01OGel0Hf=S06EUI@1YJFT0JVYZ06e]K@1`L700Lg=c0P1gMgL0
1`1fMWH0NGUi07inOP1oOgl0Ph>308N7Q`29RHT00P2>SXh06P2?Shl0SHf=092@T02EUID0V9RH09jN
WP2SXj<0ZJVY0:f][@2d];@0]kNg0;jn_P35aLD0a/K60<c<c03;bl/0d=3@0=7Ad@3Cdm<0d=3@0<k>
cP3<c<`0b/[:0<G5a@34a<@0`<300P2m_Kd0402n_[h0^k^k0;bl_02l_;`0^[Zj0;bl_02n_[h0_Kfm
0<71`@2o_kl0`<300<C4a037alL0b<S80<W9b@3:b/X20<_;b`0S0<k>cP3@d=00clo?0=3@d03?cll0
c<c<0<_;b`35aLD0`/;20<30`02n_[h0^KVi0;>c/`2d];@0[Zj^0:f][@2WYjL0Xj>S09bLW02ATI40
R8R80861P@1eMGD0Jf][06=SH`1JFUX0DE5A04Q8B012@T80?Cdm03Lg=`0c<c<0oooo02/[:`0Y:BT0
0P0X:2P202LW9`809RHV00<09bLW02HV9P0V9RH0103AcJT000<0dLfY200V9RH302LW9`0I0?ooo`0X
:2P0:BTY02`/;00_;bl0=SHf03hn?P13@d<0BDU904M7A`19BDT0C4a<051@D01CDe<0EEEE05QHF01J
FUX0GEeM069RHP1UIFD0JFUY06YZJP1]KFd0L71`079bLP0307MgM`0607YjNP1kNg/0Ogmo0820P022
PX80QHF50P2<S8`208f=S@0708j>SP2ATI40U9BD09^KV`2OWil0Xj>S0:VYZ@020;:b/P0C0;Bd]02j
^[X0`<300<G5a@3;bl/0c<c<0<o?c`3<c<`0clo?0=3@d039bLT0b/[:0<O7a`34a<@0`L710;no_`2k
^k/0_Kfm0;Zj^P020;no_`0>0;fm_@2k^k/0^k^k0;Rh^02k^k/0_Kfm0<30`02o_kl0`L710<;2`P34
a<@0alO70<G5a@37alL30<S8b00P0<K6aP39bLT0cLg=0<K6aP38b<P0`/;20;no_`2m_Kd0^KVi0;Ng
]`2c/k<0[jn_0:^[Z`2VYZH0XZ:R09bLW02DU9@0S8b<08F5Q@1hN7P0L71`06MWI`1IFET0D51@04U9
B@12@T80?3`l03Lg=`0b<S80oooo02/[:`0Y:BT202PX:0809bLW1@0V9RH40=7=Z@000`3AcJT802HV
9P<09bLW02h0oooo02PX:00Y:BT0:b/[02h^;P0c<c<0?3`l04A4A018B4P0BDU904];B`1=CDd0D51@
059BDP1DE5@0EUIF05UIF@1LG5`0GUiN065QH@1VIVH0J6QX06][J`1^KVh0Kfm_075aL@1bLW80M7Ad
07YjNP1hN7P0Ng]k07emO@21PH40Ph>308J6QP27QhL0S8b<08n?S`2BTY80TI6A092@T02DU9@0UiNG
09^KV`2QXJ40ZJVY0P2`/;001`2d];@0][Jf0;^k^`34a<@0aLG50<_;b`3<c<`00P3=cLd01P3;bl/0
c<c<0<S8b035aLD0`l?30<;2`P80_;bl0P2j^[X0202n_[h0^[Zj0;Zj^P2k^k/0^;Rh0;Jf]P2g]kL0
^;Rh0`2m_Kd20;jn_P80`L710P32`/800`34a<@0a/K60<?3``020<O7a`0L0<;2`P31`L40_[jn0;jn
_P2j^[X0];Bd0;Fe]@2][Jd0ZZZZ0:FUY@2QXJ40VIVI09>CT`2<S8`0QXJ607]kN`1`L700JVYZ05iN
GP1BDU80Bd];04A4A00l?3`0=SHf030`<00];Bd0:RXZ02PX:0<09bLW00<09RHV02LW9`0V9RH00P0V
9RH00`0W9bL0dLfY0=7=Z@020=7=Z@000`3AcJT702HV9P0502LW9`0V9RH09RHV02LW9`3oool00P0X
:2P0400Z:RX0;Rh^034a<@0g=cL0A4A404M7A`1:BTX0CTi>04m?C`1@D500DU9B05EEE@1HF5P0FEUI
05aLG01MGEd2065QH@0606EUI@1WIfL0JFUY06e]K@1_Kfl0L71`0P1bLW801@1hN7P0NGUi07QhN01j
NWX0OGem0080Q8B400<0QhN708R8R02=SHd00P2?Shl309BDU00;09VIV@2PX:00YZJV0:ZZZP2^[Zh0
/;2`0;:b/P2j^[X0_[jn0<G5a@37alL00P3:b/X02@3;bl/0c/k>0<W9b@3=cLd0b/[:0<71`@2o_kl0
^[Zj0;^k^`020;Rh^0030;^k^`2l_;`0_;bl0080]KFe00X0/K6a0;Bd]02m_Kd0_;bl0;Zj^P2i^KT0
_;bl0;^k^`2j^[X0_;bl0P2k^k/01`32`/80a/K60<C4a032`/80`l?30;fm_@2n_[h00P2j^[X05`2`
/;00/K6a0:VYZ@2VYZH0Xj>S0:6QX@2HV9P0T92@08^;R`25QHD0Ng]k079bLP1[Jf/0HV9R05EEE@1<
C4`0A4A403`l?00e=CD0;bl_02`/;00Y:BT0:2PX00<09bLW0P0V9RH0100W9bL09RHV02HV9P0V9RH4
0=7=Z@000`3AcJT702HV9P0>02LW9`0V9RH09RHV02LW9`3oool09bLW02PX:00Z:RX0;Bd]02l_;`0d
=3@0@D5104I6AP1:BTX204i>CP0;051@D01CDe<0EUIF05MGE`1IFET0GUiN05eMG@1QHF40HV9R06AT
I01UIFD00`1YJFT01P1]KFd0LG5a075aL@1eMGD0MWIf07]kN`80NWYj01L0O7al08:2PP26QXH0QhN7
08R8R029RHT0SXj>09:BTP2GUiL0V9RH09NGU`2LW9`0XZ:R0:NWY`2VYZH0[:b/0:j^[P2b/[80]KFe
0;^k^`2n_[h0`/;20<W9b@020<S8b00=0<c<c039bLT0a/K60<K6aP32`/80`L710;fm_@2l_;`0_Kfm
0;Ng]`2e]KD0^;Rh0;Jf]P020;>c/`040;2`/02a/K40];Bd0;Fe]@80][Jf00@0]kNg0;Fe]@2g]kL0
][Jf0P2h^;P0102k^k/0_kno0;no_`2o_kl20;bl_00I0;Ng]`2b/[80[Zj^0:b/[02XZ:P0YJFU0:2P
X02JVYX0UIFE092@T028R8P0Q8B407UiN@1`L700Jf][05mOG`1FEUH0C4a<04A4A00k>c/0<c<c02h^
;P0[:b/0:RXZ02PX:00302LW9`H09RHV103AcJT000<0dLfY1@0V9RH0100W9bL09RHV02HV9P0V9RH4
02LW9`0<02PX:00Z:RX0:b/[02l_;`0b<S80?Cdm04I6AP1:BTX0C4a<04m?C`1ADE40E5AD0P1GEeL0
1`1IFET0Fe]K05mOG`1PH600HF5Q06=SH`1TI6@00P1WIfL01`1ZJVX0KFe]071`L01`L700Lg=c07Ad
M01hN7P00`1jNWX05@1lO7`0Ogmo08R8R026QXH0RXZ:08V9R@2@T900UIFE09JFUP2GUiL0W9bL09fM
W@2QXJ40Y:BT0:NWY`2][Jd0[jn_0;2`/02c/k<0];Bd0;fm_@020<30`0080<G5a@3=cLd0c<c<0<_;
b`37alL0b<S80<;2`P30`<020;^k^`040;Vi^@2g]kL0]KFe0;>c/`80/[:b00X0/K6a0:f][@2^[Zh0
/[:b0;>c/`2b/[80];Bd0;Jf]P2b/[80];Bd0P2g]kL00`2j^[X0_kno0;jn_P020;Zj^P050;Ng]`2e
]KD0/[:b0;2`/02/[:`00P2SXj<05P2PX:00VIVI09FEU@2<S8`0QHF507moO`1hN7P0Kfm_06][J`1N
GUh0EEEE04];B`12@T80>SXj03<c<`0^;Rh0oooo02TY:@0X:2P09bLW02HV9P0W9bL602HV9P@0dLfY
00030=7=Z@X09RHV0`0W9bL03P0X:2P0:BTY02/[:`0^;Rh0<C4a03Hf=P14A4@0BDU904a<C01@D500
DU9B05=CD`1FEUH0EeMG0P1IFET0101KFe/0GUiN05mOG`1PH60206ATI00306IVIP1WIfL0J6QX0080
KFe]01@0LG5a07AdM01dM7@0MWIf07UiN@1lO7`0NWYj07emO@1nOWh0Ph>308J6QP27QhL0Rh^;09:B
TP2ATI40UIFE09ZJVP2KVi/0WYjN0:6QX@80Xj>S00P0Z:RX0:ZZZP2_[jl0[jn_0;>c/`2f][H0^[Zj
0<71`@80a<C400T0b<S80<O7a`37alL0a<C40<;2`P33`l<0_[jn0;fm_@2g]kL00`2c/k<01P2][Jd0
[:b/0:^[Z`2ZZZX0Zj^[0:j^[P<0/K6a00@0];Bd0:n_[`2`/;00/k>c102g]kL00`2f][H0/;2`0;:b
/P020:j^[P0E0:ZZZP2RXZ80W9bL09RHV02EUID0Shn?08R8R021PH40Ng]k07EeM@1/K6`0IFEU05]K
F`1ADE40B4Q80410@00i>CT0<C4a02`/;03oool0:BTY00<09bLW0P0V9RH00`0W9bL09RHV02HV9P02
02HV9P@0dLfY00030=7=Z@P09RHV00<09bLW02HV9P0V9RH00`0W9bL02@0X:2P0:BTY02`/;00_;bl0
=3@d03dm?@16ATH0CDe=051@D00205=CD`0:05EEE@1IFET0FEUI05QHF01IFET0Fe]K05eMG@1OGel0
HV9R06=SH`80IFEU00T0J6QX06YZJP1/K6`0KVi^071`L01cLg<0MGEe07UiN@1hN7P00P1kNg/02P1m
OGd0Ogmo07moO`26QXH0R8R808^;R`2<S8`0TI6A09FEU@2HV9P209bLW00;09fMW@2NWYh0XZ:R0:JV
YP2WYjL0Zj^[0:b/[02][Jd0]KFe0;Ng]`2l_;`00P31`L401`34a<@0a/K60<O7a`33`l<0`L710;bl
_02m_Kd00P2f][H01`2b/[80[jn_0:n_[`2ZZZX0YjNW0:JVYP2YZJT00P2[Zj/0902/[:`0ZJVY0:n_
[`2`/;00[Zj^0:^[Z`2ZZZX0[Zj^0:b/[02`/;00/k>c0:j^[P2[Zj/0YjNW0:RXZ02UYJD0XZ:R09bL
W02FUYH0TI6A08j>SP24Q8@0OWin07YjNP1_Kfl0J6QX065QH@1HF5P0CTi>04I6AP0n?Sh0=SHf02l_
;`0[:b/0oooo02PX:0<09bLW00<09RHV02LW9`0V9RH0100V9RH40=7=Z@000`3AcJT00`0U9BD09RHV
02HV9P0502HV9P0402LW9`0V9RH09RHV0?ooo`<09bLW00P0:BTY02/[:`0];Bd0<C4a03Lg=`11@D40
C4a<059BDP80EUIF00H0EeMG05QHF01IFET0F5QH05UIF@1MGEd205aLG004061PH01SHf<0HV9R06IV
IP80IfMW00H0JFUY06a/K01]KFd0Kfm_07=cL`1iNGT207QhN00>07UiN@1jNWX0O7al07inOP1oOgl0
QHF508R8R02<S8`0RXZ:092@T02DU9@0V9RH09^KV`2HV9P209fMW@0=0:2PX02QXJ40XZ:R0:JVYP2[
Zj/0[:b/0:j^[P2`/;00][Jf0;Zj^P2m_Kd0`<300<;2`P020<?3``070<;2`P30`<00_Kfm0;Vi^@2b
/[80/;2`0:j^[P020:FUY@0;0:JVYP2XZ:P0YjNW0:JVYP2WYjL0ZZZZ0:NWY`2XZ:P0ZJVY0:ZZZP2Y
ZJT00P2XZ:P06`2YZJT0Z:RX0:ZZZP2WYjL0YZJV0::RXP2OWil0VYZJ09VIV@2CTi<0SHf=08J6QP20
P800NWYj07AdM01[Jf/0Hf=S05iNGP1CDe<0BTY:0451@@0j>SX0<c<c02h^;P0Z:RX0oooo02PX:003
02LW9`L09RHV103AcJT000<0dLfY2@0V9RH202LW9`030?ooo`0W9bL09bLW0080:2PX00P0:BTY02/[
:`0`<300=CDe03/k>`1>CTh0EUIF05QHF080FUYJ00L0FEUI05YJFP1JFUX0FEUI05aLG01NGUh0GEeM
0080H61P00<0Hf=S06ATI01TI6@00P1XJ6P306a/K00B071`L01bLW80MWIf07UiN@1gMgL0NGUi07]k
N`1nOWh0OGem07moO`24Q8@0QHF508V9R@2<S8`0SHf=08n?S`2FUYH0UiNG0`2KVi/01P2MWId0WYjN
0:2PX02TY:@0YJFU0:NWY`80ZJVY00@0[jn_0;:b/P2f][H0_;bl0P30`<003`31`L40`/;20;jn_P2j
^[X0][Jf0;Bd]02b/[80ZJVY0:>SX`2PX:00Xj>S0:BTY02XZ:P0YJFU0:RXZ0020:NWY`070:JVYP2U
YJD0Y:BT0:2PX02RXZ80X:2P0:6QX@020:>SX`0G09nOW`2LW9`0V9RH09JFUP2CTi<0S8b<08R8R021
PH40OWin07AdM01aLG40IFEU061PH01GEeL0Cdm?04I6AP0n?Sh0=cLg030`<00/;2`0:BTY0?ooo`0X
:2P00`0W9bL702HV9P@0dLfY00030=7=Z@/09RHV00<0oooo02LW9`0W9bL00P0W9bL03@0Y:BT0:b/[
02l_;`0c<c<0>CTi04U9B@1HF5P0G5aL05eMG@1NGUh0GEeM05]KF`1LG5`00P1KFe/01P1OGel0GUiN
061PH01RHV80HF5Q069RHP<0IfMW00T0JFUY06a/K01^KVh0Kfm_079bLP1cLg<0MWIf07MgM`1hN7P0
0P1jNWX0301kNg/0OWin0820P020P800Q8B408V9R@2:RXX0Rh^;08j>SP2BTY80UiNG09BDU080VIVI
00L0W9bL09fMW@2QXJ40XJ6Q0:>SX`2TY:@0Z:RX0080ZZZZ00<0/k>c0;Bd]02l_;`00P2n_[h0;`32
`/80_kno0<30`02g]kL0];Bd0;:b/P2][Jd0Xj>S09nOW`2QXJ40X:2P0:FUY@2RXZ80Y:BT0:FUY@2S
Xj<0XZ:R09nOW`2PX:00WYjN09bLW02NWYh0W9bL09^KV`2LW9`0Vi^K09NGU`2DU9@0Ti>C08j>SP2;
Rh/0QHF507moO`1fMWH0LG5a06a/K01RHV80FUYJ059BDP1:BTX0@T9203Xj>P0d=3@0;Rh^02/[:`0Y
:BT0oooo00@09bLW00<09RHV02LW9`0V9RH0100V9RH40=7=Z@000`3AcJT00`0U9BD09RHV02HV9P08
02HV9P030?ooo`0W9bL09bLW00809bLW0P0Y:BT01@0];Bd0<C4a03Lg=`10@400FEUI0080Hf=S00L0
IFEU06=SH`1OGel0G5aL05eMG@1LG5`0GUiN0080GemO00L0Hf=S06ATI01RHV80I6AT06EUI@1VIVH0
J6QX0080Jf][00L0K6a/06i^KP1_Kfl0Lg=c07AdM01fMWH0N7Qh0080NGUi0P1mOGd0401nOWh0PH61
0861P@24Q8@0R8R808J6QP2<S8`0TI6A09:BTP2FUYH0VIVI09NGU`2JVYX0VIVI09fMW@2NWYh209nO
W`050:BTY02SXj<0Zj^[0:n_[`2a/K400P2h^;P0202l_;`0`L710;jn_P2m_Kd0^;Rh0;Jf]P2][Jd0
YjNW0P2VYZH00`2TY:@0XZ:R0:FUY@030:>SX`0O09nOW`2LW9`0Vi^K09bLW02GUiL0UIFE09BDU02C
Ti<0TY:B09>CT`2>SXh0SHf=08V9R@27QhL0PX:207inOP1hN7P0LG5a06][J`1UIFD0GEeM05ADE01?
Cdl0ADE503`l?00e=CD0<C4a02`/;00Z:RX0:BTY0?ooo`0302LW9`0402HV9P0W9bL09bLW02LW9`<0
9RHV00<09bLW0=7=Z@3AcJT00P3AcJT000<0dLfY2@0V9RH0100W9bL09RHV0?ooo`0V9RH302LW9`0=
02PX:00Y:BT0;2`/030`<00e=CD0>c/k04U9B@1XJ6P0KVi^06e]K@1/K6`0J6QX069RHP02065QH@80
GemO00@0H61P065QH@1QHF40IFEU0`1TI6@01P1UIFD0JVYZ06UYJ@1[Jf/0KVi^06m_K`80L71`00<0
LG5a07EeM@1dM7@00P1hN7P01`1nOWh0OGem07emO@1oOgl0OWin08:2PP24Q8@00P28R8P00`2=SHd0
Shn?09>CT`0209FEU@0409ZJVP2GUiL0UiNG09bLW0<0WIfM00h0X:2P0:>SX`2XZ:P0Zj^[0:n_[`2e
]KD0][Jf0;Zj^P2i^KT0^[Zj0;Fe]@2c/k<0/;2`0:RXZ080Y:BT00`0YZJV0:BTY02TY:@0XZ:R0:2P
X02NWYh0Vi^K09NGU`2CTi<0U9BD08n?S`2=SHd208^;R`0F08R8R027QhL0QHF508B4Q020P800Ng]k
07YjNP1bLW80Jf][06EUI@1OGel0EeMG04m?C`19BDT0@D5103Ph>00b<S80;Rh^02`/;00Z:RX0:2PX
0?ooo`<09bLW0P0V9RH00`0W9bL09RHV02HV9P0302HV9P@0dLfY00030=7=Z@/09RHV00<0oooo02LW
9`0W9bL00P0W9bL202PX:00>02XZ:P0];Bd0<S8b03Ph>011@D40FUYJ07EeM@1hN7P0MWIf07AdM01b
LW80J6QX06IVIP1TI6@2069RHP0306=SH`1RHV80IFEU0080IFEU00D0IVIV06MWI`1XJ6P0J6QX06YZ
JP0306e]K@0E071`L01_Kfl0LG5a07AdM01cLg<0MGEe07QhN01kNg/0O7al0861P@1nOWh0OGem0820
P023Ph<0PX:208N7Q`2;Rh/0SXj>08n?S`2>SXh0UIFE0080Ti>C00D0U9BD09NGU`2GUiL0V9RH09bL
W00209nOW`0<0::RXP2WYjL0Zj^[0:n_[`2d];@0]KFe0;Jf]P2g]kL0][Jf0;>c/`2_[jl0Zj^[0P2Z
ZZX03P2WYjL0YJFU0:6QX@2RXZ80W9bL09ZJVP2FUYH0TI6A08n?S`2<S8`0QhN708B4Q025QHD0P820
0P1nOWh04@1mOGd0N7Qh07EeM@1aLG40JVYZ06IVIP1MGEd0FEUI055AD@18B4P0@d=303`l?00e=CD0
;bl_02`/;00Z:RX0:BTY0080:2PX0`0W9bL602HV9P0302LW9`0V9RH0dLfY00<0dLfY00030=7=Z@<0
9RHV00@09BDU02HV9P0V9RH09BDU100V9RH00`3oool09RHV02LW9`0202LW9`80:2PX00T0:BTY02/[
:`0_;bl0=CDe03dm?@18B4P0GUiN0861P@20P8000P1mOGd0101dM7@0L71`06][J`1XJ6P406ATI003
06=SH`1UIFD0IfMW00<0IfMW00P0JVYZ06UYJ@1/K6`0KFe]06i^KP1]KFd0Kfm_079bLP80Lg=c00D0
M7Ad07UiN@1kNg/0NGUi07]kN`0207emO@80OWin00H0Ph>308B4Q025QHD0Rh^;08b<S02>SXh209:B
TP80TI6A0P2DU9@02P2HV9P0VIVI09ZJVP2MWId0WinO0::RXP2ZZZX0/k>c0;Jf]P2d];@30;6a/@03
0;2`/02b/[80[jn_0080[Zj^0200ZZZZ0:RXZ02TY:@0XZ:R09bLW02KVi/0TI6A08j>SP27QhL0Ph>3
0820P01mOGd0NWYj07QhN01gMgL0Lg=c071`L01]KFd0JVYZ06IVIP1OGel0EUIF059BDP1;Bd/0@d=3
03dm?@0g=cL0<C4a02`/;00[:b/0:BTY02PX:0@09bLW2@0V9RH40=7=Z@000`3AcJT602HV9P0302DU
9@0V9RH09RHV00809RHV00@0oooo02LW9`0V9RH09RHV0P0W9bL04`0X:2P0:BTY02/[:`0/;2`0=3@d
03Xj>P16ATH0Cdm?07QhN029RHT0QhN708R8R020P800N7Qh07=cL`1_Kfl0JVYZ06MWI`1XJ6P0101U
IFD00`1TI6@0IfMW06IVIP0306QXJ00B06YZJP1/K6`0KFe]06e]K@1_Kfl0LG5a079bLP1cLg<0M7Ad
07IfMP1hN7P0Ng]k07YjNP1kNg/0NWYj07emO@1nOWh0Ogmo0P25QHD02`27QhL0RHV908V9R@2:RXX0
SHf=08n?S`2@T900Shn?09>CT`2DU9@0V9RH0080VYZJ00H0WinO0:>SX`2ZZZX0[Zj^0;6a/@2_[jl3
0:j^[P0Q0;6a/@2_[jl0/;2`0;2`/02^[Zh0Zj^[0:NWY`2UYJD0WIfM09VIV@2BTY80SXj>08J6QP1n
OWh0NWYj07IfMP1eMGD0M7Ad07=cL`1]KFd0JVYZ06EUI@1SHf<0GemO05UIF@1ADE40CDe=04I6AP0o
?cl0>SXj03@d=00^;Rh0:b/[0080:BTY00@0:2PX02LW9`0W9bL09bLW2P0V9RH40=7=Z@000`3AcJT=
02HV9PD09bLW01@0:2PX02TY:@0[:b/0;bl_03Hf=P0o?cl0ATI605UIF@24Q8@0T92@09FEU@2ATI40
QhN70861P@1jNWX0MWIf06m_K`1/K6`0Jf][06QXJ080I6AT00L0IFEU06IVIP1VIVH0IfMW06IVIP1X
J6P0JVYZ0080Jf][00X0K6a/06][J`1]KFd0Kfm_079bLP1cLg<0M7Ad07MgM`1fMWH0MgMg0P1iNGT2
07]kN`80OGem0P1oOgl0>021PH40QXJ608R8R026QXH0Rh^;08b<S02=SHd0Shn?08f=S@2ATI40U9BD
09JFUP2GUiL0W9bL09fMW@2SXj<0ZJVY0:^[Z`2YZJT0ZZZZ0:f][@2_[jl0];Bd0;Zj^P2i^KT0^;Rh
0;Jf]P2_[jl0YjNW0:2PX02JVYX0U9BD08f=S@25QHD0OGem07EeM@1cLg<0Kfm_06a/K01YJFT0IVIV
065QH@1NGUh0G5aL05IFEP1ADE40Bd];04I6AP10@400>CTi03@d=00_;bl0;2`/02XZ:P0Y:BT0:2PX
0`0W9bL00`0V9RH09bLW02HV9P0802HV9P@0dLfY00030=7=Z@0302DU9@0V9RH09RHV00X09RHV00<0
9bLW02HV9P0W9bL00P0W9bL05@0X:2P0:BTY02XZ:P0/;2`0<C4a03Xj>P10@400CDe=069RHP2@T900
UYJF09bLW02MWId0T92@08b<S022PX80NGUi07EeM@1_Kfl0JVYZ06MWI`0206ATI00506IVIP1TI6@0
IfMW06IVIP1WIfL00P1YJFT0101ZJVX0Jf][06][J`1ZJVX206a/K00906i^KP1`L700Lg=c07AdM01f
MWH0MGEe07QhN01iNGT0N7Qh0080NGUi00H0NWYj07]kN`1lO7`0OGem07moO`21PH4208F5Q@0708R8
R02:RXX0SXj>08f=S@2<S8`0Shn?09:BTP0209BDU00W09VIV@2NWYh0X:2P0:>SX`2TY:@0ZZZZ0;6a
/@2i^KT0_Kfm0;^k^`2o_kl0^KVi0;Ng]`2c/k<0ZZZZ09^KV`2DU9@0SHf=0861P@1kNg/0LG5a06e]
K@1ZJVX0IVIV06=SH`1PH600GEeM05MGE`1DE5@0D51@04U9B@14A4@0?clo03/k>`0d=3@0<30`02d]
;@0Z:RX0:BTY0080:2PX0P0W9bL00`3oool09bLW02LW9`0902HV9P@0dLfY00030=7=Z@l09RHV100W
9bL202PX:00E02/[:`0];Bd0=3@d03Xj>P14A4@0Cdm?06e]K@2ATI40WinO0:>SX`2RXZ80XJ6Q09NG
U`28R8P0PH6107QhN01aLG40JVYZ06IVIP1WIfL0IFEU00<0IfMW0180IVIV06EUI@1WIfL0JFUY06YZ
JP1YJFT0Jf][06YZJP1]KFd0Jf][06e]K@1^KVh0M7Ad079bLP1dM7@0MWIf07EeM@1dM7@207IfMP0:
07MgM`1jNWX0Ng]k07QhN01jNWX0O7al07moO`22PX80Ph>308F5Q@80QXJ600l0QhN708V9R@2:RXX0
S8b<08j>SP2BTY80UYJF09BDU02HV9P0X:2P0:ZZZP2/[:`0^;Rh0;Zj^P2l_;`00P2k^k/06`2d];@0
]kNg0:f][@2RXZ80UIFE08b<S022PX80NGUi06m_K`1XJ6P0IFEU061PH01MGEd0FEUI05EEE@1BDU80
CDe=04Q8B012@T80?Cdm03Ti>@0e=CD0<30`02d];@0[:b/0:BTY02PX:00402LW9`030?ooo`0W9bL0
9bLW00T09RHV103AcJT000<0dLfY1P0V9RH00`0U9BD09RHV02HV9P0702HV9P0302LW9`0V9RH09bLW
0080:2PX01/0:BTY02/[:`0^;Rh0=3@d03`l?017AdL0EEEE06IVIP2@T900WIfM0:FUY@2VYZH0YjNW
09jNWP2CTi<0Ph>307]kN`1bLW80Kfm_06QXJ01YJFT0I6AT06EUI@1SHf<0IfMW06IVIP1UIFD00P1W
IfL01@1VIVH0JVYZ06UYJ@1ZJVX0KFe]0080Jf][00<0K6a/075aL@1aLG400P1`L7001`1dM7@0LG5a
07=cL`1gMgL0NGUi07EeM@1gMgL00P1dM7@0301fMWH0NGUi07inOP20P800PX:20861P@23Ph<0QHF5
08N7Q`26QXH0RHV908N7Q`80SHf=00H0T92@09RHV02PX:00Z:RX0:n_[`2g]kL20;Bd]00K0;Fe]@2c
/k<0[Jf]0:j^[P2TY:@0V9RH08b<S01nOWh0MWIf06YZJP1UIFD0H61P05]KF`1HF5P0De=C04i>CP1;
Bd/0B4Q804=3@`0o?cl0>3Ph03De=@0`<300;Bd]02/[:`0Z:RX0:2PX00D09bLW00<0oooo02HV9P0V
9RH0200V9RH00`0U9BD0dLfY0=7=Z@020=7=Z@000`3AcJT;02HV9P060?ooo`0V9RH09RHV02HV9P0W
9bL09RHV0P0W9bL302PX:00D02XZ:P0/;2`0;bl_03Hf=P11@D40C4a<05IFEP1fMWH0UiNG0:BTY02U
YJD0ZJVY0:FUY@2PX:00TY:B08:2PP1iNGT0M7Ad06a/K01WIfL206EUI@0406IVIP1TI6@0IFEU06=S
H`80IVIV0P1WIfL206QXJ00K06YZJP1YJFT0KFe]06e]K@1/K6`0Jf][071`L01^KVh0L71`06m_K`1`
L700Lg=c07UiN@1dM7@0L71`079bLP1aLG40M7Ad07IfMP1eMGD0NGUi07inOP20P800PX:20861P@20
P800PH610080Ph>300T0Q8B408N7Q`27QhL0SXj>09ZJVP2RXZ80Z:RX0:VYZ@2ZZZX00P2][Jd20:VY
Z@0H0:FUY@2OWil0VIVI08b<S01mOGd0Lg=c06QXJ01QHF40Fe]K05MGE`1DE5@0D51@04];B`17AdL0
@d=303lo?`0i>CT0=CDe038b<P0^;Rh0:b/[02XZ:P0Y:BT0:2PX0`0W9bL202HV9P030?ooo`0V9RH0
9RHV00T09RHV103AcJT000<0dLfY0`0V9RH00`0U9BD09RHV02HV9P0502HV9P030?ooo`0V9RH09RHV
00809RHV1@0W9bL202PX:00:02XZ:P0/;2`0<30`03Ph>010@400BDU905QHF01eMGD0UiNG09nOW`<0
YjNW00X0X:2P09JFUP27QhL0OWin07MgM`1_Kfl0Jf][06UYJ@1TI6@0IVIV0P1TI6@05P1SHf<0IVIV
06=SH`1VIVH0IfMW06QXJ01WIfL0JFUY06][J`1ZJVX0Jf][06YZJP1]KFd0JVYZ06e]K@1^KVh0KFe]
06i^KP1_Kfl0KVi^06m_K`1/K6`206i^KP07071`L01aLG40MWIf07IfMP1hN7P0O7al07]kN`0207em
O@090820P01lO7`0OGem07emO@1oOgl0PX:208j>SP2DU9@0WYjN0080Xj>S01P0Z:RX0::RXP2PX:00
WYjN0:6QX@2JVYX0Shn?08R8R01hN7P0Kfm_06EUI@1MGEd0EEEE059BDP1>CTh0BDU904E5A@10@400
?Cdm03Ti>@0d=3@0<30`02h^;P0/;2`202TY:@80:2PX1@0W9bL00`3oool09bLW02HV9P0902HV9P@0
dLfY00030=7=Z@/09RHV00@0oooo02HV9P0W9bL09RHV0P0W9bL202HV9P<09bLW0P0X:2P05`0Z:RX0
;2`/030`<00h>3P0?clo04Y:BP1GEeL0L71`09:BTP2NWYh0ZZZZ0:^[Z`2ZZZX0YZJV09jNWP2>SXh0
Q8B407]kN`1fMWH0LW9b06a/K01YJFT0I6AT0080Hf=S00L0I6AT069RHP1UIFD0IFEU06IVIP1WIfL0
IVIV0080J6QX00<0IfMW06QXJ01YJFT00P1WIfL00`1ZJVX0Jf][06YZJP0306][J`0706a/K01]KFd0
Jf][06a/K01]KFd0KVi^071`L00207=cL`0507MgM`1hN7P0MgMg07QhN01gMgL00P1fMWH01@1eMGD0
N7Qh07emO@25QHD0SXj>0080UiNG01X0Vi^K09NGU`2IVIT0V9RH09:BTP2ATI40QhN707inOP1bLW80
JFUY065QH@1IFET0DU9B04e=C@19BDT0A4A403lo?`0l?3`0>3Ph03@d=00a<C40;Rh^02/[:`0Z:RX0
:BTY02PX:0@09bLW00@09RHV02LW9`0V9RH0oooo2`0V9RH40=7=Z@000`3AcJT0100U9BD09RHV02DU
9@0V9RH202DU9@D09RHV00<0oooo02HV9P0V9RH0100V9RH502LW9`0I02PX:00Y:BT0:RXZ02d];@0a
<C40=cLg03lo?`19BDT0EUIF06EUI@2>SXh0WinO0:FUY@2ZZZX0YjNW0:JVYP2NWYh0UYJF08f=S@21
PH40Ng]k07EeM@1^KVh0J6QX06IVIP0306=SH`06069RHP1TI6@0Hf=S06ATI01VIVH0IfMW0P1VIVH0
1`1WIfL0IFEU06ATI01WIfL0IFEU06QXJ01VIVH01@1XJ6P0101ZJVX0JFUY06][J`1XJ6P206a/K003
06m_K`1^KVh0Lg=c00<0Lg=c00T0Kfm_06e]K@1/K6`0KVi^079bLP1fMWH0Ng]k08F5Q@28R8P00`2=
SHd0502>SXh0RXZ:08>3P`1kNg/0LW9b06YZJP1TI6@0GEeM05IFEP1?Cdl0AdM704=3@`0n?Sh0>SXj
03Hf=P0d=3@0<C4a02d];@0[:b/0:BTY0P0X:2P402LW9`809RHV00<09bLW02HV9P3oool02`0V9RH4
0=7=Z@000`3AcJT01@0V9RH09BDU02HV9P0V9RH09BDU00809RHV00D09BDU02HV9P0V9RH09RHV0?oo
o`0702HV9P809bLW0200:2PX02LW9`0X:2P0:BTY02XZ:P0[:b/0;Bd]034a<@0g=cL0@41004Y:BP1C
De<0J6QX08j>SP2MWId0YjNW0:ZZZP2/[:`0YjNW0:BTY02KVi/0Shn?08Z:RP1nOWh0M7Ad06m_K`1X
J6P0IVIV069RHP1UIFD0H61P065QH@@0I6AT0P1UIFD03`1SHf<0IVIV06=SH`1SHf<0IFEU06ATI01U
IFD0I6AT06IVIP1XJ6P0IVIV06MWI`1VIVH0JVYZ06QXJ00206MWI`0506UYJ@1[Jf/0Jf][06e]K@1[
Jf/00P1^KVh02P1]KFd0JFUY06QXJ01VIVH0JVYZ06i^KP1`L700MgMg07alO01nOWh208>3P`0E07mo
O`1lO7`0MWIf06i^KP1ZJVX0I6AT05iNGP1IFET0DU9B04a<C015ADD0@41003/k>`0g=cL0<c<c030`
<00^;Rh0:b/[02XZ:P0Y:BT0:2PX00@09bLW00<09RHV02LW9`0V9RH00P0V9RH00`3oool09RHV02HV
9P0502HV9P0402DU9@0V9RH09RHV02HV9P@0dLfY00030=7=Z@0302HV9P0U9BD09BDU00<09RHV0P0U
9BD302HV9P030?ooo`0V9RH09RHV00D09RHV1@0W9bL202PX:00?02TY:@0[:b/0;Bd]02l_;`0f=SH0
?clo04I6AP1?Cdl0HV9R0820P02IVIT0YJFU0:RXZ02YZJT0Zj^[0080XZ:R00P0Vi^K096AT@23Ph<0
N7Qh07AdM01/K6`0IfMW06IVIP80HV9R00@0Hf=S065QH@1QHF40HV9R0P1SHf<0101RHV80H61P065Q
H@1RHV83065QH@80HV9R00<0I6AT065QH@1UIFD00P1VIVH03@1UIFD0IfMW06ATI01UIFD0IVIV06EU
I@1XJ6P0IfMW06QXJ01VIVH0J6QX06UYJ@1SHf<00`1QHF40101UIFD0J6QX06QXJ01ZJVX306e]K@0B
06YZJP1XJ6P0I6AT06=SH`1LG5`0EeMG059BDP1>CTh0AdM70410@00k>c/0=cLg038b<P0_;bl0;Bd]
02/[:`0Z:RX0:BTY0P0X:2P302LW9`0302HV9P0W9bL09RHV00l09RHV103AcJT000<0dLfY0`0U9BD8
02HV9P030?ooo`0V9RH09RHV00H09RHV0P0W9bL00`0U9BD09bLW02LW9`0202PX:00J02TY:@0Z:RX0
;2`/030`<00f=SH0>SXj04A4A01>CTh0EUIF071`L02EUID0Xj>S0:VYZ@2ZZZX0ZJVY0:NWY`2PX:00
WinO09BDU027QhL0OWin07EeM@1bLW80JVYZ06IVIP1TI6@2065QH@04069RHP1QHF40HF5Q061PH0<0
HF5Q00D0GUiN061PH01OGel0GemO05iNGP02065QH@05061PH01QHF40H61P06=SH`1QHF400P1RHV80
0`1TI6@0Hf=S065QH@02065QH@0506=SH`1QHF40HV9R069RHP1QHF400`1NGUh205mOG`03061PH01O
Gel0GemO0080GUiN0100Fe]K05aLG01HF5P0F5QH05=CD`1@D500BTY:04M7A`12@T80?3`l03Ph>00c
<c<0;bl_02d];@0[:b/0:RXZ0P0X:2P402LW9`0302HV9P0W9bL09RHV01009RHV103AcJT000<0dLfY
00@09BDU02HV9P0V9RH09BDU0P0V9RH202DU9@<09RHV00<0oooo02HV9P0V9RH0100V9RH00`0W9bL0
9RHV02LW9`0402LW9`<0:2PX00d0:BTY02XZ:P0[:b/0;Rh^03<c<`0j>SX0@T9204Q8B01EEED0IVIV
08^;R`2GUiL0Xj>S0080YjNW00X0Zj^[0:FUY@2PX:00VIVI08n?S`22PX80NGUi07=cL`1^KVh0JFUY
0P1SHf<00`1PH600GemO05iNGP0205mOG`0705iNGP1PH600GUiN05eMG@1PH600GEeM05mOG`0205iN
GP80G5aL00h0GEeM05iNGP1NGUh0H61P05iNGP1MGEd0GUiN05mOG`1MGEd0G5aL05eMG@1LG5`0GUiN
05eMG@80G5aL01P0Fe]K05aLG01IFET0EeMG05IFEP1GEeL0EEEE05IFEP1DE5@0DE5A051@D01?Cdl0
CDe=04];B`17AdL0@d=30451@@0k>c/0=SHf03<c<`0`<300;2`/02XZ:P0Y:BT202PX:0@09bLW00<0
9RHV02LW9`0V9RH00`0V9RH00`0W9bL09RHV02HV9P0802HV9P0302DU9@0V9RH09RHV00@0dLfY0003
0=7=Z@0302DU9@0V9RH09RHV00<09RHV00<09BDU02HV9P0V9RH02`0V9RH202LW9`0302HV9P0W9bL0
9bLW00809bLW0P0X:2P202TY:@0<02`/;00];Bd0<C4a03Lg=`0m?Cd0ADE504i>CP1IFET0Kfm_08n?
S`2MWId0YjNW0P2XZ:P03`2VYZH0Xj>S0:2PX02HV9P0RHV90861P@1eMGD0L71`06][J`1VIVH0I6AT
069RHP1OGel0H61P05mOG`0205eMG@0505iNGP1LG5`0GEeM05aLG01KFe/00P1JFUX205]KF`0@05YJ
FP1IFET0G5aL05aLG01KFe/0GEeM05]KF`1JFUX0FEUI05YJFP1HF5P0EUIF05QHF01IFET0F5QH05MG
E`80EUIF01H0EEEE059BDP1CDe<0DE5A04m?C`1>CTh0CDe=04a<C019BDT0ATI604A4A012@T80@410
03`l?00j>SX0=CDe038b<P0^;Rh0;2`/02XZ:P0Y:BT0:2PX1@0W9bL0100V9RH09bLW02HV9P0W9bL5
02HV9P030?ooo`0V9RH09RHV00T09RHV103AcJT000<0dLfY00<09BDU02HV9P0U9BD01`0V9RH00`0U
9BD09RHV02HV9P0902HV9P0302LW9`0V9RH09RHV00@09bLW0P0X:2P08P0Y:BT0:b/[02h^;P0a<C40
=SHf03`l?016ATH0C4a<05EEE@1ZJVX0SHf=09fMW@2OWil0YZJV0:6QX@2UYJD0Xj>S0:6QX@2IVIT0
SHf=08:2PP1gMgL0LG5a06a/K01VIVH0IFEU061PH01OGel0GEeM05aLG01MGEd0G5aL05]KF`1MGEd2
05]KF`0305UIF@1JFUX0FEUI00@0F5QH00D0FEUI05QHF01IFET0FEUI05QHF00305MGE`0;05ADE01C
De<0E5AD059BDP1CDe<0DE5A051@D01ADE40D51@04i>CP1<C4`00P18B4P03P17AdL0ADE504=3@`11
@D40?clo03`l?00k>c/0>3Ph03Hf=P0b<S80;Rh^02d];@0[:b/0:BTY0P0X:2P302LW9`0302HV9P0W
9bL09bLW00@09RHV00D09bLW02HV9P0V9RH09RHV0?ooo`0;02HV9P@0dLfY00030=7=Z@809BDU00<0
9RHV02DU9@0V9RH0400V9RH0100W9bL09RHV02HV9P0V9RH502LW9`80:2PX00d0:BTY02XZ:P0];Bd0
;Rh^03<c<`0j>SX0@41004M7A`1@D500F5QH07EeM@2;Rh/0Vi^K0080XZ:R0180Y:BT0:RXZ02SXj<0
WinO09RHV02:RXX0OWin07MgM`1]KFd0J6QX06ATI01RHV80GUiN05aLG01MGEd0G5aL05YJFP1KFe/2
05QHF00505YJFP1GEeL0EEEE05IFEP1CDe<00P1DE5@00`1CDe<0EEEE05ADE00205ADE00M05EEE@1C
De<0DU9B051@D01ADE40CTi>04a<C01=CDd0C4a<04e=C@1;Bd/0BTY:04U9B@16ATH0A4A404=3@`11
@D40?clo03`l?00k>c/0>CTi03Lg=`0d=3@0<S8b030`<00];Bd0;2`/02XZ:P0Y:BT00P0X:2P402LW
9`<09RHV00<09bLW02HV9P0V9RH01@0V9RH00`3oool09RHV02HV9P0902HV9P@0dLfY00030=7=Z@80
9RHV00D09BDU02HV9P0U9BD09RHV02DU9@0402HV9P030?ooo`0V9RH09RHV00P09RHV00@09bLW02HV
9P0V9RH09RHV1@0W9bL00`0Y:BT0:2PX02TY:@0202XZ:P0<02d];@0a<C40=cLg03/k>`11@D40BDU9
059BDP1KFe/0Lg=c08n?S`2KVi/0XJ6Q0P2SXj<03@2TY:@0X:2P09^KV`2@T900QhN707]kN`1aLG40
Jf][06ATI01RHV80GUiN05eMG@1KFe/00P1JFUX00`1GEeL0EEEE05EEE@0205=CD`0;05ADE01ADE40
D51@04m?C`1ADE40Cdm?055AD@1=CDd0D51@04i>CP1<C4`00P1=CDd00`1<C4`0Bd];04Q8B00204M7
A`80ATI60P13@d<03`12@T80?clo03hn?P0l?3`0>SXj03Lg=`0e=CD0=3@d034a<@0_;bl0;Bd]02`/
;00[:b/0:RXZ02TY:@0202PX:0@09bLW0`0V9RH202LW9`L09RHV00<0oooo02HV9P0V9RH01P0V9RH0
0`0U9BD09RHV02HV9P040=7=Z@000`3AcJT01@0U9BD09RHV02DU9@0V9RH09BDU00809RHV00D09BDU
02HV9P0V9RH09RHV0?ooo`0>02HV9PL09bLW0`0X:2P07@0Z:RX0;Bd]030`<00b<S80=cLg03dm?@13
@d<0BDU9055AD@1MGEd0MGEe08Z:RP2IVIT0WinO0:6QX@2PX:00WIfM09RHV02GUiL0RXZ:07alO01c
Lg<0Jf][06IVIP1QHF40GUiN05aLG01IFET0F5QH0080EeMG00P0EUIF05ADE01BDU80DE5A051@D01?
Cdl0CTi>04e=C@@0Bd];00/0BDU904Q8B018B4P0B4Q804M7A`16ATH0A4A404=3@`12@T80@D510410
@00203hn?P0;03`l?00k>c/0>3Ph03De=@0c<c<0<S8b030`<00^;Rh0;Bd]02`/;00Z:RX00P0Y:BT3
02PX:0H09bLW2`0V9RH00`3oool09RHV02HV9P0202HV9P0402DU9@0V9RH09RHV02DU9@<09RHV103A
cJT000<0dLfY0P0V9RH00`0U9BD09RHV02HV9P0202HV9P0502DU9@0V9RH09RHV02HV9P3oool03@0V
9RH00`0W9bL09RHV02LW9`0602LW9`80:2PX01d0:BTY02XZ:P0[:b/0;Bd]02l_;`0d=3@0>3Ph03`l
?014A4@0BDU9059BDP1HF5P0JVYZ08F5Q@2@T900VIVI09ZJVP2HV9P0UiNG09>CT`28R8P0NGUi07Ad
M01[Jf/0IFEU065QH@1NGUh0FUYJ05QHF00205EEE@0705=CD`1BDU80DE5A051@D01=CDd0BTY:04];
B`0304Q8B00=04M7A`16ATH0ADE504A4A013@d<0A4A404=3@`11@D40?clo03hn?P0m?Cd0?3`l03/k
>`0203Ti>@0903De=@0d=3@0<c<c034a<@0_;bl0;Rh^02`/;00[:b/0:RXZ0080:BTY0P0X:2P202LW
9`809RHV00<09bLW02HV9P0V9RH00P0V9RH00`0W9bL09RHV02HV9P0802HV9P030?ooo`0V9RH09RHV
00T09RHV103AcJT000<0dLfY00@09RHV02DU9@0U9BD09BDU100V9RH0100U9BD09RHV02HV9P3oool@
02HV9PP09bLW0P0X:2P09@0Y:BT0:b/[02d];@0^;Rh0<C4a03De=@0j>SX0@41004A4A01;Bd/0DE5A
05aLG01ZJVX0PX:208j>SP2CTi<0UIFE09BDU02?Shl0QHF507emO@1cLg<0JFUY06IVIP1OGel0Fe]K
05IFEP1GEeL0E5AD059BDP1@D500Cdm?04e=C@1>CTh0BTY:04U9B@17AdL00`14A4@01012@T80@D51
0410@010@40203lo?`0703hn?P0l?3`0>c/k03Xj>P0h>3P0=cLg03De=@0203@d=004034a<@0`<300
;Rh^02`/;080:b/[00H0:RXZ02TY:@0Y:BT0:2PX02LW9`0X:2P402LW9`0302HV9P0W9bL09RHV00d0
9RHV00<0oooo02HV9P0V9RH0100V9RH01@0U9BD09RHV02HV9P0V9RH09BDU00@0dLfY00030=7=Z@03
02DU9@0V9RH09RHV00809BDU00<09RHV02DU9@0U9BD00`0V9RH00`3oool09RHV02HV9P0@02HV9PL0
9bLW0P0X:2P202TY:@0X02XZ:P0/;2`0;Rh^034a<@0e=CD0>c/k03hn?P14A4@0B4Q804a<C01DE5@0
GEeM06a/K01kNg/0QhN708Z:RP28R8P0QHF507alO01_Kfl0Jf][06ATI01NGUh0FUYJ05EEE@1CDe<0
D51@04m?C`1=CDd0C4a<04Y:BP17AdL0ATI604E5A@12@T80@D5103lo?`0n?Sh0?Cdm03`l?080>c/k
00L0>CTi03Ph>00g=cL0=SHf03De=@0d=3@0<S8b0080<30`00D0;Rh^02d];@0[:b/0:b/[02XZ:P02
02TY:@<0:2PX1@0W9bL202HV9P<09bLW3@0V9RH00`3oool09RHV02HV9P0602HV9P0302DU9@0V9RH0
9RHV00@0dLfY00030=7=Z@0602HV9P0U9BD09BDU02DU9@0V9RH09BDU0P0V9RH202DU9@0302HV9P3o
ool09RHV01409RHV0`0W9bL202HV9P809bLW100X:2P09P0Y:BT0:RXZ02XZ:P0/;2`0;Rh^038b<P0c
<c<0>3Ph03`l?010@400A4A404Q8B01>CTh0DE5A05MGE`1QHF40KVi^07EeM@1gMgL0LW9b06][J`1U
IFD0GemO05UIF@1FEUH0DU9B051@D01>CTh0Bd];04U9B@16ATH0ADE504=3@`10@400?Shn03dm?@0l
?3`0>SXj0P0h>3P02@0g=cL0=SHf03De=@0e=CD0<c<c038b<P0a<C40<30`02h^;P0202`/;00402/[
:`0Z:RX0:BTY02TY:@<0:2PX1@0W9bL0100V9RH09bLW02HV9P0W9bLM02HV9P@0dLfY00030=7=Z@L0
9BDU00H09RHV02DU9@0V9RH09BDU0?ooo`0U9BD;02HV9P0302DU9@0V9RH09RHV00H09RHV00<09bLW
02HV9P0W9bL01@0W9bL202PX:080:BTY00/0:RXZ02`/;00];Bd0;bl_03<c<`0e=CD0>3Ph03`l?00o
?cl0@T9204=3@`0204M7A`0304Y:BP1?Cdl0De=C0080F5QH0140FUYJ05IFEP1DE5@0D51@04a<C01:
BTX0B4Q804E5A@14A4@0@T920410@00n?Sh0?3`l03Xj>P0g=cL0=SHf03De=@0203<c<`04038b<P0`
<300<30`02h^;P80;Bd]00H0;2`/02/[:`0Z:RX0:RXZ02PX:00Y:BT302PX:0X09bLW6P0V9RH0100U
9BD09RHV02HV9P0U9BD40=7=Z@000`3AcJT302DU9@809RHV0P0U9BD01@0V9RH09BDU02HV9P0V9RH0
oooo01409RHV00<09bLW02HV9P0W9bL00`0W9bL00`0V9RH09bLW02LW9`0302LW9`<0:2PX0`0Y:BT0
5@0Z:RX0:b/[02d];@0_;bl0<C4a03@d=00g=cL0>CTi03/k>`0m?Cd0?clo0492@P10@400@D510492
@P11@D40@d=30451@@13@d<0ADE504I6AP0204=3@`090492@P0n?Sh0?Shn03`l?00j>SX0>3Ph03Hf
=P0d=3@0<c<c0080<30`00<0;Rh^030`<00/;2`00P0/;2`00`0[:b/0:RXZ02XZ:P0302TY:@<0:2PX
0`0W9bL00`0V9RH09bLW02HV9P0202LW9a/09RHV00L09BDU02HV9P0V9RH09RHV02DU9@0V9RH09BDU
00@0dLfY00030=7=Z@@09BDU00P09RHV02DU9@0V9RH09BDU02HV9P0U9BD09RHV02DU9@809RHV2@3o
ool202HV9P0302DU9@3oool0oooo00H0oooo0`0W9bL90?ooo`80:2PX00<0:BTY0?ooo`3oool01P3o
ool00`0e=CD0=cLg03Lg=`080?ooo`0403@d=00c<c<0<c<c038b<PP0oooo0P0[:b/00`0Z:RX0oooo
0?ooo`060?ooo`0402PX:00W9bL09bLW02LW9`P0oooo0P0V9RH00`0W9bL0oooo0?ooo`060?ooo`<0
9RHV2@3oool;02HV9P@0dLfY00030=7=Z@0302HV9P0U9BD09RHV00809BDU00@09RHV02DU9@0V9RH0
9BDU0P0V9RH01`0U9BD09RHV02DU9@0V9RH09BDU02HV9P0U9BD03`0V9RH00`0W9bL09RHV02HV9P03
02LW9`809RHV1@0W9bL302PX:00402TY:@0X:2P0:BTY02TY:@80:b/[00<0;2`/02d];@0^;Rh00P0_
;bl4030`<00302l_;`0`<300<30`00<0;bl_0P0^;Rh202d];@80;2`/0P0[:b/00`0Z:RX0:BTY02TY
:@0202TY:@0302PX:00Y:BT0:2PX00@0:2PX2P0W9bL302HV9P809bLW6P0V9RH00`0U9BD09RHV02DU
9@0202HV9P0302DU9@3AcJT0dLfY0080dLfY00030=7=Z@0502DU9@0V9RH09BDU02HV9P0U9BD00P0V
9RH202DU9@0302HV9P0U9BD09BDU00809RHV00<09BDU02HV9P0V9RH0100V9RH00`0U9BD09RHV02HV
9P0>02HV9P`09bLW0`0X:2P302TY:@<0:RXZ0`0[:b/202`/;00402/[:`0/;2`0;2`/02`/;080:b/[
1P0Z:RX302TY:@H0:2PX1@0W9bL402HV9P0602LW9`0V9RH09RHV02LW9`0V9RH09bLW2@0V9RH00`0W
9bL09RHV02HV9P0A02HV9P0302DU9@0V9RH09BDU00@09RHV00<09BDU0=7=Z@3AcJT00P3AcJT000<0
dLfY0P0V9RH202DU9@0302HV9P0U9BD09RHV00809BDU00<09RHV02DU9@0U9BD00P0U9BDA02HV9P03
02LW9`0V9RH09RHV00<09RHV00@09bLW02HV9P0W9bL09RHV0P0W9bL00`0V9RH09bLW02LW9`0702LW
9`D0:2PX00D0:BTY02PX:00Y:BT0:BTY02XZ:P0302TY:@0302PX:00Y:BT0:BTY00<0:BTY1@0X:2P0
0`0W9bL0:2PX02LW9`0502LW9`0502HV9P0W9bL09bLW02LW9`0V9RH00`0W9bL00`0V9RH09bLW02HV
9P0G02HV9P0302DU9@0V9RH09RHV00d09RHV00<09BDU02HV9P3AcJT00`3AcJT000<0dLfY00<09BDU
02HV9P0U9BD00P0U9BD302HV9P0402DU9@0V9RH09RHV02DU9@@09RHV00<09BDU02HV9P0V9RH01P0V
9RH202DU9@h09RHV00D09bLW02HV9P0V9RH09bLW02HV9P0;02LW9`D0:2PX00<09bLW02PX:00X:2P0
0`0X:2P01P0W9bL0:2PX02PX:00X:2P09bLW02PX:0X09bLW0P0V9RH00`0W9bL09RHV02HV9P0302HV
9P0402LW9`0V9RH09bLW02LW9ah09RHV00<09BDU02HV9P0V9RH0100V9RH202DU9@809RHV103AcJT0
00<0dLfY00<09RHV02DU9@0V9RH0100V9RH202DU9@0402HV9P0U9BD09RHV02DU9@<09RHV00D09BDU
02HV9P0V9RH09RHV02DU9@0C02HV9P0302LW9`0V9RH09RHV00@09RHV1@0W9bL00`0V9RH09bLW02LW
9`0G02LW9`<09RHV00@09bLW02HV9P0W9bL09RHV0`0W9bL602HV9P0302LW9`0V9RH09RHV01X09RHV
0P0U9BD00`0V9RH09BDU02DU9@0302HV9P0302DU9@0V9RH09RHV00809BDU00<09RHV0=7=Z@3AcJT0
0P3AcJT000<0dLfY00D09BDU02HV9P0U9BD09RHV02DU9@0202HV9P<09BDU0P0V9RH302DU9@H09RHV
0P0U9BD202HV9P0302DU9@0V9RH09RHV00P09RHV00<09bLW02HV9P0V9RH01@0V9RH01@0W9bL09RHV
02HV9P0V9RH09bLW00@09RHV1P0W9bL00`0V9RH09bLW02LW9`0:02LW9`0302HV9P0W9bL09bLW00@0
9bLW00@09RHV02LW9`0V9RH09bLW0`0V9RH00`0W9bL09RHV02HV9P0Q02HV9P0302DU9@0V9RH09BDU
00809RHV0P0U9BD0200V9RH09BDU02HV9P0V9RH09BDU02HV9P0U9BD09RHV103AcJT000<0dLfY00<0
9BDU02HV9P0U9BD00P0U9BD00`0V9RH09BDU02HV9P0302DU9@<09RHV00<09BDU02HV9P0V9RH01@0V
9RH00`0U9BD09RHV02HV9P0I02HV9P<09bLW00<09RHV02LW9`0W9bL00`0V9RH702LW9`0302HV9P0W
9bL09RHV00L09RHV0P0W9bL602HV9P0302LW9`0V9RH09RHV01d09RHV00D09BDU02HV9P0V9RH09RHV
02DU9@0402HV9P809BDU00<09RHV02DU9@0V9RH00P0U9BD502HV9P@0dLfY00030=7=Z@l09BDU0P0V
9RH202DU9@0402HV9P0U9BD09BDU02HV9P<09BDU00<09RHV02DU9@0V9RH05@0V9RH00`0W9bL09RHV
02HV9P0402HV9P0502LW9`0V9RH09RHV02HV9P0W9bL00P0V9RH202LW9`0302HV9P0W9bL09bLW00<0
9RHV00<09bLW02HV9P0W9bL01`0V9RH0100W9bL09RHV02LW9`0V9RH202LW9a@09RHV00<09BDU02HV
9P0V9RH00P0V9RH0100U9BD09RHV02HV9P0U9BD202HV9P0302DU9@0V9RH09RHV00<09RHV00D09BDU
02HV9P0U9BD09BDU02HV9P0202DU9@<09RHV00<09BDU02HV9P3AcJT00`3AcJT000<0dLfY100U9BD0
0`0V9RH09BDU02DU9@0402DU9@809RHV0P0U9BD>02HV9P0302DU9@0V9RH09RHV01409RHV00<09bLW
02HV9P0V9RH00P0V9RH202LW9`H09RHV0P0W9bLb02HV9P0302DU9@0V9RH09RHV00809RHV00@09BDU
02HV9P0V9RH09BDU2@0V9RH00`0U9BD09RHV02DU9@0202DU9@@0dLfY00030=7=Z@809BDU00D09RHV
02DU9@0U9BD09BDU02HV9P0202DU9@0502HV9P0U9BD09BDU02HV9P0U9BD00P0V9RH202DU9B@09RHV
00<09bLW02HV9P0V9RH02P0V9RH202LW9`/09RHV00<09bLW02HV9P0V9RH0:`0V9RH202DU9@D09RHV
00@09BDU02HV9P0U9BD09BDU103AcJT00900dLfY002@0=7=Z@00T03AcJT00900dLfY0000\
\>"],
  ImageRangeCache->{{{180, 323}, {664.062, 521.062}} -> {-689.508, 1946.12, \
3.75948, 3.75948}}]
}, Open  ]],

Cell[TextData[{
  "Before running the restoration algorithm on the observed image, an \
estimate for the 2D support values ",
  Cell[BoxData[
      StyleBox[\(p\_\(x, \ FITS\)\),
        FontWeight->"Bold"]]],
  " and ",
  Cell[BoxData[
      StyleBox[\(p\_\(y, \ FITS\)\),
        FontWeight->"Bold"]]],
  " of the inverse filter ",
  Cell[BoxData[
      RowBox[{
        StyleBox[" ",
          FontWeight->"Plain"], 
        StyleBox[\(s\_\(\(\ \)\(FITS\)\)\),
          FontWeight->"Bold"]}]]],
  " is also given as input. The computational time required by the \
restoration is also shown."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({p\_\(y, \ FITS\), \ p\_\(x, \ FITS\)}\  = \ {17, \ 
          17};\)\), "\[IndentingNewLine]", 
    \(\(s\_FITS\  = \ 
        Table[DiscreteDelta[i, \ j], \ {i, \ \(-p\_\(y, \ FITS\)\), \ 
            p\_\(y, \ FITS\)}, \ {j, \ \(-p\_\(x, \ FITS\)\), \ 
            p\_\(x, \ FITS\)}];\)\), "\[IndentingNewLine]", 
    \(\(\[Mu]\_FITS\  = \ {0, 0, 10, 0};\)\), "\[IndentingNewLine]", 
    \(\(Timing[\({res\_FITS, \ val\_FITS, \ variation\_FITS}\  = \ 
            NSHRIF[g\&~\_FITS, \ s\_FITS, \ \[Mu]\_FITS, \ 
              n\_\(y, \ FITS\), \ n\_\(x, \ FITS\), 
              NSHRIFMaxIterations \[Rule] 3];\)]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \(326.02`\ Second\)], "Output"]
}, Open  ]],

Cell["The restored image after three iterations is the following:", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(showImage[res\_FITS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0238095 0.00186012 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
512 string
512 512 8 [512 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0D090B090A0C0B0D090A090C0B0C0B0E0D090C0B0B0D0B0B0C0B0B0A0B
080C0D0A0A0A0A0A0A0C0B0A0B0C0C090C0D0B0B0C0A0D0C0C0B0A0B0B080C090B0B0A0B
0C0D0A0B0A0A0B0E0A0A090D0D0A0A090909090A0A0B0A0D090E0B0A080B0B09060B090D
0A080A0B0A0B0A0B080A0B0906070806090708060A070307060407050304010404040203
000102000100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000002030000020102040304040608090407060808060A0809090909
0A090B0B09080B08080D090A08090B0B09090A0A0B0C0B0C0C0B0A0C0A090A09090B0C0C
0B0B0C0C0C0C0C0B0A0C0B0B0C0C0C0A0B0D0B090B0A0B0909090A0B0C0B0C0D0B0C0A0C
0B0A0B0A0C0C0B090B090B0B090C080B0B0B0C0B0B090A0C0B0A0C0B0A0B09090B090A0B
0C090C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0A070C0A0A0B09090A0B0C0B0A0A090B09090B0A0C0A0C0C0C0C0B0D0B
090C0A0C090C0A0A0A0D0B0A0C0A0A0B070C0C0D0B0C0A0B070C0B0B0A0B09080E0C0C0B
0B080B0A090B0C0B0A0D0B0B090B0C0D090C0A0A0A0C0C0C07090B0C0C090B0B0B090B09
090A0A0A0809090A08070B070505080909050708070A0707050505010504030105030300
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000001040103060405060205060908050706070B070A08
08080B090908080A090B0908080B0A0C0B0A0A08080B090C090A08090B0C0B090C0C0C0A
090B0A0B0A0B090C0B0A0B0C0D0A0D090A0B0C090C0B0B0B0B0A0B0C0A090B090A0C090B
0A0B0B0B0B0A0A0D0C0B090D0A0B0C0B0A0A0C090D0B0B0B0C0A0A0C0C0B090C0C0C0B0C
0B0C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0A0B0B0B0C0A0C0B0D090B0A090B090A0C0A0B0D0C0D0D090B0D0A0B0C
0F0D0A08090C0C0B0C080C0A0E0B0B0B0A0B0C0B090D090D0C0A0A0B0C0B090D0B0B0B0B
0D0A0B0B090D080A09090C0A0B0C0B0A0C090B0A0C0B09090A09080B0E0A090B0A0A0A09
0B0808080806070808090909080608040908080806050804060403030502020302010001
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000200010204030205060503040607070407090506
080907090708090A090B080A0C0B09080C0E09080B090B0B0B0A0C09090C0C0A0D0B0E0C
090B0B090C0B0B0B0A0C0C0B0C090C0A090A0B0C0B090B0B0C0A0B090D0A0A0C0A0B0A0B
0A0D0C090B0A090C09090B0B0C0A0B0A0A0A0B0A0A090B090D0C0B0B0A0A080A0A0A090D
0B0A08000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B0D0C0A0C0C0B080D0B0D0A0D0B0B0C0A0B0B0B0A0B0C0C0C0C0B0C0D
0A0A090B0A0D0B090C0C0A0D0C0A0D0A090C090B0A0D0C0B0B0C0B0B0B0B0A0B0D09090A
0C0A090B0B0A0B090A0B0B0A0D0D0D0A0C0D0D0A0C0A09090C090A0A0B090C0B0B0A0B0B
07090A0A08090B080A060A08090709060705060509040407040206020402020200010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000200000102020402040304050507070708080A
0706070607090A0A080B0B090C0A0A090A0A0A0B0A0C080C0A0B090A0A09090B090B0B0A
0B0B090B0A0A0B09090C0C0A090A0B0C0B0A0A0B0A090B0B0B0B0C0A09090B0C0A0C0C0C
09090B0B0B0B0A0C0A090A0B0A0B0B0B0A0D0C0B0A0C0B0C09090A0C0C0B0B0A0A0D0D0A
0D0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B090C0A0809090B0E0B0B0A0A0C0B0B090C080B0D0C0A0B0C0A090C0C0B
0B0A090A0C0C0B0A0B0A0B0C080C0C0D080C0A0B0A0B0B0B0B0C0A0B0B080A0B0B090A0C
0B0C090A0B0C0C0D070A0D0B0C0B090B0B0A070A0C0C0B0B07090B0B0B08090A090D0908
0B090909070707070A050708050605050608050703030300050303040101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000100020300030508040506070808
070609080B090A09060A080B0C0A0A0C090A0C0908090B0A090B0A0D09090B0A0B0B0A0B
0B0A0A0C0B090A0C0A0B0C0A0C0A0B090D0A0A0C0C0D0B0B0D0A0B0A0B0A0B0C0B0A090B
0B090C0A0C0C0A0B0B0B0C0A0B090D090C0B0C0A0B0A090B0A0C0A0B0B0D0A0B0B0C0B0B
0B0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0C09090B0D0C0D0B0A080E0A0C0B0B08090D0D0B0B0C0A0A0B090C0A080B
0A0C090C0B090D0E0B0D090C0A0B0C090B0A0B0C0A0B0C0C0B0E080D0A0C0B0B0C0B0B0A
0B0B0B090A0A0B0C090B0B0B0B0B090A0B0B0A0B0B0A0B0A0908080B0C080B0809090A09
090909060B07090604070507030605050303020304060103020200010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002010102020404030606060706
0606060809090809070909080B0B0C09090B0A0B0B0A0B0A0C0C0A0A0B0A0D090A0B0C09
0B090C0C0D0A0A0A0A0B0B090A0A0B0C090A0A0B0C0B0C0B0A0A090A0D0B090A0C0C0D08
0A0A0C0B0A0C0C0B0D0B080C0B0B0A0C0C0A0B0A0B0A0A0B0B0C0B0A0D0B0C0A0A0B0A0A
0B090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0A090B0B0A0909090A0A0D0A0B0B0A0B0B0D0B0A0F0A0C0A0B0C090A0C
0C0B0B0D080C090B090D0B090B0C0C0B0C0C090C0A0B0B0A0A090A0A0A0C0A0C0B090B0C
0C0D0A0C09090C0908090C090C0C090A0A0C080C090C0A09060B090A0B0A060908080806
090906080A07070708070608060404050204050302040102000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003000201040304070705
060808080706060707090A0C0908090A080A090A090B090B0A080A090B090C0D080A0A0B
0B0B080B0B0C090B0B0B0C0B0A0A0B0B0B0A0B0C0A090B0A0C0B0B080B0B0C0B0A0A0A0C
0B0C0B0A0B090A0B0B0C0D0A0A0C0C0B0C0A0B0C0C0C0A090B0B0A0D0A09090C0C0B0C0A
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0A0B0C0A0C090B0C0B0C0B0B090B0B0B090B0A0A0A0B0C0C0B0B0C0B0C
0D0A080A0A0A0B0A0B090C0D090B0D0C0C0A0A0D0A0C0B0A090C0B0C0A090E09080A0C0A
090A0A0B0A0B0C0A0A0D0C0A090A0B0A0A0A0A0A0E0B0A0B0D09090B0A080A0A090A0905
080708070708060604040607030403060405000103010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000800080C06080C07100E0D10
160D0C090B000A0A02000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010201000403050405
040606080A080608090606080B0B0908090C0B070A09090A0B0B0D090B0A0B0A0A0A0A09
0C090B0B0A0B0C0C090B0A0A0A0C0D080A0A090C090A0B090C0A0C0C0B080A090C0A0B0B
0B0A0A0A090C090B080A0A0C0A0A0B090A0C0B0C0B0A0B0C0A0A0B0A0C0A0B090B0B0B0A
0B0D0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C090A0B0C0A0A070B0E09090B080C0B0D090C0D0A0D090C0C0C080A0C09
0A0B0B0A0A0D0B0A0B090C0C0D0B0C070D0B0D080A0A0B0B0A0B09090A0A0A0A0B09090B
0C0B0D090C090D0C0D0A0A0B0A08080B090E090B0D090D0A080B0A0B0C0B080A09070809
0A0807060707060405070606030403020302000200000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000007070812101A1B2A1C2425212C2E3135373136
31363C392E2F382C2C221D1D151918131310080A0C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020303030705
07050605090905060A070A08090B0808090A080B0B0B090909090A090B070A080B0B0A08
0A0B0A0C0D09090A0A090A0B0B0A0A0A0A0A0A0B0A090B090B0A0A0B0C0C0C0C0C0A0B0C
0B0D0B090C0B090A0C0A0A090C090B0A0C0B0A0A0D0A0B0C0A0C0A0B0B0A0C0C0C0B0D0E
0B0C09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A0C0B0C0A0C090D0C0A0C0C0C090B0B0B0A0B0A090B0C0B0D0C090C0A0B
0A0B0A0C0A0A0A0C0C090B0C0D0B090C0D0C0A0B0B0A0C09090A0B0A0A0E0B0B0B090A0B
090B0D0B0C080B0B0A0B0D0B090B0C0C0A0A0B0B08070B0A0B090908080A0B0A0B0B050A
080508080607040705060605050202010000020002000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000040002050B07080F0F181D191D1F28312A2A363D35373A3A3E45494B524C
4F494D4C5954534949454D524A3845463E45473B37372127201F080D0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010104
04050704040707060706060907090708070A0A0A0A0A090B0B08090A0C090B0C0B090B0B
090B0B090A0C0A0B0A0A0A0A0A090C0A0A0C0C0B0B0C0A0C0A0A0D0B0C0A0B0C090A0A0A
0B0A0B0D080A0C090B0B0B0C0A0B0B0A0B0C0B0B0B0C0C0C0A0A0B090B0B0C0B0A0A0C0A
0B0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B0C0B0C0B0B0D0B0C0A0B090B0A0B0C0A0C0A0C0C0A0C0C0A0C0C0D09
0A0C0B0C0C090C0A0C0B0A0B0B0B080D0B0C0A0D0A090A0C0A080A0B0B0B0A0B0C090D08
0A0A0A0A0C0C0A0C0B0D0B0B0B0C080E0A090A090A0B0B070B090A0A07080B0808090805
060605060505050405030303050100010202000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000060F0D14181A1A181F1F202723322D2E30342F3D3C413D3C43434A47444D4954
5555544E545D5E585F61605D6264615A5F6262685D575F575D4A4B3D38221E161F120900
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000002
0202020501060706040606060A090A0906090A09090A0709080C09080909090A0A08080D
080C09090C0C0A090E0B0A0D0B0B0B0C0D0B0A0B0B0B0C0A0A0A090D0B0A0A0C090A0A0C
0D0A080B0A0A0B0A090C090B070B0C0B0B090C0B0B090B0D0B0C0B0A0A090B0C0A0B0B0B
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A090B0B09080B0A0A0D0C0B0B0A0B090C0D0A0B0C090A0B0B0A0C0B0A09
07090E0A0B090B0C09090A0B0A0A0B0C0A0A0A0B0A0B0B0A0A0A0C0A0C080B0B0C0C0A0D
0A0C0B0B0C0A0A070B0A0A0B090A0A090A0A0B0E0D07090A090B08090708060706060606
060704040404050204020202010200000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000002050507
0A0B171714111A16201D252B23252C2122252C202D28273F2E3A3E454641403C46494A51
4C4C4A4D50534B545E645D676A6D65726B6A6E776C736D6A72646862674D524E4F423F2E
2A2408050000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
040404030605060507050906080706090709080A080B0809090A0A0C0A0908090A0B0A09
0C0B0C0A0C0B0B0B0C0C0A0B0C0D0A090B0B0C0C0B0A0B0A0B0C0A0B0C0A0B0A090B0B0A
090C0A0A0D0A0D0A0C0C0A0A0C0C0C0A090B0A0D0C0C0B0C0C0D0C0A0A0E0C0B0C0E090B
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0D0B0B0C0B0A0B0B0B0A0A0B0B0E0B0A0B0B0E0A0B0A0A0A09080C0B0B
0A0E0A0A0B0C0B0E0B0C080B0C0D0A0B0B0D090A0B0C0D090A0C0A0A0B0A090B0C090A0B
0B0A0A090C0C0A0A090A0A0D0D0A0C0C0A0A0C090A09070A0B0A07090509090905080505
070405050200030402030000000301010000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000010700050D080811111016
131815151B18171E1E28232622252327242A28262A272E25333637393B3C3E4A4B3F3E44
463F424948454C4E565D5B5B656062686D657569727B766F677974717686776B636E6862
585249362D211D140A000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100020305010404060605070507080508080909080A07090A0A090A090D0C090A0B09
0A0A0B080C0A08090B080A0D0C0B0A0D0A0B0B0D0B0D090C0A0D0C0B0B0B0B0B0A0D0A0B
0B0B0D0A0A0A090A080B090C0B0A0A0B0B0B0B0D0A090B0B0B0B0B0B0A0B0C0C0B0A0A0C
0A080B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B0B0B0A090B0C0A0C0C090A090B0A0B0B0C0C0D090A0A0E0B0A0C0B0B
090C0A0D0D0C0A070A0C0D0A0B0A0A090D070D0F0C0B0A0C0A090D0B0A0C0C090A070A0B
0C0B0C0C090C090A0C0A0B0B0908080A0C0709080A090A0A090908090808070805060705
080407030303000003020302000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000050C0F110E1612171A1A161A10
1B1F1A181D16161723222725292324201E2E241F2023261F302D303431313C3A40453D3A
423B45433D494545514D5253595A62525560627063727371727E807F83787C7B7B6B6F78
746C6A62545850463B372208000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020002010402060505090407060709080709070A090A0A0A0C0A07090A0908090A
0A0A0A0C0A090A0B0C0B0A0C0A0C0A0C0B080B0A0A0B0A0A090E0B0B0B0A0A0B0A0B0B09
090C0A0A0D0B0C0C090C0B0B0C0A0E0C0B0A0C0B0A0B0B0A0B090C0B090D0A0C0C0B0A0A
0C0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0D0C0A0B0B0A090B0D0B0A0A0B0B0A0A0C0E0C0C090C080B0A0B0C0B0A
0B0A0B0C0C0B0D0B0C0C090A09090B0F0A0A0D090A0C0B0A080A0B0D0C0A0A0B0B0A0A0C
0B0B090C090A0A0A0A0A0C0C0C0C0C0A090A090A080A0608090705090608070702050503
050403000202010100010000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000500050F1213151B191A161316161A1E
161C1A1D17191012211D20282B2C222625212020201C211E1D2629353B32323035423E3A
36383D393E454A433E4D4049484F4C484B535E52626C706E767D747D80867867707B7E78
7277837D746D726E64645B50342814020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000201010503050606050707050907080A080A0B090A0B0708090C0A0B0B0A
0A0A0A0A080A0A080B0C0C0B0A0C090A0C0C0A0C0B0A0B0A0909090C0B0B0A0A0B0C0C0A
0B0D0B0D090D0B0C0B0C0A0B0C0B0B0D0A0B0B0A0C0B0B0B0A0B0C0A0C0B0E0B0B0A0B0C
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B090A090B0A0B080B0A0B090C0A0B0A0B090A090A0A0A090C090B0B0A
090C0B0B0909080B0C0D0B0A0B0A0C070A0A0B0C0A0B080C0A0B0B0C0A0B090A0B0B0C09
0E09080B0A0B0C0B0A0A0B09080609090B080A0B08070808060606070504060505020404
050201000102000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000004050805050E151419161B191F17141B1816151616
1A1C1F1B151D1A1B1B231A212522241B221C1924211A221A1F22272D2531393138303D36
423840443F35393D463B3D3C453B454943474E5F555B67646D6D7072757D837E78747E70
77718B897A8A8075727E706E59534C362C23160200000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001010305030404040706040507090A0809080909070B090A0A0A0A0B
0A090B0A0C0A0D0A0B0C0A0E0B0A0A0B0A090C0B0D0A0B0B0B0A0B0C0C0D0B0D0C0C0A0B
0B090B0B0A0B0A0D0B0A0C0B0B0A0B0C0C0A0A0A0A0B0C090B0A0B0A0A0A0B0B0A0A0909
0B0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090C0A0B0A0B090C0B0B0D0B0D0A0F0C0B0C0C0B0A0C0B0A0C0A0C0D0B0B
0A0C0B0A0C090C0D0A0B0B0B0A0A0B0C0A0A0C0A090C0D0A0B0A0A080B0908090B0B0908
080D090B0B0B0B0B0C0A0A0806090C090C0A070B080A0809080808060703060603020300
030000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000705080D11151D1717201C1616191B0E1818121217
1A1A191B140F191714231D1E1D24271E1C181E1D1B1E16221E20242D292D343230323C32
393334363541383931383F433F3F41364546494B4C5461666C6460686B727B70786B7A6B
73778188747D6F7D807A776F6C706166564244392C170E02000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000102000306010506070606090807090809090A09080A070A09080A
09090A0C0A0A0A0A0C090A0A0B0C0A0B090C0A0B0C0B0B0B0B0B0A090B090A0A0B0A0A0B
0A09090C0B0D0A0D0B0A0B0C0A0B090B0A0A0B0B0C0B090B0A0B0A090A0B090A090A0B0B
0B0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0A0A0B0B0C0A0B090C0A0C090C0B0C0E0B0C0C0B0B090B0D0C090A0D0D
0B0D0A080A090B09090D0B080D0A0A0D090B0A0A090D0C090B0B0A090A0E0B0A08080B0E
0A0D0E08080A0A0C0A080909080909090B0B090605070808070907020503050502060203
050103010100000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000004000606050D14221F1516131E191F23151D1D1A1C191D
161D1B191B1A1A1A181C1D1E211C17131C1C1E221C17221A291F2E292D312C2A2F2B3433
33382E3135363B35393C2B303F343E40413D4A453C424C555A565B5E6273667079707574
6B747677756A7876768375727E726E6A6D6570574F3A4628150E04000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000304020606070506080709090B09090A0909080B09
0B09090C0B0B0B090B0A090B0B0A090A0B090B0A090C0B0C0A0A0808090A09090C0B0B0B
0A0C090C0B0B0A0B0B0B090C0D0A0A0A0909090C0B0A0D0D0E0A0C0A0B0B090B090A0C0A
0A0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0B0B0B0C0B090A090D090C0A0B0C0B080B0C0B0C0E0C090C090B0D0B0B
070E09080B0C0C0A070E0A0C080B0A0B0C0C0A0C0A0A070D0D090B0C090C080C0B0C0A09
0C09090C0A080F0C08080908090A0A090509080A09040607070205070203030404010200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000001050405060F101B17201A151815201F1A1E171B17181A
222019131B1920171E1B191F1F22221E1D1E1A2224211F201B242E1E242D2B2E282A2F34
2D383735303730383935313333353C314447423E36424952505355525D5B57616D6D6570
7C7C77706E6C74737F7279727474777876747369595F5656443534221000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000003030001030504060607060709070808080909080B0B08
080B0809090C0B090A090A0A0C0B0B0B0D090A0B0A0D0B0B0D0A0A0B0B0C0C0D0B0C0A09
090B0B0B0B08090C090C0B090D0C0D0B0A0C090A0A090C0B0A0B0C0B0C090A0B0B0B0A0B
090B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0A090D0C0C090E0B0A0A0A0E0C0B0B0B0B0B080C0D090E0C0A0E0A0909
0B0E0A0B0B0A0B0D090B0B0B0B0B0B090B0A0C0A0B0C0C0A0A0B0E0C0A0A0D0C0B0B0B0C
0A0C0A0908080A0807080709080808060907040B080708070B0504050301050302010203
010300000000000000000000000000000000000000000000000000000000000000000000
00000000000000000002000002030005040B09101B1B1A1B1E17201E1C1D1C1B0F121A16
1D1C181415151C211B1A1F18251D22221A1B1A24261A212226281C2328252D1C2D242C25
2F2F32312C2F2E3631323134403B374139394441414C49514D4D5150565E5E655F646B5F
6F736E706D6D6E7B6D6F6E6D77747B6C7C74786B626164605A5C524B4638231906000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000100000000020304050506070708090708060A080909090A
090A090A0A090C0B0B0A0A0B090D090A0B0A0C090A0C0B0B0B0A0B0A0B0B0A0C0A0A0B0B
0A0C0B090B0B0A0C0B0C0D0A0B0A0A0D0C0B0C080B0C080B0B09070A0B0B0A0A0C0B0B0B
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0D0C0B0D0C09080D0A0A090C0A0A0C0D0A0C0C0C0D0A0B0C0C0B0A0A0D
060C0A080A0A0B0B0D0D0A0B0C0C0A0A0B0A0B0C0A0C0B0B090C0A0B0A0D0A0A0A0A090A
0D090B0D0C0C0D080A090A08090805060509080905040603060504010404010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000000000000010000000608000E0E181C1A1C161D1A191E18141A1A191B11150F
16141D1A18141F271A19191D1C1E19131F251E172418252224211F1D2B291C24261F1D23
262B322F303B293F2D343530382B333833343B40433F3C3C4F41464A5E595A5C5259675D
646067696268716A695B696C6C696A646466686961616769656E60635F54563C3A341E00
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000203030406080406070807090608080A0A0A09
08090809090B0B0A0A0A09090A0C080B0A0E0C0A0A0A0B0B0A0A0B0B0C0A0D0A0A0A0B0B
090B0B0C0A0B0C0B0B0B0C0B0C0C0A0C0B0B0B0C0A0A0D0B0A0C0D0A0B0D0A090B0A0B0C
090A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0B090B0B0D0B0B0C0B0D0E0D0C0B0C0C0A090C0C0C0C0B0C0A0A0B0D0A
080C0B0B0D0B0B0809090C0E0A0E0B0B0A0C0B0B0C09090E090B0A0C0C0B090B0708080B
0B0B09080B0A0608090A0708090709040908020507080603040205030301040000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000100000001030709050C0A111619221B162116171E1323180B1B0D0F0E1413
0E170F161D181B1C1620161D1C1B171D151A12151A1B1F1D1C26211D1818231E211E1B26
292532202B21372939342C323528302D3932423235424141404D4350555342595652524B
58615D5B575F6D5C606766666755646B637373626869696B6A6C7467746360585C4D3D27
1A1600000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000040300020506030B0809040B0608060A0B
090907090C0909090C08080A0A0A0A0B090B0A0B080B0B09090A0B0B0B0D0B0B0C0C0C0A
0C0A0C0B090A0B0B0A0B0B0A0C0B0A0B0A0B0B0D0C0B090A0B0B0A0C0C0B080A0A0A0B0B
0B0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D090C0D0C0A0B0B0A0D0B080B0A080D0C090B090C080B0A0A080A0C0C0D09
090B0C0C0B0B0A0B0B0B0C0E0D0D0A0C0C0B0D0A080B0B0A0A0C0A0C090B090A0B0B0A0A
080A0C08090A09090706090809070B070709040405030504030203010100000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000010005000605060B060B0B121315231C201E221A1F20201B151C11130D110E0A
10121D141E1D2120191C29191419171B161F181B11211D1C1C191D131F16201720241820
201D1F26242E2F282C2A322D3230363730323430372935353E404047513842444D4D4B53
4F544D5E68636F70675B616B655A5C675F6465646B706C696D716C6A6D61645E665B554F
3C3D35141000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000005030506060505080609080A080B
0909090B0A09080C0B0A0A090B0B0B0A0B0A0B0B0B0A0A0A0A0A09090B0A0C0B0A0C0A0B
0C0A0A0C0B0B0C0B0B0A090B0A0A0C0A0A0B0A0B0A0B0B0E0A0A0B0B0A0B0A0B0C0A0B0A
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0E0B0B080B0A0C0D0B0A0B090A0C0A0C0B0B0B0B090A0B0B0B0C0C0B0D
0B0C0C0B0A0D0A0A0A0B0C090A090A0B0B0B0A090B0A0B090C0C0A0B080B09090B0B0707
0A0A090A090A0A08070B0A0B050606060505060606020102030003000101000000000000
000000000000000000000000000000000000000000000000000000000000000100000000
000300000006010304020D0E0D0A101E221922221D271C232622211C161711110D140E17
181A1A1918141E181A1B1C20211F1F1F1B1E1C1E14181E201924271D2518241C16181F1D
1A231F1E1C23242B36302D292C2C2C2A2E1F2B29252E37333A2F3E3B3E3D3D413A44493B
474F5152545C5C64675962565952555A5F62625D63626A78636D746E6F6A6D7263676B60
57524C4739331B0900000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000010000020306050106030706070A0808
080A08090C0A090B0A0B07090A0C0B0A090A0C0B0A0B090A090B0B0B090B0A0C090B0909
0A0C0B0A0B0A0A0B0B0C0C0A0B0C0C0A0B0A0B0A0B0B0A0C0A0B0A0A0A0A0B0A0A0A0A0A
0A0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0A0B080B0B0C0C0A090B0B0B0C0B0E0A0A0B0B0C0A0C0B090B0C09090D0D
0C0C090C090A0A0B0C0C0B090B0C0B08090C0B090B0C0C090B0A0D090A080B0A090A0B0A
0E09080B0A070A0807090A05060507050403050504020300000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000200
0102080300000B0905060C0B090B151918211D22201825221E2019201A1213150E141414
211B251F201D1C1323211A201A1C191C1B201B121C1817161A141714171D1D1721131716
201B161B231C171F1926292522292B28252A2A232928323235363A3A3C46403D3B3D4343
485242534D54544C5D585D5A61615257605554574D5C5D5A5F5B666B6860646267656A6E
6F67615552413F31280B0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000003040304040406070708080707
0908080909090809080A0B080C080C070909080A080C0C090A0C0A0909090A0A0A0B0D0A
0C0C0C0C0C0C0D0B0B0A0A0B0C0B090C0D0C0B0D0C0C0B0A0A090A0C0C0B0C0D0C0B0B0C
0A0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0D0B0C090C0C0B0B0D0A0A0A0A0C0C0B080D0C0C0D0A0C0D0B090D0B09
090D0B0D0C0D0B0B0A0A0C0C0A0D0D0B09090C0B090A09060B08090B0D090A0A0A0D090C
07080B090708070B07060507070405010505010200020100000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000005000601
030304050704050A1206050909101919171F191B1F261E221F171D190F1918181D151818
18191E1F140E1624101F1D241F20252820201B1C1415101C1D1B130F161425171E0F2116
12180D101A1C151F1D1927262D2D292531312C2D252C2B25272C2B383839404447423E3D
463E47414B4E564A524A5362584A665156545A4F5953635E54655E5A5B57695F5C645C6C
6167666F5E55545842362918080000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010102040304070707050908
0707060708090A0A090A0B080B0A0B0C0B080A0B0C090B0A0907090A0909090B0C0B090B
0C0C0B0A0B0E0A0B0A0B09090C0B0B0B0B0B0D080B090A0B0C0B0A0B0C0B0B0A0B0A0B0D
0A0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0A0C0B0B0B0C0C0B0B0C0C090B0A0B090A0B0A0B0A080A0B0B0D0A0A0A
080D0C0D0B0A0A0B0B0A0B0C0B0D0B0A0D0B0A0A0D0A0C090B080B090C0B090A0B070A08
0A090A0A0908050506060507030502050404030301000300000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000004030001
0009050003070F0D0908150E10130E1D171E181B1C1D21231C192112130F181E1B151B1B
1C17181619191C15211E1B161613141B231819171B191B191B14161E1B1B181621111419
12141C131B181E1A250A191627221E1E1E2F23332A2A292626221E20343538473C3E4042
463D3B343D444E4E524B57535C624E5D5D4A4C504954535C5563615867675F6164696C70
61665E64726E67695A4D49403A230B000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000020404050604080506
060A07080B0A09090809090A0B0B0B0A0A0B0909090A0A0B0B0B0C0A0A0B0B0B090C0B0C
0B0A0A0E0B0B0B0E0B0A0C0B0B0A0C0B0B090B0B0C0C0C0C0A080A0D0B0C0A0A080B0A0A
0A0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0B0B0A0A0C0A0C0C0C0B0A080B0A0C0A0A0B0B0C090B0C0D0C0C0B0B0D
0A0C0E0B0B0A0B0B0A0D0B0B0C0B0A090B080B0B0A0B0C070C0B080B0A080C0B0C060A09
080705080606090808070506050504040402000100020000010000000000000000000000
00000000000000000000000000000000000000000000000000000400000000000800030B
03090A06050F06090C080A141215111109171B131A1D1E20201A1A1B111017190D161D11
1317141215141B1C14141B1B1914161E12211C1E1F18191017121B141418171E16120E11
130E19101313161109191715171F1B1820202A232626221D1F25221D302F3336363A422F
3A2F382C3E3B3D464747514C4A4A615A5E6A4F504B4B51505B64586260605F51655C6862
5E5E5C5C60656F6E6264655B4D4B36251C00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000040307050607
0809070A090A080A090808090A09090A09080B0B08090B0909090B0B0E0B0C0B0B0A0B0B
0B0A0C0B0B090A090A0C0B0A0B0B0A0B0C0B0A090D0A0B0C0B0B0A0A0B0B0C0B0B090A08
0B0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A0C0D090A090A0C0B0A09080A0C0B090A0B0B0B0B0B0A0B0B0B090C0C0A
0D0B0C0A0B090A0B0B0A0B0B0D090C0A090A0B0B0A0C0A0B0B0A090C0A09080A080C0808
08090A080707060606050103050204030300010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000107000104050001070108
05050908080A090D0E0E0F0E110E141314180F19161D1F1D231D1B181B1B140E141C0E16
07181C1A211B0D1314100F18191516182217211C1F1B1F17111E231B16141C171B0F1F16
090F0E1F0C1510160A1320181D1E1D1B1E1B1D2E1C222516231E2129222523292C2B3334
342E312F3834413F434C4F4A4A56454A557245554E4351534F515D5F515E62565A656066
6C63665B5B6566666D65635E5F5757413826120900000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000002030303030306
0606080606090B090909080C0B09080B0C070B0B090A0B0D0B0B0B0E0A0C0C0A0A0A0909
0A0B0E0C0C0C0A0B0C0A0B0C090A0B0B090B0A0A0B0A0C0C0B0D0B0B0B0B0C0D0B0C0B0B
100F0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0D0C0D0A0B0E0A090A0C0A0A0C0B0B0B0B0C0C0A0C0C0A0A08090B0C
0A0B0B0C0B0B0B0A0A090B0B0C090B0B0D090B0B0B0B0D070A0E0B0B0909080A090B090A
070606080708070605040105020103040100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000070105040000040C0A0A0507
0608060C0D0C180F0D0C0B180B0F1F121011161316181B1B15191C1A1317171C1C160E18
121018101216191C13191B1517251C13241F21212028231D191E1F161B1516121C15120E
11130D0E0B0D0D0B0A0C171910171A1A18151A14211E1D1C1F161F201D151B2C2E21322C
2B2C31253535353C2F3F464548484045474146433F3B4C524741554A525761525E575C59
6A5F5862635F5D5F5D6B5C65685D5D555C5642381C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000020003040403
060505080708060709070A0809090B0B090C09090A0B0B0A090B0B0C0D0C0A0B0A0C0A0A
0B0B0B0A0C0B0D0B0C0C0B0B0A0B0B0A0C0A0D0B0B0B0A0C0B0A0B0B0A0B090B0D0B0C0D
0E1A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0D0C080D0B0D0B0C0D0B0C090B0A0B0C0D090A0B0B0A0A0A0A0B0A0C0908
0C090A0B100709090B090A0B090B0E0B0B0A0A0D090A0B090C080A090A0A0A0A0A0A080B
060706080506090504060303020102010001000200000000000000000000000000000000
0000000000000000000000000000000000000000000001040208030B0006060A090B0D09
0B07051206140B0B140F0A0E160C0D171619131C1A161C1A211B12141C18181A14121918
19100F1210180E161116151F182217191B1B182B2021291F1E120F181615170B11161413
0A12111314050B00050312160B0F10111D0F17161D1E251B1D201C181D0F231C14272A25
28282F2E2D323C313037434044433F44443E3F423E494E594E40454D515156595C57525C
575A62625D61606065615F6566616167655C54504633210D000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000102020106
0707040607050707090C080A0C090B0A090909090C0B09090D0C0B0A0B0B0D0A0C0A0D0B
0B0B090B090C0A0C0C0B0A0C090C0A0D0B080C0B0B0B09090C0C0B0A0A0A0C0B0A0A0D10
0B0D0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0A0B0B0D0C0C0C0A0E0B0C0B090A0C0B0C0B0C0D0C0A0B0A0A0A0C090A
0A0A0C0C0B0E090A0B0A0B090A09090A090B0A0A0B0A0809070A0B060A09080A08090506
080A07060502050504040301040300000000000000000000000000000000000000000000
0000000000000000000000000200000000000600000101060009050809080C05070C0E0A
080D0B0E0E0E0C1B12110E0F16151B15111F160B1A191F1D191F1B1315191B161A171C12
1D1A12191A131A1A16151A1612211E1A251E2B2120252B2317221119181D0F0E0F110E11
120C0C0F0606020D0C060D18131709181312121716231D1E10181B181619201C1F1F2621
292B2724272A35303538384946444140453A3B393F45494D4D4B4C4F4D52445A53525951
485556545B5B625B4F5B6A64695F6A5C6366695C64514D421E0700000000000000000000
000000000000000000000000000000000000000000000000000000000000000000030401
040504050605090707080908090809090A090A0A08090A090B08080B090A0B0B0C0A0B0B
0A0B090C0B0C0A0A0C0C0B0B0A0A0B0B0B0B0C0A0B0A0A0D0D0A0B0A0A0C0C0A090B0A0B
0A0A08000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B090D0D0A0E0C0A0B0C0B0A0E0D0B0C0C0B0A0D0A0D0A09090B0C0B0909
0C0C0C0A09080B0A0A0D0B0B0A0A0A070A0A0B0C0C0B0C0B0A0A0A080809080907080A06
060706040704050504030300000000000000000000000000000000000000000000000000
0000000000000000000000000000000100000A0004070A0005070608030E10070D081012
171011181A16181116100E151B1E11141E1D151814191012101A1B16121716140C161918
170F15151914171919131A191C111F1E1C1A201D181E211826171F18201717120C0E080A
080511000F030C080905110C130B130F1C07151617110D1F161B15111B121B10201D201B
241F1F26213730272A3630383B463D3F3A4248374A484C3E565341413F504C54564E5155
4E4D575C48585453555756545A5C5D5A6268695C62645E52513A22110000000000000000
000000000000000000000000000000000000000000000000000000000000000000000101
01030405080508070706060A09090A08080A090A0A0A080B090A0A0B0A0C0A0B090C0C0A
0C0B0B0B0C0B0B0A0B0A090B0C090A0A090B0B0B090A0B0D0A0C0B0B0C0C09090B090A0D
0D0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0B0C0A0B090A0C0A0C0B090E0A0A0B0B0D0B0B0B070A0B0A090B0A090A
0A0B090A090C0A0A090B0A0A0A090B090C0A0B090A0C080A0908060909080A0A0A060709
080307060505040301010100000001000000000000000000000000000000000000000000
00000000000000000000000000000000000604020800080404050B0A0906120D0F170C15
0F170E1018150A151114151510131A1A1B1A132011211A191A2119181A111C0F12141716
1C101A1312221A161F12152117161E1A161A0F1C200E211C130E1B111A171417150E0412
13081509060806060E06170C04070E06110D0C090F10171819251D1E191919161923131F
201B1F202B2421203030302D3C36373637323141404A43464A4A46523C473E4848524053
4E524E4F4849534C5A54635D585E5B5E617064676D606561615F4B3C2903000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010404050506070707090708080B0A0908070B090D090A08090B090A0A0A0A0B0B0A0A0A
090B0C0C0B0A0C0D0D0A0A0B0B0C0A0B0C0B0B0A0D0C0A0C0B0B0B0B0B0B0C0C0B0A0C0A
0C090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0B0C090C0A0B0D0A0C0B0C0A0C090B0A0B0A0A0B0B0B0C0A0A0B0A0C0A0E
0B0D0A0B0A0A0B090A080A0A0B0A0C0C090B0A0D090B090A09090A0B0808080806060908
060505030503060302000100000000000000000000000000000000000000000000000000
0000000000000000000000030000000C0008010001070C0D080A090B0E0C0C10110E1416
14181C141910151F181A1A161819161D1E1D201D191A14111715150E160D14141C0A1513
141210131D141B151912191E1419161A14121B191A150F0D17101715190F0912130D100A
1609070A091202110C0C0E060B0A0B130A0D110A1811151214141E17141616181C151C1B
241C211A1B2520192B362F313430353639303A3432303B4047414B4C4B555143473F4A42
48404F494F4D504F535D5A56585B5C535D5D7261606B6A635C5962544A331C0300000000
000000000000000000000000000000000000000000000000000000000000000000000000
020301020404050509050608080808070A0A080A090909090B0A0B09070A0C0C0B0A0C08
0A0A0B0B090B0A0C090A0C0C0A0B0B080A0B0B0A090A0A0A0A0B0B0B0D0A0A0B0B0A0A0B
0A0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0A0A0B0B09080C0C0A0A0A0C0D090B090B0B0B0B0B080C080B0A0B0A0C09
070A080A0A0C08080B0B0A0C080C080D0A0A0A0B0B0B0A090B0909060808070807050706
050304030005040204000000000000000000000000000000000000000000000000000000
00000000000000000000000002020500020505040405090D0F0A150812120A0C130F171A
18191F141D14181615181D1A20191922201C1519171C1C131A1A160811111A1612121916
14181D0C0A1D191C1C22201C1A1316151D0A0B19161A12181A071A13121B0A0D080B0C0D
110A0009000F070C060C0A1108140A0B080B10140E0D15181616191C1617171A131F1427
1C1B191A231D20182720271E2B272A332F332C302E2C393E424C48514C3F4F4242454241
434432454147443E53554640535452564D525B5D606763666373676E5C5647391D030000
000000000000000000000000000000000000000000000000000000000000000000000000
01000001020305030506060707070908090A080B080B090B0B0A0A0C0B0A0A090B0B0A0B
0B0A0A0B0A0B0A0C0A080A0C0D0E090A0B0D0B0A0B0A0A0A0B0B090B0D0B0B0B0D0A0B08
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C070B0E0D0C0A090C0B0C0B0B0C090D0B0D0A0A0B0A0B0A0B0B0D0B0A0B0B
090C0C0B0B0B0A0C0C0A090C0B0E08080B0B0A0A0B0D0909090A07090807060705020607
050602020303000000000000000000000000000000000000000000000000000000000000
000000000000000000060501000201020504040005080E0D1009090E141719120F1E1216
10171D141A1916171F13191E1F20291C12171E181815161A141417140C1A14191409191D
1E121E1E141C151B171D2A2C221B1713191117121811150F0A1211151815130B06170F11
120F0F0D03060A0C0A031507140509050E0B0C0D110C1C17161A1B182019130913141B1A
222119181A261F22171E1F222A242A282927312E2F3135373F3D45453C50535450464443
343C3B344343383945505556485052535658575D5967695B6465636E6C6B585946381C01
000000000000000000000000000000000000000000000000000000000000000000000000
000000000302040405040608080609070908080A080A09070B0A090A090B0A090A0A0B0B
0B0A0A0C09090A0A0B0C0A0B0C090B0C0B0C0D0A0C0A0B0B0D0A0A0C0B0A0B0A0B0A0A0B
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0D0C0C0C0A0B0B0C090A090B0C0B090A0C080B0B0B0B0B090A0C090A0B
0C0D090E0B0A0B090A090A0A0B09090C090A0A080A0A090A09090908060A060608060704
050301030001000000000000000000000000000000000000000000000000000000000000
00000000000000000001000006050209060C06070D0A080B0D0D1311110F151810191A18
1E11181F141C190D191D1E1E211C1D1D231B1D201616131C1F15151A1B1115190E1B1715
16120F18221D211A21241E22221719122516191A1B0F14111E1111151316130005060D0A
10100C0F0C060407100D00060C00000C09110F12020B1113111F1C141310131017141017
190C110C20191D1C12101E182A2B242A2C2D2A2C31312C3134373F404036434440494F43
40353A3A3A3D44414A4053414653465A584555585D5758595B7372676474725B5A4F4536
160100000000000000000000000000000000000000000000000000000000000000000000
000000000000010303090707050705090A08070809070B0B08080B0A080A0A0B090A0B09
0A0D0C0B0B090B0D090B0A090A0A0A0B0C0B090B090C090B0C0B090B0B0B0A0B090A0D0B
0D0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090D0B0B0A0B0A0B0B0B090C0B0D0B0B0B090B0B08090B0B0C0B0A0C0A0B
0B0B0909090C080B0B0C0B0A0C0D0C0A0A0908090A090A07090908060706060507070503
040303000100000001000000000000000000000000000000000000000000000000000000
000000000000030100000803060901030E0305090710110A0D0D1308131B131B1D141C19
20182121221C18171C1E251A1E27211D1D181E231A1F20231F111D182316181414171814
15141E1523201E211F262E161819191A1B20221A10160E0B0F1E10120F0E0608070A0C12
09060E080F040A0E0C03060100090B050A0802010F070F121C111911110C0D150A101510
161E1F171214161A18181612171B21201C253230312F2A2F3A37313E373A394C4043474B
3B36363E373C3E3A403A45483F494D4B4B47504E536260666D596068696868716562664E
402C10000000000000000000000000000000000000000000000000000000000000000000
0000000000000101040304050707070706090B08090708090A0909090C08080A080B080C
0A0B090A0A0B090C0C080C0C0B090C090A080B0B0A0B0A0A090D0C0A0B0C0A080B0C0C0C
0B0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090C0B0D0A0B0C0C0E0C0A0B0B090B0C0B0B0B0C0B0B0C0C090C0B0A0A0D09
0B0D0C090D0A0A0A0C0C0C0A09090A080A0C080809060707060A07070506060405040504
010300000000000000000000000000000000000000000000000000000000000000000000
00000000000000000500000006010B0C0306090A0F0A140F0D0C100F191217181A242411
191C1A1C1A221A281A201A1D1A1E1A22221B201D201C1E1F131A121B15160A131427141B
1B141A1E1417201F1919261E1E150F19231A1B1C2317141D160D0F0D130A13130F0F0A0B
040B0812120A0C1007070E0315040B060E070E040F0612181F1414130F0B00080B0F0E0D
1313161D1A1C1D1D1B1F1C1F2023211E251F292822272528323D322C37393F393D364A33
33403B32363B454045363B3D414448513C47585A514D55525D6454626665666166646E5C
63533A2B0800000000000000000000000000000000000000000000000000000000000000
00000000000000010003020305080305050706080A09090A0A0D090B090A0B0A0A0A0B0B
0B0A0A0A0B090B0B0B0B090C0B0A0A0B0C0C0C0D0A090C0B0B0D0A0A090B0D0E0A0B0A0C
090A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0B0D0A080B0D09090B0B080A090A0D0C0A0C0A0D0B0909080C0C090C0B
0D0C090D0B09090C0C0D0B0D0C0A0A0A090B0B0809080B080A0806080508070605040304
040401000000000000000000000000000000000000000000000000000000000000000000
00000000000000000105040404040B050808140B0A160D0D080E12130D1A151610191C19
1F22181B1F1E1A1721211D212522201E24181E1C1F1A1C20181D20211F151D100E151614
201915111C1A161E0C211A211E1518241A211A2A1C1C201A221C1C0E1E11120B0B0C1414
0D080A0B03100B0A090B06030E050D07030E19140D150C0C191610130C06070B0703110B
0F0F120F1D140C1914151410231C20151D2920312E212E2B2F3136333635392D3C393C43
31373A3D413D413A3834384632353E453848564A545252555E5E535B635E6B675D6D6B63
65555A493A19010000000000000000000000000000000000000000000000000000000000
0000000000000000010103040405030505070907070A090A0B0C0A090A0A0A0B0A08090B
080A0B0A0A0C0C090A090B0A0B0A0C0B0B0A0A0B080D0B0A0C0C0C0909090B0D0C0A090A
0A0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0A0D0C0B0B0B0C0A0A0A0D0B0D0B08080A090D090E0B0E0B0A0A0C0B0B
0C0A0C0B0D0A090A0A0B0A0C080B0909090A0A050A0A0708080603070506050502010301
000000000000000000000000000000000000000000000000000000000000000000000000
00030000000000050000050203040606060B0C0A0D0F050A120D171914131B141A131D25
272124231E2221191C1F191C2922241E212B18191C261F1321161F182217181420181214
1A180F1D1A101A191A171B201816251E1A221D1A191E14141216121B0E0B1716150A0C09
13110D140E0D0E10080D060910030A010A090A0911100D0E1B13120A1312101008040C09
0B0E1C0B0E10191510102017241D1A1A20221C2D252D2D282B2C2B3229272C2C363B3436
3B3E2D38323E3C3339342E3D40313A314246504E47524F5050535E496853586868636463
65666A5E4F3F260900000000000000000000000000000000000000000000000000000000
000000000000000000000002040206040609070609080A0B0B080908070B09090C070A0B
0A090B0A0C0A09090A0B0D0C0A0B0C0A0C090C0B0B0A0B0B0A0A0B0A0C0B0C0A0B0D0A0C
0A0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B09090909090A0A0A0B0B0E0C090D080A0B0C0C0D0C09090A0A090B0C0D0B
0A080A0B0E0D0A0B090D0709090A0909090A080807080507070606060705040200000203
000000000000000000000000000000000000000000000000000000000000000000000000
000000000200000002010000020208040C0A0B150E0C0F120C13141011140E101518161B
201A1A2728201F1B1B1C1D221F192B251F272017221D18151B1C1822100B1D121A111714
1312160B150D190E1C171D231B211E21201C21191F211D0D1F1B1F0F171417120B111013
0D0606150909160E1407160D12110B0B06060711060C0E150A0F0A0C110F070D08080503
11080814090B031110101B0F161E1F1A24221C2B222D2824281A191F302A242D20322E2C
303C363F3B422C2F3A2F384132323A3B474038494B554C51555553595A5766665E625D5F
636B69626558503E21000000000000000000000000000000000000000000000000000000
000000000000000000000000000304050407060606080709070A080A0B090A0B0B0B0B0A
0A0A090A0A090B090B0A0B090B0C0C090A0A080C0B0B0B09090B0B0C0B0B0D0C0A0A0B0C
0B0A0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B08090A0C0B0C0D0B0C0B0A0C0B0B0C09080C090A0C0D0A0B0B0F090C090C
0B0B080D090A0A090B080B0C0A0B0A080808080706090608070A07050302030302010000
000000000000000000000000000000000000000000000000000000000000000001000000
01000002020205000200000200070A0A0B06121110160E121A1A0C111217140E14191E14
1B191E1D22261C19202120191F2831262B25211B1E181D1A19170F16141521191617251E
1A12131C181715182019181C211B1A18221E1C1A24241D1C1E1B14221A101A1216190D15
1012101A0E130B0F0D101D15180F09000E00090805070D0C0A0E0C080C060D0207060C03
000B0913141613140E1A1D191B1D19181B191C1D201E1C1B231F2A241F24312D2E2E262D
363D342B342D2A35333A322F3435363A3443433F503A584756465152544E5C585E605F5E
5E5E656E5E5B5B5144300E00000000000000000000000000000000000000000000000000
00000000000000000000000002010303050505070706040606080B08080A0B0A0A090A0A
09090A0B0A0A090B0A090B0A080A0909090B0A0A0A0B0A0B0B090D0B0B0A0A0A0A0B0E0B
0A0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0A0E0C0D0B0A090A0B0A0B0B0C0C0B0A080D0C0A0A0A0D0C0A0B0D080C
0B0C0E0E0B0C09080C0A060A0A06080A0908060908080A06070707040105050202030000
000000000000000000000000000000000000000000000000000000000000000000000003
0000000003000000090502050A0406070C0E0F0C0812140C110315171516141113191114
14191E2327211A22282829222727271F1F2320231819191B1B1D1A121F161C161B0D1C14
181C14111817191E1E141318181C1F1825221A1E1A121616231916181A19181808131320
1213130F19070E1009160C180E1010070F0404060D0A0A0A030704040A13090606050C04
0D0806150D0417110E0B0D1316131018161817221B14201D181E2B281C252F202A1F322F
343833373E2D32343138383A373C323235373F37394240444B4B515355504D5058545856
635E6864686C6A5A5A4F3D2B0E0000000000000000000000000000000000000000000000
00000000000000000000000000000103040706060605070709080A0908090B0B09090C0B
090B090A0B0C0A0A090B0C0A0B0C0C0B0B0A0A0D0A090A0B0B0C0C0A090A0C0D0B0A0A0A
0B0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0D090A0C0B0A080A0B0A0C0B0C07090E0B0B0C0C0C0C0B0A0B0D0A090C
090C0C09090909070A0B090A090709090B07070706070509060603040703010100000000
000000000000000000000000000000000000000000000000000000000000020000010201
09040300040200000101060806091108051210110B150F0F16140A13201C121814181614
1F131A171723201A2C2C262520262322211E222223211915121D281821101D15181A2020
1D15221D1F13161B1F131C1C1F161922202C241C191A1C1A1D13101D1A1E140B100E1819
19180C10190A101414120C100E090E02030A0502080910000007090A0907110D01050200
04070201040F060D13101B0E12181019181A1E11120814141922131617222125272D2B28
3633302F2B3837303D3738393244333843413F443C2D3E3E484A4946534D48505A514E57
5D605E6161606C686362584D3E1B00000000000000000000000000000000000000000000
00000000000000000000000000000001040204040306050808080A080A0A0B08090D0909
0B0A090B09090B0A0B0C0A070C0A0B0B0C0A0B0C0A0C0B0A0B0B0C0B0B0A090B0B0B0B09
0D0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090A090C0C090C0B0A080B0C090B0A0A0C0C0C0B0A0B0D090B0A0A0C0C0C
0D0A080908090B0A0B0B080908090907090A070A05080307060305030104000100000200
000000000000000000000000000000000000000000000000000000000200000202060803
0704100600090306020000080E030B05090F070F0B16080C13151A171E201F191919241F
21161D1A1C281C1C27222B222528242B2B2826292A2426201F1D211C1D181A25221E2019
1D1F1C23191C171D13151E16191520201A1917181F261E1A191B141D12171B190D191409
110E1D100C1111070B1217170E0C0E0B0A050B0A06040E1205070A081412080E08030001
000D04000E140E0C0A0A12110905051215110F111809110A1A0F161D1615101A211C1D2A
1F3025282C24352D303C412D382E3A383E3A4243322E41343A39424E3F48455251535E4C
4451545D6463565F6B60615F4E4126070000000000000000000000000000000000000000
0000000000000000000000000000000000020204060506080607090B050A0A0809080A0B
0B0A0B0A0B090A0B0B0A0C0A090D0A0C0B0B0A0A0C0B0C0A0B0A0B0B090E0B0B0B0C0C0D
0A0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0B0A0C0B0B0B0B0B0B0C0B0C0D0B0A0A0C0A090B0B090909090B0A0D0A
090C0A060B0B0A0A0B0909090A070B0805090A0604080305050500000203000000000000
00000000000000000000000000000000000000000000000000000004020000080B05080D
0B080D0C03020E090B050A0803090C0406080E0A0C01150C110F15161A1414171F121A17
141C1A1E1F1A1D2328262522261A2E2B24252218201C1B19221F231416201918231D182A
2C12161C241A1725182017171C1F12161D182114172B272823261B17211F19192517191B
111E130E1713190F17111A0B0D110F03040A06000E0F010D0C06130F11110F0800020B11
060B0C0D081708100D18120D100F0A070E1414100E190511091E150B11111A1C20212019
2423232C2B2B3735362D33302837313A3D3B45363736373641454045423F45454E51564F
5354555B595563555E64635D655748311700000000000000000000000000000000000000
00000000000000000000000000000002000102010104040606080707070709090B090809
0A090C0A090A0B0B0A0C090D0B0A0B0B0C0D0B0C0A0B0A0B0B0B0B0A090A0B0A0D0A0C0A
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000908090B0B0A0B0D0C0C08090D090C0A0A0B0B0D09080B0A0A090A080A0B0D
0B0D0A090B07090C09090B070A0608070706070506060602050303020001000000000000
000000000000000000000000000000000000000000000003000000020A05080E0B0D0A12
11110B0C120F0D0B09020B0800090701030C08070F0F070A0A131A14171B191714181820
13122229142722201E21242A1F2A2A2C2F27292C32282F2927281825231F23232A1E2D19
1B282019181E191A11131E191622171A1710212223241E202313291C1C151A1E1E16211C
1A191A0F10171411171011190B0C0C080D060B0E090A0B00020F1A130C090D0B0907080B
010A05071012010F150B000909111003040510090F0B0A100D0E14151B101F1E12132223
162721172C24262C333D2B2A3630312F2F3E3A2F353B363C383A4D4C503E393E4546594F
56455C595C5760585C5C5E6B6D5F564F46260A0000000000000000000000000000000000
0000000000000000000000000000000000000200030304050406070A0A0B070609080B0A
09090C09090A0D080B0B0C0A0B0E080A0C0B0C0A0B0D0C0A0B0C09090C0B0A0C0A0D090A
0A0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0D0D0C090D0A0B0A0A090C0A080B0B090C0B0B090B08090C090B090E0C
0B0B0A0B090A070B07090709060706090608030606060403040501040000000000000000
000000000000000000000000000000000000000000000000000303080405070F10110F10
0E0B0D0F13150E0F0C0D10100806040C0208050C0E12090C0F171216180D1B1B1C1C1822
1F121824211F211923272C2324292F26242A372D2E2626222B25281F1D1E202F212C2214
231F20231B1923211322171316291D1D231E15111E1E20171F201C192821241D20241D20
0F2418111417191512141110140D0E110E070E0710070B0C0E0A181214050A100A030206
0D09100D131A0C030D17090A0810070B0006080505110B0D12091614101B12151E1D1819
201826292A2E29222D20312D3A263733383C373A3D3341344B3A493B44363A3F414B4D42
4C4C4A575A494C5A5465676371615D62564B301400000000000000000000000000000000
000000000000000000000000000000000000000001020503040604080807090907090B0B
08080A080908090A0C0A0B090A0B0D0B0C0A0C0B0A0B0E0A0A0B0A0B0C0D0B0A0C0B0B0C
0B0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0B0D0D0D0B0B0C0B0C0B0B0B0E0B0B0B0C0B0B0B0B0A0E0B0A0C090808
080B0B080A090A0B0A090D06080704070607040702020102000300010000000000000000
000000000000000000000000000000000000000000000000040A0605070E101418121A11
1411151817141D0E110C100C140E0E030B130C0A080E090910140C10161619171417171F
1222142021202620212821222B2829302D27322A2B211E2129231C1C221E1F2B23282420
1F1E27201E2B29241F17111B17151C24191B2624171420131D16241C1519261F121A241D
2B23200C0E130F1D0B1E090B111913140A0C040A0C1013110D12130E0A070F1502120E08
0D0F090D0A07010B030E170C0C0B0406080D0E0F0E0D070B160F1317140F10180B191821
1B201E1D24242F282D2F29252627273437333D2A2F33353644473D363733474037494048
404C57524758545E505F51636B62635E6355484627080000000000000000000000000000
000000000000000000000000000000000000000000020102020603080908060907070A0A
0B0A0A0A070B0A0B0B090A0A0B090A090A0C0B0C0C0B0D0B0A0B0B0A0C0C0A0A0A0B080D
0A090D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0B0A090B0B080A0B0B0C0B0D0A0B09090C090B0B0B0A0C0C0B0B08080A
080B0A0D0B0C08090807080B070708030508040505020200010200000000000000000000
00000000000000000000000000000000000000000000040002040C091212151318101A1A
1A1C1419182118132017151917151A180C12110604110A08180D1418091C1115231D1B1E
1E1423171C14241B1B261B2624282427302428292C2C292D2F263233242D271F21242A22
2E271E1A262E23201A253029241D19181A221E21151922211A14181E271A1A1A22252A1D
2E2D0D17111E131A1D0C0A14140D091312090D14100F1012151614110C0D0B0E08110807
0C0814061003090412080E000A100F0303000406150515120E0F0F17130C0A101D0C2118
1D1F1C1D1A201B1F1B1F2B2F28272527282D3C363B392F3C383B342F3E353D3C414E4043
4242435651514F4F5259535762645D6263665F54502B1C00000000000000000000000000
000000000000000000000000000000000000000000000003030204070706090907070708
090809090A0809090C0B09080C0D0C0B090B0B0B0B0A0C0A0B0B0B0B0D0B090B0B0C0B09
0B080C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090C0E0E0A0D0C0A0D0D0B0B0A090B0B090B0E0B0A0A0B0A070A0A0A0C0A0C
0A070A080A090C0B0A080607090805060305040603020602000000000000001D00000000
00000000000000000000000000000000000000000006000201070E0B0E16131516181917
1B1D191F19191D1D1F1E101D12161C130B110C0D090B0C101207140B11121516171B221D
1D1625210F19211C251E2118241A3027222A2A2C382D322C1D2B2F272526242B2A2D2F2B
2B2B282B1F1F2F22181C221D1620161A0E1913181A12161E111B27231E26291F1A261423
2A22030F1F1B191B1E101214130A0C140E0C08140F15191A171811110A120C0C0B0D1208
0C12100B060E0B09080E08050D0312000704000E07100D11111B08081D0E1014110F1619
1816202528222921222725201D262B2C2A2C2B3635383831392135323A353D3446404744
3C4C4D48445354594F58565B5C51645B56685F5F4C493223040000000000000000000000
00000000000000000000000000000000000000000000000002020906050606090B090908
0A09090A0B0A0C0B0B0D0C0B0B0D0D090A0B0B0A0C0C0A0C0C0B0D090C0B0B0A0A090B0B
0A0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090B0B0A0C0B0D0C090C0D0B09090C0A0B0B0B09090A0C090B0A090A0C0C09
0A0C090B0A0A090607050306060606030605020502000001000000000000000000000000
000000000000000000000000000000000000000000060203090B0F100D171614191D211C
2028211A201F21221F1E23241E1F1D13141813100C090E0F090B1112090A16061317131C
17101A122018271F201B231D252A26252D2C2A2E352934332831282C2F2F25323A262B2E
2F2E3C31303125181E2A18221D1F1A22141A1A0D111F1C24181618161D1E1C1E151C241D
261D181E1B1D191A2C0F150E1711120B1F131014152A181A161B180814150E10130A1510
11141905100807060D11080C050F0F0304050F000A0B120A16171116100F0B110F061720
12151C1C1F1E2424282126291F242B2F2C25322C32313A313432302A2637403B39493A3A
4238494C505243524E584F54575D5B626555675F5E535542381400000000000000000000
000000000000000000000000000000000000000000000000000001030507070609080906
0A06080B0A0C0A0A0C0B09090B0C0C090A0E0B0A0A0C0B0B090A0A0B080C0A0C0C0A0A0C
0C0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0E0A0B0A080A0C0A09090C0B0D0B0B0B0B0A0A0C09080C0A0B0B060B090C
070B0A0A0809050908080605060602040404050100020100000000000000000000000000
0000000000000000000000000000000000000200030208090C0C111116121C18211D181C
1D211620182420202D2F2023202B182119231B170F130B0E131816120E0F151119161C15
101119121919201F282325202426272E282B2624212930313D322E3E392A2B332F292E38
2E2D353736312120251C2711251A1D201C201E19151B211C1F10242321191920191B2523
1B2E212327252D19221917111C131D1C201C0F0E231C1608131C1617130D100F1213130B
0E0B13191005050504100A08060104080501020000030F100D17071113120E0D15111317
12201D171622211C2327242721272027192E2823312D26322F3133202F26372E3842343C
413E494F414B4546565153585D5B5A5F58606265565B6154423818000000000000000000
000000000000000000000000000000000000000000000000000001030505060708070A08
09080909070B090A0A0A070A0A0B090B0B0A0D09090A0A0A0A090A0A0A0C0A0A0A0C0C0D
0B0B0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0C0A0D0B0A0A0B0C0C0B090A0C0D090B0A080A0B080B0C0B080A0B090A
0B0B0A070907070905080B05070306020201030001010000000000000000000000000000
0000000000000000000000000000000000000000000506090A16161A1215131F141C1C22
222C262A21202324252F2B242B2B2C1A2423181C150E121204101416090D0D0E0D1E1816
19102D1B1A17232129161D1F27212334283028282D28312C2A35322F362D382D351D2B30
303333392F2C2D292021291D2A1D27201916181F16220E191B1D141320191916141F2623
222A1B2B2523201D241B191B1E1A1416161A1E14091D2320131B1519131E0C150E140C07
12110F0A150B080D0D0C041105020B0E0607020A00000C0909090D14221810161315091D
201319161A201E1E1F25201E2229242621232F282C2B2822252A211E2535382B313C493F
4C45443C453C4047444A4D4C4854505E5B605C636264615A514F4A210400000000000000
000000000000000000000000000000000000000000000000000000010203040508060807
0808090A090A0A090D090B0B090A0B0B0C0B0B0B0B0C0C0C0B0B0E0D0B0B090B0D0C0C0C
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090E0A09090A090B0A0B0C090A0A0A0B0B0C0C080B09090B0B0A0B09070B09
0B0808090B0C090607040A08030402010200010000000000000000000000000000000000
00000000000000000000000000000000000002030C081013141C1B141D1818171A131C1B
291E27242127212521251F232D222D1E27291E161A12210F1411110B080D0E0D0B180C14
1C141D1E20181A2319212C202121201B1F2D2E3435273A2B312C33362C312E38303A3135
3D3937223B322F2C2A282A261E221E2025261B23142415261C2A1E161C18191D1B221C29
283326272C282B2A2D2C22131A1719141B18151D1A17111825110B11130B19180F181A14
0708070B090809060B070C08080805080C0D0C0B00000B0211051C1A141B0F1310151311
1F1919171E1D191D1B1F1F242A292C2825192E2C2B2F3D2C2F2C2B26322C35302A313F35
3A313A4F4B4D48434C455546514E5D565A5557585464605E6560503C2A0E000000000000
000000000000000000000000000000000000000000000000000000000003030305070708
070A070809070B0A080C0B0C090B090B0A0A090A0A0A0B0B0A0B0B0B090C0B0B0B0A0A0C
0B0D0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0B0B0E0B0B0B0D0A0C0B0A090D0B0B0B0C0C090B0B0C0C0A0C0A09070B0A
080A08070A0A0B0709090606030204040001000001000000000000000000000000000000
0000000000000000000000000000000001050506090A140C151113202122241E271C2425
1D1D2129202E25292326303232282A2A251116211321171C0E1310130F120D18090A1213
0C131519122420211728242C2B2E2A28272B312E2D2632262E322226332C353628362A2E
332F2F37252C34353D35342628152D23282E1D1F1F261E1F241C2529221F1A1D201C1C20
271F242228252B2B252E1F1A181C1119141C17131C1E2120241A13201016171A12180D15
0705150D131015121615020200070E0D0E13150E0A0E03100C050E150C0F0D1A1A1D1326
171A13181E1A13141D1B1D1D1F1D232723212B2421272E2E2D2D27333731353128232A2B
38363D413E393B3C5A4B464C4B4C535355554D55565E5F586A605C58473C1A0000000000
000000000000000000000000000000000000000000000000000000000100030104040706
04060908070A0B0A070A0A0A060B080B0D0A0A0B080C0C09090B0B0D0A090B0B0B0B0C0B
0A0909000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0E0C0B0D0B0C0A0C0B0B09080C0C0D090A0B0C0A080A0B0C0A0C0B080A
08080A0B0A07080705030605020700020300000000000000000000000000000000000000
000000000000000000000000000003000001030D0B111416130E1A141D22211E24272D2A
282929222522322E2F222A282D212C2D27211F25251F1D0F110D100E10170F06150E100E
12110E241D192220161922252B2B2228262E2C313324322B282623381E2824303535322D
423837393F40325A3D2D29222F262F212D13172B28251C1A1D2A31232B1A1610271B1826
151E2227302132283322241D1B1E2414141B10191C161D091F14160E1A1C0D1510120B22
110B0D140D13100F101612080B0D0B11130E0D0A0C0E0B0D07060C11050D141322102319
16151C171C17121D1B1A241F1F2822202C1E253A2D2F26292C2C2527353231412C27232A
382F39363337464040454852504A504C464E58605261505F54575B57584A3B2205000000
000000000000000000000000000000000000000000000000000000000000030105060706
0705080909080A0A0A0C08090B0A0A080C090A0B0A0C0A0C0B0D090C0B0C0C0A0C0A0B0B
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C080D0B090A0C0B0B0C090B0A0B0A0C080E0B0B0B0A0C0B0A0C0B0D0B0C
080C06090807080604070301030402020000000000000000000000000000000000000000
000000000000000000000000000000020002080C180D19141217191E212628232421241F
232A202B2A26302E2F322D2722232A2227222831261F171B171918121214181A10190F12
0D0D10181119171E23291E222E28222C2D2B272B2D2E2F222C3126262924261B27263C30
2A2B36383C393C2F35322E2A2A1C2B2A221E29231A1F2529191A151B1F29172111191825
25201C2026242B2B20251F1A1E231C101B1717151717141F141D1819161F17141E150C09
07120D1009160D1311121B120E0E120718120E0E180C0B120A120B160B05132718211E16
1517150D151B141F191F1D1C2120231C241D2D182F1E2A2024242131272D3028251E2326
283D3638403345413F39474550554950554C4C4D605E614D6363645B5A4F554A340A0000
000000000000000000000000000000000000000000000000000000000000000100020608
05060907070A0A090709090909080A0A0B0B0A09080D090B0B0D0A090C0A0C0C0A0B0B0B
0B090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C0A0A0C0A080C0A0D0C0A08090809090A090A0B0A0A090C0909090808
090908080609040904020004000400000000000000000000000000000000000000000000
000000000000000000000000000000000304000F080E1A1C18161A181D2525222B262B29
28272621302E2B2D3B2D39272C312B2A23342930372E27251E1D1E1F1E1D1516130F1711
050D1717101B0E12211B1B231F282F1E2B292F2B27282D33261C272526222C29242F302A
3A2F3736383D2F2E2C312C3D253021291D161F1420212122231F2A1F1F221A261B1C1D1D
14361F1D221B271B261D22131617181E21211D121910110D0C22150D1D1F1D1F140A0C07
15061219171D181212091B1316121115100A0E0F130F0A140F0D1F1A1610101913191914
6818161C18181A1020281B1A151722131E1B27212423202121292928312D322C29272A2C
2B28322E3C4A3D4442473E4D5144474D4A474B4C394D5B6150565F5B6A5A6A524D2C1200
000000000000000000000000000000000000000000000000000000000000000001020103
07070608080909080C0A0C0A080B090A090B0A090B090B090C0A0C0B09090C090D090A0C
0A0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B090D0B0C090C0A0C0B0B0A0C080A0B0D0B0B0C0A0C080A0A090B08070A
070809040A03060303000202000000000000000000000000000000000000000000000000
000000000000000000000000000408000A06121414180D19191B17181E2422212D29231F
2E27292E2B27252F2A2638373328293130242F2B282A2C2F2119201F19191A190F0F1214
140B151B211B1811181112232C292724282221232824313023211F171215242833303826
26292A2E293D3D3735333B302E20272F1F26201F212114281E242B242D21281F211C1F1D
21142325261F30292627231F1F1D21221C1A1C101F220E151716201C1314161D1D101016
0A0F1211141A24170E1B1F2710131718130E1913181A18111E1213170C162815171D1B0E
190E0F091A161E14100F191B1C161F1D1F1821241D1E242123221F262D3327322D292327
35282E2F2D353E3B373041463D47594B4A4A4C4E434F504A57565E5E636A5C615B4A3217
000000000000000000000000000000000000000000000000000000000000000000030604
03040805070609090809090A0A0B0B0A0B080A0B0B0B08090B09090B0B0C0A0A0B0B0C0B
0B0C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0C0B0B090C090C0C0C090C0A090B0B0A0B0B0A0B0808090A090B090A09
060506050804040604050304020000000000000000000000000000000000000000000000
00000000000000000000000000000004080A0E150C1A1A13201A191F211D2623272F2826
263020342D2C2C312F2B1F342D2E282D263A282B313735272D1E261C1E201D211C131916
151C140E1014141D1F14261A222C1723282D333429222726272425291C122122212A3636
373D313D313333363837282B36322C301E1928221627272620171F251F291F1F2121241B
221E1E121E1D1D29251D1C141621251A1B23181D2316221E1C181115191317121B1A1712
0E1710100A19151108191C261612160D181D1C151018120B16151918151F1C1B1C211917
1212141A13141A1D1916251F2116141B1416181E251E211615222224282C2A252E1D232E
29352F242A302A3C37333A3F414345444C484D4B4D4754544C5059545F61595D5F5B5336
230600000000000000000000000000000000000000000000000000000000000000000102
0602070807040809060A0809080A0C0C0A0A0B0A0A0C0B0A0B09070D0C0B0B0B0B0C090E
0B0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090D0C0A0C0C08080B0A0A090B0B0A080A0D0D0B0D0B0B0A090C090808080C
060B07050807040303030000000000000000000000000000000000000000000000000000
000000000000000000000000030005060A1214111A0E151A1E1B2425242A2620262A3229
2C2B2F2D322828262E2A2E313031353E362B3B26342D2C31342B24242923281C2723190F
1B10121B18151A1614171C1B31272621292C2A21252529233030261E22181D2B251F2C2E
322438323A2D2D3230302F1B312D2D2B282627272128341A171F1C2D1F222E1821222323
17172512202820221F1C1B221C20232D221F1E251E200F141E131C0F15141B151B1D1420
0E1612140F1312161B1D1E1E1B17140C151B14171213111E140923181E161F1412141318
201118171C1718161C1C141D1B10161111281F13201D1C292628272F3032391D2B322E30
222B291F272C2F38373D433A3C3637474F504C455A4D4F4E50515060605D5B675F625A52
3E2305000000000000000000000000000000000000000000000000000000000000000002
0204040805070A090C07080A09090909070A0A0C0D0A0B0C0B0A0B0B0C0C0A0A0B09090C
0B0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0C0B0A0C0D0B0A0A0B0D0A0C0A0C0B0B09070C0A08090A0C080A08080A08
060707050605030504020000000000000000000000000000000000000000000000000000
000000000000000000040000030A08090F040C0F0D1715191B201F1D292533252C282527
2B2E282B302B2B2A333B252735323B262F253535293334332B322D272B242E1E22222727
2028171810170F0D17171B221F141B1F1F1E1F2621252B352A1C26241A25241C27253A31
313A342C452D3E373131222D2B442E1F2527211E222A1F1912162A191A232126251B2A17
1A191517162A272923271E182125250C1C1D191A1C211D2418151D171B1A17191A1C1F11
121F0F181514181B15141B1D1D0E0E0B061A191C1614171116182B19151A160F1C151C19
24121611131417211E1C1B1A1E181A121415201921201B1D1B2828272F2A262E35313030
282C29252B283832353333392E394746453E434C42464C434954524C545460635C65615C
534127030000000000000000000000000000000000000000000000000000000000000000
050204040506070A0709080A0A0A0B0A0B0A0A0C0B090A080B0A0B0A090B090B0A0A080A
0C0B0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A080A0C0D0D0C0A08090A080B0A0A0A0B0A0A0A0A09080A0C070A0808
060507060305030202000000000000000000000000000000000000000000000000000000
00000000000000000000000005090B06070F0F1610191E11191C1D2824232C2D282B3129
2C2E35293337372B2D33333F36272B272B322D363A353931303A3A2D252D2E292519211F
221C0D10121B240F2515221B1C181422261C213024322A2D322E2E1E31222421252C262B
2B3C2A32313C31392C2F403E2C28352A2C2D282D2B121C19251C162128201E271C291D25
1B14130E1D26191C1F2726221A20211A17231C1E211D1911252A1522122015181808171A
151C1A15192319192A240D12170D0D1C1114110F1A120A1013121E18191913111A0C0E1D
23180D16151E1F19191F200F191F1C16231C131F22261E1C1E2034322C2B2633312F3235
2E261F242A1D26402B342E353D37383B36404C494C535343524D4B6A555D575E65626369
5D533D230500000000000000000000000000000000000000000000000000000000000000
00020105060505070807090A090909090A090A09090C0C0B0B090B0C0B0A0A090A0C0C0B
0B0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0B0B0E090A0B0B09090C090B0B0D0B0B09070D09080709070704080504
070608040704010301000100000000000000000000000000000000000000000000000000
000000000000000000000003090B040C0A0F0C08181A151E1A1F2129282120281C233327
1E2A292F3831382D3936293033292D382D36343B3744232C3B343E2D3C3036372F1F191D
22191117141213190B1620110C040C1818162815252F29282F3B202D2D29312D2C2D332E
28302633322E303E3A353B412F2B343131322F312A2D261E18231D1D221B142324211724
201B0F1F1A221920221E281D231D201D1B241E2B1D2D131E1E1C1C2524201E281C161316
1F23200E16131A232220190C19080811160E191C14101213121A14111B1C0D250E1D1A18
231E231920231F171D1F24201F251E211E25170A231B201D16262C2922281D282C282831
2027262026262E242E2D303C33362E302F3A403B4B464B534C4D50584F54515C62625D5F
625E58462C0D000000000000000000000000000000000000000000000000000000000000
000203060105080407070B09090B0A0C0C0A0A080B09090A0A0B090A08090C090A0B0A0B
090A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000F0A0A0A0B0D0B0B0B0B0C0A0B0E090A0B080709090C0B09070A0908090708
050704040402020001000000000000000000000000000000000000000000000000000000
0000000000000000000100000101090D0B1209140A1618221B2615262A1F2926262F202A
2C2A2B352D3031332C323030312B393330372D35283136463B4032322F333A2F322B2521
32230F170F15201C161516260E16101E1B21232F211D1E1E333427281F25242D2E2F3630
2722333636392838303B31312726272623291D263126212B1E2D13101A1C1E1C1921251A
131F191C2120222021261F2D1C1E222A2224171E2322212B1C192C1D2421201C23210F1A
1D14160D161B121F21241910120E18120B0F080E110A0D120A110C181314110D131C1A1C
1F12171B1A21141E271B232F1F28201E1C17201B1C1F1D1F1815201D281A2A1B24282827
1D29321E26281D2A272F322C35322E2C2D392F353944474D4F51485B465558564E62605E
5E615D503F370D0000000000000000000000000000000000000000000000000000000000
0000030005070608070806080A0908090909080C0A0A0A0A0A0D0C0B090B09090B0B0A09
0C0C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C0A0B0D0B0D080C0B07090B0A0B070B090C0C0D0B070B0B0907090705
040407080901000000000000000000000000000000000000000000000000000000000000
00000000000000000100020200070009090B0D0F18111B161B1F1621231C3126202D2C28
332C232F2832272B222E302B33362B393D2C2D2736323C2D3A363235332C333B3D2D2127
25181F1B20181F261A1A16161F0718111F1B20171C211B2A33313123272A242632282826
263129312C3125283C3231312A3226262A2E2B292419281F2C29262023231F23282C331F
1B1B191A1713241922151B2221181E23331E1D1A221B1E1C261E23231C2B27302C201F21
29161C0D29161A14170B1B0B0E1105110C0E0B101306061112151A1D1816201216091519
1B1B1F18251A2F211E1E211D2923262A231E23261F1F191D171E241F2722131A2015222D
3528231F211F1920272C2E31332D32322732353C3B39403F434A4C47544A5154505C5D5E
6469695C544B381500000000000000000000000000000000000000000000000000000000
0000000101050407050508090B0709090B090A090A0809080D0C0B0B0B0B0C0B0C0A0C0B
0C0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0A070D0D0B090B090C0C0C0C0C0B090A080A07080A080A080708050706
070504040405000000000000000000000000000000000000000000000000000000000000
00000000000200000001070208060D130D0A17141B201417172617251F2C232723211F27
28313B2F2E2C332B31302B2F2F2E323D3E38362C2F352E3B3D3234382D3E40412B2A2723
242D172B2320172C171D171D1B1F18161C16141E22192027201B31302D26232B20213134
2E2C212533273131322F27302E372D32322A30372923232F2229262325202D261E291A26
191220232622121A181D171A091324211F1D1D22242C261F23302A27282D2829271B2323
1A171A1019170D1D19201415130B0914121A0E0E03161211140B1419101C10150F0D170D
1818171F24182223242D182A1F20251B1B30252B1E242624251F1B191E1D201924231B20
2B272723242A1C251B2321282F302D2F2D202A3235303E3F484A4E4F51524E5C4F5B5E65
5A6262555F5051371B000000000000000000000000000000000000000000000000000000
000000000005030504060606090A070A0A0B0A0A0A0B090B0C0B0A09090A000A0C0B0B0A
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080B0B0B0C0B0C0C0B0C0E0A0B0A0B0B090B0A0A080A0809060A0806060802
040200020000000000000000000000000000000000000000000000000000000000000000
000000000000000000000503070A0A040F0F130F0D0E191B1B181914272626201F282323
262C2928201F2C262327252A2D22272B3C353B2D2D3037373F3543423C3839393C30312E
312E2E27212626271D191C1417251A111A23201F311622241C1D262231232431252D242B
3824292B281D2839322A3321232F2B36262E382F292E31271E2622232C2625212324251D
24211E1E1E1E2A24151F1826211D2117181C152628261C231D1C202624212A1E1F282A2C
151C160F12221A1416211F191E1A10070F0D0E10130B141818090F1D191D151A0F151104
1A121C192119251F2B1F21262E2C2B222F28241E2C19231E221E211F161F1A1A171E2822
2922261E1C2C27231A1A2D2727252729262C2D2F2E3B3A3C473F4344464B54555D605757
525C586265595D4C39240000000000000000000000000000000000000000000000000000
0000000002010307050603070908090809080A09090A0A0A090A090B0C0C070D0A090A0A
0A090C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A090B0B0C0B0B0B0A0C0C0B0A0A0E0C090C0B0B080B0606090805060206
040403010000000000000000000000000000000000000000000000000000000000000000
000000000500020203010A01040C060E0D110E190C171220141B201D181B122024291C23
2F392A2931261A1D22221F1A273A243632383C3332373A353436343F44423531313C313A
302435332C201C2C1C291A2318131720181B1112171E1A262426222328211A26242F2A25
3229261D2C2F2C36322F2E2426323428253A32352F2E312C2E212A2E291D232C231E282B
2E2326222023292022181C221522202019251F2325181B27131A1B232D1E21292B342925
221D16111020241A0F271B17141410151111101013030F030B0910101312100C0F1A1414
131B111F131A1A242125212423271C2B1D28262C1E1F27212218281B11231E17201D221D
2020192C2A1E1C25271A1B29262523302D281F272B2A3333343E424B43484F494F595A60
5F5F6062696360634E3E1704000000000000000000000000000000000000000000000000
000000000100030204070709060607090809090A080A090B08090B0B0A0C080B0A0A0A0A
0C0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0B09090A0B0B0C090A0A0909090C0C09090B09090707070A0708050603
060602020000000000000000000000000000000000000000000000000000000000000000
0000000000050608060706060E080D0E0D08160E081016192015181621211D152227271F
262F24272319241E2429241F282E2130392F332F343834394636353341373C40493E3E3D
3B38292B32222F1E28201D242B2B24170E1622181F2222191B2525201B19242C1D202421
2825233624313130352522311F2B282F322D38362E2634292E2C26232B211B322E2E362A
282227292C2B2A21291F201A1E19171D221A291A1B1C1F1819151E112F2528202C252423
2126182618130B2016090E1B131A1C0F0B130B090C0C050B050A1112160B000E0F0A1013
1221141422171B161F281B242022241E1E22242628231E2727241F22251A1D1E1B21221C
1E1B1F202D0F16161D24251C29182822312A2A1F25272A38333B493C484A4356594F5953
5A635F6358575F615A544125040000000000000000000000000000000000000000000000
0000000000000001030304050707070609080A070A08090B0D0D0B0A0A090B0A0B0B0A0C
0A0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090C0B0D0A080C0C090C0B080A0A0B090C0A080907070806090805050105
000201000000000000000000000000000000000000000000000000000000000000000000
00000400000503080C0C08091312130B10100711131B16161A1715121F231C1C211B201E
1B292522281B271D201F292C2D252F29292E31232D363C39373A4036363B45373D41313E
2F3642363B393C2D21202116231E1D131A2120192120231D1929182D282623192B232A24
2827232D2D242A2D29232A271F272B1F2734322E3437273326382D2B2D2A282B40343544
202B1C19292A1A272623171B1317151B17121D23292A221D1A142A251E1C2B2522221F3A
252B141B1B0D1C1019181D1F0D16130D1020051120110C1A11171011160E0C080D050713
1010131B131D0D1622201E23192121182819242A252A202F291C2325212017191321241C
282422231E2423171D241F2A1D302C16201D23272D2828242B343D3F3B3D43474C624748
5D5A645A655A695E5F584A43280700000000000000000000000000000000000000000000
000000000000000202030606060708080B0807090908090B0B0C09090C09090B090D0B0D
0A0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090A0A0A0A0B0F0B090C0A0A090909090A09080807080907080303080505
000100000000000000000000000000000000000000000000000000000000000000000000
000008020602000B0E0F0E0D100E07181111151211150B151219231C13170E1B14281919
1E1928211E23212221181F202A1F2524252C302D2F35333A353834453748324A4131403F
39373339362C2B352B2A2B2527162622201917231A18101C121A181D1B1928231E181D18
201E1A16242E261C27272F2A31262D302721381C362732302E2A2B2D302B2A282F39452E
362C1C2429242923282B2E242216231E121F0E1E0D1C1A161424242F2A2A292525262824
261E2A291723180F221F1613111D141915131219080C030B0A0810110A0614000D060A0C
0C0D090C0512040C161A211F131F0F1C161A1C25131428272221252C261428181D242B18
1D1E222C1B1B1D2B2128181E2521162124271B20252720212825262C3D34424550555853
57576063595B636C57675D4D3A1E00000000000000000000000000000000000000000000
000000000000000000030305060608090809090A0B0B0A0C0B090A0A090D080A0B0B090A
0B0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090A0C0B0D070A0B0A0A090A09080A0B090B070A0709040906080505050302
020000000000000000000000000000000000000000000000000000000000000000000000
0700090001030A051E130E15151011130A130D1205081A131016160C0E1A101620231919
1C2011121923201D171D261F221F2B28262727392E3A3839403C3E3C40453C31433D423C
43483B3A414B3736322B28352D1C2423170B240E1C2215130C14111A0D142113210E191B
24212122341F2120262B1C21241C38252D26292532352D2E29362927222B2229343C2E34
282A2F232C2C1D291A252D2F25251C21141E171F1B2518101F342B272527302724292024
1C1F35281D1B181D241A1B1C111E1C0E0E120B140B0E0B010D0D0A170D0F050400020C08
030C050A080C0E121C1A191D1C2117151722191C1B27191D1F2425242C201A1C221B2C22
1D171A162321251A1F272C25231F192518191A221D2429242923312A3036414448524C48
59575F615C65656267685E5A563D1F040000000000000000000000000000000000000000
000000000000000000020306070507080808080B0907070809090B0A0B0C0C0A0B0B0B0C
0C090D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090B090B0A0B0C0A0B0A0C09090B0A0A070909090A070606060503050302
000000000000000000000000000000000000000000000000000000000000000000000201
05060D1008080E0A0C15190F1A0F16070E0D0B1519120E101816121210180D10110F1411
1A0E181D1D141D1716161F201A1F2514261F332930353F363B333A363E33443E423C3747
43344437333A4633323A3B312E302E18222C262726191E19191B0A0F11111C1426180F20
201A201B1F1A272118232D2C292E1A212E1D2627281F25302F322E28312333232E303431
3734261E1E1929323E292D302F1D251522121010220F1A2523202B1B222B301A2725212E
2C2E201B2A182F231A1A1523161A0E1D181512110711120B0A05100210070D0607110E0E
000200090D0713170E1B1511151D1C151A1320111920161D24181B18222123221D201F27
1E201922292821232A2529231A241F2126271E14201F1A17192D222D2C31403E4F4E4A53
59565E57585B636F6967645C5752321A0A00000000000000000000000000000000000000
000000000000000000000203030507060806080907080B090C0A0B09090B090C0A0B0C0C
080A0E000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C090B0B0A0A0B0B090A0C0A0A090C07080908070A0405060304010201
00000000000000000000000000000000000000000000000000000000000000000907030B
05110D0F11110C1113151015191B1113161013140A0E12140F130B12111A14130E0A0513
161A0A17131114150E18231A1B1817241733273439443D44303447403641343C39423F41
404236413B403D453B273B3D41352D2F202A2B2F252E1F1B0F0B1212141F1C14181F1917
1A26211D19241B23162513231F18262A242F24331C2F272D2C2D2B3020352A3730353827
332D2F12201826232B33382D27271D2A241F251722261B1D1E2C252F2316222324211C28
211C212F1830281D221F171D1D0E111D101C120D09091310050809050B0D0C040B100C02
0607060907011116090F1A180F190F1612180F0C0C101614201D202B2B201B211A191A1A
181C2116171E231D241D2523221F2623212628201B1F1F2824242A1E2227263731494D4F
515A5E62535B5B5F6D6862665D5F5136200E020000000000000000000000000000000000
00000000000000000000000104050705050806070609090C080C0A0A0A0A080B0B0B0C0B
0A0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B09090B0B0C090C0B0B0A0C0B080B0A0907060905050604050402020200
00000000000000000000000000000000000000000000000000000000000201020007050C
0B0912120F111418101B14170F191C2913101A1515131D0E12110F0E051206090D0B0A0E
08111011110A1015120E141B1C1420142A2326353A413545382E4C3A38423D413D473F37
35413C2E3C3B393E41413D3B3D3D3B2A382B3535311E25281E171C0B160F110416121721
1E121B162C1E1A2226282B16251D1C1E26161024262D31252B352F23282020333D2C3235
2B263021302D29212A2A242322232229302C2A2918242721201317161F15130A251F2B2D
23222D21242E252427292220191B2216231A18091216021917180B0D0C18020707060D07
0A00040B0910110B0C010E0A161516101C2010160D1B1919181211251A231B1A1C201313
1C1B1B1D1A1D1E201E22272B22222729271D1B23291D221D1E242127272D2E37423F3953
53505D5C5A5E5F5F5C58666566605B4740270F0100000000000000000000000000000000
0000000000000000000000000002040308060709090707090A080B07080A09090C0A090B
0B0C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B080C0A0E090D090C090B0A0B0B090C0808080808050605050103000300
00000000000000000000000000000000000000000000000000000000000002080B0D1311
110F15111320161B1B23181A26221915160E0D1E1B190C130E14080705120C080A040707
0311100E0800030A140E09160A0C151D28182731373734364037394B4A484749303A3641
343A373F303E49464643333C353E3E3A3B2E3337322B221B1D1910100B13171714201214
100C19272321181C2A1719201A0F252B2A20342C332C1F2B322A3C32302F2F2D22262526
2A312E2B2B21282A22212C29192328243039292C271C1B2C1E24111A1A0D141B03272228
29292025321C272929202F281E291A1D2A1D141B161C101412140D10110E0D000D140D09
000900110307080C0E0E0C1416001014140A1216111A181A1B13251519191711160D1214
241B1F13221A1C1D25201B262B1E27212E2C23281A291E2B211A222F17272B3431364145
4C4D4D4D5154535E5C586160665F5B524C3C2A0300000000000000000000000000000000
000000000000000000000000010505060804070907090A080A09090B090A0A0B0B0C080B
0B0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A090D0B0C0A0B0A0B0B080909070A08080A060804040405050401050100
000000000000000000000000000000000000000000000000000000000003050E0E0D1212
1416151C141724201E221C262317202017171F141F1C161303150A080D0D050709040000
030400040B0D0501010010180E1523121C202D282A2D2E2A363F385051404F524A3A4D40
3D3537323D474F4F473D333D3D383F4444273D3B2F30211B1A0A1C1810181F05141F1624
16201B1619201719221E1A282B1C2421262A3225372E2A252D1F2E363628373232262425
2B2E2A2A33352B29362F262D2C322E1F291B282D291D1E212414120C131B15131A19251F
21211D1D271629282622282F1B1E26292F1C201D120919131F150A120E12110B0A110107
0B00010502000702080A180B1518161C13141C120D14111515100F1B111C180A1918141A
1F1C1C131E1220211D1D2629252625252B1E242024191A23251C21262C2C2D2527244335
3A3E494C5D584F605F64596C665965605C56462E0F000000000000000000000000000000
00000000000000000000000000020004050606080A0A0B0B08060C0A0A0B0A0C0C0B0B09
09090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0B090B0B0C09090B0B0809090909080808070705030404020304030000
0000000000000000000000000000000000000000000000000000000205000E0A1E12141A
122217271F261F28202529271D252119131E1E192016141A150B0C150C160E11060B0109
02000600040000010002020D11181C191D24212C1E312F2A3339444A4A37463D44533C3C
3B37444147423B444D444C4B48324340383A323C35392E2C272C201F142014110E0D1317
141A25171A1F1F1A2120271E192D241E2828352B3E2D28301E2D302A262E2B2E262B292F
2F272F2E2328282C28232A201C1F33273027242C28211D23141718111A17171A1A171B1E
17212524292D2C1F3337272F2922263B352918191E19211319110C1D1C0C1716120C0500
00060007070111000B0510140E1A1E1A1C14171A08170E1211160C0C0F0E100B12141012
1218172A151E16131B201E21271A2525272418231A1F182615281A200F1E2125242B3734
3C3C404D43535156556052625B6261635E5E4D4A33190000000000000000000000000000
0000000000000000000000000001000405050604070908080908080B0A0909090C0B0908
0A0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B080B0B0B0D090B0B080A09090C0A0A0A0806080507070204010103000000
0000000000000000000000000000000000000000000000000000000009111015201A1A13
23161F2429222C25292C23211D1C2C18221B1C202618150F130A0F0D190E020803010100
0A0000000000090003030F071015161A141D21242C2F403043473B423C503D3B4B3B473B
403F3C414F525243424D4A37354B483C544F453E3A3A3B3B40322E27281610140D0D1917
1C14141A0D1B161618201D2527181A1D2B2328222A2A372D3026272C23222B393133302F
2D2F3F2F2D38302F32313226261F2C342132252D3423262D1E25192020221E22151F2D1C
1D2223231D2630382A2D2D292C23202626232326191E2620281F2416151F16040B0B0001
0002000006010B0008030E070C1A14120A0D0D130B08100B16170509131C17070F1D191B
141A1717141F2319231A131D1F241C1F1F202A1B1D1F1B2A131B251E23251A2020262E26
2938384349514F4D584C5A656162635F605C56524C2C1000000000000000000000000000
0000000000000000000000000000000304030605080809090A09090C09090A0A090B090A
0C0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0D090A0608080D090A090A0D080707090A080606050502020200000000
0000000000000000000000000000000000000000000000000100050D0F1512151D22241C
1C1E1F1B222A242429282B1D212E2D15211F191926150F101C191117150410010A0A0A00
000402070000010A04100E0C170F1618131C291929353336394036484544404938433837
43374C4B3C484A3D423D2E41453E3D4D4A52453D43444240393234241C1819161418161C
1E0A2316160F1F241A1A1B1712202E1F29252B321927332D28312F2A2A2C272F2E283B2E
342F2C34303541282D373934293C3735393D283534372C242A1D1F1E20231E1E11181817
18261C29231F2A28262E2F2E2B1C222B323327262F251C21161C23191E1B191F15070700
0100000000000C000809010D030508100F0B0F0D1711120C0E0D130A0A090E100E0D0910
1D171D1816101B151921191B1D1D281E261F2726211C1C182118261F1C202C2228292826
3734313A3A484A555C575159515C546158676458534E1A06000000000000000000000000
000000000000000000000000000000030203060505050907090A090A0908080A0C0B0C0B
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0B0C0A0C0A0A0B0808090A07080A060A06060604000202010000000000
0000000000000000000000000000000000000000000000000302090C0E161D171B172521
192623292E2D2E28212A2725272D2134241F2119211221161818210E09090F000B070E09
00010C0B0200060C00030007090A13100E201E25292D36353C403A3C4148424948464046
464049443243423E39533F453832444843454736384043413C40392923211B1A201F1618
040E191318061E13101D251C1A1C1D22212E30282E281B202B2B2B1C202428262F2F342A
2E33342E2A22343F353C38322E263B2E2B3436292A3129362E2C1823221C14191E1F0C13
1F171E22272A2027212D2B2B28312C282D3C2D251C281421141C22191D151D130F140904
000004000600000B01001201000E0A090704000E1414110F0004070C06020A1311141C17
171E0C1B1618190A101A161724201F2126302E22242C212623121E211B2521291A29222B
2E2F3D32444944444947514D3F53635B5362646A5C503D14000000000000000000000000
00000000000000000000000000000000020403050308080808080908090A0A090B090A0A
0A0C0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080A0B080B0B090D090D090A0A050B06080607050505020302000000000000
0000000000000000000000000000000000000000000000031002070914131B1E212A1719
2E30342B2C2B322D262A34272C382B2A21271D23121F211918140912170804030808070A
090601010917000600010C03070C140A1A1E22291F1C2D3C3449434E45474140443B4C4B
4B4148403838394C5B4650523F363D43565047465532424638423143342419232318140C
1A1F100B161B131D241417160B281828262527203232302519271D2620252433332A2633
33373623352E2D3630423B2F302830323E323A2F29322F1E31302F2F282023221D281812
2111181F2321232D3E28303A15321F2A282534281E28202B101915191B11161A1C0C1100
00000000020000060800010300020100020804070A0F17080B06080B060E0C0F16100E16
1011141A150E111A1017281C1419241D1F14201F2021292321151A1B1F21201F252B2529
263132393B4D463F464C504847475B5E5B5D615B69614839100000000000000000000000
00000000000000000000000000000000010003030506060704090A08090A0A0A0A0A0A0C
0A090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C090B0C0A0B090B0B090A070A0805060707070402040101000000000000
00000000000000000000000000000000000000000000000309030810181722211D222321
23292C2E3631282C2D352D2F292F36282823292521171A141E1610130D08100B0900040C
0B00060905110202000000000C090E0E0F1B0D172B21382B3B3548423D4B4245463F4340
414A4644393A343D3F5555554748364044504749423D363241384D40393D302A36282016
141328160E111D171313170F0D0D21191E2F1C2529292F231325211D1D1622262D292A30
3B2836364535344948434842454C2F3B2845192C30312A2824282A342627221A2C2A2018
272024191E2E1C283023232A312D2527282522202A232922271D1E101D1A1A17181B1007
0D06000001000000010000000406050013090A01030704090B08090B080D051911111015
121815111711131A111A16141F14131D1D241C23252A35182A212C1E1B21202D28202B2B
2F392F2A302E32423A494B48474F534A4D5353616668604D341400000000000000000000
000000000000000000000000000000000001010204050706090809090B090A090A0A0A0A
0B090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090A0B0C090B090A0B090907080507080707070203040001000000000000
00000000000000000000000000000000000000000000060B050C0A0E1B22251B222C292A
292A272A2F2F312F34302C3432312929212E2829272C261D160E171D1613100D0A060307
000A0004000E070005010300000B070F111D1C0F192C2C372E36463F3C3452484444473F
474435392C3B393046506560514D4430403A4757474B423D48414C443D4D3C3B31312C1F
291D0F1A1B110B1A0A1B161D1816142132222F3035302C1C1F1B231C2D2023281B1F1B2E
313B322C2E332D333E4E4E564D3A4C4732322C202A2D292A2B2B1E1C1B0E22251F292F15
21222F251C2621242B1D192D2C2E2322302E2B242E2D282A28262E1E2218200F131C1115
18070000000000000000000302000600000400000C00030C080D050F060E080E120B1510
150B141213170D1B1D140D1816151C1A191A23292E2B27271E1C1E1B26181F182023272F
2E252E2A2D3A3B34393C473F3C4C3D4D475659625F66605D4A3A0A000000000000000000
000000000000000000000000000000000000000302060508040A0A0A0B0808070A0B0A0C
0A0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0B080D0C090A0908090B080908050807050302000000000000000000
00000000000000000000000000000000000000000003000C0C150F121C1C2216201F1A24
2E303C36322A3B36393C313130333C3630322D2A292528141C231F0F10120F0E0E051003
06080004000006000300000000000400121410091A24393B4038302F394236433E3E453E
494E39413C3E2E2F3D5C6461534C3E24484D46564A443C4145473B494A393F4235251C29
33282D181A2526140D0D1A0F1C20122C1E291E1D2D2D2C292C2423251719353021222526
23203E2F35231D2E3E414E544B463A3A392A2339352D282A2A201D1C1915231C19273827
2C292B1F191E2213221920281A2D262A2A2630182917212B1E2E2D2730271B1920141D1C
180E120B020907000000000A060201080C010C00060012100C000B0C110B14180B09090A
200F15191813171615201C0F0D0F18161A151A1E23291E291F1E151922141A281E25211A
1A1E32282A273033322D353E4042433E474A4F5C60626B6161482A0C0000000000000000
00000000000000000000000000000000000002020406040606070908080A0A0A090C0D0A
0A090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0B090B0C0B0A090A0907070709030A0301050200060000000000000000
000000000000000000000000000000000000000000000909101512191827232124212B2B
2C2B2B3E3238323F3B3A3B35353934312E32202A29312A2A2F291E1717150F0A07050303
0C0002000200060000000000000007121414121B151D122D32342F3227283232412C353F
3D503D362F474240404D615A585042402D383C4D513D403534384B404F423C384B312626
2C3628252023261A1A131A111C0A1C24211E1F1E232A302F2D291D22232D372E2F361C24
1F1A2D2D2B2E3134343137404A48463840283B3D2722272F26161817201F1F1E252E2336
231D1C24171B27262223292A262028271A33322A24232825342F212F3036233025242218
19100D04010D0600000100000006000F0710160A0E0A1313170E12140E160A170E100E11
180F0E16170D15171616191C190E0B1515141A1823231E222524142820221A2518241E16
212828312033283B31302E382E353A322D474654555F5C6B625C49300700000000000000
0000000000000000000000000000000000000001000303040408070908050B090A090808
0A0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C0908070B09070C080C07070808060604040401000000000000000000
00000000000000000000000000000000000000000200090711110E1B1E21232928272C2D
2F362D353A3240273840493841323D303836362F332E312A1D1C25150F09110409020B11
100600000000000000000000030406020A0F191E171922212324232B2C37353331333137
2D312D334245384D3E484B633A405138413E49484B414A3233354A3C4B38384045382939
3A293829202922141C201A1E0C15121D282421251C2C352A372F361F252530342B332B33
232428382B31222D2B35454A444B34463D3A2D3229262B311F291D1F251C231C3023372F
2F1E281F2725252F282724261E18212C222E292726252E2F2E2C2A34351E271E20172220
160B100A110F060300000A0004020B160C0910030A10091415180016121313151003110A
0D170B15201717181913190C1C1014131C120E18201C2517231D1B21261416211E160E17
1E231E211E262A372A2633332D39323D35393C43534A58655E5B544A1D03000000000000
000000000000000000000000000000000000000000010305060805080907090908090A09
0A0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0B0C0B08090B0B08090A08080507050603050302000000000000000000
000000000000000000000000000000000000000004060D090D1019151A2A211F2C1B3735
38343B3E3B4235363540383B353A3338313B3F30282525262A1D2D1D201C0D1A10080106
0607000900000003010000000000020D0F170B1203111A191D1F3723252B32353328262A
2E313D473A53464836463B3B426249553A3B3F436F414646362F3C39424337404E3F3538
2F3C222F241D1E1F2112081C0D0E1F13211E232A1D1E322E2A281D321F3E23242C2B2A23
27233B1E3030312A2E263146323B31363B2B2924212F2B24212728201F18251D2C212826
262F22291D281F342B282622282C1D282B312D2C2F201F252B312C352C26302821212325
22201F101115060B0E0C100D040D08140E0415110B0B050F0C100E1409101614130C0F18
110E0F1416161B140D181320112A1722181B1718151D2218171F1A241E23191D1D1C1914
1D1C151E2B2C22242B272B2E282F3539323234413E4B535E5A5A55524319000000000000
000000000000000000000000000000000000000000020104050606070809090B080A080A
0C0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090A0A090A0A090906090608060705010503030104000000000000000000
000000000000000000000000000000000100000009050E1215161F1D172830252D2A2B2B
3134363B413B433E34364742363E44343F33303929302423291619291C1921161914180E
10130D0D0202010602000108080312050E0915131308111E1211281A291D3236262C2925
201F253653443D422F342D1F3FAA4E5C4E428C714A404546473A47454A414F3E44454C39
353C302F39242A13121B13031A0F131610181C2E252A2E28232325252E2B2C1E2C26241C
242B351E35312F1B2730223D2D2F2B472B2D252C272D2A2C31302C1F3235252E20202425
1C2623281D22211E28233B2B272A291F182E2A22242426292C2F2C33332F242D29271420
1B1F101B170F080E080A06070B070F090C130A0A080C071213081D0F0B151017100D1009
0E0F03111614111115110F1F1B1E0C0E150E1510191C2C211A1E221E1F1C18131A131C28
1619232F22282D2E2A2923302F2C2D2A342A343F3D403F4E575F6256553E140000000000
0000000000000000000000000000000000000000000002030105060609060A09090B0908
0B0C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A080A09090A0B090809070707090804070002010000000000000000000000
00000000000000000000000000000001000600050D061119180B181C1E282529332E2F3A
353B2F33354139403E453537404B3941403536342F262C1C28252731161A1A1615111D1E
110A0704060203050B00040005010011010B04100F111912201D1D1B1227252920161A1C
132A27362E403E352E1024223A4A423E444B464245382F40443E42423A484D5440473940
44382E2B21333826272527200F251621101A2720182527212B2831212222211D2B3D2D1E
2829272A262C30332F313122343542292027242D28313333302729302B2C2628201D1B18
2034291E2B2A343224241A23312227282B27202324221D1D282E27302B3220212D282B1B
16151D0D12110B130B120001030904111208000C131115150E0F07150C12171414161515
060F031313180F0F0F121416131B251D1C161515171C1A181E1B151924181E1312151711
1B181914251D2325242D25292C33252C353D3A3A3547424B4955686D5A49360B00000000
0000000000000000000000000000000000000000000000030306060807070A080909080B
0B0A08000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0A080C090B080909080508070403030001030000000000000000000000
000000000000000000000000000000000201070909171415181A1E1B20242A2E2B2B3832
353C363E3639432A3D39464A463E42442F323E3C36272927272A392C3B2E2E1912052419
0F160A0C1112000C0600110F000B070A060406050C04180E191B130F16121E2021231C28
2116253A364634282D2216312941454B4A3F2D3D373F3E393C3E333A464B484149425149
42373033403334373126332924281D1F231B0E1A2C0D23222C261C241B1F1B2921322523
242B2C293C2E2E1F2F2939363637272A312B263523221F2A2B262F303731352F301F1E26
25241F152925131827241E293E2B2F2C1B2E1629211D242F2522332E3128282727262B29
16231A1C1211151107010606020F110B00090C0D1C170C151111140B13160F08170E1109
10130908090C0B140B1113161B1A1519191516182010161B1911171F1F1C08131913131A
15171119242C2D26252D2C34282B25282B33463F393A354446536064726047280D000000
000000000000000000000000000000000000000000000000040405090908090907090A0A
090A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C080B0B090808070909070907060703040304000000000000000000000000
00000000000000000000000000000001000304080E091117141D20272C23262E302D2A32
393737323B3E3F4D413F3E48404438383E3F35393C233329353F322C2D5A1F1A2A171B19
17210C15120A000D04130B090A060011000D090B0F100C061113060C221215101E1C1716
161A1D1B2228312F252A282A34424A3B3F39302F322F2C3E3B453C4B45444A534B5D444E
3F3F3649384533373031282C2B29251C261B160A221519201F141F2A282120272D38343A
2E1F26261A25323932321C2F382E2A38353323373628322D2A2935323D39313831271B1C
141F261D2C23202427282A2A27232531282F2E311F202320292F33362A2B292D2F34302B
211F290E0C1B111A1311100E0F09090705070F00051715150D1711130E0B06100D150E15
080F050007150C0F12121114171119121D101A161F121D201720181D17110E15180F1A02
121C13181E2625283230252B2635333528305E4B3A343D42474D616B68625B412A000000
000000000000000000000000000000000000000000000001000403050708080707080809
080C0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090C09090607070709060805060403060200000000000000000000000000
00000000000000000000000000000000000805060E1214171C1D2822302625342C352738
333E2E433E393E36403941475043443F3D4139332F2834343C39382A271E12251D242416
17141616201511160B160515091310070D000B0C180715111310160D1E0A141505140F0C
000F0D0C1A0F1E2428253724333D452928203331263E383735393E4F4349403F4D49495C
474C3F41374136463E3D2C332B343522211A181A140B291313211913251A27212B232A2F
2C27261B26202B2F253032262A24413E3D273642223A2F202B2834331B372C2F2C2D1D28
1F232A28232023322B272E2F1D1B2A29232627291E1E222A27271F3030252B2D242E2E23
2520242B121F0F1408040C000D060E060D010F03030C0F09151C120B0D00140F05010F08
0D0D0B0E0F0D1316140E14181B181616160F11171813201519211A142216161418131619
16120E18162119232029242A2E322D2C312D2E3A3734403B4943505A5D5C5A49421E0000
000000000000000000000000000000000000000000000001000004040606060406090A07
09080A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0D080A0E080B060806060506030403030000010000000000000000000000
0000000000000000000000000000000004090811080B191717221E291E1E2D27302F343B
31423831453035403A34413E3B4B4341403641434242443F3C4134342F272D2A282F2828
191B1D13211D0916160D12160B140708000C000B0A02000B0B000C0505061007130B1011
070A050A101503181F272E3136433024151A2732403C36473E4133424E44333C3E5A4F45
53545154483E3A4441373B322C351D2A2422241A1B2C1B1B1F23151A1F1E2617181D342C
2632221F21201C131D211C1C2132322F43302F29433231372F30272C372E4B292B272329
2123221C24201830293629382429202A2322283324221F202D343132283A2A33362E2F2B
231D28222F2024170A15120300070E0C0B1103030D0C09101217180800000C090B0D080E
0B0B0F06060D141515130E130C111015171B0E22161C1E21221C1C161C0F14100F14081A
0910100E1316181E2528292C3333352A2F38362D323B3938424243574F5765594E371600
000000000000000000000000000000000000000000000000000103050407070809080907
08070B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0B0909090C080809060506040201020200000000000000000000000000
00000000000000000000000000000A0006000914120A0A1922212629342728262C323831
3B3A3A3F353B4D363C3E46433A373B3A39313E3B4942444B3B3F38302E39322C3A2C372C
1A2327212221261516130E0E100C0A0A010F1610060B0B020000090D0803000602060D02
001005050A161715041617202A322A271C3632353E48403E2D394D3E4D4C40494938414F
4D4740505343474F4235423E3F3A342E2D212A140F111C2518191318111E1A1A1D202632
1F25261529222D11221B1925212E3F3E3E2229373941263C342C2F2A2532344839313E35
2517282219222C20282A30222B271F24222A1C1F172D1C2A182E332C23304E35373D251B
251D242F2125251B1A17140F0D050E0D0B00080E0407060E16181D121102090B0B0E0904
0309001205220712090E120C200A15150E091D131F181526242722190D1D110D1B1E1315
120F0B0C1114151C1B1B1C252D34342D293A3B2F393D403B44424C484E535B5459513011
000000000000000000000000000000000000000000000000000000030606060607080A09
07090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007090B090A0809080709070703050500000000000000000000000000000000
000000000000000000000000000002080C0C0F101819191F1B25212B22292E2D363A2F35
39363F3B393234473F403F43465046393B3C3B3C3D404A5B373F43343439333B322D342F
35271C1F28242315151B0A0F181408120D10080B0B050504000700090000010000000001
000E040000050D0C110E2118291600141C263230423041383E513D393D3C2F443B3C4241
4558505347564B4B43374F4146373238372D271C24201022110B1E1719161619171A2F27
1E252E302B2B2422182722262241444024222E2E363745433C272D1F1C2935392F303D3D
2E322827322C2826202C262F2E1E211F201428151321192222272E2E27352D3C2926232D
2C172C142730261F211F0D131E171717140B09090A0D0F1E1316170D1917030D09171009
08090209090F06090A140F0D230811101416181812161B1721191B0E1A1118101418120E
0518151413151A23161B263024333938342F3437363A363C363642473F3E56555056512B
08000000000000000000000000000000000000000000000000000102020508070708090A
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A08070609070B070706060405020201000000000000000000000000000000
000000000000000000000000000000020D0B101214121C1A1D22252C32302635312E3134
3B334648353D3D433D3B3F423E3D3D3833403F35383849513C39464547363438333A2F37
32212A31232226171B2419171F171E17130A090D160B000C05060B060A02070800000000
09000B0A0000010D130D1C131025271B1E23332735283E3A474A423B4B48473440423E46
4B4E6B5C645A554752453D4340443D413231362D2A2E281922151B0B1E1D190F171F2121
22271A28361F2B2C1C2915262D34363231291C26384A40413D1E24233133322F392B302D
3831312A272D2D242A26363425322425252B322310221415212024142232302727261924
151D14292831262D191E1C1F130F1E11130E1417130F1711131B121F17091011180F0F01
0700121219150906090E17050C171B1719191514171C0E221F191E15150B14130B0B1212
110A1814151E0F10121A1A1E2A192B322F2B33352E2F3C2C3C3C3B3E3C494E51605B5642
200000000000000000000000000000000000000000000000000000010405060608070707
0B0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009070907090706090708090602040501000000000000000000000000000000
0000000000000000000000000000070A0B0B1515181D221F29242732312C37333835383B
452E32383A403D3C4140414C41373D38443138453B3A43402E384D42293F39513F392F36
413F372F2B212221241B19231E14150F150D13190F0910010004000D0000060000000000
0000000000020B070C090D051811191E202E2F23352A3039413A37454348442E3A45543E
4F4C5861514B575C55504C444A463B323F3E3035292125331A1F101E1D0B1A20041C231A
271E1518242328362728222B2A303737361F192F2D3D50424124302C3240303F3A2D3A2F
34344135312B1D302C322B272420161F20272A2C211D1F071A1A1D1F282D2E232D242126
1D211122272D2022262E2A2B23271C1C191410120A111D1111171B0E1E13131717100C00
10090F18110A141306030D131D1C171315211F1220161A1D1F131910150E0E1113190013
1C1716131818111A1B1B161B1D1F2928282F332F313C343A34383A353E424F54595A5E4E
381D00000000000000000000000000000000000000000000000000000305040806080708
080808000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A090A080708070706030506030200010000000000000000000000000000
00000000000000000000020303010D0A0D111F1B1F231E221C2A26362D26312A36333432
3F3F2F41423D443F444334343E3633493C423D323A3742322E3C324556403F403B523B32
4231293A272E2826292B231A211A1A19101A0A0F0D060F09161305000D01000000000500
000000000102000007000C07140A18142D2E1C2F302B32373B4B4C38463D433F46614757
43513E534F604946614C4D46424D46463C4043273A26271E252023181E1915180D111321
2815100E0B2A2C332823242D313431302B2A2C2229333A533C29343E363B40352B2A2F2F
3F28293037251F23302C2F362B2F2A1A1F221E1F26270D151D1F28201D182F1723302430
27211C212421291C2C252C2C252C2017161E1D07151F131C151A150A1522231F1717190E
0411101715130E110A141B13070A0B10141A191D191623281F1E261E14150F0C0F0F110C
0E0C140F141A16131B272021191C2C342D3030312B3136343E3E3B3A43494E59525D5C57
49310E000000000000000000000000000000000000000000000000000203050304040708
080909000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090908060909080808060704010001000000000000000000000000000000
00000000000000000002030A070A0F0C1014181D1F182220241E242F2928302B303D2B43
3E39333536362E3C3A493B3F383E34294C3540363436412739403E44363F3E3A413B3E39
2E3544362B2A34341E1B18251A2616140F130C10181314000001030A0000040101000000
00050000000000000000040F020A0E27242F1C18251F30343241433A362E444E40464751
4B4C57534D66566465564D4B414E49403B473A3A3B322036242E2C1E2117061D0D21161B
190D2011180F27322B23303D3D2F2B2B2B3223272C3136433A242E3F373D3B483D303C36
33422532293225302F25321F2F252A332B291E2D28271E251F1A181D1B191B1920261E2C
2520212C1723222E29141E242B25221B20241516191115151E1A1A1C1D19151B1C150E0A
091817211412140E110F16190E15132214141F121921201B2415180D13140B0D100F120D
0A1E0916090C0C1A131C1C1D251E19251A2B242B38312C3E3C3E3E4242434A525858635C
5040280E0000000000000000000000000000000000000000000000000101040307070908
090908000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B09080906070A050506080505000000000000000000000000000000000000
0000000000000000000102060915111418191C2327282730352B2D353125342B443A343D
3D3E353633413B353C3D4243414C3B363630413F3539323A343A3F3F4648404954543F43
4441453B3A38242931352231241620201B1A140A1F0E1009100800120002010905020302
000000000000040000000200060C130F0F202E16272D242F3C2A3E464A41424950495049
3D38504A4D46584D635D476047444C4E44443F3E323E3B2F322B29301D192D17191F201B
141C16110C0C0F1622323236423E34252E2D2931293A383D2F262B2D33353B3D3E3B3E3F
423A372F312C322A283D2E282923201D152C201E24191926192A10211D151D0F211B202D
2B172E18211F2B142220291021291E241E1A1C171C1312191D151C12190D101522170709
0E1523291717100913100A0D16060F09121D14151D2227231F221613131117090917011A
11111C1D110B0E0A1923282316191A29262C30243C313B373D3938413E44424E4A58575A
5E4F42240100000000000000000000000000000000000000000000000000040605070607
080709000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090A070A0707060605030702000000000000000000000000000000000000
000000000000000207070C090E060B0F1C1F1922202528282A2E362E35392F3C3A372E3A
303D3A3733403634433B3542394D36353A413D38273B2E383C3E444E3D484042483D4A3D
2B4539383135323C2B462A3D2E34282B2327202215190B1516140B130805000500000003
000002000001000400000300030B141F130A0F1A1F2B3233332F34364042425042584C55
407F4A4344584F4D4A48575658434F484B43394C44443F39382D2C3323101F2A1717191C
26261010131418211F2E2A332D432D212F25302A34303A27202D2A2236343C47424C513F
433A36332C2C352F2D352826342428232B20272B272529292B1D1B1A121D181A1D282928
2C2E1F23281A20291D29291F251D21271E261D1B1D101A110F1C1B0F121A141D1A161000
101D1A14191908100A040A0C1B1C0C0E0F191612161D1C2123191B200F180F0A0D0E0B0F
191611141319191612111D231A1D1A1A1C292B27252B342B384737383D393F4247564B50
515D58351100000000000000000000000000000000000000000000000000000103040709
07070A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090708070506070706050303020000000000000000000000000000000000
000000000000000106000B0E0D16121F181A2420212C24342B32373138393B382D413E3D
393C343445353A35393E37373936483A3448353B2D412B43433946483E42454B3F434045
413F39433D47373930323D3C322D2727332C261A172019111513060B050B06010E000400
000000000800000700000007060F120C1B010E101E1C2F352F2F33404B3F4F5A524B5948
5B5C595251515B51543F524F5658445348433B41454A45433735362C3831352027171C27
1F1B0F0B100D1B10142724262A3739323538262D26243924261E262A23324339516B515D
4A3C3C303726332F2E3B351B33212327291C262728262C331E191C1A07162421181A221F
2B2B262B2D2520222828231D212526222B283928201E1E13131C1B0E121415211A17071A
08121F161A0E0B090701100A18101E0B1014170F1D1C1E1F1D181F1C14190C0A0910140B
13071A16161311141318101C15231E1B1F211F2A2D3931323330373039393E474E4C4E56
554F4E452B0B000000000000000000000000000000000000000000000000010204050505
040808000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000908080A090507040504050303010100000000000000000000000000000000
000000000000000A06090F0F1311121F131C2127222D2F313125353C2F383A383B2F373E
363734372641373D334329392E3432413330323A303D2F423D36383F3F3C4B443B464245
42543751364F2A383B422E3D402A273A33331A25180D151222121A111B05140004070404
0000030000000000010500000307050300150A12121325352C36393939323B42404A4551
49594A564351404E40494B505D4E5C624343453F3B4745485F4536413836353C1D1B2110
2110151C161616222628281A24232234243A2E2E39302A172617162C2A3D272B51615D66
4D4D33392E443C483B282A29192027371E3023292829301D1F222218291F3228211E1B1C
2A2A242F322C211E2120322F1E2821271E2D2C352C29221F1F1A0F1D161413121419100A
0A101D1A18110502000C051111140A10100D16140E1A1A201D25211A181708130B171410
0617150E13171C0E180E1A16191E1C20241E2A2D24282B33322E3B323B3C3F453F4C4B54
4E5650514028050000000000000000000000000000000000000000000000000101030305
080807000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090508070408090704030300000000000000000000000000000000000000
0000000000000008070E090D171726191C1D242529252A2B3031412F393D31363232323F
3D3E393543323238332C3C3D2B38352B2137323132413A4033384A394A393F4548395850
3A4C3C4D4A3437363B323E3E3E342B322D2E2A2B202621241B1307110A06050B00000002
030A000500080300000000080A060A00040010061D0C2A1C281F3B403C47413E3D49504C
4349444D484A4C6B463D453F404A504D5154484F46574146513D454844343D33313A2727
1C281E162317191F151B14231A26242C29403015363129202A1C22202F252C28414B6457
54483B3B3E31392D3D382D31342833232A1F241D24201A191C2820231B282B33201A1E23
281C2729231D24221D1B2A1C1829211F243A272C2D28271F1F1B1F15150D111514110E0F
161B2A12191611060E090C0B0E0B080F07130F11191C17191A271B211805090D1311040C
1B141310161216191C0F2218191D212220221D1E212C342F393138304A4A474B4340554D
5B4F5757473F140000000000000000000000000000000000000000000000000005050604
070809000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009050709090508070603040000000000000000000000000000000000000000
0000000000020203080A10161412151A141E1B1D28252D353A393D3E4433373B39383B2D
2E3A41353D37303944432D2F383D32393345322E24323E35422D333F313A373C4D534A41
4B4D3949524044332E4E423F3A3A4145443832291D2B1E271E0F1810150F08080B00080E
000408000600000C080000010C010810090804001111102126262C3C323641372F404A4F
404451425345484945554448374C484C554B544E4A3D474D4C3D45523D3F3D3330311D2B
1E211B1C1D221418181F191D302830252F2E382B2A2E2D1E222D1B322624213C363B4C44
4A2F31382731453829352B22353A1B14241F1E191221261D21252120262E3830211D1E27
272325292624232C2B1D1D1C1A2B252E242A1923273224211B1E1418231824111414150F
0E191C1B1E150D13041B0D181C050C090815131419131411231A1D22110C140D180F0710
0911151819161E10161A151C1D131E1A201D2222242B273137372539473E3D433745484F
505C4F55504B2D0A00000000000000000000000000000000000000000000000000040405
030707000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B080806070608050404010400010000000000000000000000000000000000
0000000004000406090D12100E1A1E19201D252535222B2E2B413B342E32353A473F3B3C
37413D344F3335343B3D332D343E402C473C4038383C3A28383D36342D3D493B3F514C4B
4753433B424B452F3E4B43423F4A4B46402F2C3415352D2A16180B1B100C10060E000303
040109000A00000B00000C00000D0D000900070E0D0B11251B211F202F3730323F3C3E4C
525A3449404C47384A3E323D483B3E354B5252544C404641524A4C4A4846403D4734402D
3B181F21251E1D0F181820291E1425312C2D2F252D2F172728252A1F1E222E2D2C2E3D37
3E3F322E2F2E2E2932213B2C392E2A2D26262417170D1E141F1A27333023262C1A2F1A19
181D1C1B2E2C2022261F2B261E262826212521232B221C2A2B1F2B1914251417151C1A1C
0F1E1919181613101413091514120F0B110D0C161C13130F1A241E1D1817110A03130C0B
13160E16181A1E1D1D151117161D211C1C2A1E1C232B35293236352D38383D3A38434147
564D4D464E4B402100000000000000000000000000000000000000000000000001010304
040605000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0908060503060405030001000000000000000000000000000000000000
000000040104060A070D0F171917181828242E322D32332F2B323A2E2C4145413D523F3A
3B3C3D3A39353932323D2B343E46394B3B35313C412C233A3B302E27343841404A3A453E
476140484C4E3C443D594B514C483E3B402E3827331B1D22191B1317110C120F0606050A
00000303070A00060B0300000004000A0D000700040419121C15171D1B32313F41443F48
4855424B4E404F4A384B533B33463D3A504746505B523B4F46504D55464A4838384B3C2F
282C2A25281E2D20141D1B26242D261E292B2A272B111D2A252F302A2E2E25363B33282A
30352C262C2E2D251E2B33302B2C31282D311B221A0D0F091B2C25302A2A342E2C231E29
2016191F152E20181A1429232C361C301C1B25232C322C1C223229261E1D1C1712112016
141B171618181718141516060F0F0E080A1718161A161C1A171D1912131D100C0B0E0914
10110A1519191C1A1B10111A1419171B2C1F231F2930272F39352E3139373C3941424649
514D534A4D53433216000000000000000000000000000000000000000000000000000201
050306000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A060A07070805030505010000000000000000000000000000000000000000
0000000007030A0D0F101A18171A231A232028322C32373232363E3D483C3D484D524544
474F333C433E3737312F3E2C3B355544424140323C3D45442E4238263F38324130414150
4246474C3F55493E47474E5C4B564934474138362B1628291512231D261A18281A100000
01000B08000A0000000000000011030802040B15060C0E0213172618233629293D35443F
4F4148483C404550464840435737463F3B3E504A546543484A48454E5B46434439373E2E
382F311F2D2C141B1914240F1D2B112019271220181A241324252F25213331302A3C2C2A
35252A342C313C27262C22303A2F3E2A242323302F21111C2320281A20342F2A2D31251B
211C1215271D1A2028222E2A23312F28271F23252B3827242A2B30262118211125171816
16141916161A120D1710171107180A0D100F14131F1C1A121E141A170D070C12070A150E
04101416161A1F1F2113201E1915251A1C1E242019292727262E2E2E3536313C41474747
4A474B575144504325080000000000000000000000000000000000000000000000010403
040405000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007070908070803070503020400000000000000000000000000000000000000
00000003000B0C180C101319181720262028212F332A362B303339372F363B433D3C4F46
4B373A4439453D4243453D3F323D404638423D40413E3644483B3B3E434C3E3427393943
3D3F45524A40454E664D57455E43443A4C30444538332E29201E242A282117180E07050B
0000000500011200070A00000000000000000800031610191313141135212C292D2F3B3D
3C49494B413E474C3D44514243494648363B3A45434D58514D53434E4D4F543F343D3D38
382F342C292B1E16052213210F0E1B021F2107131A1D27271B1B2F2A2E382D2F302D2233
313F223D32382E2E2F3725363A3B383933332320282920231929272E2A2B2F362D1F282C
2422211D2424132227242834233926271E1424292529332E2D28262D27201A1A1D1B1921
1911141822161227171D1D120A0D0716141117221A19161113161D0E0D1012120B0E0F12
070E10120C181A1C121920172021172525231F1E2C24292332352A2A30393B3446363F3C
465450504F4F524B3E190000000000000000000000000000000000000000000000000001
040505000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080A0808080604060402020100000000000000000000000000000000000000
00000006060810101213111A1C20201F252C2F302D2E383D3331302E3E3B403C45484A52
4B3E4D43463A2D404B3A4B3F37414039393640404A5252464A393D4E3D3F403D314F3C36
39484C3C4E46494E4E594D463F4F484B3F403C393B2F2D26271920282823261B111A0B00
1303000C03000003060808010002000000000C0C060A09080E0B11171F2626182325342B
3C364532473D43484B4450463B3F50504D414B3938424A524242595D59495358523E4336
2D324230303933242B192013181817151C181004130920241C26202B24252C2C2E3B3A31
2F30302C2B423E383A3C342A3A24303330372C29341D37223421292F2E2841373E2D3729
322E291F261D1B222718202E38332D2415182522291C28293321281521262822221E1C15
1D161624180F1F1A18101419171211131E20172217141C0E131414191310151F0E1A1007
100501150B171817141C0D19202420151D17231F271A261B1E2A35382F302F3B2B433C47
4F3F434F4A57514C43301100000000000000000000000000000000000000000000000000
030701000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009060406070505050503000300000000000000000000000000000000000000
000003080E0E090E130C12191E19232B282B282D3A2F303933383E44454434494140444F
4146494345383C4851443B3E41403C383733374A3D4E484E494443443E3C38354744443D
3543414150524848424556484D4F364244504D3F45433535212831282B2E252D21202021
00160E030011120F0E140000000500000A0000080A0A03001314050F241B131D272E323A
40362E4A4540453C3D3E434B5646494B5E48484A374F484D5452574F51625D5346404540
312A33452D3537231B2120281E1C2E1915171C250E160B161B1D21282A2C15332F352739
2E34383B332E25343135241C21222F3232383E323D3D383E30363E3932322B343B3F302B
34292C3334261E19212D182C2B28332B2628202A2F1B202E2C2A2F2622262120221B2521
20221E1B12121B11140C0C160D150E14141A1C211E1C13091B0F191911170D0F0C060912
0B0008100F0B1419131B1A242222161B2121211E291A242521282B36352D2F3030403F37
4541494A4B494C4B4A401B02000000000000000000000000000000000000000000000000
020402000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000008080903070505020100010000000000000000000000000000000000000000
000309030F09120E1019231C1A232D192A2B2F32312C39403138403B3F403B41463C433D
4A5240453A3F4B394D3F484B413F31423E333C4A514F534A3B454A3E3B404841373B393F
48294337454F434E463B52393B3E433E454E4144453744473A363A283A2C242217201C23
111620070E01090001090306000000070000050C0408060A040E150D161E1316212D3728
2F3B3726353032424F42453C3C3F464D4B47493F48514E5366515351654E5E585C524539
393D3B3A383B37323A2E1B10312119241D1312220C18161F191F2522261E2B1F1F262736
3F3737424232311B2B28302C19282F2C4C3E383A3D3533373B3938393E38443827312B33
2F3934382E2E1D2E242C1A2E1E2A292E352B1F243828382C2E31331B2F2B211C26291F2D
1C1A1B0C0D13131511130F1A1A0E1210201A191E160A1514130D16111C170D1313141303
0B0A050B0C0D01130E15222A201A100F161F1C1A1B291A1F1E23252E352B37312D3F353D
3D4747444F59584F4942370C000000000000000000000000000000000000000000000001
000407000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A050607070405030200020000000000000000000000000000000000000000
030A060C0B0D0F0D131B131C242929212E2B2E2F2F2E332A383134413E37443F46434C42
4C565046484A44474C483340394239583A405645453B553E425243423F42535A4D433538
46394139373E3C4A3F373A3E54313E4A4B5A40464C4C3F3E3B40313B312F363B2E2C2122
16120E1911130A020D08010400000000000300020D0401000A030B10180F170D121B231D
2D232A3037242D393F2E3844344839434E4640534A44536144575C504F635D53505B5B5C
4E433F3A3E452F3B35332A2828241A26191517131713191B17191D1E190E1E1B1F352E36
3533392E2E29291A231F26282128272F38394935325036463C3A4037424433383A372F3D
3A2E4043403D36241D290D1B2A1F292626272B2B2127272E22372A2F28291D20292D2627
282321170F20141B190F161517161C180F101B1A1B1F180B120B0F16121A140E0511060B
05040C070A0C0B110913161D2B1B1D161D261C1F252822101E232726302829303E3C353E
424A484349484B554A453B2B110000000000000000000000000000000000000000000000
000003000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B070506040504020202000000000000000000000000000000000000000001
0307080B0A1214181C1B1A1C27202A242623292E2D312D36303539394D3C403D44373B45
453E4F47454D444850414141433B3B2A4339404955544C3D403D42384F45433E4836414A
473F3D3B50333B40443E3E3C42424653404743403D46493F473A434231442D2D392D3127
1F21222120031401030F100B1B01000000040A100800000300040D120918180F0C121721
230E2123152D2D2F354038363E37483C3E454E5651485D4E3A585A514B565E505D61514F
5450574641394A384631312D242C352E1E1219170E1A131C1421161F221720181D332534
424B343B3137212F1E2B271C20311F3E4A3F3C34403B3F3C3C4539383E37443F3A3A3332
302D3A42494123272C221B271F2A31383733271E2618282D322F2E2628242E202B382432
302523242A141121111516171D0A131D19131D1B1A1B1C1A121C0D130D0F11000D031A03
03060E03040501071014151A171C24121B18231E1319272729172323263028333E33422C
3E3C414340464E494F4B51361B0000000000000000000000000000000000000000000000
010301000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A070706060504060101000000000000000000000000000000000000000003
020C070A0C12161A22201F1C21252829292327362C3032323233463C3C4639373D403C43
4D4448555452554F4A42374743393B514D4E434C4841464139443E50464B445547413C3D
42444A3F31534E3C39314949394D3942304E4850444C55493A3B423F2E32294B3A292E34
1D381E19110B011800070B080300000000000000000902000A0A0E0B0E100519170F1E1B
1D0E24191C1E2628262A34373539344C444C574A5553584841444C4944565B5A566E6864
6C4B51473B544837443D24342A261E2916221C1B0C1A131715140A241B212325271F2C25
322B1C272A2217202F3127252B2A26323C404C45224441433739424A4B4437322E3E263B
2F23333D403B2F332D28281D2A2A27353A25172219140E22323F392621322B291F292E29
1F2D18231A190D131719070E11171C0E0E101017131813191D170E0E130B0E08000D070A
0E08030D0610090E0A170F0C18250D22181D141B261E271921171A2728282C242A2C3F35
313C3D433F4A47494D494A42311400000000000000000000000000000000000000000000
000103000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007050805040202030000000200000000000000000000000000000000020A05
07100E0C12131F1F191F1F2524232729282E3331312A2A3B352E46383E3A41524C413F4E
44534A46534C56474E4C614A4346544A4A443B4B494C3B3D45445442453B4B574A46493F
504844353540374B4C403D44424A43363D4B4542424B3A4F4E4E42393E352640343E3938
272E27240D0D0D000C190A060000000000000C0009000A040A010B09131100090E120D1C
1D2011202C111F111831382E3A322D423B4A4345484A534B40515B495E5E59564B5C646A
625B555443454B50453C463E282D271F25102A211F151014151926151810252913222224
332C232A18261F311F292E382D2D2730313D3D3D4537414E34463D41494747303E3B3428
373335352D303B261F28233727242B222A1621281019222724392A26242F24272628331E
37252922261D200E0B161413131D13200F19131F1116071D1B110C0E0C030E01090D0906
040A0B06110805040A0C161A19161918181D1B1C2519191B1C181C13282B2C2B2F322E36
2F393C42434749514F484B463D1C02000000000000000000000000000000000000000000
000001000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000008040404060304000200000000000000000000000000000000000000070802
03090A1616191D1C20201B241A231D202D2D2C322C372A31393A3637383544443B374739
553D444348524C5F544C5561504C464E4C5B414842464C413B4344483C55514F554B5341
3F494C3C2935403C3B3B4A373E303041473E464743594B4B3F4354503B44354A3B453243
2F3029122B04100F0B1204020900000100000001000000000C03070006080000090B0A0B
122315100E0B15281E262029292030393945474B4D414E52595757545469595054595576
546F5F646450505B4252374B3E373A31282924212B211F1A2819100B11261E1F271F2814
1C1B1F24303230363A20281E2F262839273A393C3C3B503E3C50443D393C473B3E434839
2C372E362135271C28251C29312B2634283628232020223531352B182725362822231E22
2826201E2121151B11221816141E0E17111810130E1B1318181B150F150F0308050B0D09
0A040C04000901050F0C0817121E19171D211C211A1816141419261A1E2F1E2524333932
3D3E3F423D44454F4D424E4B423119000000000000000000000000000000000000000000
000001000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007090707050502020300000000000000000000000000000000000001010306
0A1013161917201D211D23232A262C3D2D2A2E2B2F423230413A373D333D35433B483F4F
484D4C4045464F564D5F4E3D4B484C48505344514A3A4E4B5A52555B5761564F5D4E5546
514A34352E313A3E303C333F3D2F3F513E52483E44533C4860584649494446363B402C31
3B293324231E1E11110E0C030C0B0A070801000606000500000200010000000003030F0F
0B100A0B131116121B171D23221B26363F372F444D48494D4858626F604B6351515D5665
6561605B50584D554B474D4E4F3242362E34242733150D141D190E0F192C13221218251B
20132F152A342C2B3B1B272D2D2D2F3632474343353B413848344A5244404E3E403A3144
3C353A292D1F2824232B272F282A2A3A2B2A2D302D20282A2E303636282B21212A2A2921
26211C2A1D302B24181D180E160D110D1A0D111110151213131011060C0906010F120C0E
0A16080E07100C0A11050C14121D141A16201C14191719141E21231916132723262B252F
2B3833444457434443494C4E4A392A050000000000000000000000000000000000000000
000001000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009080505030000000200000000000000000000000000000000000000080C0B
0C110C1C1219181A22251B2129292A292B2E2C2B332F36292E3E3D4136423C434D48453B
474B42474959484455525946465441423F414845484E4F544E68665D5B4B4D3F4C524A59
4B5340433639431D2227403A38473B3D464E443B43473E43393C443F3244372C4F314434
33362D242027221E0B0C120D090C05000200000000000500010000040000000003010E04
000A000E0A090C1E131111231B232C2A33413A403E5042465A5D4F565C60504A5C56576A
556C6371555F55555B5953363D4B4242362F312515241C201C2116201A291C192C2B190F
1425191F25263A3E312A24213B2B2C242F373A303C40443D383E463A48473F5441404542
343B39352C31202524332123381E2B2F3E362F1B2F282D352E311E232B2833252139282A
2A26242932241C22251B15190911171C0D16101519131C10181B0E141108080B0A121111
0D0D0B0E0B1A180E05090911141B1A191415141216131C141B1D1A1C171D1E36292A2F2F
332F313A394049494B42435448463B1C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000705050505020201000000000000000000000000000000000000000000030C
1214181A1E1E1F22201D2A272924372B33322D2F3239424239303E403931424740514941
414B4E46454F57365E3F4C5B56514E4D4E5752395B3F4C4E595A665D4B5A403E484D564C
3C583C3E3D42422B2427463948493E3D3C403E41344B3330443F543947414641331F343B
384A36404325210C1E160D0500120A000508000000000000060000000000000000000000
0B02000206060A0B05100D1E111A2734233238333C403F4F43525845505B5A6B655C5559
59636B5E675E625A5B525C4D47484640413D3B332C261E1E1F201A1B161C1B24242B2E12
1016152429233429383C2F321F2831233C24203D2F2C3148424539493B4451494A3F3A4A
3B393F37352A230E1E1D2B27252D323342352D2C272E2D213224352827242A20302C2623
2F2E1D2B2A25282B291C0B1516130D141715112112141A151D14131B0F1013100D0D1308
0C030D0513140A0A02040B1013181B0E12130F101715141E181B1D121E131B261D232F32
32363A34334739403E4A444C4C4C40220F00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090807040103000000000000000000000000000000000000000000010B0E0A
0C0F15151518201F2C2A20232A2B2C353734353834333A3D3B3437323B443B3D4C3C3B41
414A4458503E3E5C595C5753484C4A4A55554E55484B39404E6052594E454354424B494D
4845353F39373C3A38462A42443B324E3F324840563E2B342D3545433B433B2C443D403C
46373134262D2B2913180C210B0004120D070A1809000000000502080100000000000000
0000010C00020900000A09090D1E101B232E2E2D2F383B45424F525A514E5062585B6855
55505E51535E6C666958525B47444C4741403D3A2E1B23371B2113231E1821262421191A
170B27231D25312E271F31372B2B1F28232233273236424345463349463E4252523E434D
3546353B2629342E2B27332D21261F2733342B272727292E2A3229231E2A2B322D201B2B
33302E21212E252E1A1C1D131011000410130D0E0410121322191720101014101E0B0812
0E150D0E08060D02100905111413120F0D101717081A0F12161415181B251824252B2827
252C34373D3C434044434647484D47341A00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050705030002000000000000000000000000000000000000000004040A0B0B
0E11191923211E201C241E262E2C27372D3836393E39423A3A4238343D473D434A42473D
3F403D4945474B4E424145545948496051574E4860574E574C545D484A484940505A5544
4B2E48374438422D373F393B404439403F4137343A334934383A5445394135373E323941
313D37463B323E2F371B240C1D2123130C00101F07080501090002000000040000000000
000000040000001000040001141716101D29172D422F4449444E414454495C5C644E5446
5C5E595E715E5E625C56505B4A4D54414D41352D3239353431241D2013151A1B19251315
1210211F21111F312C2E332528233F231A3034343733343840383A233D2F48514E444948
4041443C41352F2F2A262828252B242B302E2938293436332D36302016252B2B2F263721
2C2520273222361E21241D1A1020201C1F100B1115060517120D1312150C0B131413190F
0C180B0A07050D05080D110A0F130D0B0E121C130C0F15181711110F1719171C2423262B
2C2A2F2D273C3F36474143464D4E4C402511000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000070605050402010000000000000000000000000000000000000003050B0E17
1416151F191F1E261D252B2A223430393832333D3E394740434337424D4431483C3F303D
413E414A4C463D424C5140534C4B504D52565A57595D57515A53325140544C594A4B4231
3F5C445238443B3F38343D32382B2F344530413E30382D2D1F4D404644494A33423A3F55
2A28343F2E2D46223C2A272B271A0A1722130B07081F0D000500000B0000000000000000
000000020000000000000A0400060A0D1F2416192E3939553B5141514C4D3E4A57544D51
5B62584E5B6D5F64625A5F634F45494F4E454543403C2C30283D33201B1427181A151E1B
351313192220112421262723302D1929302028392B2E403B393F2B352D3D3B3E3D473840
3F423E2E3433323631312C1B1D222528262527312D2F3D2A2F1830261F293126242C1929
2F1F26223A1F252E2B29212216201E1E18150A100A1B13110A0F181B161419130F220E13
0D0E0D0C1408140F1210040E12120E0D0E0C120D13141A12191310181514111B1D1D2332
2823292F30392E353B44444D4F4B44473C1F030000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000607050601020200000000000000000000000000000000000505040505100F
1A171F22241E25272D2C26332E323E343636373845403D3840434D4138383E4C455A493E
4245463A48443B4F453F464D4A55605A68536153665B5C6A625C624E5A4B544D574F3745
454C4546474F433B3F4939202E2126342749333750363A27343A42413C43353B3B414242
303B3B2F41374C3D383E412E3F2829320F1C200B1C210100000000000100000000000000
00000000000000000000010000050E0A101B13151D252D3C47443E4A4240464953495B48
5D4C4E60635D575F5B6557575C593E4A514D50453F34433A362A222B2D30251E1E0F201C
2E1622211B13150E150B1E1C1B171E282C222E29382C3B3E2732332929233C3B3A394540
4139393C38354544352C342728241A2C321D2027272A293224281C1E1A1D213D25341F21
35232D2B1C3027262E20232223171816281A2015110B1308120C171C15151F0F25161609
0F19130B120B0C0E0B0A14160F08150C180A0E0F160F151314141117161519201A241E24
2F252E2B302D3C373C414647504A4C504031190000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000004060204030401000100000000000000000000000000000005000B0A08110F
131E1F1F1E211C22252D2D2C36323E343E3D39374238424045404447433E3E48464A4143
4E394940464349494648444C464B51464A4658595A5951574F4B535759525C545045464F
394230344A42474E443B40262E2223281F2F314C4B4A37363C3D3B4B3F3635442D484C54
2D4A30364148484E48324235382D282A29222023200F0919040400000006020000000000
000000000000000000000000060200080E10230F15282B293642443F4040514959524F56
615C504F576A5367554C4B59515856535357475154503A4841463F2A37201A22161F283A
2425161E11050E1A1D241C28151E261F203B1B36272A2D2D30332B2A29352F2D3D374943
40583F3F3E38343D4B3F262F232A3A3D1E372026101C1B28232119221921242532281B18
1F221A2E2A2E343327222C182113212D2525141F1A16151A0D0C0C0D100E101112161E12
15100C0C0D0A10050B0D08150903100807170F110F0C1015100A12150B141A111A201D25
2822242E302C2837383A45434E47424C423F260700000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000707040403000000000000000000000000000000000000000202030B0C0917
1115251E282D1F222B2E2E2736413B38413549474033463E4B48474F423B4137454C4138
3D424C56503E434842454C49574A624C524E4B4C5D4D5A606749594D5C53594B454B5037
38534246473A3D444F57443A21261D2F2E33344C4E432C1F41333C303C3E3F3750412F4D
413E4E5247493C4B3947464D393E342F2C2B2C32251D1C0A12090103030000000D000000
0000000000000000000002000009020000191E00141822133431323B415A4F5250544C55
58555251444F544E4A574C51534956575658454458464043523B4F3A383826202B2A2A1C
291A231518241B161A131211212A192B1E2C282E28292527231B24342A32473D39382C32
413A3C4A333C3C3C4C3A2534292A282932372B292719251F1A2A1D231D292C1C2F24252C
2A2A1F1E2B252E2323382F27272725262B2C2823181B101516161312110F130E0E1A1C15
281C28120F0B0B090D0000040A0B0B100A0C0D0A0D070E0A11130F0D0F0B0F1B17192919
1925252C2F292F3535394238484C49454846331E00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050604010101000000000000000000000000000000000000050707040D0F17
12161C221E1F282C2036303B2F323834313B3E3F3B3A42493D4237494743423347424357
583A38393E423F45414D53505C4E3F4D4E53414D4F6558584F554C514D5952575046414B
4B544243333F4A2B3F473A35182A1C362A302C493E3E292A332F352E3B3E343648554331
42493C4C464C453448414447394B363D332D2D282A23120D07200B000000050300000000
00000000000000000000000200010F120D0F151C101A22272E262937413E4B3F3D485049
5142554C4B595D4C4C505A5856655C5C524146545750504B4E45494F3C2E1F2F2D322B32
2A13111A130417151C0E1C19161F211D211A1C291D2225252428182F3830273136394537
32373E393C403C463A3E4E34192730392B3A2D262E30222027232F26162B2A2D24192529
1E191E1928201F241E332A3A27312C3521351D20232224201714161D0C0E1112181B211A
1A232220181B14160D0A05060614090D0B09110D100E11120C0F141913111F1F10181B20
1B232328283436342F394346444F4E43474F362305000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007060301020000010000000000000000000000000000000007020D08081114
10121A182121282D2D322F2F37343032354132323B33483E41434444444C3B3F3B474C37
454C3E4230472D4A463D4F444B5F454E4444434F5C4554585C51594D5259594246464445
46394539444540313833283133271F343333373B5033312F373E4132353F553C433B383B
4340495553543C35394646404E3631492D36462D312014131407050B0B08020000000003
000000000000000000020000000000040F09090F14151916281C2B2D2D393536413B4751
454E554B4747503C583E5B625F516147455E565E514B51575362554E50432D392C2F3830
20252420081A161A0E19171E16221B1F1F23291C25322A1E131C31282924463331393630
2D2D3C3347313A364441393340241D34323A34382B302B2A2B11202424211E2C27242B26
2E1E18232327261F222D2B253727322C32331D2F152B29231F2110161A0C1C1517192617
213D29261F200C17150511090808060B0A0C0C1113090F100E0F191815111C111B1B1814
24252729232B22293B323944414B4A414A4C48341B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000607020100020000000000000000000000000000000000030110040A100F11
151C1C1828232C2A2A3037342A362E313D3A3B3939375046433D4448434E4647444A3C51
48433C3344484A4442504D5358415048484F4B55585359515D68534A625155515D47424A
344A3E3E442D31312A2B1C2533342434343C353C2F2C283A2433373B41384A344E5A2C3A
34363C48493743554B36423F4D4D36362E283937362C1824182D1A14070B000000000000
000000000000000000000000000300000800140B1C14151A1C201219232B32363843303A
403E56493B454B495056494C495F494F554145435245444A53553D4A5145434237403327
20231D1F1A182513162818151C1C1817101D091D1B212D1F1E27211B3C2F303C362F2F38
2F34413F412E30383F453F30352E39352638483E332F332C2D2F25292120242622241C1F
2E1D2719231A272122202228362E242C18292C1A352C2D25181E161A1609201918131F20
212F29281C241C211A25040F140910000C0D07110E100B1E0C050C141414101018101B24
1B2118252125252529313940424D404E4A5145432C120000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000060301010301000000000000000000000000000000010007050A0B0A0D0F16
191E17201523212A2B34363230393D37363D333D3D41364D3F464A42483F404D434C4746
454647493A413145524B494B49524650515348534F4E65575B5A555B57555E504E4A5949
3E454947334C34282F30372A442821433C2E22292A280F2B34304933403E413B3E372D33
2D384A4F4D3F403A4C524458434A57473D45503C322B271429142A1F1901010701000400
0B000000000000000002000803000000040004070F16191813181B1F2419262A3C2B3031
3A3D483842454C4C56443B5A5547554D53584C3956645848534659574C405E4D45292936
27221C27161C1F141E0F211F1D252311120E191B32272C1C2514201B241A2D2A1E363632
2C3133353737382F373A3137363E2E37363348283C2B3C242C26361D32141A1524222129
29270E2A151F2220291920212026251E24252A20202F2D22322A1E21180C1D13161D1C24
29292C2B10141D19140A11110F0B030105070B010F101319180F191B1D150E110C15221E
1B1F1B1E2325242F2E2E3C4041474B4E4D4944423A1A0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000020003020100000000000000000000000000000000030005050F0F1A151113
1C1C20231A232425372C30323A3930313D3F3C3F353F424240393F44363C3C344C46493E
4C4B454240394455464D3A51464C4F4A3C5759444763635E57565B5F575443565856555B
47484047365135333734373128273E373226283322262B323326434542443F41322F3745
4044444744454347435953506258536251514B56403A352537252A19050E150511000D06
0E0010000000000000000000000000060A19000D17100C1D100A170F141F192C2C1A3039
2C393B3D3B3541374047414E3C574C504D5B494E4A535143535A4C4F5056454149473039
282E32262220171B142F0D290F231A0C121D2023112B1E2127221A26202731392B23342A
2E312C253429392F3C40474E463D3C263E492D30343C282B2641342927191E1D1D191123
2B1E0F1018121D15242A21221F1A23142023272F2727272C34202727231B080F101E1316
1F3030291F23151F1819141215100B0208010C070E1211100F150F11061A110613171D23
18221C1D221F2E2628332D3C3D4643434B4B494240230F00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050202020200000000000000000000000000000000000101020F100D10131A
18191C21222426272A31343A352D3D3337403D3F433744433C463B3F3C43374E3C443C4D
344640483D52444A48443C46545353514A544D534254524E54575D555D495D5B53543F62
57445A30443933353B42422E362E3D3E353231242735342D36304E373F363D433F3E4B41
4753544B474F4A564E50595F5C7065585A6157504741312331233124271B0D1309061A11
220C080000000000000000000300030000000C0000051610101C150A1B131924241A2025
3522302D353E38483539504342414B4751485E5958565B48514D4C544F47565249555032
42332C25362F121C222B240822121F1B170C2A1E20262A1316211F202621271822162320
2F11312B313D2F39373D3F494E47333A293132273C352A332E3035322A241B1F16271D21
311F2B1A1827201C312324272B1B101E1A222A2D1F202A32262D3634211D1B191A1C261C
202B251D241D201A18110A17101012090B100B0601040F141011141314150907131B161E
19212620282A252731313632403A414C49515A4A4E361A01000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000303010300000005000000000000000000000003020107000907040C111D1A
151C172428201E301D2632303A353D4437363C303B3E4237413B3F363E493E3E3D44444A
3640494036413F4C3D483C574B4B4B5A4E56474F515E404A4C595F5B5C595D62494E5151
4A583B5041353C33314243382E2E2B292A343F342F2330362B3D52434D3C3D4234484048
54545640444B4F495B575873747177756E5C4A3E41463C393E32333C2F15241B281F042C
1C0213060B000000000500010000000400000400090B0512110D131E160F16181619221D
1A2D22242D3A3B43424043263F4A4F53454D455B5454595160655A5A4A57545463534A4F
444644291E30321D2A1F1C2521141A1907180B1A231B1C162515161B0C1F1D251121241D
1B41312A2D3E1D352E2D444B46383428332727383F373E3521233A29291F0F1517201D29
25241E1E251F17232020251F1519121C1412291F2824253742443E29271F1E1D1E33232E
2E24201F110F1810161D151C150D10170D0F0D09010D0015100D141416130D0C11171A11
1B1F22251920242627303033344045434648525548382D0E000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040002000000000000000000000000000000000000000004090C0F11121419
17231D1D272A292425252B322E342E31374044403E354E47414130453C3C3D463545513D
454A4D43393649384840435E515C414D43475459524D626858584D49565759474F4B5B54
5E384B464E4F453556432F292B252030234B3E3F483A3C332A3D314851444C303A563B3A
4A4E4F414545414E60695B686288666E805E454E415E4744393C4538242A2125121D2012
1B200F090C0A080302000000000000000700010106000B180A1F1010170710132E0F1F27
2418232C37333F364C48433B35433E4F423C56423D455353586051534C575D6A5B5A4656
5D49503F3530252A312326211815182522220D2D1F19231E2227150F17121D121C202A1B
27302734302C3332304C38543C4137333E38362249382C231E272C271F21190E291C1C16
2121171F1C1F220D1E1A231B2223191D202522222D2C2B3A3C424C32312D292326272126
23222B191E151E151E18211B16130B18120F0F0909060D140D180B0F18060E0C14111616
1C2121221C292628272D37383C404C4550524C4C483C361B000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010100000000000000000000000000000000000003000307070A0C07121811
201C1C282026272B1C2E2D2A2D32393B3F393337333E313E373A3F3C453A3D394D3A4149
4C433B464B4B4A4D4D4F57464551586551564F414F5B4D55444E58504B60464C4F5F4352
54484350394F494441403531281B2027293E3C3F38393A3534223A3F423E3337494E4C3F
3B2A293D292F3A476263585964596D66595E63424C39595545383A4F3327302132232D1D
0B000508000D000B000E000002040F00000009111000040D15120D0B15120A140E18181E
21131E142E302333414B3C442E3C38434138474D4749545D45495558615857696052605A
5B4B54573D362E2D33302714151B342D243F0F14181C081B1A1D1F18171F1716222B191F
2F2C302227273130302C3C3C3A3D3F452E3038413741332C2F2D261E221E22251D1C1A26
18291915282D243318271A241F111F2522202028272D24333C4646482B352D271F23292E
24211A211A141810161217171D1317120812070F0D0D080C0A0E0F131206081013150E13
121C151C202421272E2329373234423C4E4F59504D4D3F26070000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000101000001000000000000000000000000000000050003030C100F0F151B14
1C1C1A1D1F2728272D2429212E35393B34323B343941393A393942374341473D4444514F
4F404B4445414A4D5047514C574B444D4C53425049565048465450454C504543515C5A4A
4858515654493E3A463A2241242F22292735424842332E393A2F323E54424C4C56404F38
3F3C2E2D2D35444B5049463F4E5B5F6D716A55644A42564D393439313B45333C3D391A0C
0F0E1C07181C130C191300000A130B08090508020000000A110706000F0F140E0B181518
0B0F0612221F2442342D3D2F43352D47404049524D4957695864414D58614F6172514E52
585E685849563C3731362131192723252325140F0F0B0F101913251C201B1D211D171D25
1C1E2427252443323D3D3A483F373E3E42513E394230354141412F26271A1C25252B1E1E
2B301E2A262A231D25172B2528271B202125261E272E26313547454A373C2D2E2827272D
1E2521221B1B10081012130F10110D10140F100B09090C180A040B0C120E0F1119141615
1B15231B211C28231D27292F2E37363C47444E5054433E33160000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000030000000000000000000000000000000000000005000106070C050D0B111B
211F1C1A24292C2831272B2C2933323126373E2D30313E2D47393B474142472F3930384E
4C40424440464D41554D4D5446505353474E4B5748544F51534E66433D4341555A505453
5346584D443937433B53403C3141222F1B3B3D343C384553303C3A414E50434C4D595B3E
353B24290E1B2A3741413D4B485C66647157525A4C6452454760443B413D4940442A3724
15151616211B1E140F0308110D190E0D070A120B030A000500090509001005010D091400
0B191008131A151E281B272C28323A343D4E3D434A4442675B45634F63586967576A6359
5048595A654C454E352C3934252C2D25262113141507171E20211D080B1D171A171A1925
24121E28382C1F34334E3D4C434437404148463B3F3E2F3B2C404D2C2F2F282F242B291D
242A22212323211F301F232623291E291A1F291B2624222C333C3B3C2D3C29282C26242B
2D2116261C1D131606130B18100D090F16121D2013131813060A0D1014120D1B0B0F150E
0E1B1B1F1F1C2625292A32292E32343A3B45524F5251493F1E0700000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000501000000000000000000000000000000000004020007050508110D111413
1A17211F23252B292A332333303830292E2D2C353E3938453445483A423333483E3F453D
3F3C3C373B543F4853504D4B4F4B4E57515F515043555E664C574E5F5358573F4A4A5446
524E423F3041473D3E383E3F433D232E30342C223C2A2836454130455E51494F4C4E5238
35261415161A2C2E3B404B46526C635C655C526751566C684F3F4237383A44464A2E2D1F
1D2B25232F262C2C151311121D100D001C0E031400050004070000000B030600000B040C
040D0C0C0B0B0F0B1D261C28303A3137404748433E4C4C566C59574852645954655A5457
4D4C5E6D5C5A494E46463D2C1D3225232D331A1907142108261A16172318111115211C0C
1718202D2A392F2C3D2E3F38384842423944473038393E353241363D3D343F352B242137
28271C1B2B18142C2A2927252B2E33302A25282D2724222F2F332D302F202B322C352225
20302025201C11171C15110F12070F0B08140E140F0C0C0A100C130F0C0A0D100C100C12
14121D12131C291D27273239312F373A43494D5653524742321300000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000100000000000000000000000000000000000000000502090C081114141616
111D2723252C282F2C2B2635372E31312B372E38352B333E443A3F45424538483D4B4844
45453C3242435244524A564A494C51594F524D443B43425C5B5F55474B484D4252544D30
545050473930424E50574B4C40434338213A3544263243474E3A405058624E4D4E544240
2E322A332725263B4E4C44484760626E5F5B69677369573D464936424147504A3E47302A
272C2A304432311F28172519191D0E26111F0E0714060704050000040000000900000E00
000D000E050D031F081424191A2E1E243741383A394E4A4D53525258625C626662624C59
53535474625D5C5B544E4F4D2C2C2F2227190C102B121524172426091722212514151B11
13261614291224392E3729413A2D3F344644443B2F37343036443A3C4047473E3B2E211D
2E2B22272023191A1A232C21272B2B281C2D341F26282A2626363722242A2A3122292E28
2A262E27261B191D11100F0F0A0F10151112100B0D06140E18160E11090B0A0B0E0E0C0D
0F1A16131C1E211E1E2432262C3338363C4950464D4A49423E2500000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002040004060A0A0B0A100F121B
18141F1C252C23262A28263A2C2E312C2936312A2F393231364241413C4D4055393C483F
44373D2B464B4E4A445246474A455B5A4F4F515549564F4C4A5749354C514B4A494F4A4A
504D483C394656535E493C303C49473D443E3A2F1D274C4D5940423D5055524D4A374649
3531342C35222938494D503F4B666D6767768A79816B5E5149464E433C5B56424736363A
3A2F333135403A222C1D1B26261919111D04201B101B230E00040E030007000705020003
000006090B00281E080F09171D2827222C323439313346495B4D47675C5F685D6665514E
4D515E6D7A6E5D54584E5B4443403E3A342A282221271D1A18210B0E0B0413191722181F
2219132F201F1A3429302B2E2C4441433A2E3126312F35232E303C324542463E33343529
2E22242626161C1A1E2221271E1E211F242517202622292B24241D1E2329242925262421
21272F27281F1B1A120A0E000D12070A170D160E161B131B17180E15080808101115130E
1E15121A101D1E29251E1F282E3A2C2E3A3F454E4949484A3D2E13000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002000205090B100C110C121314
1D1A1C252A2C2C2A323238352D2B2E34363C39393A2D31413336483C3E49383F3E484448
4545483E3B4A484A433D4B3E4F545454565743625D5D4E5168674F485148544A484C564C
50484A424B5D55624A5539494D5147393C39402838413C5C54454D4A3B433E4437413439
402E34403A3C37484A4C3C51595A6F6F7082797E7C705F59574954565558544F3E453744
413942384D3C2D2C333329312F2E171F0E2E0E1513110D12020A07000002000001000100
00000E0B01000B020B0A050D030E19052524142020243149423F44436273635D55655866
42646775625F676A664D5348454540302C28231025271F250E29070F051020141B12120A
1C171B2722241E271B313A282D39393C2A482F30262C2E2733364B4E444B3D3E3D3F2329
2C382F2B211F0E1E1F1A2C33202B18231F251C22181B1B21212423282A29191C2F283028
26242921272927111C0A1105000A0C100C09071A1910081D161A110D070D080E0C0D1408
120E040C1A15171C231F202532292D34353B464047484F4743341A000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000401000206030B050D090D13121B
1815211C25202D2D2E2D2B2F362C28243435313234363332393B3B3843403F414642494E
44463E3740473E413F4B3F4B3E5856544A4F57534140504C565C514256494A3F41485E50
4750485A46474E465E4035334A5A3C514449585A41335B3C5E373737374B384048344233
383E435C4B3D36333A4153435A5A6A6E6B717D79815462655C4D3F475167454349494B3F
3F3F54404B2F3A3930313E323A223022200F1A201C1B120A000002000100100100000000
0509050002000E04090C0500030808120F271A2B172028324140454B4869584F56565F58
6663646A57706D5A5D5B605F404E473D442A2A2F171B1F270B10111305000A10281A110A
06151417190F1F19211B213B2C3E292D2F2F332E332324322A352A4442414B4344452B2A
2A2B292828211C1B2F1D19252322242224232C392B1A1E262A26291F2223252022271D20
232827242D1E2220231D130B1D060506100E06141B14170D1B1012091A000C0C08090B10
060C12111A22141C1A2425242729342B37373A4340464C483B3D28000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000020000000000000000000000000000000001000A0409040C0A12150B141618
211E211C1D2E2631243035282E332F2F3D2D2F2E3338312D3438342E4E4A3B3C4B42413F
4648494043373547474A414F514B394A4F4F4B535C46445944474B564A4B3D4D4C465043
3E424943455155484D463259544B495731534B5B374E4D52374743473F44435B463B3639
36464531414028292C4043494B62615F7282615C5B655C726F5D5C584D58515947435341
3A435357583F2432333F42473D332616211D1F10201F1F00070000000000000000020007
00010D0A08000108030D00070007061A1F1C0F232009192A37333F3E434D4D5D48575F5E
555469716A5E69605565575D666355504A48442C2A2A2D37181A09020F0C0B100E18151B
1D1013151B23182D1D1F1E2329291F1B391E313C2029272939334444434B47453E413F38
2F3227322B372E20262125291B2528242B2625202021242A251B2B371F242B2D1C271B28
2D332529252A1A261C130E11090A111203070718110F1015101E17151A110E130B0A1106
0312070C1A141E1C17202129212B282830333D414541453F403C33180000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000300060C0B09100C1310131B
161E141D2425241C262B322E302B2B2B33342E2D2F2E2D3A2A342A2B303D403B403A4740
423C474646564D3C303E5B4B4244464F4D4E604C564C2C4E4D5148525355474644504347
4F40464E504653484D4C493C444C444E4D4F656049525D58593E573E3E4B5B493A3F2F1C
352E3E3B503F282B29222F4850594B4E6372685B66655C68656D5C595F565755304A3B3C
50554647544435362E3D494A2B462C2F2D3424212A1D0F170E0000000D00000000000000
0300000000000000050003070005130413191C111C1B0D172E2E3C2D343C494A47544F50
61616254536460566F6A4F5E58545B5C504F5044392A2C181B1C15210F0310060803170F
102C221D191E20281D1F1E281F222A27332233292D262A293034423C3C4C4A4E4A433B2E
2C2F38283036312C2E2930262E202624322329142E2130272C1A2C222E212D291F2C1E2C
2129282F2B2123231B202016121814160F0C0A0F0A17111012170D1A180A140E1004000C
140A0D080F16181922231F1B292C222D2A293134343C3A3C493E36241000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000030001040703090B130F10191317
1D1F201C1C18272D27272E3235322D2B3430342E2838302F2D29353B3A482B2C3F513C45
3E46474647375144314B423E3F464F4247584B52553636423D514B564B5C4E394951424E
4248424A574D54534D4934475E4F4D4840515A515E674653525A495543533E463842253E
36182523303C292C232B363968497378685F605658535B657365514A54564A4C53525552
4D3C4D444654445845374C3C3A47412D3C281F1E1D11020B000000050000000505000003
00000D00000700000000041200050A160F0E0D1210160019232824312C3834493F494B46
4B544D594A5C565966587672656F725659444C463F2E1A18181E1D1F0F170B0E171C1920
0E180E1D1A201B20201A231C2434232A2B302C2F1E3C2A2E2A3C3C402D2F2D3F3B2E423D
30432B3732302B28212B1D2820282B312C1F2D2D142A20322727212A382C162828282B23
2227242D2728252222201B211A181D211D0D161111140F1B16241C1F151715080C090C0A
0B0F0413121818161F22171B21252927262C332E42413E3B3C373B2D1300000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000020000020306080C0711040C091414
17171E1A231A232930292F2C2636333638293638303233262D2A303E3F3A373637364939
424952394D463D45463449413D424553524A4B3C55475A454E5541484253493C5C5A645C
4D48553C5E405B514C5649424B56574853573F53504F5C5756453C4F5C4B585563505836
2C3C2C2B1C1D2A133B3031504B59425F5159575C624C42646B67507160654D6E56474542
53462E48484266464A42503A483C4643273E3020220F0C0700050000050000090A00000E
00000006000005000300070B000619081100041215131611131F2D232926273A393C5651
425851554E62597164625E605D605F694F514A47373D3622272A262123111A11001C1615
0F18261B17261A122628221F15293021372322322A133F2E2F3A313A42344143373A352B
202D31322E35352528292B2E242F2524282620252A2426342C26252D2C302E2C282A2329
2D22252427252B2A1A2A2A1D282523201C181A1219111220130F1D191615191C0E0C0510
0A090B1011141A21201921201C29221E1C2A262B2B2D353C3937352A2000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000001000109060908100D0D0E0B1819
1919181E1C24291D27272735312A30322439393B3032342B2D2F2D3A36352F2E32342B33
3A3D344454364049434C40464C493C34444B564F4F52484046483A30444A44464F66545A
49434B3E454868525B514D4F5E54594556514A474A555C65764741534E4A55595649442B
2B242A252738423D404243464E625D5B5A4D48615A5757715A5A5D624E4C695364545349
50515F483C5A54565A444D4A504831464144312E39170A0E0B0A00000000000006000000
000000000000000000020000020208150D1909020C111317192D0F282B273A2B3939484C
5A4B5550535D626E6273696A4F655648545C65563A352E2B2B292B24292B1E1713121D16
12121E1E0D1C13281E14201A26192E2228202922263A26242F30362C23262A3F3B383538
32283F3F343835262F1D1F211D211A20211C2D212F2D28231B232E271F273121261F2324
272B2B282E25212C2831312327252B261A1B181A141112201C221D282323171C141A120E
090B08110B0F12100E1716222022201F252826292F2F2B322E373636290C000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000004070505030C0A060D14110F13
182019221A161F22222A2D28282A33223223363632312D352F1F252D3237433231232D30
2A3D4C44384F445745354843474536474A4E3651414835464C4544474E574F32514C605B
54445555475448461C15201B3C5B5A4E43434C4C424261644C6559454D4F4F4D524A453B
31382C153E3B382E4533364F4F4265525F5C4B63636558786F5C694D5B59645B5F565644
4C5B4642565948434C6A4F4839464A4C39463126190817120E0100000406000900000004
0003000001000000000000070000000012090100110617020A07172D1C2D2B2F34364844
475553555B67535C61606950614E536557585D4C4B4142473B3637352A281C11191A1708
130E1514161618182328151B1726282B261629212021282D2A333A29323331272C222E2B
31362B362F392B2F2B1F21202118232A2C201A2B2B2E2C24281E1B2929252E2226222A23
392F1F2B22223131392C282F3029281F1A25241F221B1B1614171E1E1B21222513121308
100B0411121310141218191B1C1A27261C1F1F21282C3133313036392517000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000020505080507050A0F0E0B081B1712
1318131A1C1A1620132B2B2326252B2A272B2D30363432353036243B2F2D39323E353B32
3E2E37444E434E473E484A443A484C4B3D3B423E40474748484C3F483E5045524457545E
65524F394B4355443E312A4D4C615254483349474B615A4B47565A535542355753473647
3E3936213337454B3C434F53596867685D61697057625D654C624F54566D5C5C6D66554F
484E5B49435D625750584D57435A513C31412C1D331925271E1800180506000400000000
00000200000000000010010000000000000004060B0704130211140B232420312A272B3F
5545535F524F4F545A635F6F617761665A61555C5A5653423F49322A2A2D2A2022261A11
1A1F0F2118051E130F16151A281B151C1F1E2223202D232438242A3D2D3D2A3433372E30
2831382D1F333A2E2C2E273621322720262F1926232323281C2B1E1F1B182327292B2534
312C242A312C242B2D293430292E1F1E2229261B191E1C19201D242521292A1E12150E0E
0C120A1309140D0E141A1818221F1D201B21212A2A3B2B312C2D302E3220060000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000030000000A07070B100D131711150B
141A1A171E151B231B232026232223292824232F2E333D3031393035303C313536332927
40343338423F5148454444464342464451523E423F3D404C504C43475057444B5351535A
41474956605B5D4946415150596A505F584D402A5A4C463E5352464F403B51564B4E563D
444B45515053464F445956634F576A4B49504E4C5D65515F5F4D6145606C6E5C64626453
5852585D555459565C485E5B4D4B404F512E42262F27341D170D0600000300000B000000
000009000000010002000001000000000000000010030200010300181E141B281F292D33
4750594D574C52555A5C6C5C72575C585E685966685D4E4A454234262D2E262A22292113
24161B0D1B1B140D1A171A1622201A161A1A1B111D292B2A1F242E302C392538382E1D2E
3E3332322C22252E292C39242B2824251F24232A191927162025221E212C24332937312E
202B1E1B242A1C2F382B272F2B272E22212F2B1F1E231F121413181B2820191B1F131714
110E160D160E03100A14131211111B1A1C1C25272B2A312429312D3029290E0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000005050303000308070A09110C101A0F1C
1710141417221F1F2D231D2723232726202731253630303032263325383043383A362739
3239363A484847474B3D3C4C3E4C4F45463B4A4552454C3C4F524F33493D4D394E604950
564B535960575B57595250595F4E434A5C4F5C4D5D4849424F5A5D50394B3E5344564D5A
364A4A4B554C4F4A4E47703E5356516969575462635E55504E654D605967725E5C605855
3F565452524B5B524343484B42584D4C422E202A28202015140700070700000000000000
00000000000300000000000800000000000000060002000000000010050F1A3027272C40
3B4E3F5952485254606459715A75605A5A66655A59625A4B555239322434223727240E24
210F0D1C071D15272518112A18291113241B202F141D1626121B2A2A29302A2C303F333C
2B3E2F273222291F2C2B3924321F3A26382C1F262122262E1C2826242A24221E28242026
2D20242F1F26292E2A302D38272B2627292A1E242224191919251B1521281B1E1E151211
0D12101512160C0F0E050C0C0D0E201A1A1322242B231D2428252930342B190300000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000003050005000805090F1009130F191212111A
1113131B1C172216191E191E261921201F232E2A2C312A332D3B29212D323A352C353633
342E373636394337434B442C39483E404B514D303B4A2B4238453E39412F414C3D545A5F
4C4B5351506069545A535D5850454C6272605C51564D4D44504B54545E3E3D3041514B46
4C505051513F414F3E525A68585D564B58566C6043584C624B4E5A4D5F66525E675C6366
67665E5B4A4D674A545C454B515D52453240252C2B252F17081203000011000003020000
000002080000000000010400010000000000000300010000020012170A0C1321292F3225
45424E41465D60636562554A485A4E6D6266736A575B696965484A3F423A3441332A2D37
1E211A301A0C161F131F1A181E160E0E1422292A292621261421201B2D343032252E2930
314131342E302A2C3A322B302B321E2725252B222224213021222B2F23212525211E2025
202526261D24282C2E2E38212C24221C2221272623292A1D201C19231B201A2014181017
160A0A0A0F0E0C0F16100A080C130413131B1A252B213323252630322E34261000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000602000A080A0A0B120F16101519
121416151B1C1D1B171A1E1C1C26212A201D1E28322A30312A28322B322F2E33393F2F3E
3035323C2F3938433B5142364D3A4E49553330473849363241483F3A41413F4A504B5663
5A4F4A4965515C5F595250545B5152575661545E535D4F4744475F5A584F564C5E585947
49594C5356483A56485C6154565A54674D4D4B5C6B4B4E4B534F5449555963575B656770
60576C4855525C48543F41474B48594C4F3F3B2D33292A2D1A130A0615060B1100070000
000000000700000000000000000000000000000000000000000000070C0F170E2C19222B
303B423A545C595D5C6C68596D5E655E5B64765F585E675A545F4D5A484139434538353A
231E182120151E241E1A12141E120F08101B1D32232119241D27301F322F322E3D2C3129
37413C372B312A312735352F312A2C22332B28212517222325292626231522162B222C32
2A342E242E312F2C2D242A263524272A2E2023301D1F251D1C1C17231A1519141C161413
0F121B1A0D1019101A0A0B08080A11121518151C1C2328282A21282C3130241300000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000308010A09070B0C0F08170E0F0F121412
120D17221919131A1F172223242023242329241E2C3236393027352B35383F3D33342D3C
3E3B393B403A333A353334433F353748494A3B4D393C49413C3A38434843434A304A414A
5649505551595C535D5B63465B5248515450674B5E53495548464A5A6165555E4A5A5045
4F475E5C3E544D3B4F4B5052635B66696E5E57624833454A4C5248485167526153636461
616F6C61615E4F55424F47364B4D4D4B48302D2A142E1C1D1E03000F0013171006000000
000000000000020F0000000000000000000600000003000000000011091E2C261F252B2B
32492E48515E5E625D5A6360525F69646876546171605359635C4E5853444C573E333428
2E30172417270F211418180D1E23161824171C3510211F202822243418233D362D312C27
3528232929363B332F292A362E39282A2A27292B2C2F24272022211D2029202B231C1521
1A2A1D212C202A273630312C3328231C2921282722272121201C1F1B1616101D170A0E0F
110D0C0B1A100810160D0204081203100F171E1A1E23231E1E2720242F30262409000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000002000605050B0810080C110A0E0F130F160F
101B1813181C180E1A1E1815181C1A221C241F242A22352B3235252630352F3646243842
33453F41333D43313643353B354647524D554E374D4137423938383F2F47484347455646
5156655D5D6D655B585D50654A5653525F5A52625659464C345E696172776D5A555C514E
4E564C564F4B4F394F4F5454465B516155564A5E513C4855314B474E545340464F6F7870
7463696479625D4B553F56583E474B4E54444A4A2E172215110D012419121518000D0508
000303050000060000010000000000000000000000000000000000110A1823252C202926
302D3C4A483C5E69645E5B566267696D696A5B5C645663606B575B53525F463E4D3F2F29
38364A34231E110F181C1A121E18051C0B0D142219261D221D2E1E23322E342A231E2926
2C2C1F293739222B2E34273434362F33312539292E312724291B1D201F1E26261A251625
2C271F2B23292420312E1F26251F2722202616272224232314241A1C18180E141A09200F
09080B0C0A0C12150E0E040809120E140E18151E1E2026262C252F292D2E2D2814000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000070509090B0B100A0E0B121211091A161B13
1617141A1B1419171A1218151D1C221121191F201E2428222E28323D452C393936382E2A
323C3B383A332A314233353F2F3D3F3C533A414C4838283A253842393537454F48434E53
5750674E6A5D56696052734C62505A505D5C626F625554576357675A755458505355504C
6650415B4F5A564E5B525B545D3F5F5C4C65525762544B395F584853424E514F64566255
696A706F6B5C5B53415A5147583B54483F4C39452618180E181124171C26251B1401021A
08000500000602000F000000020400000000000000000000000200000C0D19293D2A2C25
2F282D3D42554F5D545B53546962635C5F5F6B5D5A5C5867535660655F5E584F47474742
3239333D352933201718151A1B1D221916141E152A161526202221222B262C2D282B2027
272A36262636232641252F302E302C342F394B33303C35222A2020183121252518172922
1A242A2338262D2025252E25212922281F2118251F18231C171C1F0F1E190F130B0A080D
09071709100C0D0E15170D041104121118130E141926262627272D28313935311B010000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000020A07090E090D0C071518130C1716151A17
151E171A17141411151B1916221B1B1A181721211B28301F21322B36333837383C332729
34383731353837383C3325353D382F3B413D454B48303F33453E35443C56454C3F443841
555158625F5C66615C6F5D576A54504E4F6D68675952555F5361525D566663555D586956
61512C504B63505239555F464E664B554C6C6053484D504B6355684D643C645649585C7E
765B75736A6466636F596B57595B4445484740262E140716070914171E230F101E110B11
19180F0800051709000100050000000500000000000000000000000000041B1B2E27303B
353A3A333043403F56505460555E53625B5A5C6168565C646252596B665C554E4F4E584C
42494A494033241A1E221B1722101C161519151C1C10161A1E1F24272A1D1E2231112A2A
1F2437201B352B2A33273D2E2B253A2E302E30312A2B2A201A241A251D1D24182113211A
242324182B2A1C231D1F2E2C2E2E2F212C2326142B25231F1F2622261D250E100C0C060A
0B06100F0C1110081113090B1504131213120F17181D271D27252C2F33303931270B0000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000C09090B120D0D10160E12131113131D18
0F13101017190B141417211E2A221B1124241D1524251E22213528332E302B322F32282A
3B2C383235423642302D3B30383A2B3A3E4545504053364B323842374944364144314D48
55414D5C505D535E5D4A59655B69565F6F6E576049666B6B5D4F556A4744534A5C575C63
5746185D594F3E5949605C695C5838455940564C55525A65473B5E584B4850645B526462
6768646567785B5F616E5767555C594D4641512B21061012152025231317171319030F0C
011A10150B2618110300000100040E0100000000000000000000000000000C0F0E25372F
42262A17302D35404F5C4B5B5858617359636C54655C525A515152577D6D6065545D5445
3F444E4B3C4439281929261619131216191B140C141B0713171F221E1C2624241F232923
262220312D352D29333B2C313431323A3528323126392F311B2426251C1F221823191B1F
181F1C17231E242D211D261E3135251F2A21221E1E31251D272823231B1E15130E0F190D
190D0A0E07080F0E100E0C14110F0817110E1A1A1C1C282A242B212B343035362F100000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000605030A0B0B0E1919121D17191E1B16151A15
1B21181A12131C16191A1715131E101524201220182719262029302D21272E272A282B28
2D3C2E382D353937373D3B3A33373D3F3643553A423F40463550454234372A5545434644
3A45654E3F635563575A515B65686F5B4E45655B637A64544E66484A425150526B675861
485E4B58556550684A405A3F385442555C645E4B58514E5B4A4B465B4F585264555C5D56
695C70737B7A76656E666D61575B4A5846452B393119171D2A232326210D001210191A17
2619121F152416100D0C0B02000F01060000000000000000000000000000000D08141428
3B262C1F28253746424344566B69565A4D585C635361615755575F6560666958565B4E4D
504A51534D452E3428391E24191D11121A110D110C0F1D141D162D29272728321B312925
19322D222B182F33262E262434422A2A203532262C2E2F3C352623271C26201C27191F1A
172229242A1E282419242432273025281A1D27242B2722251F25211B1B1E1E1D1618171A
110B050A00110F090C050C0D0C0B10190F1C16181C1D242627292C283130313933190000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000030207060912161114151916191F1E1E1E1E111B
2120191918180E140F19121017131D191C22151C2325212F1F2F2929221C1230292A2C2F
1C322E38353734252E27283A33442F363930433C50454646344B4143403541313A48364D
3A484D47514B4B5B5A5463746A696569546761785F57735658604B515658515355646268
655B5656615F584F475E51584B434B3E514C4B515A4A5250554E5763584B545157594561
767C69737465716E686660796662653D454D36362018170B262929311913191115242728
252D1F07151D1114150A0B051005090201000000000B000000000005000B0500060A1B27
3C2A2D3A18323F3A3E41496256675B5C584F574A6B7463645C575E56675E58625B655263
554F5C51585245493B352E202A14191B1919130701070C1B232126281B1E211B1F200E28
35272B2A212123362A2E272B2C322E30392B2732322A33362425252D282723321E201E21
1E1F2117251A261D162222251B1A202921312A22272525211A27211B131E1B191C15151E
12190E0E110C140B10030B0D090F1014151C1F1A1D21201F22222B2C342C2A342E240900
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000070306050808121415101F1F141E1C1F211E1A1A11
201D1F18141A11191811151621181A1F152026201F231E201623231F26211B23272E1B2B
2B2629302E3C2E322A2B463C2F34383930433E3939483E404D4441405241554342474245
4B4150504847484C5E604E707A5D585B5E5C64665D6E755560674F4D5152545858684F59
5F605A595837626852514255464E5239414B6552564E364A5D4038504E6561524C5A6164
635E6B6F7A7B6D756B6A746C655452463E4E37332225161B24302F3C18221F2433232A34
2F2E2229201C1B202217220B0914050F0800000206030000000000010000000504020F29
262A29282C262A29363A474B574F5E5B4A59676E60706259505A5D62555F696A515D4B51
57625D4D484F3F525C3B48242A301E172D230B0D110D131F0C0F251E1A1C1B1F1D29252B
202C17282E2C2E26242F342D2525273A2E2F30342E2E3825242F2A2B2D23262427271F2A
23121926211516211719160C1A1F1E1918211D252517281F14121E241D23201B1A151721
1A1A13110C11180A11110505090F0C1911131B161D1E1A1F242225232D2C2E2930221500
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000020404060613121B1B1D172319212B2322201B1F1B
1D191F13171B20190D191915181519171F2B23241F1A14181F1C232C2317232E27262422
292830262B2C3A3332373230332E382B453D3D373D3338493F4B3E3C333F403A3F494A34
59463249515055635C5E5E67626A656B746F76665C6B685F565F555D564E4A5964475450
69564D4B5B6B5F5452595C595447565A4E44396060513D444B4A535750585B4C5F435463
5F4F7659806569786D55636360494A484C334B2E3B252A192938432C4335282A2927282B
3A2C2D25282A1B1521271C2624151A0519040D031500040000070A0A000300000E050E1A
273C27242E2E21202F41374644534D5873565D5F6361635664635253525E60535C465B5B
715F66454748463A484937382D252019272C1C1925100A1F1B17231612170F1F1F1D272B
3A2C22291D201D352C262C3A323121302B2E33332F352C2A30252B31212E29271E2B2E24
1F231C2129161C231B12181318191F20231C2015191F1C1C2A1C222723211C21211B130F
1816171219150E1614181610120D0F1013181719201F222021262C2B272A2C2E32231C00
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000003080B0E0E14161E1D1D202122292828221B261F
23201A1622221C1A1A13120817171D13201A1F25191D1E17141B1C201715202425281D29
182E2B20252D30423E2C32373422373F3A3C3C383F4830354A3A3F4B4E493B4B4946454F
5B49404847405C474F5B5D51716A665F78605E5C515A72567063585047555D4E4A3F4253
5C665E575340605D61544655585C5243584B524B474957445C554D464845435C4F52515B
59596B675B6F695264656B616A6F5E4C46403A402B2B221E322C3D414834372D3835382E
1F322F3111282A21231C2B21121A0F1C090F070F12040900000416051401090008001124
1E11261B212A322C2C1C263545514E5F57605F5B685B5C686250684D594A4E51465C5F55
6A685B514448545351503F4634262A27381D301B1415281A1A1014010F17161F1B201B1C
21292B2627232A2A2227321E1F242027282926292926342B282C2C252A2E302122232527
181E24252021221A1D180F1920181D152610211E1F1D18151D1A1F1C3026192016131511
181C25161618130B111313161817150F070D0D1616221F26312627212426292C31262105
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001040A090D0E101D17181B2829242D292A2327272D24
2D20211B1C1F1C13160F121112150F121113141F2A20211C11131F271617212B282E2828
272520253D3730402F292F3C3F3D3F373037352C3429332633453B393A3B4B404F464A38
3C40494455394F48475A5C5B66656D6A5A6B70626D626372767765525B60494855575355
564B4D544F645D64415F5B55644C494F5751474F5345493E5747404245404F3F49484545
4E626B6D736367666F706D5B5E626D53472C4932392B2436263234414E484042453F3A39
3F23213D321627312E21261D231C221908100C020D00010906120915070E00000B030023
2421281C1728212A2422362E3C44454F4E5E5D5F68566361654F61625F455C524E48525D
5C56574C4D4D4C395E5B50413E32332427202B271F211C1D190A1912181F22161B16221E
2C24211C23262820312C231F2A251D2F3628242F252E282A342F2C32292729292A20251A
2018151D25241E1C19191F1C1C1A11131F14231D17161C2720201D1D1E2021241C1B1818
1B1B1A1B1F18171015181614150C161216101A191724242A2A29232126252927342C2109
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000070A080A1010151A1C24202A272A3129272B323225
26272221171B231F1F1D211E1815130B191F171A210E162C1E2919161923192E25222031
19251F262D223334313C39293D382A3A513B2B334335282C28363A303A314542534E4039
4345444C495143464D5D4F5D535860655F585B6658546D6B6F5A5A62624F56664C42272E
4A5751574B62455C604561576048445C534B5052415B3E5D4450483B504849484753474C
49535764625C676666555E5F5B505E544B55463E2E3021232F38404C494A3F52513D3F40
44343E2439333E402E2124201D0C1D2822060B0C0C0000040C1A14170B0A0B0A05041108
1C071C11151E19161B1E3435383D37334358555A65685F565B575E5E5B506149504B604F
625052455B4758605751443F3C2C2E292C292025311D1A1E2317140C16141B201F15111B
1C1C1C2E212A1E2D0F29282A2320182E25232C2A2B2D2D2F26293228313724322D262F24
2111171E261E221F211B2220101F1730191D1A0C201114161C1E121D21201A12151B1C28
2729232524171A18171D181D1211130C11120D131D211B27232A21201E25242C28261F0D
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000050A0D121213111A211B21242B2B26323330322B3A
312525222326241E231A23121B1D1819181116111B1F1F1623241D25201717151E201F32
27181315262233382C33282F39363C32342133462E3931403B353F3E2F2E423C413F3940
4A334A4E4947484D444559644F485C5A515F67725B4E62685F6B5870625062594E3E312B
58434547565D71586F60596253545C394A41654A5B58515653324C566044573742425147
49634B5A55496558735A68486564685B535C454B102E2D2A4B423F41594852574E524552
343E47453A2834322C2A2420281B102221031B0902020002090C131B0C060604000A0907
0C1411000D12281B1F202A252330372D34404E476E665B6A595B5F5F5D544F574B61585F
675A5253585E574F54564A564E344B3C27202825291B2020101415180A1E1A1310191C0A
23151424251A271229262A161B222A26201A2C282B2B2A21332A2B342C302E303327211B
30282B271B222A22151B17111820171C20182818181B15161B1B1B18171F1C12262B2C26
211D201F23251A15191B191E0E1B181E181A14172019232A2C282A20202A1E2628221F11
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000004050708090F161F1C2120272A2F30342E3237423636
2A2B2C222420201F241E1B1E1F1919151B13211F151E232526262D27201C2C191B201F1F
1D1814180D1C292B322B312E3227372A373135303F382F392135402C3D313F3F3A38454B
3E50313F46463D475F494E546250595D5F5C4E657368574D525D615A634E6356554E4D55
5A474158516B3F4B52548D626768514C46563E4C4941535164564C485044604940385256
4C45595255546359495F4B6A5F55683E5B45423D383A2F2A1D314151496D635F545B605E
45464F3E4250403D332F2B3427372723202B0B150000070600090211051200030D0B0208
0000010714121D180A1C212C1B2A242323292C3F55594E524C4E5659594F575A4E555C5F
5463545858645B575F534B55414456413739251D2C2814121D1113190F110F100D0B1B13
151013001F1A0F2A2A291F1F1C291C1D1C292925282026322D2E2B32342E212631301F28
2817212722281E2022231A2622272B1421141515111317121B1A1C1616181C1D1B282A28
2A2E28221C262621281E2113131715131B10170F1A1F2A2631352A2E2E301F1D1F1B2115
020000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000002060D0F131210171E1E24292A2832313B3532303337
33362E312C242B2425252629182A1C1C12171619141E2023281E1C1F1B25191D1D25142D
27121B1B1F231E2019232E2E2E2F3942362F39252F273B333037353A31383748473D523A
423E5A455C534843563047404B4B6049584350465259595854534F505A596552534F5448
55496054545B505B6160545E54515351495344644A3952414D553D5B674C53304E4C2D42
51424D45535A5E5D5B546354504A4D5B4B4835464736252E32373B525C5D875C546C5652
514C494C4436503F3C3C3323283429331E201807190B150D0104040D06070308100E0E0A
00000D00150C06061517271D2A1D172719182C2F4E414D4E3D4461535A5B5A4867516050
6E625E555C5460526462604B4A484C4549473E35342922231F1D11192117130D120E211F
161C1216172F18201C1A141C16171B1F1A2622211D2324312D382E23212C2D3227262F1C
292F262E181F281A1725272C2414292B1A1C170F171C15161D0F161417151819252A2226
231A25242B1F20232623201D191A161B17161A15131921262738313F3937221D1B161912
0C0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000060B0A100F121A221A1D232E29353538322C36343837
3D3E3A3E3333222B2C272D212323211A201D1C1D181A22232122191B1A2623131E1F191C
1A191A2022131C1B161C202C312D3D383833284637343F30342C3A2739313C3F2E303D35
4649494349423B4C332E374D464A5449594B5B515C5255554D55515D515254655B515859
5556505D495E4F6E6B4A5C4A61585F6168555758615D424F5350524554604B5D4B3E3F3C
4E433E4F333E43564F4F574D58505B5563624C4F445554484A394351516A6972635E5562
49473B4B3B3F463A362F362C2E212D3E412E1A25062922000000080A0704001906101000
03000010120F0C091319201F332E221B211B1E2232354635314C4C544E5F4F5D62624C59
69555961505E5A687A665953635163504F45474641322A2F251D202710150B0B1719171B
171512191D0F15112C261D21281E2719272021181B1F1E1622242A2F273D392C23292D29
3325292E2A291F2027221E23231F281E21151C151D19141A151414180F1A1B151F252B2A
1D1F1B152127222C271E1B1C1C13202119171613111515241C25263937472716120F1615
0E0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000001000A080D0A181A1923211F232F352B2D303B3D3C3237
3B3F3C37443833342E211D2B272C2616121729221C211E231B21161625292226301B1A1F
1A05191A1A262325141B242B2925363B493D392A39303B303A3C2F352F3B34364345454C
39423D5441594C4E41503E44424D5346645037585B4D435B4455634B584B585154585D52
403A6C66585A5A545F5B685053615C555B54614F5F5C585F685045643F3C495A42555247
484D3D4B36435248434C5E515E5C62574F47384352363E4F4C405348515B6A5A67686874
64665143574A363B3C233A223A40342A2034201B20231A1A1F1418060505020E02191301
03090D18000E03091615192F27131B2B1D2D251D32362E2B303736405E4E555B5D565064
5F55625F5E68595A6454635E5E62545A533E593E433A3B3C3C3525291D1E171516101F09
1D1D1614101A192B18211D251E20251B151E39202126271E29242823282E212833203130
292D25242F282A23181E211D1F1F2529130F191D181E1F191118150E1812090C24202C21
2020231B1B232323221D2A21251A221B151E10151B0F1B1D21262B3140352F140C111318
0B0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000409080E0E0F1917182522262D32293638353734393F33
363B453F3434333929302C242E372F1E24211C191F1E2D25201E1A0C0C26202B20212222
271927212D1B161C2031212B2F3340343030372A2F2C3A3332313034342726292F2F3A42
4C574A3F4D3B463F4543333E515241434C5356574856594C4F4A4C4E3F465C4552474C59
4F635D4E5D49613C4555505D5E5A5A4E5D5D5B4D5445585E414C494757474D6A64524541
3E4E48483A4F4B3A6A53525D3F615964705453563C3F47495458594C5D676E6C7C5A7961
5E4F54414C36504A2F3E402E2E3C372D4730222C20191E2A0E160D02020200080E0D120F
00110608080006070004070711231007181425261E2A28252E2F403C3B4249575859625F
5A505E647059635E57544A544E63606D5657584B55503332373C1F2324131F131C171E28
1D1A2C2118151F17171B1422282D22282A1D2321231518152427282316251E202E2C2E22
2830262A272132252F2222131D1C2B1F281D181F17181B1E161A1C12100B1214200F2F22
1F21221A1E192E2C2D221D1C1B1D1E1A131411181C1A141420272327211E1F0611110C0C
170000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000606131010131D1823201F2A292D313030343B3E3C3E
4842473B38393A3A3326352926363324232D2322261F25151B1C16211921232F232E232D
1F211D1F2C2E2D223220332727201E2E322E333B452E3730342F3E2F3D462935322D3A3F
38573A465C395548494947484D494A5950584E5F4944523C494F454047473E394B3B4853
5454636259615245606268725A5D615F595461324761593C645F4E5B4E524E3B474D563C
474A3F3D2F465435434C53565C57555258415D495848554F4E4A585C5F5E69746E626876
6847543C423D504541383E3E2434342E2336282120211E191B110E1209180C0B000D070B
07150D040802000400000A08090C0C0C251F1F241C0C1D302F312A3B2C3F484A4E465C50
47544F504E55595F594E624E5C6257626057586657484039303139322F24252017180E1D
1E1C1C262310111C192027161118151F2318232921172B21201D1B201C1F1F261F22322A
332C1F2F2C29172428231E2227212C26302C211F27151A1E14130A15140F0C0714242520
1B1B1F17122024302B2323151D1C151E1B15170F1312151B1A191F1D171A1C0C12170E0C
130900000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000020104120B1217151C1C1E262B2E2B3035373A393D453F
3A36403E3B4345443D3D302F37392A2D362D232B2B261F27181F1B13191914240E262725
292A2126322A31271F38261F2527242D2B392C353B2F322E3830392C2E3C303A3A3A3C41
4F3C3B3C4C3C50515A4B514B525051565F5B5851633F4E553F3F454051444237413D4B45
62525A565B5B5159575E605D60564B554E5B4C3C64486A6F4C5C4F6F4C5F5865554E524C
443F4E374F384E4D40553C4F4D4B5C5C504C4C474D4D2A534D4C564C63766A67686D6661
665A58524E3E4532503848363433382A2C29261C24151A08140B09001C0C0E0C0E130C0C
0A151E00100706070B0000040C000F000901090A1E161A2A2328222A493140505148514F
585A4A5E565B5451624C594B52535F4D54625E55585048473C323D2A3B262220241F2522
25160F091B18211D1A22181F1E1C1A1B1C19181B111A2924101A220D1A1F271D2420222E
26161D1E1F20292627273025312834292D2A2C26251B21191719161518141118111C2023
1D1B171B241C302A22282B1B1C1A1C19141214151C1211161317191D1F1E1D1615171311
130800000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000001010E0E0E0F1117161C24212E282F343B383B33403343
41423D4E434E46533E3E302F2C3E3B29312C432E2F262A241C1F24191117141614242021
2A1B282621322F1C1A242C281B29331B2E262C2F3135433A3C2C36332C312F3C3C393A2D
4543413E4A513B48445B4C51323F4E4B4F4A45444C4F484A424A3D3E5B4245443E5A3F56
58545D5A5B6D686C5161614C6C4B5B70665E595464586E5053504F5C604C684F673E5452
4D4B335232453D40494B433E4B355E4D434B4E584D3D4849484662505F7367768E765B5C
575751585949373635483A36313A3E2D282D26290E17111712110707121B160D10181409
1F161A0015070000080203080F0200010A1E192516151F2A1E3031232E383B393D455266
544C5B534F6E605D5E505A49554F596462585A5D544C4444453F3C33241733282A1A1F16
1B0E0915151B1D1B230F2816251E241E241D20171920201C1F1B291C211A23161D222225
2521262C1F29311F27292D252B232B342D2B31292A292430161E15211C19120C14131615
1B201D211A202518241C1E1C1C20241914160C1314161815131516191E1219111917160D
110800000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000040505100A15191B1E202523282E362F2F343538424240
3C423F4149444D3D413B37413F3F3B382D35332B352A212525271A1E1412191C0B0D1D1E
2E1B2124222E241F262214261A1C27201E191C2130333D3039333B40393E3E3340353F30
3A3C3E36414A4043454D4345424D47535352404D3B49474248474959494D464749494F3E
5052535655596361615F666847504759494A565F5A554C57525769695157536463654E63
5D3A4139474B4A4A2C404943554E493950514E3B4A4D4C5142435860605C6F647867625F
5A45514447414244443149363034312C3115181E040C130D070A1C1A0611050E04051014
05121B170B0609190001071109000A091001130F1B0F14191F1E1F22312F303947424955
5B525F484F43496857445260535E5360655A5D49435A58464F48463F3233382E1E1D3214
160E1D140C15171B2323282510111C182124101E1E2432201D1010151C1120140F2E2E2F
1F27302335243728282329372C2C2D2D2D2A24281F3029211A1814191A121915170F1C1F
171F211B1C1C1B292517201E1D1C151911161612151519100B1711161A15170B15161312
140B00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000004020F070D151419222021252A292A33303C363E3F3C43
3E3F4142434644404A3C494141334349473145362F30351F32252F1D1D191E161218181F
2A2426241C31221E1D1415231D250F2136252E362E2632393E3436364045443E323F3643
402C3A4132463F3A38413B4B483A3A4F48433C505048464649384E4F425654655A454C57
5E5D5B51575A584C7A61545A564E5F5A5A4B4D5D504A5F4557515166625B596C584D5C6C
57553F4C58483D3E3642364138414648473F4C4C4F3D4C4E5359554E625A73587169674A
5A59573C503D4343423F2C2F363B2B2F1E1617201D040416021916141F130E0F12121104
0D170A000700070010010B0000000000060C140E06050F210F1E081C2A29342D2C3B4158
4F4E475760565857625B58495D5A54556156715D5C525D4E424B43362C3F323731291F1D
2220161C161E191B17171B1F202429252019102219211E1B1F1A3027221E1F201C1A1F25
1B282C1A242A312F2A22252E272B2C25252A2728222B271723221F181C1D1A0D16191119
1E201A1D1F1F29201B1A1C171A14141D0F1310151F151713190C1413170E131214111011
160B07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000010B0B0C0E17131516221E2924303334323636353F3B3E
36423F44423C50414E413B373F4E4A4B38423B30332E2D27342F2816180E17142017211B
23231712121C0F0A1B1B2A282A13252D2C1E2A25323F38393135343D322E3D363E3F374E
394A3E4945382F37493D464B514B54573F464441504341443D4B57492D4C4C5C455D3D4D
58574F67595759567363657C5D6F586E53526041575B56565C58594D5E485E5D625B6662
5E504F434B41583D39333F4B3D3F3C51423B51424C474A405F4D44516B484B615C566A49
5C535957403D513B323A434641352E2A33211821221B200E0B110F0F12140F090C16001C
141C111C01001B120C16120F060300000B000B090F051611111B1C10182E24242E344A42
463C50535B4753485B635A47565B5E654B5B55524E51555A555D4746453940432D3B1F26
2D2325191512141418230F1B27181A0F19191A201A182719261C2323171F171713222A1C
26271E1E1C2D2E26293226322B27291F1B1D20262E282C223022271B1A17261817060E0F
0B12211A241F2115151616141A101F110C150C1015121417171B16121815171B130E130D
0F0B0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000206090A0D1311131B1820252B2725342F363B33363A41
403C3E42444A41403C3F5244494C4A485341393B3132353F2B2A272723171D162F291D20
2C291A170E11151418251D1B222225222421241B2029362C30373E4D3C493C3936343F3B
3E393C434836372C37302938444C43554A4A42515333523A486144425039424641524B57
5B4D58585D6A60566B5D5852636A6169675462566545645A54455D506058577254555F4F
584D534B5755543D3844373B2E413F474941474B4E475E3C463C53484F58566558736D6E
6451513E5D5E4C4D4A2F3B2F3E3A4338262D2B351C1E1C0E130D101D131107120E141208
14031C0D00091A110A1B0C070B02080001040000000A041403171F2119302320342F3231
3D44414F434C465760575152545360617169545A5B5F47465B5B5B485A3C503946402E2A
352F372F231F110E04120F20091415101C17171C20252524101B201D131D1E151818171A
1F211A1A2129251E2C342E24272821201F2B1B282C292924232023201E221F1B17151215
1D111E182111201213171113181518101710121316161113131F141218121515170E1212
19100B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000010000030A0D0A1210141B131C21251F2F34332F32373D3C473E
3B443F383A4A4045434A3B4444474A564A493A3A2F3930343138282A2D1C222D26222530
2E281E281C232618191C27282D222C242B2E182C2D2C242E363C3648433F3E32393C4835
3738393E303E353133334C30374E413E4D4D43493E40373F553E3E3B243F2A41415C5E5C
594E4A4C536564625A5B586B7B616467636065535E585753664B5549525C76605A595264
3E585D53675B5E414F45433C49524648454E5341483B494A4B4955515656384F6457756D
5E5D435E603D47433A523B3F3A394928263018232618201B0417161C0319080E06161707
18051903100A0A0C0C0C0C030008000002000000000305000A0A16241D2C1B28372F324C
37484B50495A5248685859606262645C6F6B545A57655F563E61465356494B484C3A3B23
383A2B2C1B29271C1B0B1B0E1E1B0B28151628101A1B1C1E1E2123171A18231C1A251C1E
1D1B2120291C262D262D2A332C2536242A2F1C222C2F302C232D201E272C22271C0F0E0E
0E101713151616131113121711121414091517180C16171B26161E1518110D1116171B14
140F0F000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000050506070C12170D151822222026262B2E3230323835373B
36463F413C48404A4A404F3A423D534C51463D3D4A443B3D494831292A272A2E2B2E272F
23192C1E23323C2C172F262423261F2F272D1F163327222B312E3D423A48393B48322C3F
412F373A3B354042382F2D31333747453C48453948473A554E483B33332436323847524B
5C506E576D5A6A655B626F7268756B7567566656594B4C5B5B5F46554D5946585F52623A
5D5C5C575860514C4935453C3C433F3E484652533B4A43494F5C424D4B4B5B6554495050
536A6854453E494D3D3D464D5146373439302B2733101118120F1B0E1B2115061E1F2013
1116120600011313061707070A111B090B000502020000000A03161E1C111412200E2426
304247364E49545C544A50554D4E4C5B5B58655B565B60605E5D574D565C5F5F52553E37
422F3E37351C261C221214101312200F1F1C261D1C19191D1E1D13181A1C191A241C1320
261A1C2D212A1E2022202C2C2E2A2D2F2D302B2A2E2E2D28222120282226191C1D1A1B19
1C170213160D0E1416131015110C151517191113140F1614121714161A16140B14171111
19110A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000006040A0B080A0B1B15171F1B1D1F222C3333313038353F37
3C3B3C38453B3B3C464254494D4E424F41474D4C4A4343454B4131262C122B3B3239202A
13251629413C2A332C2D291F1714212122291D222325352A2F27333A3A353A3C3133343E
363D3A3D3D2F2A342C3F3337383C4935413E434C4941533C444C3332293625402F3B4B4E
554E4D4B5060555B63707265656378746A656570445E645267616054644A616666565E68
574D544D4D60644858454E444F3A463E3E4141484D484E464B6035475C4E575863506156
5B61624E5C5243485830563A4F4432301F1F392C2116141A051A1F1F2213030A120D1D1E
111B0C06070601070A00000A0B00070503030400000000000000040801081C261B16222E
254C383E42364C4A4D4A5541394E52535559455F6551675362555B545B50674D544C4E3C
343B3B2E312B28221B1B160F1D14201413201E171F1A1E1F1A231C2218111C1F1B222C23
1A1B101315211A2A25152F2A211E312E323425312D272728241F2228251A2B23261C231E
120F100E0F10110F090F16130C1219150F19171114151318160F18141A141B110F151011
130E0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000010403040E0F15141213171B2117291D2A2D2D32332D313237
43444741423C3946424D4B3D4C4D4749584356525058424D4C46362E2A3D2B3B372B2126
17102E2D2E33342C251E211B1F181524292C1E2534202128362E1B1B373134352D342C3B
4037412A254037352B2A463B2A322D4036434E3B543A37573E4636373A333C33413D4747
3C324252435C5061586A666967685B63656069646E5E5E665859594E4B4E57505C68525A
453E495C544B474A5E585C464B363A484633254952503F58584B5443413E5054515B5649
434048514C3E5143323B3D3D3B4130373930442B20221A17211C0A081E2113171B121515
1D09060005001500080A04030200070004000000000300000007000E070813130D1D241E
2B1F382C38393F3E433C42483A585849524A566C59485452544F545A5C5F5E615E585648
4F433334383F26242117181C1A121A2114171F12271E1F1E2027221E1913171E251E1A18
1D2122152823222325143428342428282C322A2C29252528282831262824172518202317
1112161E140E09110809160B140D1511120D140C16171A1A131A1B1814100E1218120D0B
0D100F000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000030308030405150E0F0B1226191F1D272A2D282B3232303546
393F3636413A4644523943493B474E4A4B545B4E4D555D4F5748353A223031303A2E3526
312126173B382B2E2A211F28331A1921313227212A1F1720170F302735362E3439352F31
3038392A322C31332E302E4A2E3B1D383A2A4448483E3A3C424F47475238503B350E3F49
542D454044425C4F635D5A756854645A5F6C5A627174715C545D5C5C4E5D46535B3F5C66
545C5A464B394C5C73365B5B363753594E5035395132534E60463645374642485F696746
4C3F4E4F35384D5440283635483B3A362C2D252C3730011B171D1F1E110F131A15152021
2008120F14180E060F000900000002000000020008000000000806050F0907010E211C0D
0F19272B293D25394B3F494350485559475B594E674F4D60645A595E525C626467504C44
48544E3C3032282D37261F231911162113181E1916141311100E1F1C1A231B161A191618
1D3320181813202E1223212224322C203627302A2621261A2829301F202130161F1C201D
16181E1812150F0E1515091112100F190E151B111717141321131A16141B1C1313151012
0F0E09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000020305040C0B120E17181C1D1A1E161D23273128212B2D2F2F
393B3335403E4244474347544B52463F4B4B59504C56454D554642362E43323B423A372D
2D1630313230223024282B1A24211712232B3B281A1E1524221A1E332930312F39273130
3B403C2E3237303A31473E342D391E1A2A3D3B3D46384A42434E50535A4F4F2B43004642
46515449534B46445C5063696B6969755E6A566D6859596C5B465D4D4F605F4C475A5A54
6754533B404E5B5B534F46453D514B5940404B54485248524A454E25492F49574E5C4444
5B403E2D514E4E35523431424B335141413C3F322D3524162B151E1A241925110A121C14
1A180C07070D000000000002000000080500000001000000000000000002090D08051509
191911281C2437353D3A50554E3C4C464D4E585B4F52575B5952575B5A5755515F694B53
4A4C3E453035432E2D41332834192219111B2109191E1318231B231C251C1B0921191623
292A161A1522221B181D251E23322925332A2E2B3328272831263129271F252628161E1C
261F1C13141510160A0A14140B18151111171517160D1919131818151B19172016141712
100F12000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000030506080C0B1810161D101F201C21252320202923302C3A
3A3C373E4438444C45575149453A4F3D454A4C46464B3748554D46424048494237443127
221A222931232D202523142727191E171F162C212524202A2B292B242C2528202A282C39
3E3D313B4928263433353A343C2A24323537483E3F533B4A4846525C563B3D41412B493E
4B3438354E414E55464B675B5C5D5B5B6E5E576B5F695A6C635564594E56654B474F5E50
456C655F664D3F4E674E5C4F4B3B4150474C41534E402D433E3845393A4A3D4E5C565050
4543443431433B4539463638304558403E3D2838392325110F121B14131A121915132212
1E14130D1B000000020000000000000000010E0012000000000000040009000007030C15
161F1D161D1D24202D273B55414C4F4937564B5C595367555C5C5A5954575C4E61436353
504D503D3C323E313730341F1F241820221D1F1818121D1B0D0B2A15161015142112230D
261C1D210E12211C0E1E1E211F2C21222133202F2A272C1C2C28251D29232B21201C2B23
27251F2617171A15160D120E0D0F14131510140C1714140F1718121C18161B191416130F
120B0E000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000010604060E0B0F17101015101318232227201F1E2824272427
3137343D3D4044434B4B4D3D464B46585246474A464854424B4D534E4C464A4D484B363B
3A2D29322F2F24241F28281F1829281D271924312323342B24181919211E241F242A2925
322C39413B2F2F34293B363A2A37393B39303F423B20514753415347464B48373A352F3A
39353C4C5733443F574E564F705B505965756654755C625C63636071525760505C625B53
51554A4B57594A534F58465A423B5352514838413932383C5545413C504F553C48414042
4346454642443F3B3542393653473D424747442F33271D1E3A230D030D03141A202B302E
2A210F18170D110B0000000000000000000100000000000000000000000400000000060F
0A0F110D1F0C1A132021273838354A45434F534F4D564A5D5454595B514B433C4E555257
665D5D4B535043362726312C272F23301E1A0E2011120E1A11161A10211C1F1817201E16
241A26272812241D2A281E191D161F29241720292821222332302B292D2B2B2A2E2D251E
211F211A1F1A211D191714100E130D0D0F0E13121A170F1E1B1B1B15181C1816170F0E14
120C07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000020608100B0C0E11181E1716181C1F251B2024201A30292C
342A3135373B3B3E434848504B464D49514D514A524D554B595E556A4B5750474F4D3E3D
2F372D45413838312E2F1E24301718242A161627212A0D25231F29141D0E191E2A232022
2B2634313141323B37323F313C3E3C3C33324B363C44343C352D3C392B44492E3E303A38
3539303A423A444F4F5C4D405F69635E5A618050565754695E52675F72555860555E5368
68545546584A4E584C515659505A4F435B3E38383B4B362C324C433D46524B4C514E3947
444C4E52534452494336324A384E2C41384346462F2D3225112B11081115261811243C37
2E303B1F1E0D0D1115000000000000000000000000000000050600000000010500050003
0B0303040C14131D242723233E3C4C463B43433C494D65535E465351525A585045495050
4851635B4F4236453C30272A32372D28261D1E11190E19061503191B14131F2016202A19
1A33161A211E171C2E2A22221E1B1C19272C1C18181C24222A2F30312D2B282A2E27261F
1718101A1B1F221F1D1A191A18120F10171A190A161316131512121A1C161A1517111410
0D1009000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000100000509010A0B1011161717191D1E1D1D1E2C22211E2E202525
272A25343039364748494D3D42474E51475352545746504D52545F59534F484A4F4D4F40
524642464638392E272325262E2C351C2C2117152C29201C2124171221131E1A222C2221
261B3B3C392F453535453A5340473E344A423E3C41362E312F25413F3E46563F4524343C
4D34503B41543B443633523953525B495C4A735C63625E6E716C6B575657505D5D4A4245
4B515054634B5C515D5B656F53505A46424B4C404346534B43494B464B484C4B4E393E41
4548515246483E3A41384A3E5346544D4B4B4041442545220A060D081A1014243137473F
44484B2A231D2B1611030C03000000000000000000000000050001000B00080008000006
000804090010160F2616291B24374D3F4B524339516147484C524F54525F5D4A41503D4A
535B514F4946464A45382F3A43393132291B1F1C171716141D151022160C0513181A111C
251725192829241D15282D2E122B181A25181E1A1A211E251F24222B262E2129302B2223
1B1E241B201F251C1E191A271414090B0E111413120F160C181714171F1D1C1411191415
110B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000020006030B0A0B121412121D1C161722181B22191E251D232128
26302B27322F364746434A3A3D454E55465C574B4B524C484A57575949485054555D545C
52563F55423A2D3C32383421292926232A231D1A18161D181B2922261A2322212319222C
282E39322F383541393E495148383E3B3F2C35352A3931352B302D2E2F43423C422C1D38
34363239534B4731403F344451424459544F555F6C704B63656877726C626558684E604A
544B755A5245683D6465576958606756554A605344433F54424E354B473C524E4143473E
3D5D5346403F37463D544A2E4C43313C3E46402933282F251515060A1C142D1C2F545354
4F4F4E5039351721121B0D00000600000000000600000008000007050808000904000006
0600000A120D0C0D0E261A0F2532342E3F3A4B41424142414D44544D4756424B4B4D4C57
52575E56614F4D4B4744392D28372A243C13291817191F0114140D201317201516191A13
1F281922181C1E262322171C1D1A1E1A1A1922191C19161F2A191B1F2E352E2B29282A25
1E281F1820181D21231C181215111A0D161611130C11100F170F1113131A16131614150E
150910000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000003060505080F0A1313161E151B20161A1A21221D241E211B26
272A2D283235353D3C44403F3F3D4F4B54554A53543F4D5351555B4C5351504A554E554F
5B57574E50493F334738282B2A27322818212326291B241D261D2622212A1E1E2331252B
182718372D2E40474249453A30363F312E3C353C323130212C1B2C2D2E27444138354239
363D483A3C3F462A3B585242504457394646555659525F595D566F75636968745748545F
5458535168654C5A665E55525B47695C49595155374D444F3B5455413947455B354B5541
533B5A504146372D3D4549515C543A424D59574C59473A283B171613100F202844385A53
4E576257574734221B160A0D0A0000000000000000000000000000140300000400000009
05080C05000A0703190D192429212535173E39473E4944444A604559495457425A424152
4950555A5446555A414834342A3238372F201C261A250E1E12182214170E0F1D1D111A19
201A1D2629282B1F23261F2018171A041918231B0E1514191F22292B29222F2F30272D30
231E211A291F211E1F1B16181315171C18171D0F12161214181712141D1213171618120D
0E140D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000205050608100A0D0C1618161A141D1D24221F281E28232926
22182322282D302A353B46434B414E54515054414752454C5755535250494B534E594E4E
55564A41524F5046382839302E2927242C1E202020221B1E27331E35232A2A1B28251D1E
231E3117283633363637322D3A2B23303525404432272E3027212A2637342F443D434046
482E33323D45474C4D38463C423637413E434243405D676B4E63515C696D5D4D655F5A51
6654685E5F56675252674C51575A545159455D46395A54464B454237494A524A40434C30
4E50504E3B433F444C584A4A4750614B50485D44423F57362F2421180E1E3323444E5A67
67677065594B481C28172B1511020000000000000000000000000000000000000D000314
0F060D0C0614030906121A0B1A101F1A221D403B313D4047544753405756474756525352
495058494D42514B4646363D3F393D452A372E1D231922221319190C1507111518190E0B
1B161C111A1A1E2A1E22182417212123231F151D1F2009202121202C2C34252F2E2D2821
22291D221F1D1E1E15211A1B18241B1F1B1A1B110E120E0D120E15181215171916120A11
130909000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000605030707090F0C131319161A1A2020232028262522231E1D
1B261B24222E282F463436434F50554C49563B445F50505144544F5C4F5755574A4A555C
4C52585644413F473A3830283C322831381C282D1B191D1B17241D25221E221410242A17
1A2E221F20293935373B352F2C262831362F4244324153242B3242323E3B4641384C5549
2C293745494C323D432D3F2F463A4353494634405048595E6069695B6D5E5B686B705E5D
5A564D5854545E5856584F525D5F49565540494845515C564B4945434B375835504D5341
364251453D3541374950404B56534C555256665C554C574C36323330362C273A3D464F4A
666374695B5B4B4D303022290C161800000007000000000000000200000307050C000600
0A0503000604040A0411141218100E162329303140444C4442444C3E534F4E494E495D57
603F535F61584F55483F4140473A47484339352F2A23211D1F1D0D0C14150E1B230A101B
1703201D192325171E1F251A1D261B1D29241D221612160A1718291823281E232A282A26
291E1B1D251E1A161A1B1A1C1710231F120D131B17101311110F141317101314140E1410
120D03000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010100050A0403050C120E131A101E1721221C1C1A271E26222025
212C262628292B28323D46434845524A444D3F504947484348495D554D53595256525159
6259484D4950504C4D3F452E353D3C26302C3622231A2A232D27161A1D2526191E23262A
3114202D1F2B2E342E152C21372D19202B243C2E48394142393438373049383851474545
2E412B453D383A433652313E34484C3D3F3C39312B534E66645555516359665A564D6D67
505E525F4B59616252524C595A525D6059566243454760465C4B3A30342F46324A3D4E4A
4F49453E454C434D4641462D52384A535E58585B484B4D50393D3C42412C2A273E444A50
5A5E66546C5C5D5A5B363116280908131104000000000000000000000B000A0400000308
0D090A0200010E0E0802120E0D110924151D2028283B2F47434F40504B404746545C4C53
5D575F3E5E5B4E4B404D4B3E534D463F4844343B342E311D201614210D080D1801101516
14140C20231B1D201A2A1A201E1C2C2623292C231E1519110F191D1D242523271D292425
222B25241E22221D2D222420171619181E1F151B160A1913151712151C1C181E1A11190D
0F0D05000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000010201090206070D0F17191A1915202322211618181C1E251B
1C20162627232834392E373F4549484743494B4A595E5445484D505F584552555A534E5D
4A4D4A4A655E52535055443A46302A32322932282C2D26250A1C1E1D1F2B221B24291724
2721312D1A2827233A28263931282D283A353E464A485C36263D382E2E3F31422A483536
36483533384D3D4A3E3C402F3031393D483D464C41434E4D614258524F647C5E5969595F
5D5B645F6D58636461555453546672646C5E564E5E5147464A4F444436403B535242313A
4F503F3D3C3F4E3F4D47574750655A454C505B5A4D314D4F5649524F414E3A2B3A3F465B
6A6B6F6967724F6F664F49413A2A1B201B0D0A0600000000000000000000000002000303
10070604070204000F0200000D071110170C2E191F3A393934344A384F45404E56425754
4D4E57445548524D57445953504D62584242423E2D3A312623192215121505230E10170A
0D190E16181C21171E1D2325213D2732301C1F1E1D1D190E1C1815151E1B2622201E2D32
27252F2E2D231F251F1D1E221C1A141A111514111A151B1B1718171A1412151B1217190D
0D0B07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000010006060208080F091410191F1B19241E1E1D1C26271C2021
272527282B1C2B2B32353C39464444423E4444474D5D50524141443B4B50625F5E535E55
564C524F5B5652534D5343533E423832302B4A2B36292E1823221D1B2C252C2A19272B2E
2D1C2A2B19261C1A1B2C2B20241A24262E3539364D485A35543C3E343F34403E373B4340
3447453A42354F4945312F303A294A4F3D49523737423D3D4C374A4D4962695F54625C55
5C5C574B6362685F5E60525E5F4E795A655257614F665756434C5455324A3F3E584D394F
4B4B38524A434B5C46524C4848456075525354575747514C85646B6B60453D3A3B2A3D47
5748696669656E555E5B484D3E301F3B221C081300000000000000000000080B00000002
040100060500040C06000000020703041610061A16242535333A3E2D313744514F454946
4D4F55464D583E564547464E585D555552593A444343392F331F191B201E241813130E09
19110B10151519121B082627312935301E24321F201B181C23201019121C211E2C202A35
262B2C292824291A1D1D171F1D1B1D1D1519141D17171818161617181D1E191B18110D0E
0B1109000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000001020106090708100D0B1110141A131E1D241E22221A282B251C
1D241E232B272A272F26323C394039433D4A4B445747474B52524B45534C5C595D515E5A
515751515F5E59534D55574E4442454743333238332332183229212F201B20291E33241C
2027201A1E3324261B1A1B2427262A2D2A2D382C3935434C4D4A4438313D2938353B4941
3C4147434A2D47503D3B3E452D3C3A442C342E303238424B30464F3B41465B5269595F68
605763676873616F4E5D6362576E715F62684F4B504C57595C53463C4E4D59565041524B
47444856514D2E3D43603D56563C5653595667514D50545466747A60564F563F3C463E41
625F5B5363616764586B636258423B292E1B241804080000000000000000000001030913
00050600010308000F000000000302050708120C1B1E24282E26343739403E48414A4E46
53525C5E5646504F46515C5852685B4F52505145443A3E332D20151B17161715150E0B12
0E1217110F16130E231910221F1C252B29191D231B1D2121221813151E1F29292225341F
2F28362923262128231A1818211F2022171919131B25201D191716191D1519141B0F0A0E
0F0C00000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000020307040C0905090A0D0F100E1D1D1E19211D191B1E1B212326
191F2D2B24232C2C252E343931404940343F4F40414A4845454A504855494A4A58585852
4A444C5E514D584E534E4E555447543A40463D2330383C36312C2F1F28192F252A27272E
161B24291F2E1D1C271129201C27271830272F2836423F454142543A432D23312926532C
48394A41313855384443342B2F332C2A3F30304734252C28533353434C5B48525452584B
624C6568536671686E526E516A66637B645D6D445C495F48486462483E555B4A544E474A
5562394553475349344A4F3F513E503D454D3F63455C5871545A78644D5B5C4B53494650
4E68625D5F54685362696F6552424E4233212B0E06170500040000000000000000020002
000007010501000007020A0005030101010A04090D13172C1227242D302F2C403A35424C
4E4D4E41494F434D524B5B6052565C4E556253454A434334382A281C250F13211B211F14
0F17130617110B271514121A191F1E2B151C24232925251B1D221A1A161F1E201F202627
1F2926233128241932222724251818201A0F1C16221F1E1E1D1B19141315121611160D0A
090E07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000020307060909090D1013131319181F2620211C1D1B18191F1C
2A1B2920241C242B28272534322B283634433F3C4E434F424F4639505F4E4A545A5C574B
5C504F5260505B53544955544F5355403F4A36323E403E372B2B2D2A2127331735202B2D
22243324171C222420182516231B2222372E382A2F323E32273E34362C2D2F2947364535
383B4740413F48533F43504A2D43414B2D434339344035382D433F4948314A4D5A585559
5454703E60607A6E7D6A61786C6863796F5E63666B5F54564B514D68576553634B49504E
4937403E3B453F42615D5842434D413F483C564765493E585F576751765F58465B675B5B
5D5F5B67686461746F716766674A54573B37212A230E18220E0700040000040000060800
0D000D0100000000040104000801020807021A0A060F0A1D2514221F282730332D413E40
454B524B63474A6C553D4D45454A5258584E59654E524142422B3B221F1C1E1D221F1716
121B10181E1C131E1A181A151E1D212720261F222522242522171E21191022222722172B
1E2425182029252F2824282119201B19221C181C1A15181B1E1C1A1B1D171A150D100C05
0A0900000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000030707090D050A0D06100D13181A1B211B1F211D2121221C1E
1E1E262A2125212D1C2421232D2A342F33313A44463F424536493E454348515748555656
515D66565859554D4A585B59685A52424B44443C493D434941352B2334301F3B1F24281D
31271B2224232A29171F191B2A1E1A2F372D302A29273F373E403F2E3B2F363937324548
493044333F2C3C4148444B41443D47444E45404A414D38303C42484640274F4E535D6057
595A486E606A6561665F73716F617D6B685A5A536167756547574550694F5B505A505C53
4A585A59513C525844424949413237363734454D455C58636D6E5F695A68704D5C556866
5F50696A627A5D716C716E625550534E3B3A412C281F121B171900040200040000000100
0000040000090001050F00000A001108090C000001111910150B230F132E2B2836363438
3F4B534E4F404E4E51564153444E41526059504858594F443C3B362A373B2B232A161429
2419111C161D151021110A161E121D0E1C1811223327242212251B1E22221A1B23211D16
211C1D2027272229261B221F26171D2111181C1E18151B201B18141B1E1311140E150D10
0C0906000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000020001050607090D110E0F11181C23211D21202523291D1C2724
25271F1C1924261A2E272627251D2D29262F3D31343D5140373743464B514A5150525051
47565861535B4B504E474E495E5D5D614E56503F37414436452D3D4732272E2A272A2D2C
311A28302F1F1D22220E180B271F1A211A1E2D2221211D44352D2F4039343936413C373A
362F3B3B47453A454A4847524C514A5D44644436463C45523B423F304F524C545C655F60
4C5366556B5F6658556F6A6578656A655B615A6A6E5C5F51514C5645495A6469585E5854
64554E4D3B51524F5247527A444246354B3A584B4C6A5145525C6F5B6A6D605866596D7A
6E7864657B6C6F6D7D595D5F6158524C5955434B46302C2116120305020C000105000000
000000000A0400070D0011100000051404030100040A00000F0016132127202828374C2F
4A4A414449323D454E4C4546364B563F4D4E57554A4C5E4A4A3F3B3A35313123272E2924
211B1A0F1009100914160C172210101C0F1324161D1A241C1D0D221920212724231B2519
161E251C2322202B2A272424301E1D231D191719171A221519191D1A1D16130E150C0D09
040703000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000104090508070F0B0D0D1117141D1C1C211F1F1F23252520231E
1C272617222923202B1F25241F20273239302E2A383143334347394B4B53524847455F51
655A584A664E4B4F505D535655595853545A50534B3F4D424039473F3039323037222F21
2313271C2F26182824080E25131C3123282E1B29203839323D2F3A2C39412D3D323A3B38
3A4E2D46424541434F3C3D3748463E48453546394D4A42482F37343640293D4E4F504C54
606672526D5B6A6A67616A6470696A5A5A7062576B6B7763575B5D5D6D6248514751584F
5B5A4E464C44423D505753425146324432474E50494A584E4259645F777C7B63585E5977
7169727781576F636967716665615651595951494C4E281F3320200F11040D0302000000
000003000000000304000000000C0A010900080306051700060D05110E2018252C2A2443
3C3657414D4A4D434948504A4356393C4954494554534852554B473A442F291E33281A2D
302613111C100E1905070D100D1C1B1522131A14231A201C252020212A1C192624262123
20201D241D28212B2521262123211F281B22181A1C161D131F1D1A13191310140E120308
060001000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000506040B0D0B0809140F0F191A1A23232024262B2728172025
2126241E2B24252A252727241C24272B2430222028281C412F3B3C3D43443F4A4B394053
4E575B515C525A5F5A5A5C615F5E5052535948494A49424238523C3D373D362C21352F3B
193532272D2216211E1F27132828211833211F2E26292531343A28393E503A3B44463E45
49402D4631443934392C462E334C453E3E344838333C212E362A433F393C3C4B4B474563
5E625B4B605B57685764766764736A7D415D5D83615362574B5C475F534B5241514F3C5B
3D5E5D464540675B51594A4343555546444F5F49405C5B584D4C6B7571746A645E5E6E6E
697A59727455737060685F526B59575364555F55383A423238262225231C24210E181007
0000000000091400000000000000000008000300020D00000005140C14121B251A2D3845
3337515138404F3C5B41424C434A413B4A565E3A504D53465E464B3746412F283B27362B
1D191B1B181D1915090B0F090D1219150B181A0B1E122C17231E17211E181D241E202728
271B201D1E25202224261B342424231F17291B1C131D1615191919150F13160D0D0C0602
010100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000202080807090B0D1115141518221F1D262D2426282C25242829
2224202821212126292124281D23221E2C34292523242726303D3C404D3E4D3F41464B46
505F545A5A5858595B464C4C4E6159565B6B605B56555450454D3E3F3242463E3B373130
28212729242E2020212E2C1E1D2322211F1C242D322B273B3B40263C3D33433B41344038
3F36403D4D3F3A322F40413C3733313A343B4243344D25373C3D2F3941444A343C47413F
585F5F54634561644E636576716978676F6B6057695B6D63546D715A5D5458475846695E
473E444F4D49624F4E4B585C5B464C474E374A3B464458564E5C7E607F6E7C656A62576E
7E7666575D6B83717474696663585C5C54585E5636434535353F3D423C3421261E060300
00000003081000080107000000000B030A0002000000000000040F0B0D0920100D1F2321
2B3C4E4A424649513F3B42354B4B4F5051474D385039524E4D534D494235423334382E35
332A19241A12151617071F130C111D17120F1A140E0F252B202419232D2A22242C272C21
251E1E152624281F2E292928221F29201F1C221A16181C1917211D18120F0F1010090408
0A0100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000106030A080A09091210161A1B23181C202A3427342B2B222619
242A2220271F1F292C2D2A1F241D1F242C243529292026282C323B393D423A3A443A464F
4753474D524C5850585655585A595E646D60665F5C5854524E38554C40403D2F38322C2C
4B2832202A23241622251F262610131E201A2B36283E332F3D3B393833293328324D3238
3A313C362C2D292C3A3342393E3449383E3143333E344242393A3B3F30332D312D363536
5052645A686A596B5D776E5E74697B72705B707166847359565A5A495A525C575C435951
4759524A574342535C534E524558392F37425235504F393E5E5F6D5D775A656A6E6D6E6B
6E657F5F72706B6C61585966614F6359634C445555434D3F4631542F4228361719121101
0000000002040000000000000000000000000003000500000207000E050B000705101C17
1B213A434C393E3E4245384D4751555140565A4F404E52485047504C42483736392D3927
2F2E29372411200A190D110D151A0B17130A070A150F18241F2512231F20262728202322
271C191E221D252323282134201E272A25291C1D1F1B1314121E221B1113100E0C0C0707
030502000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010305070A12100A12161417131C1A1F23242F31323D3C31252723
1B2A21292B19242127261F262324241D1E271B232320282B2E3233333B34343D40434F41
4C4F505D5F565D5054544555555C6D604D566065566048463F5D48494C47423236283633
3B314120363522202E2929212A2A0A1E251A0F25302C2635252E2E2C343C31393E37371C
372133372C303C282E413D3D353A353C34402E3B5C56523630344438283651414C3D4B3D
405256615B59625E6063836D5D5F687B6A746B72736970646B6767696C44475D67625A5B
583F4A4B515F584B654D51545D4F4B544C54523B3F3C4F4F656B79605C5A5C4F626A6678
7060525B5657505A6F626C635F66685C466C4F3B4F3D3649354A433C2E3936372A151203
00000000000608070E050000000600000000000000000000000000000C0110040004240C
1D14272E3E3E323A48494F424F4C4E4B4F49463D47424D5C505645475344463836393D2B
38372821172C1B08120D141514091A18141212040D12150F21171918161F1A261A292F28
1F1D181B13232B261D23251F1E2829241F1920171A1D1B1513191B25160D1107070E0704
060100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000040605080E10161918141C161F1C27212B343343494437302328
2421232F221E26252F302A24242B231C2F2B2E2B271C29291533212B282C332B303F464E
5356526E4E5651495B415C535D615B564E565660626365565A52564352474A4D4E44433E
36362D2E2F242C361E2E2E2524151A1F2B23262A173B252335182B2F2A36352E2C3F3932
4730362F39453626363A433C2A283F433D4134543E4542353A43434745282E2F38362D2F
465B584A615058674F626C5E5A5C7B6D706C6B5F766F717176626B5D5B535E525E59655B
53435758474E5D53655E5048505054443E424659573F55425356696B6059646B69668778
6C5C5E50475E626E616658595F5B5359434D45496043433D314C462E3D3F41312A2B1E0A
040000000000000000000000000000000000000000000000000000020000020903000911
131B2F242A36351C313B41404A515D674B594A414D504146554360594F4C4D3653463E43
322F30313123231E1F131A0A1D140C0D0F05130F1111121917121A2527161E2426202926
252511201E221C282127251D1D1A29232621181A1916121713191E17111512120D0A0603
060602000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010105040B090A0E1318181F1B1E2323292A3C484B4C4D41362428
2D20301F232023282927282A282B222625231A1E301C2A292B1E21242B2A273D2F3B4242
55405B554E45555E5850565C5B505C4B53535F444F555B50614855484E5B62492F38443B
3C4542382B2F2E2A3A1F2528222816132619221B39332833362F35233C31343E43333F44
32352A42412B2735364849413E373F323E3438414F595744443E41453A353A4337484D2A
3D4758444B3C5851455F706674646F7282796B6F715F7367626D6D686168545C705B6E66
69565F525751535459646E4F55404B5149586B595C535055625B60716756686464778182
756252555964616783695F4E6F5D4B524B5F564443354633393A4C48382B353E3425201B
00050000000000000004040000000000050000000000000000000000010100010000080A
09211C1F2C2322283D3539444A414C3E4555473F4B584D52414752525A4353484E48403C
43444637332D1C241A210E19120812141019150F0B0A111C19131F1C272E1D161C1A2917
1E2027242329251E211C1F2722252420232822181A1D171A15201D161411150B0E050706
050104000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010000000002050A080F0F0E152017171921252B282C3B43524B524C36302A
2E2A2A2B282A2730332C2F2D2424242F2716392F2821202C2B262B1C212C292C292B3939
3E3B4D4B42534B4A524E505C4F4C5651534D59566956515F595A585A594E3D4E58434A43
3C2B4136332A372E2C213226271F201F222B201F1A30382330272D30382335362D404637
39302C2A2D3C343940484D463C3C34272F3B4038584F4F493C43532A4A3F43444F373728
44483531443D4F4F4D5A715C5E58727177807C58616F656A6D6468626A716E4F695B556D
55664B736F3D655F5864635D645642495B5751676148475E586777564F60745B72838D8A
786E664E5E5A586B6F5E626E5C3747555B47574B4466503E3E3F42314F37323327262A20
232B00000000000006020500000000000009000000000000000000000000070000000103
12091317081B25262C362D384243485543534C4245434B4F42474B534F51544940474954
4B463A412C4029282E2C2C1616130F071D180E120D0F171417180D1F15141F18151A0D10
201D22221A1D22202422221C1E231D271A16211B1C1A1B17181D1D151314100E0E110703
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000008080C110B1511141E191A1B252226304242534F50473D352C
262A271C202328242429252A272F1F302230303D272B212A2B252B1F212423353E382738
3740415D405248574F514E4C525E5E6354584D5961536149715E57684A605E4F41653F47
49423743313629383639383F0E231A1F1D261A362F28243730352C2F2A2B33392E3C4336
36363E302A383F3C344552465C42343422373346373E3B3A41473D4A4244434F3D44403D
482D4D29475349475860616D68715D6D746B6778735D597474657170785C685F554F5366
525D5F636369607458605C58445966605D5B5365614658576A4A6E61644D568083869CA3
9B78626C654B505A605B57465664544D5A574B42434D3F5138425146343F373E322E3B29
2A281D08060E01000704000001000000000000000000000000000000000000000000000A
0D15110E1C1B2522243332372E33384144354A434451494A4E4D4445434B504F4553464B
6446484A433D32342C3638250E12251A1F1A1C16110C0C0F180B1A0817160E111215111F
151F2B2427221F21261C16231D1C1B261D201C1E1D24161F151919171013180C120B0C00
050200000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000805090B101213131C2020182022262B40515757575641352F
2C312B2A2C24242828212C2F28232F2A35273022241E2A2C252B222D202E2D1F2A2F252F
4531354B4D4D495154473F4760516261585562575B63635B575B5A5F535557385A5A584C
54514D2D3B2F3A33271728312515172518213A2F3228242A3129353841222B1432302B32
2A21453E393C32393D3C41435747323A4B3B3242413739452A3D573D3B445C423C474732
3F3B3945324A5257675B6554506A5B5A756F6C78626E7E5976767D7D705D64665A5B6A4D
6A5960676B6D5D495D4D47535F6650637A575C65596C4554595C554D56625A656480727E
69726E76815C655D5149414E615067564E3F494A565347454847412F55432E36282D2541
323D1F081308130F09000000000000000000000000000000000000000000000000000201
0E00160B14161F103429222537382F45533F44514D4848414F444C43504A43463A425156
4A57454933344040412D2B2C2312261D251915121915101309061307160E1818181C1718
1F191F282321200E1D2421202320221F231B222417171920221C11190F1113110C0B1003
040000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000108070B0B121218141919181E1F1F29303F4D535A534A3F393A
2F26302C24302723282C2726302E1E2C38352D2922252824292A312E292C2A342C2A3A29
313F33454B553F48464D4441405C5150575D51575B535A526372685C606353515A575D5F
453F3D413F392F403A33312A3F20312516162530221E262B2732313D4234172728311D20
2C28382D3F44513F47433F4C423742353D423637323F36353A48424A5339413A55514D4A
4B3E393D32404A414F68595A616361646655716A5C75697F6F77717B706B635A605E5D5D
5B6F6268725C556C5E46435B586C6A5D5E6C736D5E576A715E59605F5069747973716279
525B5965726E5F5E666A5A4B4C5E594B5444424A563F465B405E382E2E3621453D374945
3F373E2613140914170C0100000000000000000000000000000000000000000200050007
0A00190C0A0E0B1B182825332F323836364D494142484E565048443F4856514648524D5C
42494A403F413F483B3F3C2E2E2A3421271F271B151F11150D1A0C1409080F1316181B10
231D19162523171E191B2A171D2321222A2122122320171D1B1819121319130D0E090901
050500000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000003060A0F12131611121F1C1E191D2A2C2D3B4A515A5A534C403B
2E312F2D312920292D181E2122242D2621312220342A282C302F2D282D2D3028282A2B3A
25403745362D383F4D5040443C4B56504E544345545457635B4E5A60546E58634F575C6F
68564D453F33343F434631341F2C29302B2426311E241D112A3639402A3A3A1C2D2B2B21
161B2D2E2E443E373F2F3B4535493B393D453F3F2C33292F3B404E5C3B4936393642393A
363A2D302F42534A4F635D515D5A40574C715A6B6B65796F6F7654707671787471646F5E
64635E60546062625A575E4F5E6C6673746368705A64615B7E7A5F565B6B747A70674B4B
3638525B796F7A4C4A5F726D564E5D40444F5D4440454D44464D413D3C243F45314A464E
49433E402B241A0220080900000000020000000000010000000000000000000000000000
0205040305070E1A25202634351C2E3B353E3E3E4A4C534A4445435746485242474E574A
4456504446484B3C363640373234254332231920191217021A18170C070E071B0A111B27
27151E17171D17211115191D1D1A201C191E211C1A1E1D201B1D181A150E10090E0B060A
070100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000208080A0C12121314191D191C1A21242B374355515D4E4D3F34
3235262D322B26242D232821222B281F281B2B24292B2B30272829322A372E342A352D30
232624332F4C2B3441403E383B494A4A58606165625159665C605C6459535A6861565254
65595251473E3B33494135343E2B39342D1D2C1E2B2A3433312F252E222F1C1C23292A2C
0F2F25293435433837414B483C37434C334227351F34233437354D5147473B3B4630292A
363B2D41363044524637423C4D525448465956654F68685C556D817A685075726D6C5052
5D65625C58605E4F5C65634371766668566B647C6E57676C735F6B6065757B745F554746
35443D69647B6F5D59595F5E505A495158643A4D424A3E4C344B3E524038353848474B4E
4748593C3A2F2E181114000200000100000000000000000000000000000001000000000B
0C00000B231402080B1E151B2632232F32333D513C3E4E44465047494848454855453B4A
3E424C593E4C4E44453547372E4441323833241F1D1C16111E140E1503100C0D151D1A19
1D151A20171E1B1916221822232714241C191F191618201A1A191C1710160F150C0A0000
010500000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000104030C0E0E13141A1C1C19171A252429373950515658484434
2F34302E392A322C2229202324282A2F26262B2A2C282129342A2D30312835212B333532
2B2E2C2F36333638373E3A2D393543434F51554B5455675C6E5F57526762606272565352
4C5566676157534B464144403D422F26341C3428212F2133302B383732212D230F2E2621
1D1633212A41393C443E2F3843442F333E3E382B2F2E333939394146444C36443C383F3B
3B2C3C3C3B4F433B3B444E424C3A54415A535259555E5E5A646167737169696F69656760
61615D5F5E56625F5B5F6C5C785F62626C556D6D5B66666E79685254596F68656864584D
414A536B706E5F6064585254585B5A443F404F364E41373145415145374F3A40504A5251
505B4C5E57452F3C242310091100060905070A0000000000000000000000000000000000
00000000020C0A0E06220F14171727222E353642453D4243484C3D43394A3F3A4D45403B
4E434D443E4243453F45442F47393D4C44353023251C22251F241C160B070C020F16171F
201C2117170A161A1619171D1A1F1D1F1B27221C151D1A191C221A1F181209110D080702
030007000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000030B0E0E1215131915171A201F1F252F2D4044485D4D47372F
2728313633292F25281F1F282A28291F25262A2F382B2F261D2F26302B2C2C3032382D36
2C39312C293736322E4A3F3B33464E4B535D534F665F55605F634B595F5C5F6B666D4F59
5863606758605149454249403E443E3F2D3F383C322630373135292F282B2D142B1F2F24
202A1F27272B333B3542434D4746452F342F39332E37432B3A493D444333383950563756
45482F284B444E3C43403F394D5C48525A4C4859534C665B6E686679676B62606974656E
706A3E5B515C6B636054624F67506965756D5661666C65676D5E64605D64606B72756845
4766484A5B725E4E4D5149566049456B3B4B3A453F413131393849524939465639554C57
5A5B61414E3C4A36372D2C0D180D130F1012000B00100000000000000000000000000000
00000A0C00090415101517142026212F272A353E3C3E3742424B3E3C4345333F4B3E4B41
3F3B3748515248513E454640313E3F4444363D2A2C1D281E2C261914110A090A0D0E1211
17180F171413152011211A21181C19181E201E2515171E1A1F191A1610100E0D0D0C0304
0A0101000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010000000401050C0C0C12151415181B1E1D1D19252B2E3A484B515842352D
302D32392A2D3623221C29221F30292A261C292C3330272B26222D2D2A332B2E26342D2E
28253430232524243E3D362349464643504D4A4F50596B6E5B615C554C5660575C655D56
59636C6B5C6750504551413D424E3E473527343B3A281F3629331F31393426312D302527
2522243C30312828442932384B40353334372B2A3429494C2E3327343A4439504C524558
32422B3F493F2D4834483D494F50664B4553343D47594E4F4C67685D5B5F5D64625A637F
755460596264615868775263765A585C655B716B736D7C6C6D5B4E5F646E7677767B565C
4C68585F62474C4931604C4B43555147423D383B45432736254746392A5448544B5D5956
5C454B4D59623A463D2F26322D1912231B1D151510080C05000002000000000100000000
000000000002080F0015141E1D1B1F1F23282B35373C334145403349424F4D474A4E3B40
363841404B404545403B3E333A413A304A472F2731302E25272C1C1B1E130E070D0C0E19
161C191C12171717151C1B231C21201C15202019251A1B171519211C1414120E0C0C0C0C
020505000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000300000003051009140E1615191C1E171D201E1C26303D40484A3F372F
2527282B302B292C1F261923212226333D28292B2B2C2D2D28252632342E202E242C302A
232E252C2333273039383B35363E3E3946374F484F52566B5D5B5853535A5B63616B675E
4A58676971615450525D554D424943363A36282E4735352338232D392C2D311F262D3931
30271A271D1B242E2A372F353F3628222B24282937403C3C40374B40313F2F4052485356
504435313A353E353A373E3F365D4B4B4245464B35504D57574D596B685955616869606F
5A55684D505657676D62665561617374677669575E766F7B71666067685A6D6F72746662
6C546877745C5A4F3E384D504A53424E46403C403F32243B47453F583E44435349605745
534F6A5747535C5B503E392F3C341E232D1A161A0E121D190F0801060000000400000000
000000000000050D1503040A0E271F231D1E313420363A383D364D444E4C3A4E453B454E
3947334F4C49463C4740484C3D3F3437383F3E3D2D2A1C3629231C251D13130E150A0C0F
171214171620221611181919152018181E20111918211A1814131A161115130D10090607
080003000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000010000020003060F0D0B0C121716151B1C2023221A20252B2E39463C342728
262E202B2B1E2B2A29261827222B2A30242C2E2D343135311F3423232D2A322A302D382F
40373C38342E2B312C2D2F343D39393B4349434F5267535A605E595463645B5D58646662
5464625F6A545C505F4B40414A3E3C3941422F423335392B351D26212F132C3B29392A2A
122C131E192A24362429252A2D27371C21293320323423363C2D284041485B5A3E4D4340
364741393D4642452E32434835483F2545414F4C374B3E3C44515150575C4F3C5D4F706A
59694F635C736E6B616B565C5B5E4E525E6A6C6C716175766C776A6B5A5267596B885A56
6F6C7B6A72676556415A574B44414D49443C3A2F3B3723352E4745424A4E3A63574D5C48
4E57526463574F5C4A3C32414038293A1E292A1C26252225152008130E00000000000203
0000000000000901000C0C02091F28121628212F29282F3431403D4E4146524843473D47
423B433A3A433B4E3B473A4A3D2E42414D3C3527352C2D281D1C302F1521161009131115
151D1A131D241C10181B1E1A0A1D17211B17171B1B15180D19191913160C120D0B070B0A
000604000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000200050A0C090A0F0F1517191C1C211B221D242C2C3130333A2930
2922242A29302D32262D2B2323222E2E3235342332322D261E2A251F352E2932332F392F
362F3A2E2933332D3C363F393A443E394557474C4A4E57565F6066515D6263626B6C635C
4D5D5A6069734B53505D555D595A4548463D353B4048444130352D2F353033282332373D
36302329231D3229352C172B342E202324182F18252328332639313F3A5248453643323C
3F4B41394947433F4145434E3A3736424C3A434E3D4D4644464F505851506C595D5A5B5B
6D636A5C495C64546E436052665E53705F666F69676C7269705B6977605F705B60696B78
6F6E6B60785B5A5B514A444E434B45574632343B2F2A2E3334464146403D4F4653465C53
565C3F5352543E47663D3B643F41392D35322F3A32292929283120260A00010B00000000
0001000000000000000604000C0B0702121B2526282C24353B3E373C463A453B4D3A3E49
49363C54534239373E3C3840483A33413B503F4031352E1D262B242D2925201E1C181810
09191918191D0D1D160F15190C1B191C191E141F191614121B140F161312110B0C0D0A04
050600000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000006060A0C0C1313151811161D1D21271B281F28292C262C2B26
1A2023232A2A2E282F271F26242C2235302C33312F242426311A231A2A2E222D3C273036
3D37423A332B24392E394730383D37353A3D3B4148525048536153705951586A6D746A6C
58595667665C546B5F5F556D5C56564C4146483D4F3A40403A3233272F282A3438292430
25252B1729232C282133381F262E26152730273627313C2D2E3123362B5C614546452F3F
404040493E3F4A57473F43454A4157445250414A42504344483F58405A404A5140636668
68665E5D7562526949655F6576565B50745D58605F63636D6C825E6C616B555D66596171
58725973715E4450405D4059445A4D533E302C38253A36313637404158553D4955524162
4E56653F4D44565A4B4C4D4D464B4545463A433235393A382C35372C2918150002000800
000000000000000000040501110D0F140A10111A32272B2A3131283B3D474A3C46453F36
433C3F2A483C3C3435353646373F43374C363340433632242926322630271F23131C140F
190C141316271A171A0F1111151B15171416151C151A16150F0D150F13141518080A0D08
040103000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010005080A0D110F0915141618191B1E221C1D29212A28212D2B27
2026202425292B2C33282D262D27292B2A32302E2F26242D222D2F22212830292F2C2B38
3535342D2832392B32323C352E3D43373E3D2B3C4A46454B4D5960645D726E7068585F66
685A605B6F675661595C585D56695E4E4E504A4B42513A322C40343E2A3A2E392D221C29
26311D212B2B312F422A152D2B1529391C151D27353F444B2C26403F444544484748353B
304A362D314D4E434F513C473351423E523740364E433958393D344C4350494E3E4E5863
55675A613F58645B727363666060515B50735B64585D5C5D5F7D65717A6466696C746554
5163416B50544F4852474F49454E4F5145352F39462F375043472F423F344853434D5657
3C4E55644E4F4557485E54594C3646494D50394A503D49483A4A38282E321B240B041100
00000D000000000004000D0300120811130A2225223A1E29262C32282C3543403F3A4945
3E3A413B42383F3F403A3044434442403E424439312C272B372B262E292A24231B221F17
0E171B181221191410130F141D0E161014151113181619140E1B13161419130E10130804
060300000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000010000030208080E0D0C0D131B1214141C191C1720261D2B221B242824
222826251D27262A26212A2A2123242B26252229252F292727272C25222A28202D293130
342A313722282D39353A313B3836343337353F36445542505F675A566661626B69605D64
5D645A6256635C5E5C617167715F6365464D4A4B4F4E3E504544382E3139213533232F35
22393039373A3337322D201824232439302B352B2B36363C3E413651495B463A2C392A2D
2F54433F403A3A3B3B43463F503F373B3E464045373A2A3746533541455F434F454B5167
625B4945575F576169666A69546A5C6D62615C6B406D64725B686360746665536162535F
48454665516C6E55444B4B49595C57542B2531323E4D305134404B4938434B5C46585A57
3C564A6649545E425650423D3A4E4046464C444A3D504649564D404F3B2A301B2C1A2319
0A1209100007080C000C07171211010A031B1D1B1D24191A2D21362C283B3A39413A3D37
463D3B41433C30443D30353846424A41403B3D3A363A322A2F3747352D2F2B2D2A1A1B23
12131415230F150D0F160C1A16101113191708130F12160D0F1E14170F0D0E0D0A0C0C06
060B07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000002000001060B070B0912151315181B181B1E1F1B2420241E201C1F21
21282E25221D242C282A2529362B22291D203331362B2427302A2C2C25242733272F2C30
342E29372F2E282B2E31303A38292D2223352A2D3C5A4A4A445A605D6977546C616A6E59
6F665C52536161726C7260655C6561565D4E554F475043444A3C3B473A362F32202E2F32
30261B2C1E3B2F2A2D3E222A10293A35393C38401B303A443E3C26424B453A3218252737
243A4441373B4636393B403D3C2C333C362D34283F3136363D3941414542424B48524B48
524D4E3F4B536F5A5C56605E5E555B54615B56506666574B6074705656775E4C564F4D6C
4341594C4B3E5B5B5B4D3C4C57565750404F43484141393B433C334A4435474F63496458
66565A5D5B60565C3E51403F213C5A5853635249504352515649504042412B2C21242725
2D161B0A121400050000010B07030600140813251F26212929201E29322C2739343E3232
2A3D403A353D353A47443D394143463E3D3C4235353E443B3238382E2D2E1E33282D2824
2A1613161E2112130A11110A0E170E17150B0C070E0D1411100D0F10130F05090D040705
070500000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000509080F0C0E131319101318131F211A201A1F1F1D1C1D2522
2127211F2229282D211F242A2328262328292E272B2835312830232325292A2E2D272C2B
3D2E362E29322C2E2A2F403B3E332B272E3D3A3C4A4B483D424B434F585B6171595A5169
6468625D6B6762637C6658677360736E61514D6858555947504C4A494C4F3D2E3E2B2A32
3A38372F3236383C3F2B2F282A2E1D414B42352D303239442E29454049521E331D2F2621
2F434835251E363F3E39383F37393942403927241E3621462E3D43443F32523F39583E43
46443548405A56554E5F526B636057606264645563555A71656557656D5D696A55776769
4654535A604E5B4F455A485748545A463C404B493D473738393E34404442484D58577559
5F5E4F755F6E4D605F493A44435048454E595E6054634C53594D4B3F3C3A2D3532313138
2427241B1C120008030509010D0506050B020E100F1624211B1B1C1E27251E30332C3D36
3A433943363F335036343B3F3740374041483D473F3737473B363A3B302D2B2829242625
252607191C181813181313091615110D10130B0F070C0E0F0B14110E0E06100C0D0A0C07
060004000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000200000005010308070D0E0910161811181B1B1A1C1C181A1D201C1F271F29
2621222625242827241E2428293121242D2A2A30232B2F33332629332929232E2E302C35
3536362934312D3B32362E38342F3130353C3246373D343944524550575D62675D59664F
586A6152626A5F5D726A696C65656A69644F565256665A5059474B483A4E4B262C34262E
343139322E3F2D3E32331D1924241C38312D43213632322A3F2F2E41393238404650393A
37333B393B45464A3C39404E475247474A512E1A252D35353F233C35323C343D423B3242
3E3E453B5157525D64625D67686B634C645A60666E5F4B675C696069625E716F556C5863
5C5A5B525452615D5C572E5439414D372F4A4C48353E2F45395436463D3D3F4B626B6161
54574D6E555E5A5947454D383F4442444E504459626352515E44474242343C4539503B27
41251D2E1B1C1D0F1005000D0D09000C0C100A110A26141A141C2A201A2B2D312D373131
352D353E2F3C2D36463B413729443F3D463F374338473B443342364142372F3331312623
231F1E181A1C150F0C1C1212081313170F140F1413100D1013110D130A0A0D0D0D080304
060704000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001030005050B0D0E12121218181619201B1B131C1C1B1621201E1F1D
1D1F2123221C2020222223222B232B2B26282E25292B2C2A2D302929282E2D2A342D2431
29373434333C30352C30353833333A363D4F3842374241423F49484F4F5F5C595E555C5C
575A6D666D56626A5267706A6A60545C68606D54595F5A635E61524E4A4A484144403C42
29242322282934312C252E30252F30303C2D333A3D2B1C2D232F343C39455D4B515F4B41
344C4051423A4D64453B3A3A414A484F554E4D3F492E242F32353F35493922393347293A
35353F4347504D3E5655595651655561655B55615C705E624B505A60696C614E48656073
61566B5F605E4A42674F3C45523D4C314B533C3D453E305934483E3E2E293C5756666C4A
3854504E545155593F3C483C473D3C443F60605E605C6C5B4D495956484839463F383B33
262A292E2B1B141B091D0E01080A0000070519011111091911131C181928251F3226343B
3236413C3B393B3736323D3D343F383D3E483F423C4C38463A45413E2F3D2D3F382E2C34
282F18271D211C1F0A16091017120E151117110F07110C0C0711090F0D090C090D090504
040100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000300000001000608090A0F12101114191B191A1A1A1E19191B1C201E1C2422
21201B1B1C29282724251A26292D2C2C2B342D232B2A2B2631292C1A23272F362A2C3030
253B302F2C353236363133334241353A3F473E3F3B44363B313B545255504A585C58745B
584E5562716B736E6B65665D61685C5F7164616B4E67656157565251404D46554D344138
352D2C2915392530343D373034333E3430342220252926232D103625434A4E6150563A3F
3A4A41414A4E474941432C3147464E5D4B5B344831354436292F3F362D3F3F3A1B422B2E
394F4F4A4D494A5661435C5B59654F5667575E665B5F566176515C6746575F5F6F575C5D
5B6363546057545E4D5A394E4C3B3B403C463F493D393E2B2B3D473B3D4B444450585F4F
374A425D52556F4A4A564440393A373F3F514548525B5A67595C5C5A493C323638322F34
1D21191F2228251E14091B120C0F00081609000602120C1C171A151B10241A212E2D292C
3125372F3A413A39373C362C323A3F46384A2F483E4D41424A3D4B4440453A392F343033
2E221F2427201B1D1D171017161A12110B130C101417100A101C0D0C0D0E0C07000D0300
020200000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000400010606090E100E171A13141D1E1F141013191B1D19152327221E
252424232428261F1B271D28342828332624201F332C2D2122282E2A252B352923382A30
2B2C403533302C283333353A35393432303F493A3D414F483C4149414A504347514B5654
615757675B64646A5568636F5568676C6C7066605C535455535B5350444A404D4937433B
453C2E21292D3033361A3537282F4C38354032422A251D2132403938492C3A615E56554E
233A48544D485F575145422D3344484E485E3950453E322D312B192436372E3F332B3235
293F2939403A364A4E48494954695E5E596666665F6A5A5A5C676C60636A555A64476A69
6657516342575A5F5C55484C4F40423D4B455249513F2E3A274A333C314D47556773555B
595D3B555746504B5840464B3450434B3F414449595A5F58596C676046403A351F2C2E2D
3226222E12292F1C23170527261515180006000A070D00070111160D0B1F1A1B1919282E
1D2D3B332F362C223933333E402F3F4E414038353F453A43413746383E36423B3539392C
2E2F2F29291B231E121A181A0A120C0C0D0711110E0C10140D151014090C0A0A060E0701
030100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000300000202030A090A0D111112161A1715111621171F181E1C23231F2227
1F1E2624212027312E2F262A2E241A202A2C3130292C322E2A292F2C2C3232323431312B
382E24313438262A2E312D2E39382C414539363B3E30402A41383F43464C504F56454F55
57605A665767605D5A5D5E605E606469706C6951605C4F575157444D454B3741564C4847
4237313E232F3B382D2E291B3C382E3E47372A2E3A2E372F1A413B3342374D474D5B3541
42463E3A57494546424340532C2623453F3F2E47444F344842313D222F354D2E3A4C3738
39423F3236403C38354B473B5F4E64645A6366644D52675A6A5C6061595B5858485B4F52
54655A51454D6D4E425F454C4C4A4D414750333D482E3C202A2B3E4F523D475765745659
5B58494E51595975624E6351394548304344514B52536F635E72655B5B3E3A3B313C2534
33312F23232F1632242B252921211D230D0A1E06000315070A04170904141A180E181814
2E163031342E2936353130353B2E3847334134473B4140454841424541423942383E3435
28262D232225261F1B1619131215100E15070917180F0A0C0D0C110F0A0A0A0F07010209
010101000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000002000001000201050C081114121313181C1C201B12211D1E141E201A222020
1A262120272C262926231C2621202C27312A25302925222C263528372E3132373C413C36
2A1C26253B2B2F25292D2230302D32332B3A463932314833453D4041314E4F4851374954
554E55574C674F6A56645C62676457666B606360605959515F5E574C4C4B4F4238424C4E
41343A442F2E35313E39352C2D30272C403A36334537201B32322329354A403A2B344141
3A444648544E6341443144442A312B2D35423B334D4D474D2F2D212D46422D3D3D3C3733
38343A42303D3E43413A3851555A615F60666F715B685D596473595F5360625A58725B52
4C6F42624B5A4C4A573B675453444E573B414A45263119392C434C615056585F625A6567
52585C504B585861505847454E3D453744574842535F517268625E594D31463C32302529
2B423125373C3033352C2B2830382B0F20190604010C0B0B18020101071815161D191821
11221C2C262D26283130273C2E3A3A3F423B413E403F3841333F45464340424434433626
322925192926251F21191317190F071409160B0E110F100A0B0404040E0B010107050000
020000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000200030005070910140F15181F1E201917151A1A181A161C1B191B23
19191F232419252322261F24262928251F2726272B2724312D242F323434323C323B392C
273030242E3523262E21271D292F2A2A3B31352D3F393B3745343F3C484A483546553441
4651505A5B686473575F5E6563625D6A63694E5D70565B6867536662545E556450524943
392E4D4834313F4045232C2E2F19233028312D283135352C2A373B2E3D3A34393D384157
3A3F465256464D483E383C303A322A302E393133354945432F2F373134293138372F4639
41393A2B2A2B264848352640455C485C64514C515B6467695B586668414C61585A6A575A
586356585E46544F4E4D465E33494D5A514C3E3B3E2F2D33435957596F645E506B635F51
546B586547586A54575643524C42483E3A4241555C584E655C585C6C63574D423A222C3A
323E363D3337483724402835293025231B1D1914080E0F1D000E03050900080B0F13101A
1619182317292929292F32344239403C30393048483F33413A3D3747484942483B392F35
2132302C2A2631271B1D18140C09100C0C05100B0D070D080A0E0D08050806090A050001
020003000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000101020000000406040D12151416191E1B191F1A1F141B1A211B1B161E1C25
18201D1F221923242328231C2523222322222C2C2A28282D2A33352B2F353B3A333D3736
312D2932363031272023231E1A1E1D2C31292B34332040464A3E453A3F464C4E484C3C3B
364A534B4A50686562616355686B606D6663736555626A717C747470705D565E55494B51
414145453A3F424A47423828294F202D2E403430353539222D3535353E282E471A353539
504D3A3E4A5F483E3A303F423D2B22282B301D332C42444B3A423138242D3B2D203E2E36
36473026273726463337443E404B564B4E544763606E69725A6866705C6B59694F52565B
563C5A6B5453666243674C4748585E6256583F35462F23433F4247514C43506650535A6B
5F4C5F52686A5F59545642484443344B5546292F4F475A57625D6466444037542C312F40
3B3C42393C372A33462A242D27382A221D2C2B1B161005141006000F0D1209170B020E06
0B15171B1021291922321F2F3B3B343A39393A343A3E46444241433A413A45494E423C3B
39333537323230201E261A1F1319111E0F150C0E020C08090C0807080809050A06000003
030100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000200000001000003030B0D101511171A1C2019171F151919181D211D1E1C1A
1D1B1A1F231E291D2A1F262727241C2A28302929222635272F29323036343F4A4647483F
463B3336342A3032201E161018201F25252B2C3532393E4C40413E46463B3F40493A5054
4E41403F534E535C515D5A5655626362636D594E4F65587471687B7473735D5454595A47
4B54443D4F423F4E48402D2E2D322E35493235312A372630293D434B3E323739322B293C
5038374D534150432E3735363E34302B1A2526381D36364A3637333E3B46283B2437331E
362928322C2F2C373444323634565A585248546B6262575E5C806D6C72535859606D5E4C
686559545A6D665B475B5E484D545F4232455152343D48484840383A3843424E3D4B6663
6A676D696467615A604B4542384C2C2E35453C3A494A61666162645E5848474D2A383434
323A4C2D3F30313F1B2A313726363627231F1920232B210D08090A01000007090B140008
13140E1718201F16111F24282A362F3529373B3C304E453E3F3741374342403E45433C3F
353938412A2E2F212422201D172112150F0B190F0A0705020B090A0A0609060203090503
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000002010203000201060E0F1112161316181C191A18191219141A1E1C101D17
1716201C1F231B1F211E2328252624242626231D292922292F3A323E393B3E4A56504446
383E3C38302E35291822180D1A171D101E27262C1E263F343835413F4241463C3E434A39
3F4B4649463F45484F6252595964576758706654575C59656F6E66725861656554545150
51404E543F4C48353C3A333A393E2A3237413929412F2B27323F444A372A43301E322E38
4F4D374D404A3F594A50353F2F282C2F2E36231B2F3F1D3A273F2C322843393D2A323833
29323032302F37263A3E3135583E373F414948656B5B556553545063516A61695C5F5E53
59563E5B65535A5A665A4F444D4D454A4E423948314B464C473C3038223724353B484C4C
5F6755505966615E4B4C4340374036373B3D32474A4B51446147635A4D62483B443D1C43
2B3531352E2A313126152535273E37391F2B2B241C1A24170D0C110A160E080000000007
0C0A15140C161F161E151A1F2C2932312A35313D3F3E333D3E3B4140453C3D3B3F4B453B
4546313E3536293431262221241414191116130B10091213070900050905030000030203
000004000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000101020100000003080B101413131319221D201C17141A1F1B1B1A191C151E
1F121824191A1E17191E25292A2421201F302F262C2423322B313C3C3E3B4A4A58595353
46342F3D372F282D2B21120A08110C1D162425231D2E313735353E4B40424A3D3E47464D
424B3C47534B3D42594F44545D52635A5867666B626065675D6A65615B566B73615F6766
5255584F474241464A3B4345262F3830363433372E2D1926302E383B382F283136284145
5D453B33364A40445057493E3F252D383732153C324B2A24382035413B4C24413233292A
2E383C2F453F302D283626363C2A3E484D453E405E5F545F62655B544E505C534C586559
4855525B7253576A5D66655B3A5654524A39293E5553444E4D482338213636263E474053
5E607257494D503F544C464E44444537393B2A362F4C3C4049514C484A584C42483C373C
352D2026181F21151A261C2431201C3D2D2C201C1F15150B0E190B0F000A000C00000405
02080E12091C10181917181A1A2931303A3539302E423944343C383F2F3D3F4B3E454642
363D43353232333336292C1C1821121A111914110C09030B0E0A080B0501060203010400
000100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000020103040404050E09110C1414181918171A1A17151B1725201E171B1C
1819201E1C1F162B1F221F24211F1F27212E29272C2B1C2F272B2F32383B3A49595A6757
434E333A31382A231F150A14141C0A1023221D261E30273C3D3E3642443D3C3C393A3B43
3243433B3B4A51414744515455515A666F68656C6D5D51695F68674C685D63705F576155
5661456744453A3C42384C3D34382D352E3E2631245C312A1D44293631433B362A483C61
404B3C3743584650524D5A402F32353A33261D2D2E2A342C182A203C362F37393933372D
353743352735343339292F443C4642404D49435D63615D4F59665E405440695C50606455
624F5D57595D625847505E5D634547413C4D4A444E3C4B5D4234333C302631423F485843
51355D484E4C474F60503756475349464A4138313C434540314540424C4E424935373232
3228200E150E162322151719160B1D1A251A180E101A100C160D0704010B00000F040200
000004000207050E080E120F232516182725333533383436353F403B3F443C3F3E413944
3F463C37353D4139332D23232020181B152217160C1109110C0E0C0A0A04060102040203
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000603030303030002000B0C0B131A1518121A171419181A1B1B1C1B191C1D1E
1C231C1B201F2322242126241F221F19261C29272C1E2D2C24272E332C3A4A4B595B5A4A
53413D2E3637332E21171E13170F17101B1A211E1B252F2F3232334838403D524342434B
424A40323B424D474B505557534950546E65646A7963665E555D5A635C58555F67647460
626C5268565148434B46344E353E382E39343F45343C2D29393137273A4949444E43424A
47374128314543423C4737273A343D3626273B3331322F1F25242B27373B3B2B42424241
49232037353640433D4A452E2C3C2A3B3A3D3D494249565F565462545C5C4B654A58615B
5652545B5B5558584F595B4F554C3A49464544543A453E554F3E31413D444B2F584A4F35
364754593B4C553950444D4249734F493E4730382F472D3D4A3A5043354447503B341E1D
3019180E19232C2A26292023170E2823251419170A011B09191118011002011401000000
000800000001050B1203001A110D1C1B213330202C2D3A353741323541423A46393C443E
323E3D463A3B3E3C32333932271C1D1D25201412120B0D0C090D07080802090000000200
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000303020302000200070C0A0E18121710121718171A191C1F1F1928191A1E20
1B1C221A1F141C1F22252426292A1E1D1F23262922252824271F2B2A423A2F3F4F55554B
47444136343236262B2B1E1E121C281019191021211E2829282535323D414D474B4D3A4E
4D3D394A4B4653534D4F4246524F50585D5B62615D5D78555F57515760545E5D6B665D61
5F61574F5F4D5D524C584449433D4F453C483831372A342B1D2F2322373841473A41533B
273339322E3D3339474739474F46413A41303C29301B28192B1C3C2E262C3A3E38444441
5C384D3E4A42352E393B3D424032403D3450433D4C4559515550596B64526258564C624C
583D694E54595451545358634C544C393B493958444854443C3D41405A55455C5150444E
414A514B4044465343384E566459584B4B2F3140413F2F30473A403D3D3D58433341302F
32321D19252B2F3627073419181A1D2B33200F0C0D150E0A030000060002051400000000
0000030000000000020E020D0D111117132226252F323D3E39313A444136423735373A3E
403F32403F3C3E413B33362926202423241720181A1511151511130F0506030505060300
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000105030202010001020A1211191617141914191A191D161B191B1F1C2B1D20
1A17191720261E2420271A1D1D292127242121232B1B2429232530313029374547515044
3F3B3E382E373327272025161514111C15171B15161F281F23244233373C463249434D4B
3B4B37374350554E494B484A4F4642515F675F68616D6E684F6868625166555D615D5C51
596E5C65586A5758474A555D54493C362B3338423226323A30221D33392E3B2C3E514440
3B322D313238283829354431253E343140384035272C19272730303C28202F2C2C2F3E38
423D40463C373E4D3128333E35444138373430375253474C595054644C58644A584E4E5F
49635C5A5D56695363644E67565B525652405A4D566836413846496A5853535E50495243
35454E59363D425539515A505751475149403D2E393744403C2849423A485233463C3F2E
472F331C2E382E323D35292330191F1821171300090F0B10140C07050814080302040000
00000000000200060A0A000B060B0C1418181E222434392F4140354037403E3F313E3741
4343333B3B383B392D343B412E2C251D2928282218161B120F0F0F110D07010005030005
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000303030600000004070B0E101415131215171616161C1C1D1E191D171C1F23
1A2127221E271E1D1C2D1E1F1F1B20222125292827302A25292B2E2B31353A373E363130
3B393735352D2E30302728211B191F1E1D171620211417172A292A2D2B3332334E4D5341
4C454D4E3F4945474C523F3F354B4D5A5A555F705E4C5B74667168796B6C696672616B5B
56595F56605C605948564B575A4347483A3C3F3B353B492B2A291B1B27232F28332E3D24
3D2329342E253931323B493643455B465144413B481E20143035222D36232C2931334541
323043414734423731362733363138424033524C373A3D3E33514E51565B546767405143
5F4B6E5B5A5B594D505C5758556A505755644A63493E50535441593A5E4A6051554D434D
3D48484E4D3D2F3B483F534D3D693A453D35443D4C47343D403D3E394A4B395D5240363B
391F27243440433F4F39372922252738131C2716181B040C030C060A010009040E000100
01000000000000000100040D09050C1519191D261B2D2038273B342F36433C3033383D41
3A39324A3D3E41373A37362D311B2E2A292B29251D151508110C100E0705090307080100
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000205030102000102080B0C0E151311111212171616191A1C1B181B1D162620
2324211E27292B24232624201C1F1C221D29272E2A2B2F2A26262B1A2D30332F38373B3E
3337343230323E3C33352F2F191D1A161A191B21221E1E201C20261E292D313F434A3C42
3F4C453D445548473A3E454043464C4C5065605C485E576F666E6E6375636F6E61666163
615C645C6C4E5E605D555D5A51434F4050482C36394438362F2F2B1F2927332341342538
2B362C2E32382E27303F2E38404B352C494651473B392B2A352E2C311D1E35342F303240
3928474931443F2C363A342A34393B30353232393A3E2A30443750495D5B4A6453634261
5254575B5C554C54475E4450575E756B66636B5552494A49594F44433B5F52514C3E3C38
3B3E383E48413E4448523C434E4A4E4F40474945474038383E392F41313F48564244573E
313B3F2F3D4546534852283031221121281A20210D1C100810110203190909000A000300
0000000007000000000000090001010815131B1D1F2127282E3139453F2E2B4635383B3A
3C3F353A3F433736333A373128332A3231262B2C1E1C161313171216090C020603040402
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000020001030001000304070E0E1611151114121D17181E191A191C20211A1A1F
201E1F1E222724273423262325232B29262B2A32272135242C22232933332A2326313522
2B332E343A2A393A35352525232718151A15201F262520191518002818272E2C2A2D3840
293A4F44494A4B483F4B51433A3F403E57444A4C56665F66675E77615F6D61565D5C5453
6D635C6D62636647445D60565C5B48443B43474133314145404B2E3A2F18332832283921
2A3B372E2E3F303A2F3F44283035332F4B45453A3234292A1D3D352F33363B322A304632
3E36343B3B3431293536433947343A49403341381D322826313B3D424047494B535A624B
51535E5F684F60514D455256596A65655B48495751576451584D4C4B435451493C40332F
4439443D43413242344D4563563D5B43303D2A3E404249433C3E362C33413D503F33464E
5141362D584F5056514846483F3032313023231F0D0919180D120E060006000A03000700
000000000000000000000403000C01150A121317131A212824312D3A38393E363541383E
364439463C3B39364133322D3D33322B312B303028251F1D1C1810160A100C0506050400
010000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000202030300020302030A0D0E110F181314131B1918131D1A181B1C1C1A221B
162522211D2530292B1C26292B2626222A211C271F283125281E2027222C251E252F2623
1E362D3532402F3440343937362625261C1D1C1F112222201419171A1E1C15232F2E313B
3B3537353D3D443D514D4F4C373E3E4343565E4C4D4F5D66606B5C667167665E5F566061
6851657B7059535F6769566162634F5745433B363F424947494A4741423F273F352F263A
332F2835453F3F2E35372D322B452E474445334122253931353C394140424A3F34304A3E
2F2F35343A50394D463B3739343E2E323B3D33323436342A20443C4C425361575B485468
715F565545535752505F47625689675A5946414B4F546965615C48583D4C4F564C425149
3B4344454B4C453349493D4C46565846473D4646355348513B2C39303E40353C36311C50
356048313E553B4B494F42523940413F3E2B031914231A1A210500000701000F00000000
000000000000000002000000000500050107120C1D121A1C21273834313C2E3536383738
3842363C353D383A3331333637322F2B2F32352A282B2A1E241B1A161213090D07010100
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040405020000030003050A0F1016171112121616121B1B17101A191A191C1C
231722291C232425262D2729232927252D1F2124241F282227292B2E22243022251C221D
232D25252F35272C30342D3237292A2E2A20231F2226211D1C261F1A2616161B2019282D
273B433D4E4C3D3E3F5249403C453C3F4538413E49424F5F4E585F65625A68566468645F
5E606563596A70646D6463606063504740455047513A403C41594337393A283242382C27
372E342E3D2F323C37393434442C2D42353E2D3D2D2C46392A2B3F2C4B314D2D3F3F3145
4A2A2A2C31302D2B4B363C3B3E3E403C303A3130323C3316332F504A463B5A4A5850574F
485F5057484C5352504C5450505764535C4246455A655E68646659444A403B425A414948
4942453C484A4B573651444F4951484B4E47442E515653364B50414B40463F323B372634
3F444B41424A41464B3B584C4E475248442E2B1E20192F1C181105050F01060000000000
000400000003000000000000000004000A050E18051A1B1E1A201F2C362D2E2F35303130
312F3D3A353A412D383830362B382B38302D2F2C30242B2428231B1C1B110F0903040005
060000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040300040001010307060A1211121B140E12121317171B1D171B1C1D181A1D
13202320281E2427211C292C262F222B232224291F2030272219131C1B282C291F2B1F14
1F2A1B2429242C34252C293231373F293336172412111D1F1E161A211F1A121803102629
2836393A574331384A343B494A3E48473040384E4F5155434F53595A50494C67595E6767
766B506382626B6B66645A60646C50534F574446403F46433A3544373C272E363430282C
2337322C2D282B2F293E2C50373A36332D4244413D3738312D3D3D503149304A44393D45
40423B453A353B3044483637474B3D4E3F3E45312E2E1C362A422D334B5244444C4D4F4C
434C554F525E494C4C4A505A4C5B5062554154405F5A4665665E4C4C425668644F4D5B4E
444C4D504E3346553A434F593F4D4D3D3D5832525257535343463F35404D3B4538253F41
4546474B394C3F4D444A434A5A55523945502C37262025201E0B0C210700050800000000
05000000000000000000000000000001000301080A0B0A151E26312B302F2D332E2F3333
382E342F363737362C343B3139353A2F2C2E36372C2B27282524231B1D22130A0A060A06
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040205010001010000030A0F141514130E19170F1D171B151C191D18171B1D
1F1D212027282026221C23222A2B252727241927282133272128221B212D3030322B2A26
2220241C1F262C20242B2D39333D38323538322C18291F261E2717242020211C1C192219
2927383D3539434B3836504A3E434633393B3B3F3F383E504F4F444951545F6967586F66
6B696259656F6F6C7F6C706262557F5B555A4B574B4E553B3B372642342D3C26392D3623
322243362E42271F354143444836352A462B3E312D3728282E3A392E374044423D454545
4A434444272B251E423D3C2B433A3F382F352D2F2D372F2231324A3138303D383A464C4E
45445F456148675A54494959614F605A5A5C526A624B585D635A515444594B4D485E555E
5F4E54513C4354353F5638544D504A49624D4F495D4A4F3B4C493B4737434E3E45353544
383B493B392C4238453E4E424B5557404E4338373B3B2C1E162E170A11080A080A070200
0000000000000000000000000000080000000E00000208141C1B23202823262B282C352E
303B383E38303933362F333533312B3133392C2B342A291E222B1D251A1A150F07040C05
000400000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050006040001020200050C0B141411161610151B1811181B1C15121D202322
1E1E1E1E282622232221283328382E24211D1F231E28252423221B1F253023402E32262D
3721203021261D1D272519352C3C3836392C2C252522201E29241919161A211B1F221912
261E2A2A3B39314936363953463D3E3F3D4C37484341323F484A494B48565163625C7566
776F6B6C60686C71576C6F74747C5D6065546351564E4A5640483E3C474C4031363A363E
283D322B2B29231E252C3D3D3C44344A2D4131283E2E352F3D3F38424738433F4A3D362D
4A42272C2D292C424F4F3E413C4A413B41393D2D25302C393934373A384B3D3540554D3F
574F4D545B504A4C464145684E616B724C6D62644C574B5A5661605F4E575E524E5B6B4E
5C694D44455D42574F3E5552475553444F535443565F524538573845574A413D3E433E44
363B34423B2F364A393F34395F604F483E3B32373144312D181D221502060B050A000000
000000000002000000000000000000000005000A040D0C14200F111B1F2B2F2438362B28
33373533352A362E38292E362E302C2F35292A2A2C292D252C2627261F1C12100D0F0000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040404010000010002030A11130E16161112181C1615161C1319181A1C1617
1A26192A1D2620211F231F271D2C2120202524201F21242C1B251D2C1C292B3229404032
2E261C2523302723261D1721353932403337362535262B1E2A252A1917230C101E111A2A
2422182C2C3C3A3B454B4C3642383A45403D4540434A45423E49524C484D655168646D70
5A6A6B726D677364585E595A626B747268665861585649523E53474E4245464A47442646
372B3539303A2A3623344139403A3A3F3A473438363A271E453E3A3D3136444D48334841
39322F2A38464144333748383B38404F4A3A3B41245A2F4A303D2D203D34443D42463C4E
404F485059685A555B5D6E3E64696F6F7173745E71576664594D5C5369654D4850685961
5C6459635144614F575058454C674E505E564A45324E3D513C4F4D4E4C38434536513A43
4C3B3C2E3B412F313431595654444A514D41454F482F242A362A2E251316110014060000
00000000000100000000000000000000000000020F0D110A0F0F10141618192B222B272D
2534322F33312E312F2C352D2F322E31392E2E2825252820222323261D2515180E0E0400
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000002020000000001000204020B0F101715111719151B1A19181A1D141C181C1C
1926271B18271B242423232A272820201A271E261625262C20251822261F2A2D2A3C2E32
2C202A212F2F252C27231F12272C312C3A2E39342B392B292E1A2B231D161D1F23111521
2E2E262B2A3E35413A4843473E45444D4343483F474E4640573E425446425B6B6C6A736E
7274625A685D6A64537066665E755E78695A5A5F60614946523D435254413C4F3A3E332E
343E36403630292147414E34403C344C343E3D3E2F322C372942473B263A37493D392B39
43342C393D352B35343A37254139514F4B40353C3A3C2538343A39422C2A30374B464C4F
554B55424752555C5B4F595C6057587A6079806E6E645B585748515B64535F4F42547362
5A514557555E7155595339474B44515560535B5C433F5149475345504D41545244463B46
393845432D3E3D2F2D4444444341424B525A47404B36323D3E432D1F1A13111719190700
00000000000000050000000000040000000000000C1505080C0A0C09141E122C232E2B22
262728212E2D312F312F2F2F36322A2D2A2C292A2A2B24242A292220281D15170E050B06
020200000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000002030300000002030401080A0713121915171418131C1717151C1919181B1C
1E1D26221F1F282A2022272C262328251E2228272C222625262F1E242F21202133292B2A
2622302B323325212426231F25292F2D382E2D322E223B292C241C24211C2016211B141E
222328201A2628262F332E3B433B5A4E533D5044453F354A413A4846535C485E6A615D64
696A6D64786476585C606B636C75737A5F69755F61534D5B5A5856444F45464A3B363544
3238454049302A3B2F3E3B4C3A333F362D2E2F333940351D2F3E42233E3F423538242F44
303B422B2E3222192528372C3B344054414239304B404242423235423A3841374D373845
4547484B5252575F57446D635A625B46745F7879676762525D4B585B5A6374545654535A
5C5760716E5E5E5654475B484A47565B5B535D483A404155575E504149533F4053514946
42343C4B37364336353D38464A393B2E5950513B4643493E3B34301C2427240009110100
0200000000000B0000000000000000000000001100010C0D04120F13111420101D22281B
3121242E222733312B2F2B2427272920282226242832232A261E27222516190F0E0F0802
030000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000003050300000200010004010B0F14141316141217191E1A1B21171719161D1E
1B241F1F1C27232A17262D22221B262924282B28241F251D2826221C2520254B20252B26
23272C262F2B2D2B20151B292A2B30221D25332A334233353728282212161D1024292324
111A19151E1C272C243D362D4B554C43404A444D42533D453749354348474A5065756972
6482706C586A70666977656F72737165636E63615B635A5D475B4F5B5E4A485451493C2C
5238343A4B2E3C3E313B527B3524263424242F2B303C35312D3B27314E2B3C432D362036
2B1C25292634382A2C2F21353D444B4D41453D4F474D42464C4D3B3F312C423142363333
35444855435D526D5D5F5B6060506D63456F696F705C5F5D4E4F5C655E83635E5867594F
6A5C595A666A6D6560444D4D41513F605B49664F333D3D404E635855543C484E54666C54
515A313F3A3C3D3B3A4548483656393F3E544A5E4056474C32313A201F2119180A1A0E05
020100090000000000000000000300000000000200010C0000080A0B12150E1A26211D26
212726242A2828262A2C272C272A2B2027222829331D282F292A1E24251D191412110708
060000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000030203020000000102030207080F140F1115121514121C191E251B151B1923
24191F1C1C1E201F2428251D2C2626252B2F282128201D24212227222A20282E22292123
27212621332928291E261E2933342E2E2E23252B363B3F3F33372E3127171610151C1213
20131D1D131C23131C3224404E3C383836523F51463F4440403A422F4A44595A59525C67
66594F6D686C586B61687A64696D69535B575F70626561525B59664E40504F4644494E46
4B4441414142483432364C68000E323D242F2D29363538343B2A2E302B304B41482F362B
21241F29412B33352631303E30384232442E3F4B30434B4D44314F404A432F413D3C2748
4B3554444D474A3D5956655E664A5059474E5E6E6E695D5865656262656951425F4D575E
5A5A6B525A4E616B5945584C4E304242494957444C4251434F3A4949313A4446445F5361
4E423D3947464E4E4D4A473C4254444A3A5251434D405950434F3C2D381A23191818140B
0D0B06080700000000330000000000000000040003000B020805031213191218131B1717
20202B222815251D2526292723242B2523242A26292E242A261D28251C2111130F0E090A
060100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000201030402010001000403040F0E11140E10171116181618151921181F181D
181E151A25292320252428252124252727262C252524222027202E21282426261A232522
23272B2828261B291E222E2B1E3135312A2E322C323C382D3C34252C282614281D102628
2A1D141A1E191D292E212A3B3B393C333F3B3950493D474827522F3E4148434C5F495D5E
49555A605B6B68605D616C7A6B6A684A5A5567716C68566A4F6C5B69524F53404C46433E
434A483D3F3C3E352B292C23161F302C342E272836284E3F3D3317221836344B3D3B2830
1B201D263C2C353B2235222A2D2E253434473B4741455242383F3E403937474345443E3E
2C39314E544C565E6E5A5C60585C6A544458645E5F63635C6271546A686358534F5A5F5F
5F6165524D665B524D4F5760424E484848586347444047414539434045474259455F4C46
3C415F555247425F3D323C2B453A47443E43413A43494A3B473A37403129252C251D1816
0C090D05000D00060000000000000C060001000806000101040507090D070F0D0F18151A
22171E1E1C241D1D261E21222A272127292D262026222D1E1D261F211A1518150F0F0C09
070000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000502010102010003040604020E0D1211121013161218191C19181D1B1F181C
1019231C1A211B2528252328292C2D292C222F2D2A21201E211B1B262C251A211F17211A
1B2125202C1F22272A2529322B3134403A362C3D3B37372F29312E1C2A31362B26211311
22281E1A1517272C25262A2C21292835342C3C3E5145474E5E3A384249574C4A4F4D5C59
5955644F5B65625F68706E67775F58556E64625C6563585B515D5E63595A534F583F3E42
3E454F3D413C403733263534362E482E32404B2E313C263332301C2E1F1F2E363A4E3C28
2D1722262F3F333C2E2A272D2B39312C4F37352E434647483934484D4F443E3642403E3B
3A3E42363251624C5B5E62556B62614B615D5668756B656365636359565659545E596051
5C624F65604D5D505E6858584F5045574F414B544D494C4C3E464651443E34474E524249
4E4B40425D47452D342E37293F4E464B42385138413648524D554753373A27323021250B
08010A00000400000000000003000000010004000000060B000700080107020D07160F0F
1A1626221D1B201A2127222125211D1B322426212822242427261B201E1B13130A0B0F09
080702000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000503020302040000000200050B10171810131C141E12161818141D1B1C161F
151D1D2122252B1D21221E212C28272E24292C2227252A29202322242F242E251C211B1B
2524292E27282929222F34342E1C2F2A383532343F3D313827352F353835343C28261E24
23291E18131218262819182A1F212C1F1D362544445A4C48453A3C48374040524C574752
4B4B5F5C5E698266685F6D6C5B6D5E5B595D4D5A606B71635062534F6154575463515B38
53493A2C373246262D28383E4333393B393F323330452B3B353F3236252E13252B514436
301A2A373D3D282A3F3B304540473230334E373B3D373D493A503F3D4C332D2B29363637
23353D47453748515657495E5D5A69585E564A5B6B556664656E55645D6158516C5E445E
555E58566157515B615C596E5E524F50574A425A4D4D41493D45364A2C3D374A4549533F
473D535846484A4E463B3D42404D4D483A3C424142373C455F4C4B513E412E302D302821
23110F0817080B00000001000000060102000000000300000607000A02080E070B110A10
121A1D121B1A1C1B131E1F261C1516262220242323262220271A20161C1416130E100C08
080300000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050601020001000100010005050B1414141116161C1217151717181A1C1E1A
191F1C1B1B1D231D231E2A22272223232A2A23281F1F271E2F222A1F2920292828252625
281A292A3336252C33342F312C271E22282B322C362C2B2824322F2C362A3A35422A2215
1A24240C17180B1D2028232B2025232528343A474852474B48403E37413F494B52454D48
4D4759525A695E6364596B6A5F646761686965696C526D54675E5D636960554A5446504F
56465451413E33403C393C4531393A2B37383A2E3D37272716303739361F2434372D423C
2D292121323C353A2F5144333F3B4B2B2A2535393E2D354E43365D3F364B34363C354328
4F494C43463E4E3D5F5E65535E565164595858694C6460596163625F575E62516656565C
5D65645E75545C54625A6B656049595964575F4E5C574853584545454D43423B424A4A44
3A3F4E50483C503F372F4A434241494F53423F2F4E32504C4F484A3F453B412F3E2C2D23
1C22270E1A0C0500030000000000000000000000000000020001000000080002090D1212
14141A14120E100D1E1B211C1C1C211B2520211F241E1F2423221D191E0F141510110F05
030000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080403030301010000000002040F121414111118161716161A19161A151A17
1C1C15211A221C221D261D232425282D1C241D1E2925272C24232C31222B26232425282B
212D32313935372C1F292D2E2C2F2520222E2F272B32242833312D331E3B343A49343A1F
2D1E2B241B18211C191B2B2626221A211E272E384936464C4A404A5042484D463A4F4A3E
3E49424142705067655C555E65616067726E797358666A735D77605E5A5B4C525650545A
554059534C453641425660372C3A34382B402228323C38301C3F2D26353528212B2F363D
343115281A3F2F37344C444C2D3A3634371939283B38373235354C583F444942393A4043
37283C3B4042334755594D445845595E6F656D645E5251495A695652574F576064515150
6673644E565B6C6D5E726078626169745949575D4C534C4A45404E504830345442594D45
524C4445435A46494E5B363A5541413F3F5241403739464F41484A574B4F3F443F313621
281B0C1514090213000607020007000100030000000000000000010104040000000A0509
0C1411190C170E0E1F1613171E1318171C1D1E201D21211F181A1920181614100F0D010A
060200000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000505040503020204000000010107131714131312171A1716161E18151E1F12
171C1A1A211C221E2025211C22282A28261E262822252322232427292A2526202125272C
1F242D22343F382A222630272629301821212E292D2E262B392733283331373D31293223
3B322E292D1F271E332E312F3020231F18302F2D4B413330363146414A434F47453E3041
3F3A494B46534D4E625D58545A5C486168647865745D586572655D5C6F40665A585B4E54
5A4E564D4F524C394A504B4E3138452D2426304438223A23203E42341C3A374F33333133
354230292B3848404545414038263F2C2F2C302F313C1C463F3F434841423C42495A3C2D
362D333737284C3A3B444F4644566656627D4B82564E58515D4D514B47674F655948555B
6B665D7B4E505D7C74655D51715B5552624E58546847534438455B5053444B6253494F39
57464E4057474C59403F494544454D534D3E574C483A4B3C454F634A4D4C5C4B42423D29
2917171E141511100B040100000007060000000000000000000000090000020000060006
100E170A0B0C0911140D18191A17181810191C1E221E1917191F191D121A141212080A0A
050600000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050402060403020000020204030A0C13191417181917171816171718232222
1C1A16161F21191F1B1A2B1F23221C29191F2220232724291D292A252C2F2B282B261E2B
28242926272E363127302B272D383033242627353131313631363B3C2D34464A4038372F
3B3C3E2E321B2C272F292B2D212428241C2826403035283F3337424A434A443D354C3B3D
43364242394D544F58543A3C505151524F5161645A4165746B596D594A69574E60525169
6057605C554B4D4C4A4849533B3A4134323C373D3937242D212834363B3A29262A343839
3B343630414442333B3D293C3F39304B3A3D35282E302D33392F32355C2F38503743403D
2E382D34301F3A4045384157534F495662615D5D5651465756634E5D49585A5568645E6A
5D515C66585D58647167645C6556605369565B5852574553695456464F52464C4D474551
514F5448524D574756634352524645474C3C4449423A4A42434C48584D525052453F4333
31322F1B1F1C11000B000000000200000300000000000000000000000801000001000706
06070A0F1305060F0B0E1610201A120E111A161D181C181F1A1F150F1B0F13140F090807
040100000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000004040402000101000000000002010B0F1116131519131018191817181F1C1B
23221C1B1D1B17201A2423202623201C25262B2A222D20202B312933292B322B30232A2F
2F251F342530303629222C2C2F2A2D332C2D3C213036322C373B36383C393837333B3F34
3536483239232021292227292916191824232727272D2A1E1E2B423546323F4342404643
3C4741334B4446394740323B4145565B68534D4D4F62586D67556B535E625A4C60545A5A
486958535B566555523A504342403C3B40322E262D2A33352A24202A40342137302F353A
423C493926303E3D41383B36344B4749393449362F353B27303A3D1C2E3D392E3A3B4142
47363B3045363B494D47473C5056554F3E4B625F4B474C48625A5F5C5E4F745F694C6E43
5A58645B5E7E6D646452725C5F5F4B45554D4A574C4B57583F4D59444D4A50555452505C
463E5946483C5844385745434F4A51483D4446433F3E40414E4A5349585066545B595F43
4A2F2E1D2F130F0C07000002000C000A030500000000040000000000000000000F010B02
030C0702030E0808100A0B071111151A130F171A221B1419131619131311130F0C090703
020000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000506030501030301030200000002080F121513161C1215161B191A1B19211C
1922181A1B1D1E19191D1F221E2820262123202824282D1923272D2C302F33292A21262A
2728182426282B31192E202D3A34362A2C323028334026332E352F352D323E31363D2A21
37383E3A34241B2A1A1A2124192D272D261B1F1F2926282B162A26362B3C3E41443E3B3E
49443E3C3E443C3D4838454142444D50514A4D5D53515765525B5569575E555F65636266
65655F66536655604F3E525E4D3A3B452A333D374231353D232F3D31372A27333A3A2935
2D3D3A3A3D46453A3A39454B43534B4745442334392A3730322C26291C2C26353A3B3C40
42433742353531514E3F3C4B564142514F485C583D4A5A4F494E53636257685D495A6252
524F4D65654C6561654F6C52515E5656536A5967564F4753695555455861515B6162665A
5B565747434A4140525C4A5B4A4E4B4F514F47453F3E3B4345384E56515C454E5E54493C
3C423A26221C1D150C0C0B0E080A04030206080001050003000002000904000000000D08
050000000005090A050B06110D1214121608141618191916161413130E120F110C080601
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000005010301050000010201010400050A0C141012131719171512161B1D191919
1A1F181D1F181C1E251C1C181F1A262D261B212523282C2A28262C2E292631242D2B2E25
2A2C20212B20262626231F272A2A30242A2B2A3232372332322E272836353A3443392C28
323442362D2B251E200D131E2B2B29262A2920231B2522162B23332028322E36373F3C40
493C3F393347543543462A303A313C46423F5A545D56595B634E4A6B677F6E6D806D6561
6256545B465B555C5254555356444E45524347312F2A2633272E382C232F2228312D4836
32212A2C3E3C3C453D3C483D404149323E38323C2F2A384B2D2C301D2A2E362D4E40462C
332E38354D3944332C3C4442505367594B4B434A4D4B4140464B3E54594251535E5A4747
5E526B605C56685D6267595449685956585A4B695052734D605E49726B4D5F57614B5C5C
634B5A4C393D4E4A3D464A48453B56413F423347332B3E5256453D4A4F4A455A4D46584A
473B3E4A2D171608130E0B180C0C0B08070F080000000500000001010007000200010603
0008000002000201060A0C03050E070B11160F0D12100E1213120E14111111120A040409
060000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000604050503000300000000000101040C100F12131A13181618191A15181516
18201F201C19201E161314161E231B26292326231E2B25262E2D2C2A2B2421282C2F2C2E
342A27242C2F21251B222E2A272933312E232F222B332B31282C3335333631363B362825
25393035312D2D302A2C251B1D151B1F1A2323250C1A1C27261D232423322D3440374332
263D4045383D3F474C2D2A33393532373348494349686B6149665D5E7170746B757D7470
675653444F4D616E5C544257594147494951494E3D3630253234233C482F332D373D3639
322C39384049353B474F463E433D4840484435342D372E45321733162323302C30403D34
333D4044384F36413B363B3E51515D474F4E3B4F4A434A4E3B553A4A414A4852515C5372
504D4B595B5D5E59544C54695F6160565559645D4C5A5F5B556A4A4B645D545F4050705D
53524150574E35474B3A4E494448444245474F463F303C3C4536363E3F484956555E5B3E
4E44555232361D14101C1D190D0F15210A0A090800020000040C00000000000400000000
00000204000001000501060503070D0D0E130E12140F091217130F1212100B090F060A05
000300000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000604060303000301000000030000040A0C131116141814131A1716161E1718
1E1F1F1C121716151E1E1B1819181B242E20212D2724292327281C2B2821292A31293124
28282A303025251F211D252D2B25292C2F38232738312A342A2B272D26292C2C382A3D30
352134332E38313338321D24222C181B2A23271D321C1B15201E1C28212A382938382F35
373C463D3C4B454130402F2F4337343D333A45364F515E52575663747F818585807E867B
675F634F596153675765584653465E4258434D4E3C32402F27242729323C38322E343835
373728374D3F50374540423648414F46493C383A3B3E3E3F2C242429373D2D2A2F2F3144
4A2D3634424241323532384F513F504C44414542494743564A3A32465348675F4E5A495F
4E586A4A524D6075685261554F5D5C6C605B6A624E5D605B536158494C5C5B5454554856
4C6B544D3C40434439423F4D48515244424D323832393A37412F48445343494B5F4D5555
53524A3E442C3E29222011182520131C0D11121105000409020900000000000000000000
0001000004000100000704060706030A0D0D0609060F0C13080D140F110E0B090E080604
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000304050305020000000000000000040A13131213151218141114171A181911
1818101B171C1B1A1517141A1A1E1B1B262726292027232528221C2631281F2E29233030
242A282F303C2C2B192625291F131E282C2D26272630252A202622282C273737333A2C26
30332939332D42433F392E362A223111132723271A2523212414332D24272D39382C2A3D
37452F433E5039353B372F41423E45493D424B4F4F3237535A6770777981697B7B7F6C71
72765A63545F67715E5D63605660555C414D39403C3C3F4125423D29293B26313132332D
3930313B3D3E2C343A3F4D3C44404B44453E4E5147493F3A36342D3B412D37363A302C44
30422E3E42473B373F37464A4F4340523C504B4D4D4D434D4A3042464A5A5566454B665D
564F505B5C62625566655F54596B6C60585E605B5A4C7760506966545D62616750554650
4E4D514D5F5353564D42404748463C4D3C4C443C3F3432414042464F3E4952515F584051
4F565146483E324035341E2F2E221F1A1E180E18070E0B09051100000000000000000203
0100000000010100000C0000020406090804070D070D0E0D0706110C070A0B090D070600
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000060308060302020200000000010000030B1311161D1C101314191B1D1B1B21
1D1A19191E181A1A201C1110151B1A2220272322292F252F28252927252933222A30262A
2A28353428262B322B24222229201F182C2D2C21272D27241C182C22281D2C3029333832
2C3E442E3A38303B3F3A353730332B22241A1618151D2A23182917292B31352F492D302E
293B353642403D384F3239332B362E4C333A4E644150454457616867736E6E6B6F747D6D
67516B56784C665F5F625B656D595246494641465C404D32364B48303232353A32262E2D
263F41354D3049423930302E3E5057504E424C5B4E3E434C3B3D3B314441382D46394034
42263F30443A35403A3A3A36393845413746474F5459424D3F412E4B364A57524A5A574B
65506546595873606A6471565654655C715C5151616B5E5C624C5565686A5F5350595155
6064675F544F4B4B35373B433942514752343B3D3F3838373133514137464D514B484452
67484C4E4651414E3C4638373525271919160F020C0B010A070F0B000000040000000200
00000000000000000000000000000402080702080600070605020D0E0A0C0C060C030206
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000060604030203040200000000000000030C1212171B1818141B1C1D1D1B1921
101D191A1820201F1818131B15171E1C221F212623262A2026271E22242929262B362A34
282A29352C312E34312E2A1D291C1723332A3236252924261C2A1E25232F372D292F2927
2C33312E3836283B373F2C2B2F282E2421181D1B1B19162D222C262C2E2A1A2532302F2E
4B403E433A2F382B423C363C3540263B39444241433C44534D745F736B6E545A67625B6D
526D5E9A6D62657B70886C595158596E493E3F40484C433F32443A473B403E253A383D29
2B231E293032384B3B3C3F3E41544657443B4249484745363C35393B3A38413139292B3A
27393F403931373E314032293B30373E393A4040383A4B2E403E3E3E35454E5A5E546168
545E4457616359675A666A675072674B4A595C595C4E53645C5D50535F6259574F65514E
4E575B5543544C42424644454A473A3F332A3D3949351D3A38313E2F3B454852513B425A
4B524454494B424E4F393A2B343022262120100C0A0B0E030B090A050600050300000000
0000000000000000000200000000000403030102090707050F0907080C0C080800060400
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000040501050405040002000000000000020410171A20181619171C1819221D16
17111A1A1C17191A161C0E161B15151B161A1B1C21222B2B2320231C1A2631282D302827
2D28362830222F24292D29153022282429292B362F33302127252A2728302B2421202C27
333B2F3B2F35353435363F372F3328312323201A251E342D2B20231F1A2A2C241C282D30
3A363930353335342C37463D3E2B453529474535483C44445F69776A5F6155534C54615C
6773617270705C686672685D5966654D5B58444947395647533F3331392A3E333E303B40
392C2C31433E3D3034303E2F4E3A31334433322E4C4E432D2E402C2D3948322E2C4F2D27
282B3E2E38392E3D443939383A3D3C43383D423C41474E433C3C3641384743494F515051
494C634D614A4C57615F6862585B51576B504A5656575C5565545456515C5E545252545F
554C6850485048313D42464F53303D30473731383D4032333E34443B253A5236414A4542
58574A4C4E3B5646474044364C342B3326201C14170D120D080E07050700000004020004
000000000000000000000000020005000300050107050905060A020A050905060D050402
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000008060506050203000000000003000000060F15161A1F23111B16221D1E1A1E
1C1B1E1A1517151C1820171815121C1F0C1824191720231F1E201C1D1E21292C2B272A2A
292C212B232A2B2521212930242A2D3226302A2F2434272F222B2F2D2B251D2E1E212026
3034352C3024302F32323B2B3228352A382A2111241F152C2B1C1B1C221F262A24242328
302F2F282B2B3C39403D424C40462B35343345494543394E526679725B5A5A50585B6A68
68735E5D7F6E66666855664E6B61563B544E584A5358324E4C4A413D32313D2E222D3436
39282B3C2F2D36452E35383C303038333B3532354A474D322C243E3C312E2C3D282A2826
2E292D4028322830473E3B314A35462B362C363D2F3642383D3B475043464750444F6162
695C5162565F54645C58636158654A66556055576560625A6168636D5B5C7666554D5359
5D55684E554F5556544734444A3E384529353C313A4442372D3E3A3849313D394B434859
5048533C505351494043404639342F3D302229271D120F0C1407070A01030D0205170C02
000000000000000000000000010600030301000103020205050607010009080200010000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000003040505060104000000000000000003020C151B201E201C1B201C211E1B19
1819201B1916121318191515161A1A131414142421242823252A231D19231E242B2E2527
2B2F2E282A2833302C252A2523232A29232727282A27332B2B301F262C263521261B322A
33262820262B2D263839293127332734312D291B22272E2C2D24210E1D1B1E1A311D271D
2C342C202F2F23363636413D343A423F3941413A484139364F4F666C575B454152627D77
6F6A5F646C645E656759605F57676777535C5A70525953594F4E4B3C3C263A3C403D3B29
402D3635352C38333644252634464032473A243A2E31433533392F3333273C2E1F21291C
2E2E353B3F33202D35304C3E4138423D3C3935383F33274F4E4E52463E423A4F4A3C4B57
5B4F4853475A635B655F5D5664605F4F50615B4658546D6374766E58625359605D4A615B
47444A4958524043463E4642323C404E382A45393C3E3F3538313E3539393A34443F3C4B
524345564F564847544D444540443B3C3C39251C19170F0C0907050E0202000A00000000
000000000402000000000000000002000004020001040403000707090601020004020000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000006050505030203000000000000000001000C161C201A1C1C1E1F1D1B1F1A19
1A1516191B1A181B1A1D141917131712131B22121F1922292E313226271F282927272A2C
312E2F2A312D3B32292728232D23252F2C2929232517272C2E32282A2A21272E1E20172B
2831262E2E242B2636392E38302F322D2427222F2A3230281E291414171C2022252B342E
27271B1F212D1D223E434B474042383E4B46413A442F29434F49595F4C503C475B62656A
635E606969605C5B6B68586464666C6159645A63675951504D5B454A3A36383D3538292C
323F352C2F392025332A301D2A312F303340383B2C2A3E382F3934383225253436173830
213320282C2E312337423B3B4B453D4D49314440353B34333D394040585148464C4C624D
4E595C4F455A5E544E6362645C4D4C5D45585C6154664C5E5D5B5F5D567357645B4C3D48
47485D51574D43415A4535333A3F3C353D33364C323A3C32342D32262F2A342E303C3E36
3C4740564C554F40474A323F3A4A3542454B403E221E1B180E1208060704000101000500
000004000000000700000000000000000200000004060002080503020408000601000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080904030605030004010000000000000006151D1E24222024201E191E1D1F
1B20121B1E18171913131F18111811131713181B251C1922292B31232328322E3127292C
29302F362730323233283327252927202724242235252629252C2C272525211519172A24
222A20192F37352E38352836291F343036292C29302B35392E2F29231B1B0D242421271E
212B3327282C263140343A4343303135364D42392E3D473A44354E4F67614F434F616960
5C4A4D5A5F534250444D6864686676726A64616957544E494457444F4944424130424A33
4232293E282B4532292F2F3D422235403029453B2E4143433E2E2C413B4432333221261B
222632332E2A28223631464A43372F413D4242343D392B2937414B52484A4F525D425948
52574A52585246435C5D615957563E5755533F576155515466605162545D59604D4B5A5C
50645457544C4434365036424457453D3431393C3533263738392F3B283331313A3B413A
4C293E43363A464B424A47493B534041464F48464C2710180F050B000309070206000003
010802030007000000040003000400000000050000000000030400010600020004000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000603080806040403000000000000000000021021251F2627231C1A201E1822
20171F1B1B1F141714191915141C18131B1A1E1F1F20212520232224202929262E1E2D27
2A292F2E27352C362E2E2A2E24362A2F23303027251C22291C2B231F2C2024212025262B
2C2222212D2D34302E332C2D313B352B3B262A3438273A33353920221F2C2B212E2D2721
222A242A212730353842463D403D3B47474B415339362D3840403A4E4C57474C52544C5B
3B564C5A5553496059616074716F686A69646367635D625C554F3C454F4B4540463C3F52
31343C301A273B393C28342D2D3D3428383236262D3337453F474049393D2D271C392828
241C2E3238322C3E3B2E28272E342D45394037314647343D4641334046445847465E584E
445E4E56614B5B505A4D5C47575B565A575264494F596F516C585564586B5A5E654E4C4D
4D574D5C4C534F47504F4F503F2B35413F48443C493D4051342F3D201E2C2335383D263F
3943433F3649525B51514C4755504D514A4A5448362A2D1F131A110E020009040005030B
040007000703030507000001000000000100000000020000000103080002010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000805060506000001000401000000000000000C1B2229272A2A251E2021241F
231F22161B141818181417142114171A1721121B191D2522201B271D242E2B2D2C302725
2D25332B2F3C2A2D31283634342C352422282F272A26222E23233120202422281B122224
2034352B243A2F3037443734322B3335301F2E2F31383C31322A39201E28352C242A1C27
282A271D32151E252D323840383A3A303542453E2F393F35454F57575D47434E48475346
414561555054554358646A5E626C6560696B705B666B5F625A4F4E4351454448333B4841
3F32322D3127312628371E3231262C203A243328372B2E3239473B313E3F3D3742322A18
1D253A2A3F36354021253D4231343D4B4C2F383046494B3A39412E364A45484C5A2F3D50
464B47575B5D6956584F4F4B555A4D5A575D434E5F4D5047624B6555575E525A6A586159
54515F4D565750414B55595F3F44454E33423E304E45403D392830393435303E273E3E37
2A443C493A4A544E5247495249485452655C4D454240342A221D151C120E000E070B1308
000206040004080107000000000400000000000001020000000002000700000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000070606050604010204000000000000000000081824292D2A2D251E1D2B1E22
21201D18181615161A1B1210161D1212181A191C211C1F1B1A17222421222431262B2828
2A1E21292B2531332C242D2B322B2F2C332423291F28261C26262C1D25301C2420221A29
2E21312E313648212A3C303C4236313038252E383A3F37382933212B37363725261C291B
1E232D1E292B2424201B2E38483C31463C573E383943424E3C4A52485059414B3C404736
424C44585740505A5A6B6D67666D545E746061686B65605E5D535D5C634E5449534B464B
41333B374348484E2725262A272C3A3E273C25353E33333B3342353038494A471B1B181D
20262D39242C262B2D2A2B30343531413A482A2F324D3E3939343F4437482C4650524859
35484D515551465C544F524D4D553F4C4D5E555F4C45535B4C48494B5C644B5C63595269
4F595B5251585158555C46484A5D48434E413D464348483F483B3D373A392E3F35302D3A
353D403F404B474C4552474D4A51494F575B5447424938403C32272025240E14150B1314
0C0A080F0804080E0105000500020A050000000000040000000000020205020000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000070706040605050203000001000000000000040B22292F2E31342423232822
1E23201B161521181B1A191E13181B1111191513182217191F1F1B2120211F2624222D22
2025292B242A262C252434293B2D2B3527322823221F1D2424222829202E2A2A2B242228
2131242E2D2F3A332A343E3F2F2B2E3F3E303039313A493B3B4C43363835443E2F2F2420
261B161A2127371B1722232E3C2B2A322B4747344240443B41584C4A494F4C493745473F
2F34464B5252495E4870637A6267605C6867637465696A62675C51645D585E495A575355
4A40413C3C363D2F303E302E352028333C2C282134272D2A32373C272746403C2D23242B
242532362D263D303D3023284434263F2D2B373B423D45512D3A3E353735444A4C4D5633
4350534A4E5552445453414D5455524C5D52504652435644415252484D4F615E5A5A5562
5B535B4F65445B59564B4B3B453C53434848513B44353A3B3649553443433533253A3031
303447454942483E4145444841464A495148575C5252473A423C3B321B2828161E121518
1A1C120F131009040908090706070C130000000200000000000000000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A07050603040302000000000000000003030918233027352B2E2A25262A
27271C1D1418121A201A13141813111B1C18131E0F1A151E121D181C1F1F242818222732
2D282827233127322E2C313128321E322A2D30282A2B292931312F31312D382E2F2A2B22
2223222E1C2A2C303D3D483F2E352C2C273526313C423B42343F3D3A473B393D4028261C
1926121822251A36122313261F28263030433A4147434F4E4F47554E55434E4A3C33463D
424C605C56584C5363586F6B6764536B5D707E6F745E63615364606283606A6158594454
4D4738363644413F3130273B272A30462536342830313D25271E1D342F2C372F31142A15
312C20333A423A3B34342F373C27332A3C3632393E523F423C4F38364F3F494044414355
3E344B533E615E58454D565B5653574C3D5A4F4F3C594D44574B4E435B5851695E595E73
5D58504C595F614D564A454F49433A4C5646453326473F46323A3A464044303F2242353B
422C443E3A49373B434C443A4744425B4353535339544D494B44352D32322C271B262222
241E1B16171C180612121004060300000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000007080503080304030100000000000000000000031222282B31302C2626252D
2F2A2A1E211A181818140C100D1316171717191B1D1F131D0F1B1315111B211E1E1E2422
2529272A2D25251F2B2728241C26322F2C273025252C2F27322D3D363A3637392E322926
1D1E3023273730312B3743273C362F333A443D2A3F3D3F3B42554B3A40473B393A38282D
161B19191E192A2E25182B282524252E32243A2F363C3B44415154425155504B42333843
434259584D4A69475C605D6B67726A6A565C706B69705F7A626B726674645D595F65514A
584D5F54513D4D4A3E33313127362738372826251C251F372B1524212739333026240E15
402D2A423E3336302E24312C342E213E3D32392531353B39423E323239253D2F343D3743
4644524B45544C474E534959544C454547484B5640424A554A516156575C535556504636
5951554A575157564E57464E4D4B3E3A533D4E3A4836413D312D3E38364036323445292B
3642474441393B343E523E464D515546564B575B52404242404840453C38353635253223
2B1A231D2011161A14110D05050009000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A050806040301030000000100030000000000060B202E2D2930332D2A2C2A
2B2B2A231D1F231818130F1613151514141C131C17171017191D1513191C1F1E201F2025
272D2E281D2F2A2C2A2721282A2F28352721282835292B383E3C3B3D373C3D3B423A2727
1E1F26262A2B222834373A40362F2F2E2937384235353F38373043414841304433382E27
1E2B2216191F27341C2B1C22231C2633232B283A3645433B45404C5941464F5042433440
344B515B4D3D55564453635E55615B646A626F6B636868515A74575B615F67656366564F
4F454F4C4D41344E393A322C30343C272B3933292C262B1C17311F26202433130A261625
2A2F353D34443E4B362F2F25172C332C25382C412B54373D3233372C3B3E442C433E3847
3C584D533E4344344E3D4F4A3D43584D4B4F423E554E4644515A4B4A544741564135414C
5A5B5F6557616761564C414F354F4951514F5B473B4E4B463A3A404548342D4743393942
4135343C3C243D2E2D3654474B494B483E5A6053606240504A4B4A404848363734352826
2A23172B19161F16150E0B080A0205000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000806070604060505030201000000000000000000051E272B2F312D2B332932
322B2C2421172117181A1A1B0C1516152115181322151B1A1B211E1B1D191A141C181722
2C2A2B2D27262F2826252E2721242B2D2B24282D3936342D2E3C43454F3D4A423632252B
2725262B311D322B28253139323836372F363A2D35393F362A42473D45343A3E4330312C
242816301D0E1D181C2724362932331E1D1523241C2D433D3D4D4B2F4A52404B47403E2E
3948593E5657504951714D6E5B676963626469685F5E635767577B607067607056565B5A
634E474C4D493E43543B3645392D2E33223233323A151C2D2A3222203D253E35111A1A1C
242B2C41493D44443727302A32242628454135383F273E3D4D294632453236293840463C
3F37322F35483E414C485037584B5F484F3C4642505447514539483E55473D40424A4E43
5B4D67544F55524E534A4B454C3F4B424941584E49404B3A3A49413B453E4B40413D2737
2D393C303A2C262F354C473F544D495953515358495F454146484F4E433D443D383D3032
323027272423141E12090B080E0100000401000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000807080904030405010103010100010000000000070E1E282B2D2F36313330
32382E301E1C1C171316191116141B171C1D191E1A1D1C191C16171C1B181D191A1E191E
192B2724253127332B2231202E2E252D2B2E27342330313632353F37434A443E3A352B25
282B26332A1E1D2A26302C32362A2A2E32292C2D2C32314230424A4240493D4D45353034
2C271D28261C14191F2D1D241E29272530231E242F293037444548413E4F5B5B4C3F3A41
403D3C5437464542534C50465D5E6368546E7C735D665767746D5B675667647362645362
6261525C3F4C42473D3B333E2E321F322C352A2C28492636261D152A2C2C2826271E2325
2D4236423C48393C37403F343637322036432C201F262C2E3147373B36463D47403C3E37
3242393C413B40384945414644624E494B3A4B405A4354384B424C5743413A403B364252
33444E4142334E505F574D3F4D4E4C54594D4B413843413F3A453E524D483E343832444F
3E41444038432E3A424845444B48533F4A4B414A4F4E4150484F4646484346473835342D
3D2B29302C24231E1B11020C0C0800010000040000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000907060507040506020200020000010000000000040C1B2A2B2F3339323339
35332C2E2E2B221818171E1B161218171119181B161F17211B211A1E171E1F181B161C22
1F23283228291B2A3227272F302430252A29301F2B2E322D2C323A333740493B44312621
2B2922243327261A181A241E34292A3139323C273731392D374B3C484B3F43453F313B33
273B3139351C21171B1E25142A2C21221C183316141C2D3A33515444474A553F564A4750
4E47403E323D3E3C50424F4E57576D60616C75637170616D64697170606758616F565C62
606B5554534A504B4B4D323F3E3F402938232C36273D29292738201D24331F26292D2B1F
322D3A433D3E38453A423B383A3639323941282A2A292424352938382A40374534443C44
343F453C2D2A3537443C393B464D4743424E494247453F3C483A4E3E4D38494A2F2E403D
49406158445F4C6B5A50665C4A5C53485F57535A504B5A504351493E474142303B2C3432
4B47413A2E40354E484148423D44533B324849484C4A4540504B4746454C47453D4A3638
2A342C2E2D2A2E211C1516120A0004040608000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000806070804030606050602010100030000000001060E151E2A313737322F2E
32392E312E2C1F2B18171B141713141A101519171C1C17171B1A1B211B1C1915151D1619
1B222012252B2F252B282A2A212424252731232A242F2B1E32212B2E363B3E363B322B1A
23312E3729332429111C1A261B352227454234333132333A3C3643413D3F40433A4B3D35
4841373E37312E23191F222A282C23292C2620202622182324354646504848563E464A45
3D4C38543D4C3C48333E49544F574C64615E5A716C63595D635072695A685D7A6C696262
66585657584745463B43514A303F372D2B35243F3228292A24292529312818241B252C30
2E353838354736413D4030394029372F47392D282A212C3E42443D3B3834413A28394447
422F382F373D402F3A403E344636455152544B534A5146443C49494B41493A3D2C373E46
4745434C453D414D54584F53476A595C56545F573A3E3C2D3C44485445453A3B402C4544
4B402F39393F303B494644504C3D454A4447375839494D45584F54413D4C494943323738
302E362C202A30231A1B11130D0402040802050203010002000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080907050708050303030303020100000000000000060B1C2D36353C343832
342F30323227281F17161E19171B121916161A1110211E1D23271D1D1F1C1B191E1B181A
1A1A161C1921292B2D2C3E2C2E2D272E2732382E2C2F302D2D322D3036393933382B262F
2E2C2935202C282A2023151F2021292D3C3D4137312E2A44292C38342D3C373A45473847
3F363E3F35373A272E2121101D192521232127221B162A202732343644494B524D46334B
4B4E3A3C41554D34342D3E4A52574B565C5E636B60575C5C625879636D56706375637175
6C736C575A5C3D4F44473D453F38413D3636413733272C142D1A2C2011221E2C2628222A
3120393E3041323B3D48373D30352D34332B3937292D1E2E2E3537403B333F4342434145
4C313735492A3D3538443D532E343E34403D49454148473E474340303B343B42473B3B45
353A3C1C3A38494A5C5256625855524B484A4140534D523E4C37513C39543C43473F4740
414B3F40324D43424F3F47534347495B434C3E43534C4D454340443B4636483B39323438
382A2831242B2A2B221B14170D0A0A020805000703070001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000008050806060202000403010002010000000000000004081E2530373C393835
3438302E2B2D332A1E1D1918161D0F141B0D101B161714151B1017181A19241513191D1D
1A1D18202B221A1F232329322E2C2D32372E352A25302B242C241F2C2C2D372D28312A2A
25383A3C2B232628251E212C202A1F2A3B3638432A35363D373B372B252D312B2F403C43
3443414239442B3A342E241D1A1F1C1A20281A2C1C1B1F201D28232E2D393A444A4F4C55
4F3A45383E41464A3D39383C40485A5C6068665C5F5A61645F6F6D686752746D616A666E
5C6859664D5A425644416A433838383838363736322035242E2F1C221D19261C211D262C
3829303C2C44384142323C2B38402B353E3D2A2B321D2827263E382B34353B2D3E454545
492E3741403F3A474C4C3B423E3A34454244404E413F4C3D403D4849413B30383F485038
4B302A2A353A44474F564A555D5A4F42534C44444A544241324852403D3C4B473949402C
3B533B3F423F444050454D434A47484B474D4D443A3C45453E444140413D3944313D3736
383A2C29202C2D2C251F1A0E1712070C150D0C0208030300000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000060906080705070404020204000000000000000004020A151D3137373A3634
363832382B34302425241C1F1E1D1C1C13131B0E171615131A20181A191D1B1B191C1D25
1F2023211C19191A20211D2A272C2A24272829323028202B1F25263029362C312F2A2E28
31282E3934252625261C2B1F1C19222E252F32302731373A44303938372D21254732392F
38373D40493634303D323529281F1B1C26222610261317242E1E101D342D323C38495A46
4140423C3B404D3D373E38443D515957535C4D54596068646F5E645D69696C4F655A6B6F
76615D656458556550504B5E554B472A2D393A33341D3D37242D2E202F35302D15221B2C
18323625443634343525394A40453B3C3B2D3334291F2B2D3E3037322B303B4429393336
2D4C303E4B26433F313336303B2934393D513D504545413C484934494227403A4C574338
32312E26303E394A373A43495E4D5A45584E4A4C554E3F3944484B47484C3A373F33473D
4A364B39333D4A4D51544D3F4C49484A45414841374F454A4548493D3A403A3835372F30
36402F302C2B312B272B1D0F1016140510050D0408060B00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000907080A070807060004020406000200000100000000060D1B2730373C3E3B
3930333131352C2F2B1F22281B171C1B15161316181E191C1A221B151E1418181E1F201D
1A18271C251D1921201C1919162D19252A2F232F2F262E342B39242A272D292D2F2F3332
332722212A1B2628252B283421262A2E1F2D27262B36332B3F443A453020242233392E31
34333B3F403330333D3B263536303324221F1F2617242210161A1E252E252D453A44464C
3F444D3D344444452C4635453A36494E4C4F4F5F62614D55595A545A5E655D6E73686656
726A6A695169646C654F51494F5A3F43414F424B2E373B29292C312D1A3125211D1A1911
2E272C30321C3F402B302C3E45364D40403033322F392F273A363B3A35282D2B2E32324E
433639373B493D322E37433538433E3D3B433C3D31302E37393D2F30253B2E413F452735
323C30473E4A3A433F4C3B4F53524B54435A4B594E414C444A483F4745413C48413C3837
364040453A3C41503B49384A3949494B364C42453B4D424D3F44353E3340383F4441373C
283137322D2F2D2E31282419150A0C0F0D050C050B060700000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090708060408050805040002000302000000000000040015232E37443939
3E4134323538302F2928211F22211B1B1C1A151A1C1322231A181F191D1B171B17202315
1D231D23221E231D1C1C171A24222C322A2D16251F28292A2A26262931222E23222A352C
2C23262428272C2F2C39352934181E1B1718242E22272B3C3326364540352C2F373E3E36
30343434353D3E30383B35322F3B3928302E1A252A1F131519191B262332213A26373339
453447413E4A324A3C323130353934394D4C494C5C464F59576A745F575E5F62736C6561
635A6B6F756A5E6A68635E4C57575947594E4632563C332339302E23271E231E1A1C1B12
1C112D172D2A2E313B3E383B49674F4D4A2F2A2D2921313D34353128303C273D332F4838
3D41424E413D513F3336333531344B365039404B3837473B30353D3A263229354D3B4148
45445458644B5E5141454848475E484F543F474C5D4E50503B4A414451473C433E353B31
4742473732463C32313E4A4B403F433D4A414D434847473C4638403C3E40423734363932
372D382C3938282E2B24201B1A1712151212071106020602000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B060B0908060606070203030201030003000000000000000E1E2E373D3F37
343335333430312D33282121251E1C1B1A18151D1E181D201E1915222117221D121E2426
18271A1D222F231F1C1E182521211D2B25242F32231F2F252D2D282B2E28352B2820232A
271D1E1D2B2E253036252A2D2C292A1727151B1B131B1F26282C3830353B2D393C353245
242B383440392D36373F333B282F3136342D2C3523191A111B1011161F20282B3428313C
46383E4F433B3E444044352530323C3A3A4B52504F535F48596A5A5F665A5D6E68665C6C
5B716A6E5B727C686D64634E524D546653604E5A46462B38252F2B25232C122A11212217
191C2E32192627323E3F434C49614E495243323D2A37292A2F3C3A1524272F27392F475B
553E34543C3A423F342D38353A2D443D463C2A323333423A2D3832382D2C29322A2E3E42
4D54565760665F4654384C4D5B5E4E564F40513F4B4E54523C4F473E3D42585149393233
3A453848322E3A453E3A3E46464643444D4B47403F443147303C3A343E2D3B3E3C4A3133
35382E3136332E2434252C2522181412150F120D08070A04030000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A05070A07050603030505020203000000000002000000000913282C314045
3C3B3C3A3131342F2D2D282C1F191E1F1D1F1E171B1C13161D161E171A181A1C2A1E2828
21211A1F18232A26251F1E0E132335252326232320202D21212B2B2C2926202C2A1D282B
2326291627302D2E332E22303328221E29181D112322271A23242C29221F2C3539403832
332E293D312E3B40393C2A3332322C2A3A3C34372C38311E171C22231C1F212B33313031
473F433E4E4148444D344E383838424641464162444F544F4448585664746068777C6054
6A645F596F6F796A64605F655D6C5060584452484D3C503B373B2E382B291D31211F1E11
2129362C2C3B2D3C36454E48424248363A3A46473C342C2F35393F3A312F23332D3A2532
3F354F3F3F414C40382F333D4536382F383C423F2B3031342D2F233B3B2A292B413F454A
4E4D56655F606B5654515B5B545552485F4E49404D4A5344633B3D404E54674853394E37
484637353F42393E3D404B4557474336494D4B4750414C3F41373F41484640323228382B
302C3E322F2D2A32271D23231F2913181A0F120F10080304010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090608060709080506050704010400000000000000000600020C1D2F383A37
3D3E3B35392C2334203124232D20241C191E1D1E1A1E1A201D1B17181C1A1B2127202224
242620221C23222A241B171F2128302F31252C292B1E202318282A28222C232B27192F1C
2E2A2C2F2A232733302735282C2A2615281D1A20111F1D291D301E1A2C2D363527373B32
36382427333331323E3832313E36412D2D3A304243333F2E1F0D21121E1C262D2F3B5044
40494C4547414D5B53543F3F4341423B3A36464A3C3B414E4B4E625B4B5C52675D58616E
705D676A61606968716C5660525E57526255574D4956403F4B2F3F362F33362927263129
2C231C1B172D2F454F473938373040433C264B4746463623142C2A2A29322F20272D3B35
3239333A42373D3F4A4236434234383A323B353941353B42313133202025212B2F394642
494E585D59525946534A4445545A57524A44584E4D47444D525346473144444844493840
3B4037463F3B403E3D4546413B563F45323B4C4245384C483D3C303D373C3A3D39282E38
333F363537302D292E271F25271D191A1A0C0D0E04070401000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009070707080405050606030303000003020000010000000000061426313439
383F3B3034343A2B232D242E2720231A20211C1C1915231C202B1F1B1A1F1C2124232B2F
29202321261C212732272017132220312B2B2B212A241C21212422202325262D24231822
2E221D282B2E342724192B1B351D2F1F2E2C221E231D2120192227282321322E3E324134
3B283A16312E2D31314830373E303036412E463D453B41363D1C0F19162220353A3E3C4F
4A3E3B4352494843494158484B3C3E46414038353B41324D4D5155485F5B5158444E5E61
525A5C716B69615A535058606953605C5A5455464C3E52403A2A2D24322D44253325292C
262328312A29283A3E352E2A332D342B3C3E3E48484D4041301A311C31272A2928342834
2F35452F3838474857423E373835393838393B24212E35373E2A281B27221C1C364E4546
494E4B5C48454659564958424B604D5A4F4D574D4C484E41565A3F40423A4B45403D4A43
4138334434463A364B47484841384C3E4E4951443746443A3B353A323E36353531383C35
2B2E3B302C332E1D29252429261822191719100B07120603000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090705080706050406040503060302010100020000000000020B1E323B3B
3832333438332F2D33282C2A2023181F1B231D1E1F2222231D1C1A211A1B1C202328332F
233121251F122D30292D22271E24223B301F31272C2A24231F1922221321172122172E1E
2C1C2620252C2A2D2527302828252B362B22271A2227191F08221D2727292E2E363A3050
373530292229242F274545393533283F3B433C47483E403F382B25262924282B3235343E
3F414A48474232372A433F43393B3A3E2C414435323D382B3D4E4D4653475059575B6867
745B63686172565976656969536A59556A575A4734624847384F3A39383F3B39332A322F
322C2B372E403A312F272B15233B22333A2A2C35394136432D322635223234242D352229
2F2B393C28423D36433B423D303A3F39403E3737352E272C3A352F3A3D2A363D32445053
302F3338403E525B51514D5353564655483D454E54514556514D44424A383A474242314F
2F384334403C353D3E44343D3A40443937464E4A3A4042443D3D3C3B37362F4023323731
293F332C2D2E3328282721222422201C0E18120810050000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000809090A090708060504070204010202000400000001000000040A1D2D3536
37373A2B3930342E2E28272029222F1E1712231E251C2C1C1D1D0E1F1F161917272C3732
2A2D2F21212227232E2E252C3027231C2D2C29212A2C171D231C22232A1D25211B1F2324
262E2A2C2324211F272A202420282F2B3329251A271A1B1D1F171B1B1E201B2436313835
3F293922322B303B2F37353E3A39343D45453B4C52414A414034332F2B2A283734313343
3D4C4542514D322A303A353A313E3F3C3A354A39342D2A393342375240474D4A45504D5F
5F766C5B5E4D5B575F5373696B606365696953634C4E4D4C554F47442F2B473A2D3E3624
3123332E385237383A2534271C2C292B222A302A3531343327253D35351F2121392D2738
382B2C43302D3D36494F4A384F3E3D4D4234393C3D3E3E35453237393A353D493E454539
3637343C3B496556513C5A565354625C4F524D554546534C4A513F41454D3D423F3F3D47
463F45363F4845464B3D4D444B3B4C3047483A413D3D4739323E3933312D39333436362B
383F383833282D27231F2820252523181411140B0C070100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090A0908090809060508020401060000020000000200000000010513243136
3B353A3138342C2E262C312E2C291E211B25191B1E2031251E1D2323231C1A181F2D2B2F
3D3429291F261F24202528252127252E29251E202E29261C242325171D1D252F20242230
2A26282629201A3028273A2A25201B2F252E30252923211C142117171423142833232F30
283A3C40212F2C1D3034382E4040434148404544434C383C3D392B292E2029303437402D
33363C394F3A393D34314E482F433E3B2F3238434027342F3333393D4D45374E42555159
635F6D645A67635A67686E79627871766E705C5653494E535253454E494530353C2C3734
323E3E302C44493029342C2A3A28333930332F33342B39352D3828343C37342F2D322E35
2D1E2D3B334137453E2C48353831444444453E3C44452A3F373D1F392C2E3A3B423B3838
34342D4548444E5E465A6C6240545D5A5F70635545563F3F4F4E484C4D3E483F334C3C3F
363C3D3C3C4839414D4334433E4138354048403E344E3E4235363E30342B34313632343C
3A352D322D372B2C2A26201D2A1E1A23170E080D0B040604000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000070A09090706050909060504050603000000020100000000000000071F2C36
3A37383338342C2F272B232D2626281A1E1D1D2524251F26231D201D121C1A1E1A1C2121
2B3E2D3219272718212823222425231C2A21261E242523291F1F23202319191D2B271F29
312A2424311A2A292E2E27242A352C2E3538321E26262423291F18161D1319252B222C2B
2D453D2D442E39303727352F242A36433F465E4B474A484345323E31282D403F4031372F
2D3138423B33382F3E2B3642434D3F403B495346443A2A3F3B3B4C3A333F4C445842544D
58595A564A6C5F5A686F647F6A6164776F756D6A575B544C555C5E45484E4141413B3537
3528322B25323D253D2F203E2A3441422F41403B291F2B2C2E27343539373236382C2E1F
272C2A262C383D3C2F4140453F3C35414E3D2E3D31444332322C2F2E3B34393D41494737
413E33444C4E55636A6F60636266654C655E5B51544D514C49574A524A3F454A37414C4A
44494C38412C3B3D38443C4A474D3A3A3A353A3E433D453F363C3C323022392F39303434
352F3D2C2C27392E2A1E231C231E20171312150A0F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009070A090B0A090806070604060203040002000000000000000003020F2733
323C313B303832323032241F2D241C252B212218152226211B1E1A2221171417191F2325
352B252B2C211F1614171F1B241E2821152018211B21242420251F1D1B221F1F2A233225
23242C2F31252C282D292C342D28382C242B232D2F2F2C232E27262C1F2227282A252C2C
2F263B353439333C3A353C32412F31333A4D41414B4D40413C3F3F342C4F3F48423B3635
2C333A4B3A3B3125323737373149434B414334364146313641452947342E3B4B533E4B4F
4C5447525A53596C6375647370747E647D6C7768645D60625A5A535A442F35424D3A3D37
3142333737383D2C32362E35262F303D2A3E2C2A2D34302E23323439304229242D23291A
2C283C1C283C303B353B343F413E4A3F4146392B3D3C452F312A39253E33373E3E3C3B43
4E4F4E5C48616F66564C5A60615A5C5C5E76555B4B3E4741424D574C5543405443333D4B
3F404C4939393D444F43412E38333F394030392F36353541313D3E3A2C3E37373035322A
30293040303726242F292520211C1E1516130E0908080202000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C06090709080909070504050400000100000000030000000000000109182A
313832353838362F312B2729282620261F161B1C1C20241A24161C1C1D251D151517151D
2832232924182620181C2224261E221919172325271E241E29291D2022191B1823212628
17211E2D1A202A2B2B2923292F272624252E262A2B372E202A291F1E291621221C222128
2A2E2B36353C3827333438282F423629403340404E435349493E33313D364B503C353E38
34413646363D393F3D2E3D303C2F443A47393C32374436393C36463D3E333E3F3D4F4144
464B543E5F6261757563586A6E6C766D64666B5B6C53585E4C6B4F63594D5A3F423B4540
3F3B303936323C28282A3039332C32363A3D2416292D282B383C2443403D2427352E3C28
2D242D2D20213630433C312B3C553B3B412E332E3A514435373F3537302A36423B393B46
3B5149615B684E65674B6C6153605B665F594E464E5147575C39444A5945424C314C5040
42484542483B363C3F36463D44293D353B314138352D37424530332C382F382F362F2B35
2F3138363323272D262121252321221518130A070A010604000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A080D0809080606050305030401030101000003000000000000010E21
2B38363437312C302A2E332D2A281D2522211D141E2521181A1D1B19231C171317151523
191E1F2A1C1E1B1F1D1F21222721211F22231E221B30231E232024211D2519231429241E
271C1B172823231E3421232135281F30262E2B34252729242A2A292C201B1C1B1F292119
1E292A362F2F362C2A2B2B2F33322D322937323844443D3B3D3339383C48454B46464442
42474D43423C40362C333545412D394643453338464E4A3B2F4E3447412E3A3B2F384728
403B32495A545B655C646467636E60556F6D5B595F68616161564F4F4A57535C4D4B384E
413E36432A32353D3A403E34493235353A2928302427283435323140352E3B2736201C2E
3A383B2326342D4131453D363D3741382F45443C47403F37363E3A3824382B2B323D4047
4D4E5D5F5F58676252644F59676E4A51585F6461494E556050575B5C4E51544B5A473B42
464241433A4544473C482E402E44463F3938393C3025303839392C3A2F322E3533392E36
302E2E342C3030252A261D1E20271B210E0E030800000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090909090608070708070507040101020300010000000000000000000614
2C322E3537392B332F2D2D302D27261C212218181D1B1D212118181A1C23141D1A151811
17171B1919182319141A1E211E1B1E1E1C272025191D2420221C182C1B251A11181E221F
281B291F22292B2A24223230232226241D232A2924392B2A34293221261F181E27231D16
2C1F1E30212B2828343F36372A372A2D31383940493A393A3A293D3E3B49444A515A4F3F
49484148573F4438453739484C313B34443E35393938393A3B483744383731393D333F3C
413143484A515A65636E5E6680686E5B6263556C62675E6353515E60584E4D5341474244
54513439453E293E314636282A353B221F1B2A1F2D1F33213D2C34212F25302428333325
242B1E222F1F292D373634313B3C433B2F45443C4541514141513928282F373D33374454
44545543565E465854494756565C635A6B584C5847514A3B55444F3E5744494D403C5856
3E53443E3F3745413C32424238362A423B423A37383D44392F30332F2E3A2B28292E3E31
2931302C2B29272E27221C22201C141415120E0804000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0908070907090906070806040203010201000000000000000000000007
192D33333D31363428382E2F312C232216171F1C1D19211A1E1F1913131A1A1F12131314
140C1716181216201B15211E1B231D1A22231F201B1D241B24181F241611181819171826
2923232322211F24242B292B2128222B2B333B302B2934322E33282F2E192B31282C1E1E
1928251D1E232133353E36362A312E372E23303D333F2E3F2D34303E3D4049444D52404A
504B5E544C49494131443A363D323438353633322D3C493F3C4B38302C34263E2D30283B
40374148505966446463645C666A5F6C697D7266647A70616B635B5F5B665C5F5155514C
4E5A3F4F4C2C453E40393634262D352320252617212C26373636331D2526122D212E381F
1629222A2B402D352B343B292D383E3E3C423A38483C38453C4341454633313D3C30474C
444D49523B414D543E50384757584E4F6358554F55594E645447454B56464946493E4251
3E434D4A43403C4E403E474040503C433B2D2F313C382E443B34273B373629352C333027
3A253131272E27241F281F1E1A181613170D020B00040500000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0A09070907090605050605050402020201000000000000000000000002
0E2531363832322D2C3133312B2921181A191A0F191E181818191B1D201D12231C240E10
0D161414100D140F1C1E1924181F1D1D20232429241A261C221B1E251B1D2720191E261D
1F282C2C222921241C24322C35312A242F30312A343044302E24252C3E223029271F272A
1D2B2B271E2D2719302F4448393C313A2D2B283A2F3F3730373E3C323C40524843493B54
5053535D5B474532473735424039283537352B242A3C3A40393F3D2B31352C324025303A
3245485A63585C525E50595C61556757645D676977756C6A524D4E5E665C546660475C5D
3C45494B3542483F52353A2324212018171E1C272220351F1C1B1E302A2D2D142D1C2832
2221213024313338272A2C3931343D2C3E33361F3B2F473846374D423E3B35353E3E503A
4B4B4A463141443C474A43485A4E5E5457554E55555B534D5A3F554F46413D45573C4D49
413D4B513C474050384D413F433C433F3E3C312A32352D323738382E3530302330392D2C
2E2A2F25302A332723251F221E1E16190B0F0C0304010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C070A080809070509070706040702000000000000000000000000000000
001B2C273133302E35373037312228271D241B13171B1C17121A1C1820191F151B1B1009
140E150D090E140C151A171A13201C21161F28261B1D1A22201C282F16271F2324211B1D
2C271B252A2B1D192B212929252922332636282928262E3A2A242E2F2D242F342B282221
252624272430211F1730303C3037342B312C3A262B33343A313B3E3D49393A403D3D3946
42485B475E4B4342343138442F2B1D2A393632302F393F3C3B452A313A3B323A323C242E
2C304551584F4B4A605A5E565F5964616D5E62705E77686065695569595A665F5B655F59
5550514F4A413F453E3B44281F2E1C2427232C2C23221F1E1E2428211F20241B161A2A25
2729172D2D2E30282F292F2C2937273539383A314E48433F483D434B493D38412F47353E
463C2F3D3133373C5140253B47545651465357586B595C4B545A41424B5153464741524A
3B4F3E45494F4545383C3F3F313D3A413A363E403C303D3A3B3C3C322B37332D2D2F312A
2D2C34232C2E232D232A2119201918100C08060506000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0907090808070905060603020203000102000300020000000000000000
001122362A31352C322B30322B292C2725221A18201A16111E23171F191B1B1C1A160D11
0E120B0F1014120E10121717231819162B201A19221F2017222C2021181F221A22231F28
1F1E23212C242423252221262F26312A30312D302D2E3A34272F292B34232F2B3528251D
1B2324202F2720261B1E2D33332D30383037372D3537332E3934323D3D414C423C384241
46494C42523F3F45373F31323C2D2F2D3233342E4E3E3B4246363A3B423944463C402C37
2F28405B4D5A454B5649615B51646468555A595A65726274645B695A6270686554566562
614C654A4B363E404145452D24121F262F262C3927292820261B182E16271D200D142213
1B1C2012241B2A23282A352D3237323833373A3441253D4140494F664F4B4F3E44464947
324039262C2D35413F2B30363B585550516162626369574E705245544F3F3A4F534E4C46
464B3B3E454E493C37443E42503E36363C452D3E4A39332B3437322D35232E39302C3929
2A2D282A2D252229212A1D14151A110B070C0B0B00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0A0A09060B0B0809070905060403030000020000020000000000000000
00001425302D2B2D292E342C28251E2C1F28231E1F151F1817141B1813131E1B1819180F
10120D100E0C1113131213181C1519241E1A171E1C2A191A1A1E1E1F1E1B12221A202513
1D242A1E1C1F2021222C2228232B272F2D35313635282D32302E392D362C2C303030332F
2C232022291F231F24281C2D25352B293B42272D26303E29403443422F4D3A4837333D42
434A4C534F3E50363F42302540423A3C4745272A234A2E38363A43413D4047413438302F
2C2D40433A4A4A4D493B3F57494C43594F4D65616962665A555F6E6F6063716B55606258
665B62594A4A3C454C48323A352B2F2A112329211C262834213A202218171E181E131C08
1B1B1F222321211F27333A373D2C2C37303B3638233540384B45406A5445494B48405040
373A3534203C4C4738373F46384252595156565565565E495554444D554C41483E474343
3948454646433A45494049413C45453947453F3E403A3C2F38302B3A32312E3733362E2C
232A2F3229312125252620151912100D100D0A0400000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0C060B070A0A0608070504060403030300010100030000000000000000
00000B1E2A30333728322D3431282B2E292E2420212218141E160E19160F141118161510
0F13140C1610140F100D11161814101F13231D1923181A2A20252124191C241A23251E1F
1B1C2523252B252A271C24262F313127372A333D2E352C312A2A2C272C39353131292437
282E1921161F26201A1D272D202F2A27263C433D3837333142322D3F3E4740474A41403B
454C4D495134453344413F42413A493841382F2B3A322F27394046394355373D3F2A2A36
3E343D3A383844413F3F4050545B625A625A585A565E5C696464625E6055675F5E65596B
674D5C4F5F4E574452534D2D403F36282929221D2B17182823211621202019181D141714
1F1B18251A141B1235212F2B3932302B392D3C373C3E3336424457515042493E4E3E3A30
2A33312E392542423D493A3E4C4B4C5E5D6A555951645E645C5B535350414F4843474A54
413D53454E364B414B463D3E414044354141413B3E34362A342B372A2D3C332B3435262D
362D2F272B282027251F28200D141709100B090502000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0A0D0A07080A0808070706060604050100000100000000000000000000
0000020D25593F3C353136322C2C2C2D2B1E2B28241C120F0918100D130E050F0D0F1119
0D0F0C1413120911121213181116181B1A1F15241D1C16201A1D24241C1C172F13181C1F
1D262022291D23261E24281F2C292F2C39322D272C2D252C342B222935313632263A3725
3C2B2A37222A2B33201E1E1F21203231263D273A2F383533343D2A2C322C4A4634494253
4847584D4F574F554B4748413E393F364633413C26323D4029343344463C34323F31233A
2F392B382735333E3C3238403D41475E525A455A595F54635558605D60615E6165686975
54635C4D5155404D4C5F4C4D494F4544372E1521271D2E142A25131019211B1009070019
151C0D2E131E1F0C151E3133271E2C2F3A32242F36363539364B4A48454C4B434F393C42
3E2B38302F3E52414D44483A4140484C5A574C5150565565555B475B4850475237454847
44404F4930483B51424544443137383C39303E2D2B3B342B2D35283A332E2A21352A2D2E
2E3127292326241E1D201E121215140E0606000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0B0A090B0A0709070A060704040002031C000400000000000000000000
0000000116453329312E3339333229312F22261F25251A150F1F11130C0C1712110E0B0D
11110A120C0D1B081508121B190C1119191B23162725251617101C24231D232E1F1C2019
161A1B1B1C272F242E2C251D2920251E2F2B2B302F384333373235382A2829322F282E36
29242A262824221A28232D2A1C233626322B354038283D42413A40282F2A3F3D40564944
49524D5C5A5153484D46313D3F44463734353F4F373A3A3E3F34323C2C444D4F39333E2C
493738313D33373E3F3C3137433E3F4C484C4A555B5C5956665F625E64695F565764695F
6A5E6462635B574C58544A4F483E394F40392C262331221E28321B26191C11001511040E
0E041F1A221C2A2312182732223621393C2A2B2D393B3236342D303B57344B363C374238
424C3E3D41382A3E3D31393E3F4540484148444754484B5449544A5C5943503B4A4D4649
3D47453F453D473E464F4440454B483A3A354033343B332D35302D333534303038332C2A
302A27242326281E221516190D170C0E0803010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D090B0A0B09080A0B06070708070B05050004000000000000000000000000
000000000A172B30333D363638313133252F262726211A1511150C0E0F100A0F100B0F0F
0B110513100F141511170C121016121B1E1719191B251F181A1E15191F1C2026271D1427
19291F1D1A1C1F1B21291D1C2217212F292E282E3D2D2F392735402C2C3E363B343E303B
282A32312827272B18221C272A2423262C332C373545313233333D363A3C3151505D3C3A
3F3C45534861594C423840454D3F49354325342E374A4141282E382E2F343A3C46313842
423F3038293D3938333D4837374C40363C485054405C4B46736058715B63606C55695C69
6074705C5A595A4A44524C433B4A44323A2F3D332E261A2F2E1A160D1118090C00030F10
000D1202141E1F2A252722362026223F38372D2C343E31303E33303B433E3D4C42423933
34363A4245362F2B2F24373C2E3741354B524A4D4A5A444B5147575C4650504C4A4F4841
44454450464748414A3B4B493D413B4141402C3B3739272C30302D272D272A302E223429
292C261D241E1D161812161A0D070F0C0702000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0C090A070B0A0B0A080808050B040102000100000000000000000000
0000000000122B323539403E3E3933322B2B342A1F191F1E1B140A0C14090B0A080E130D
0F0B0F11080E170A1410120F10141412171D1F1B21181C1B1B191A1C1D1E1B291C251D22
2019292726242320291425291A2B28231E2C2729342C2D2B2E3B2E35342F28322E2C2C29
31272A3030223127222126222F2B1E182929232F30342C3740403A29363846484C44413E
413F47404D575848413C424C4A5851473A38353E332D3832402F342D3339403C4A3D2B3A
3C3837472D462E23342F3E2D342F363D3D4D4947494348564E5E67506D66625467556A65
68636C7362585B60554C434E47324941364343394333332E2F29232417171F030E091908
0B00000F061B162126252620222B38202A38362E36324233433D4330424338403D3A4044
4C3446383A31302E3135333243343834553E3E534D5150514E5C57505A4C5C4365474D54
504E2D3E47464B443B4A3F3C404B443E4530432E42343B31342E2435322F303528292431
262624232021171F16100E100406100A0600000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B0B0B0A0A09080A090608050A04040002010200010000000000000000
0000000000042530374342403A3D34322D342C252722191914150D1107160C100409060D
0809061013110B080F130B14060C1415181A1F181920191F151C17221E17231D1E22252E
13232C292A201D1A1D241E232F181F24282F2432242E312A2930313B4033363625322F2C
1D23292D2F292A2B242A2725252B23231C242431292D373431352E25334436484335383D
2F4236413D57524944443D53503B534332354C3D3F3A33442D3633392D30312E3230403D
3634402E2E272C3A3B353135293A322C354A353A293A4F4D524C5558584D5755625D7067
545E6964636C73664D4854544E5747423D46393F342D43392A292B152A1F0A081300080B
0000000008101F1522161D1E25293731282E39243346433C34393434363F354847362F3F
3C3B343C35362F2F383732493335313A353F474F4A514E55584E5754694D525946474A50
434C4F503E4E493F4A3E4544404D44403F3433342B31333C322F2328283A2B2B342C2F27
282A221F1F1E1E211A1B130B0B0806020206000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0C0B0A090C0B0807060807080405060303020000000000000000000000
000000000000132B404842484A4A3D3736382F2D211C1C191B0E0D0A090A120703010A00
050C000007090E1708101707160D131D13181C1B191517241E22171F1B1D172618232B28
2321202020201E281A231820282421162330282F292A2434323733332D353B2B332A2925
312A2F2D2B2A302C362B2A2B252B2F222329292A3331292F3A2B33393A36443843402A32
30333038545649514F40405342514A484A434C3544343F3C4133253834353B2D342B2C22
3C393433363B39353C29263428272F262D2E3B39313A3F4F4C46464E5B5A5A5C6F677B60
5A635A655D615E6965685C6751474D4845513D383B31392F3B222B3B1D2025150C060202
090000000C070E0B09071E221C24372C2C283231213D3F3338392D31213A333F3A393842
393E413B393030362A363439322E393435463342404F554F545D55514E3F4A4442534845
413F4D413F4545443F49383D433D3D413C3D3B3B353633354233392E30352A3C311C2221
25272D2C1F161B1A1E15120F040907030000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C090B0B090A0B0C0A08090908060705040204000000000000000000000000
000000000000072733444C4F4D4C443B3A392F392A291D191C0E06000C01030100010205
08000503090C0B0E0410120A0D1B170F1113191318161C1C2624181C16121E1D1B1E211E
1A191F22241E211E1A2C2029232425221D23232B262E26231D242C32352D2E2F2D292E31
27302A2E24322A2826302E1F2C281D39202A272C233B282E2D27322D2B3432403D321D24
332A2E3C3D4A454E4B3944394F4E52393F3C40413D3D4054303931393331362F353D2C31
342A2E2D374239412E313536332E3225212E213731354D3D455040545F5B5C65605A7B72
59566C6A606B67796A6560674A4C4E5459533A4C42313D3E2630291D16292521050F0606
000000000000020A091B1C1C372C292522263623263C37363734292D36362C36342E3B3A
3B283432312D1C342F363E3D3B34313633333D3D404A4357525955523955524345445242
46484C47414C3840454C3C433A4F3A503C402F383D3634363A292F2D37332C2F26291F2B
29272A1F211F1A1A100F0A0A0B0704000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090B09090D0C0A0A0A08090A080B0507060204040302000000000000000000
00000000000000122F4A4E5055524F4C3C3E363C32311F2019160E080E02000106000708
0A0A000707070F0708110E0D1018151B241C14121A11201A1D1A1A12201B251E1E1C1B23
1D19171C21191F1C1F2124242727231A2625263624282B1D281C292C362A39302F2D292B
28282A2D282E2A252A37232622271C24282727222B24281F272C2E2D3F362C452D2A1E21
291B2C36453F4A364238384241483E3F453C453A404E4B4A463334372C40302E311B3539
2F3E403C2F2E2F37322D333232382C20252B3A36363E3351334B47525859604862606E5D
586260565D686C6E6F607E666961535B5654463641363D3E353A2D2D32261E252B190E00
00000000000007001D180F1C1E3225262A2B261A26282337353844431E3C1F2338263D35
35343D353F2B3C242A3A2F302F34352B343740374748444757464B49504C624E444D4844
54423F51414C3E41435145434433343E403F3A312C3B3033372B382C2F23302825302B1D
262B2A2B161C18181B101003060C04000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0B0E080A090B09090809060906070104020301000000000000000000
000000000000000928414F51545C5556463E313530312B261F191615040200010000030F
0700020000010200120B1914161217191319181F19201D2318221C1815211B1D271A2625
1F1E1E1D1D14281D2A1A2728282721272626261E2927312628202C253739322927323333
272E272E35312832282C3B29242E27212A3826262835211E1B15222C26353D3D3C362632
2E242F2B373E2E2E27283A2F43494C40402C3F3D423F4D4B453134333B472D3438342529
423D3B3D34402C373E2D2A313732403C1E2D23362F2D2B324A4F4D5A4B6244564F685359
51685C6A616061655C70705D615B62526D5157563D57354438332F38292A212726160700
000000000000070E0C12051A27212B24221827252F2929352C34362A252C25302C323033
272E3A3E32381831322C2A2C3138313F2D2F3539384C4A414A544D48474C4D46464E4847
52423D463D4A42474849403A3D4D3B383F433A373F32342A2D31342C34302A35342D2C24
2526231F241911170D0C060D070900000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000080C0C0A0A0C0A0D090C090909070507050505050202000000000000000000
00000000000000000D2F4A5D5F57575354443B38373F2D312A221C0D0507010200000000
000508040002060A0B0B0807151213130F111B1418191F1F1F1924162818251E22212122
1D16271B1C1817162E1C22272E1E2C1C221F2B28242927232B212D2936272622352C322F
2F332C302937322234262B2F2A32312E2D342627302A2C212927292427312E352A383735
2822283A343527303620262C3238463742443A453D3747374A3936363C3E3E442C36342C
302428263F382F342B2D2E2E3F3D3F382F2B381C26253D3F4D3F513E4D5E5B45574B6363
74565F5E6050555E68595F7268685C6D5A5B55464E423B3A4E34232427242D2C2E170A15
0E001000000010020F061C1E12111718142A321D1F143337262F282B2720372C2E1D132A
271E243535292925372B3A3B362A34393D2D2E423F404E444C3844443F305140494A5041
4D4B463B49443B3741413F36383D423A32373D39362D39293530312F342A2E2A28261F25
252227181F1814110B100D03060000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A0B0E0D0B0B0A0B090A0707090906050802020202010000000000000000
0000000000000000031E485A5E5F5F60634D51424338403A292B211A0E01030502000000
00000004010003000003080A0C0C0F0E121211171D1D191E1D16191E21211A1C26181C1C
28261E291F14181D24101B1B18281F222614292325292721241E2020252B25232932292E
2E2E2C2B321F1F2A242A322F2B27242D272D3129232C252329282721122C273428342F2C
2932362A40333527242C3C324334363D2C3C3F3B443937464B3F413B323F3B41452F2B36
2237362D3A38412B3B2B30303138373A3A2D262D2C332D3C46424A3440494E435A4B635A
5D62656A5F5B634C5F616D626F5B715E6B50565D575C5342463E472B34242229231C1E0F
161A0E090A0008000B001409131B1D211E1E38332B2B1C1F32201E322E2D362931312C20
2727352D252728262729363622391F2C233A382A383F3134343C3B44423A3D4C47403739
444443443F47493B4E424149382E3D3C3F3C3C3C353039282B392E30272C2E2328282A20
282120161C1015160C050704040400000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0B0D0B0B0A0A0B0909090A080B07080407020301010000000000000000
000000000000000000172C4A666D696B5B5C53463E3A43413C282B1F1A07040000000000
0000000000000007000007050D10120E0D0516160C19221C1C1C1E16231D1C20201C1F1B
201A1E2426172024181B1F251D251D25212C2228272D1C1E201C262E2C2732292E2A2D28
2F20232A2A353126332439213528303026272729281D271E3C252B282228262228282737
2A362E322E221C3229292C34444549334748393E4339413D363A473F3E27452F3738332B
2D2631393E32343E402C2832363C464E222E37303331473B4B383C395B3634404A3A4F4F
68666E607663626656546B7161635B5A605C514F4D5C5E50403F3F3D38362B2F21242012
021508120C000011001411061307140D232928172E372329261C362C372235322E1E1719
31232C27212A322B281C33343B2223282F252E4C38372F2931354337413F4B334C3E3D44
4443384B37483A4244424441333745323F3B363D3D29392F2F2F212D2C29262722292C2A
211B1B11190E120C110B0B08000300000000000000000000000000000000000000000000
000002000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0D0B0C0B0A0B0B0B0B0909070608040205030403010100000000000000
00000000000000000000153F606F756D6F675E5249474E3D373328201E0D070000000000
000000000000000200040702060D0607110F1518191F1518251C2315161D281F1E131612
1B1C18181F27201E27201D2729221E212225211B291C2520261D1C2A1A252A3B312D2F30
2A2E25312D302B302E302B25252E222933282A242721222623382D2D24282E1F30252524
2C32322A282119292022313038412C28433945424B4438523B4B3C3D3937403C41353D35
2F2D40213C3A353A42303032353F47293B2E33383539262E3D3E443D2E3A4A424D4D3D4B
6965685A64545E626E6374767B6B6A5E6A64535E66584A4A4E4D4B4A3F332925412A270E
16111A1115101B0808231819210F1512292D24242D261E1C272A46432F33322825282025
23223134272C2528391A2326342D272A293E3030383626373835343F4A49483A4638393E
413D4A394D383E4D5143393D323D36433C42343D3343352F3137312D303D38292D262A26
201A1B16111919070A0C0402000000000000000000000000000000000000000000000000
000001000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0C0A0B0C0C09090B080A0909070A070707030406020100000000000000
000000000000000000000A264F6177807E786F645652444D483F35332725100900000000
0000000000000000000000000009040B120F15161814141D1F1920171F1F201F1B14151D
1C1C1F23171722141B1E1120271E1F23291C211A22271E2522151A242521242F2B2A2325
1B1B2C333D282C2A27292535332F30323A2327362B3436241526271D262A11242A24222E
2C30332A27292D1C292F2419252B32382A303F3B3C4A464D473A4839483C3F3A3D374133
444030343735362B3733292934333A3541343D2D3329202A302E312E3547383941454748
4C61606359554D6E637A7479696B5F6672597068615C5F544D4F46443C3339433028391F
1D1A1D161A130318171B0D0E161219111C15261B1D2A241E26333A3028302C2F2C311B27
1F282B22232619222A31161F262C1F24292B332E323D3E31242A24333E413C3C41303945
4A3E4C3D3E404047474140433D2C503A34373738343332332F2D243128362D352C282C2C
231C1F1814130E0808000402010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0A09090A0A0B0909090C0A0606060B0606080401020200000000000000
0000000000000000000000113C5E797F867C7970655757534A484137282A161803000000
0000000000000000000000000B040D0A0F10110E1E0814190E1C1E1B19232621181F2018
1B1E1E20271C181A1B161E2B232C2B1F272420171E22322531131A26212B2B2231192026
23272F35302D32282F29283628282634323029323B2A261D23221A19231D242423291E25
282628242527353C282D272E2B2C241F2232343C3D3C433D3A56533E3E3B4D39453D3D3C
353C4737333021253127363528393E3D362F3D33302B24302E2D312C363D3D3A41402C3A
414D3C4B4F575E6557605D6A6C6368716764707163535E605B544D3A382C373236332E22
222C161319131D161B11151C2116170C2312161B1D1720223A392E2F28302F26263B342A
262D2B1A2F181A161D23212B2F262A2F2931272F2E2B312D312D2D3D343941323A394348
37464A45463F443D493E3E423840463E38373C363F31332F4228282D2E262C252D2B1E23
211E1F1F1D100E1603020000000000000000000000000000000000000000000000000000
000002000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0A0A0C0B0B0C0C090A0A060A09080605050305020403000000000000
000000000000000000000003183F6E868C90837D736B5B4C4F4B4B3D3931242509010000
00000000000000000000000000000006040F1D0E0A0A0C161F18201B1618211D1217161D
221C1F291C1C182221141B1D1C2C29282522211E292A22282523202C23271D29242E2528
22252625272F2E372E332822302532323630322633393336292424271B2934292227231C
21221D22302B282A2B2D2B1E22281C3133353D3439374B49483A42393B44403D46482F38
3833382E322F3D3237333D1B392E272B2E31383D3B34402C2D31302D3025413446373D34
2F3E3B4C464A54514F53605F5B65655C6B64745C6E56625B4950524C483F2D4833303B3F
332A30171D1B132114101F10161C2820221B1919272418282425212825272B2237292824
29232522171C252D151C22292A251F23262B332A2D27232F2B2535392D312C354036423E
373E4E3F4344433F4D373C3F4947483A3B34393E36343639363232282C3027252E2D2223
1D191A131917100A08030300000000000000000000000000000000000000000000000000
000105000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090C0A0B0C0D090B0D0A0A0807080B0A070608070605030202000000000000
0000000000000000000000000C2B587090A6918C8062635F59464A413D37271816040000
0000000000000000000000000000000200030B0C080A0E0B0F1E1B192417141C1A1F1B1D
18162013202521131F1B1D2A2115291B2B272022302C2D2929252B1F1C1D2923301F211D
2E1E2327312B31321E231E262B283927221B26253D3D343235292E27292C1C282F281E17
18262623201D2427252C32193329242A38362E36433B4B433C454C52474743453D40403B
4F3B342C372D2D2D39443F3F453C383B3E2C452F2737232E3C2B2B3028212E27343F3E35
383B4A3B4C434C4D4E555A40545A5B626162604F59605969645846465B593C464638313A
303127191A28061718110F141D1F22221C1E1F1B21232B242322221E2725302B20343524
21211C1B1D1D1A20171C1E2D2425282328222E2830283C29302A333237393034302F383A
3437443D42404545413E4234433C40414531362D34382D2F302E2D2C2D2623292818201F
1A1F1B181005110907060200000000000000000000000000000000000000000000000000
020101000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0A0C0C0B0C0B0C080C0A09080809080B0807060505050304010300000000
000000000000000000000000051F45708793AB988D7971725D5C52453B3A37271F180A00
00000000000000000000000000000000000305000D060B090A14141C16152521221E181C
170D0E1C1F2624171728191C1A1A1F222324222638312630231A1E1E222A1F251F18231A
1A272C2535352E272F222C322D25242A2C35292C30272B2B36242C2A27322C27282C2B20
1E232824232B1B173334272D2E27302D4134393F4042453C49474E48504B55474B564652
363A4A39343D372F373C3F412F303C343334403B43323038343333243626312633273D2D
2A28383E4942434E3A43555046505451635A6264555C675C5D5150555147483742513639
37472631292B241913101D1E1B1116161D25290E1D192E1E252C2F153823221F2A282520
2C28281B1919142105181B201D242B2420222B2C2F282F27242F382D27322E31323D4036
2D363240323B43424337393F4A413C3B3E3B3B3537393036332D2F2A2E27231F291B2615
1A1C200E0C11100706000000000000000000000000000000000000000000000000000000
010301000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C0B0A0A090B0D0C090909080B0A080608080805030400020000000000
0000000000000000000000000700204B749BA3AAA7977D78695F5A504A41443420140800
000000000000000000000000000000000300000B10010B0D0B091414171F241D1B201A17
191D0E0D10242020281C1D1D1C2124162421312632273535231F222D2D1A2A252727271E
2324272C2D312620302B20262E202C2529302524372F3330342C292A3B3443342A352B33
382B3322211C28263C2F302F262E2C3135303A3931413B383B3A444F4C4149413C4D404B
4235473837342A3631362F343E2D2D35383F39362D2D293225222C423233362A36383029
32332C2F2B413A3D3A3B43414B5B5164585C6069686162615F59535E4D524D324A373C41
383E3936262A191B12141820191C181E21161B1022232A1E2D181E1F261E1E2B1E272134
1A2F261F28141E1B271B191717262327252C261E25191F2F2E372B29272F202D362B2E25
39333C344D36313C40303E40444442454039373C313231393831252F242420281E221B1A
1C0E120E100C0A0702000000000000000000000000000000000000000000000000000002
000304000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0A0A0D0B0C0C0A0B0909090A0B090A0B08070504050404000100000000
000000000000000000000000000810396690B2B9B49597877469645642473F2F30221813
040000000000000000000000000000000000000000010D090B0B0E1A16181D1F20161525
1D1A1B1A1C2215191A1C22131C15221920242021222B27221B2019211E27251823252823
2128271E233428251D1E261E26251A2E2B232E24282F2F31262F20313A412F3F323A3126
2F34312924222A232225272B252E392E39403A4037413445394B4F46494A3F3E4D3C4A36
4649404C3236482F39302B2B3D292B2E3429383C2F3A2E32303B4B33372F32362D2B3637
30313A383D41362A383D433F4447635E4E6157605A57625E66665B5A63574A4B41423639
333C322B35382F2129191C16242137151D1917210A1D1F241D231520241F27232823321E
2F212A292321211D28182423110C2C241C182B2A2D3024132539252E302227302A273434
31282B32403B323535323F3D413A413F3C3B2B303430372B2B253123261D25211E242219
181C1A0F0F13050100000000000000000000000000000000000000000000000000000203
010205000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A090B0C080C0C0B0A0D0B0B0D0B0A090A0807060809050102010003000000
0000000000000000000000000000081C487CA4BABCB2B79990726C674E4C4B41262C2E1F
10000000000000000000000000000000000000000008070005030F0919151A151E181923
1A21281F2021271F22262820211D181D201F2218212E2E24152D26202424212E222A332B
231B2E30272225272A292C261F2D292D21252D2727303236392A31313A3A3747332D3028
3A2D1A291E1E2727232B2C2E2B202A373D323D3B373A3D3D504349494242404632424945
4C454A273B3530323430312D35313B352F38372E38352A2B3E33332D312B37283D2E3435
372E41393836322C243B3F3C485558565C5450645A5B585C5A54595B4E6156584B49484A
33392335292F232D201C232B1E23291D1A1D2D21101C31212D14272729261A23142A3F25
1C3726241D241A211A1D1B1D1A181B2627121D1D2522241F241F30212529262E2E31292F
2F362E3B3B3E363A40394342373F423C3A3A3A332E2B323733362F28222825261B1D1A1C
170D0B060702040601000000000000000000000000000000000000000000000000010002
060307000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0C090C0C0B09090A0B0A0A0A0909060808060804040502000100010000
00000000000000000000000000000212265D93ACB5CABBA88A8376765E4E4B4A3528231C
0900000000000000000000000000000000000000000000080006110B1B1913101E18151C
17210D21231F1D1C17251D14281F1C1E1F1E261C211F1D22302125252324201C251A2224
2A1123272B24262F2B272D17212C2626252625322B22262E3332372E383D392934332D23
2C262D302623201C1E251D3332373132342531362A3C3A39393545414447453E3A3D3549
3F3F40363A3C4533402F26393A342D3A364337322236412B372A38452C2D2E292E2A2934
463231252F322F3927332A45525163605B565756605C6058576661544F615F5F505A3647
3C4242413B2E2B1B262B2D311E1C27292F231E252620243D3B22292F22272E27252F2021
1E2C1A2331351A231E1C151E131C111C1A2224221B2625142122271D292A2A322C2E382B
372A372D2C293E3B41302B3D3D434635373134242D2E29352D282C2B282125241E1C1E18
110D0B0E1200000100000000000000000000000000000000000000000000000000000200
020504000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090C0B0B090A0C0C0B0A0D0B06090E0A080A070A0505030505020002000000
00000000000000000000000000000006103075A3B6C1C2C3B0A58172765E535441323020
1A16070300000000000000000000000000000000000000000E010A0E170B161D13101721
1C161F1E2222251923181A21231A111E1E15161621212B21241E262624202E1D242A1526
2D24202B2B2625241E29312A21282C252929392F262A2636333633313D34342F2A2D2522
362D28252A161834242B3126252C2E23292B312E2F343027353838334641403D4145453A
49413A4A3D3E4546452A2C3B333740303731303E312D1F2F333440323230222821202734
273224242A2A2D2B3F2537384D595265676766646E586C606657535A60645A494245473D
383D3D312339402B293A2D3022282F2A37351F322D242B2724272B3A3324222C352D2D23
2633251E1B1C222B2627271B1D1C1B162422181617232628272522292123272625242A31
2B3127292E322F343B303C31393D303933302E2D322E2B2D292D2926242E1D1C1E111814
140F0E0D0C02000100000000000000000000000000000000000000000000000000020002
020308000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000E0B0B0A0B0C0A0C0A09090A0A0A090B080807070706070301070100000000
00000000000000000000000000000000001B4272B5BBC5C3BEA09B867168725D5A473427
1E190313060000000000000000000000000000000000000000000905110D031C0E04150E
17152225191625201C1B1D171E1E152915192426172824241F2220201E1926252A202522
2A1D1827231E202A27292B2D1D221E1D1C2723212F2F352F36293F1E302F2C2C2128292B
30242A24211D20201E2C2F1F2D2632363031323B28252B2E332B2B2F3F3640454E41433C
444140414D403E46423738363D393A352D2D3237473B353E302F3F3B3A36232A242E2D39
27302F2C2A38364B2D3534423B596A68636B6A756A7A5D60585259515D5B484E41445659
482E25443B3A3E1C463343343629363036422E343924312B30362F233D25292335323031
30272D23211C20231B1C191717150F1316191E1420281E21211F2125292B262727293333
2E25262E392C303631373534373330343C332F2A342433262B2A2C20231F1E1B1A1E131A
12120D060403020100000000000000000000000000000000000000000000000000000204
040505000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0A090B0B090D0B0B0D07080A0A0B090A07070808070403060500000000
000000000000000000000000000000000000224484B2C7D5C8B9B29C7E7E7D666D54533A
2E1E15050309000000000000000000000000000000000000000000080407050507140D0E
15141B2318151820171F12220F15291C292129201E2C1D242E272D2625272A221C2B251F
1B1D2423221F28212E21242E2929282E24201A2B212539372D303138242B232529382B2B
2C252C292A2727272823242A271D232538312F2E342E312725292F2E453946373E3C3F3F
43434F484F4044453549443B352D4032393B313937342F2433333C40493D37283D34424D
37333525332E392C4630382E4F616766757A756D7A71685F6363504A514F49414D385543
4D3A393A3B2F47423F4536282E3D3743233B34303E2B2C27342A212D2C25303D2A276F30
241D24323B27252521292322231A201914180E1B1414222119141F1C2824232E35292B24
23352E2A262D2D2F2D2F33323436302B353533363C332C2A2F1F27271D1B1C1D15151614
130D06090200000000000000000000000000000000000000000000000000000000010205
040509000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0C0A0C0B0A0D0C0B090C0C0D0C0C080A090A0806060503060101010000
000000000000000000000000000000000400172C5B9AB8CDD4C9C7B498917E87787E644F
4C3823231A0B090000000000000000000000000000000000000000000000000A0E070F12
170F0F0F151C0E1E190C1B1413212221271F2B1B251F20212820292C2C1E1B232725351D
211F1C1A1B1D281F211C1E2A2622182127222C23222E28393B342229332624203030302D
27273A28282730242B1F24342823262C26202C2A323637222E31332D363B35463C433444
3B423D41493D443C3B47392F2B372B324A3636313231323A323D3F46393843313B415253
43352E33272933303136373944525C727A707A7B8669696A665A5660525956434C423639
4132332B382D3E3B3B3E40353F32322E34362D3B2D35312C3B243726352626322D2D3229
2525272F332827231F232B1B271D10131409071520271B1B211B1F1D2E1C281E283B3229
2D322A25302E2D25262B30352A302D272B2E2E2E2C2729232A242922261D1819181C160E
0D0B0D0A0901000000000000000000000000000000000000000000000000000101020304
050605000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000009090D0B0A0A0A0C0C0C0A090D0A09090A0A0709070A070503060705030000
00000000000000000000000000000000000006183872A3BDCCD6CFCCBCA0978988757F62
533C2E2813190C0300000000000000000000000000000000000001000000000001020511
0E120F0E0C101516211A1D0B101314241C1F1F1F2216201A1F17232228122020252D2B25
21241E241E1C1D211F19291C1B1F1F2C252E24201D27222B36322E1F252B271C2E282E31
34202E362E2A222725222C2A23322B26171C2623243032332C2E323B3539362D37343838
3C44324037364136414A4A45423C303A3D192E2F363B3F38372E44413E3339493E434941
463724211C343B3D3536382E37425349677070726961695F644B56535A494C47403F422B
30382B3C26352D382C361F363F3534283632273129303130233C2B2426342D383033392B
1D1D34343A32332726222725261E2115180F1714161A1214161519141B22232C35212E22
26262D292E382C2F2F2C33282A302F2A2D30242C2A2833282A1C1E181E1E241C180D1516
0B0C04000000000000000000000000000000000000000000000000000000000200060204
03060A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0C0A0B0B0C0C0B080B0C0A0908090B080D0907080707060A0706030200
0000000000000000040000000000000000020003265181B1D7BED4D8C4B5A09692888471
5A4D3F382E13100900000000000000000000000000000000000000000000000004000208
0C0714130C050E0F0B1A1221101214191A1A21231F211A1F23251A2021201B262C25352C
2F231F162321192D232A1C1D28262C2C2625282025201D22264230273522332C2A2B2733
32352B30382C283630351B2F2224251D1E2612252A1E2E302B3B363033312F32353D2C2D
3A3330382F3A3C2D3F434A373E3E3C3C46293636293F262C333438443D3D2F3B3A3D3636
463A3028282B313C453B2B2B454851525D616E6F68786865695362523D42463E4A463937
263E2C2E4F3B42273B3732293F3539334539402E2335343C3431442626312E24333B3A38
253337322B2A272C292923272A2E221C180D0F0D181F15101912101C1C1D1E2022292D2A
2539302F2F292E2B1F2D2B1E22242C2B2D2832252C242A2427191F241A1F1A172114160E
0A0308000100000000000000000000000000000000000000000000000000000204030405
060606000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0E090A0B0B0B0A0B0B0A0B09090A0A090D08070709080805070705030201
00000000000000000000000000000000000000000D275D8EB8C5DDD9D3D3B4AE979A8E7D
7C5E4B3E3127261C10000000000000000000000000000000000000010000000000000007
000F0B1117120D1618191F0E0F0C1B1D1B192318231D1823241A22201C23241F1B192735
362E281E101A1E1D25301F1D221C252D2D2E22282A1E1E21222F362C3429362629332826
232F2F2C2C2432302F262B32293326190C1E2216191F2432352C27321D223C3F2D333724
3937313138362D362337484B3B3D393A413A382F412B39322F2C443D36363925413C2D40
362F3F2E2929303246293433463E493F595E5E7564686C636A535D63553D4949453A4636
393D30333933343033392D373B2432413037453538384B3536362A35272C2F3630283337
3233383031282F312A231E1D2129202107210F1519171918241219201D16221A1B211A23
282731293130322827222E202B23292B312730292625221E20201D1C191C1B180D0F0F0D
0D0300060000000000000000000000000000000000000000000000000002000304040407
080608000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A0B090B0B0A0C0C0C0B09090B0B0B090A09090808080508060303040402
000100000000000000000000000000000000000002112B5E93BCC3E1DCD2CDADB69E9B95
8580644E35353029160C0C00020000000000000000000000000000000000000000000002
0900060A0A1608160F221412140E1F1B191F251A2B2020221E212F1D1C1A261E26212333
252A2622231F222224272D1D222125262425393D2D262026272B262B2B3C2B392F322D29
3127272C2D302D392D3522263126202C25201B1B1F1426242C312A312427253728272130
3F34392E272B332B2C373D38432A2E3131313D3445343A302F403738482F303D333F4040
423B3F302D38413E423A2E353736475144505656646A766B6055565B4234473647373C43
3D373F334D3129272F2F3438424A434C45555A4834454F32423C3325443A393A2D2A2927
3828423B3B3328313130371E2A2A2D2017131C0E181718171A0D14141710191B2B1D1926
2A252F1D2F2B292F2C272C2F2B262A32252620222521251C20252820152012140B10110B
040500050000000000000000000000000000000000000000000000000001030302040606
070806000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090D0C090E080B0B0F0A0C0A0B090A0A0A0B0B080A09090807070706040202
01020000000000000000000000000000000000000007163869A2BADBEBDCCDD0C6B4AFA4
97957A6C614C35251F19120E0E0801000300000000000000000000000000000000000004
070000000408091113090C1B1115200F171F1C1F21231521221A20211B232B1A1E211C20
1D2B21252520201B21222C2F13151A241C1D2E403B382321202A212E352D372821313132
2119232F2E2733292D353B392F2A32251A1D231C2711232D2C221E302D30312D2D282C2B
272F392E3130342E24353B413D362A3C3D3C3A3E45372F3D2E3B3F3443372D2536423033
333737343C3E2D31393D2C3D4539453A445043595E59637069595755504E435351463B3B
3E34343B403C3D40443736434B3A4A4E5154656355614E5449475F574648424633403F2C
3F3D4032362C2B2D39273027312125261D19180B141113101A18091115121B26251C291C
232B2A2629272A252A272524332322222E27292225211A1C1C191721141312120C0E0907
080809000000000000000000000000000000000000000000000000000001030305050606
070807000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0C0C0B090B0A090B0D0D0B0C0C0B0A0A0A0D0C0A09080606050B05060502
05000001000000000000020000000000000000000000081A4C7BB7D2E1E6E2D6D4DDCCB1
A9A8927763564539292B24130B030B000900000000000000000000000000000102000000
000000000403080C07140D191E1B1D171B172027162117202325211A232226232A24191F
1F241B1916202620162432251C1E1D12231A1F2A2F3D3C2D341F1F2B263A233738342D29
2C302927332C2C2D282F28292F2C2D221D2523211529221A2821262F2B2F242D20202326
2427313437352B3D35434A2C3C3F30403430403C3741383936393A2F3737282B27333C3B
3E3B433D403943412F2F3532424939403D4D52534C5F6467606B475A4E463D3B3E493033
4A473F37363E3A3F303C535B50547066606E6F675967656F71685F5663544D483A383B21
2E3939332E2A383437352B2926262B20261B1E16120B1A090F1017151A16191A19202027
252323252C252928271F2528272222282826231C1B1A1C1A1914191517150F0E13050204
000001000000000000000000000000000000000000000000000000000300020604070508
080A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0E0A0C0B0B0B0B090B0A0B0D0F0D0B0C0A09080C09070908080606060503
020300000000000000000000000000000000000002000104254C95C0E1E6F0D3D7DFD5CA
B9AFA490907B624D462C1B1A090B081C0206000000000000000000000000000000000000
00030000020B07020B0C0D1916090F1C1814251F2024262122141D2118172A2428252B21
281B29201C221719282530262E1A191C161B241525232E2B2227291F37292D2D312B3037
242D2D2E31262A252C24372E2A442D27282822201A292C29271F20222A33392D28252515
24213719292630313934383F333933363F3C3C3F2B35393E383A4D40402E2D3634262E34
3034363E3B4B382E331D36323C412E373440434C49485660625450573E5B524541454338
49393D433B32384D3E616A606F7166656F73737D7A687268766C7B7A656D57615E4B4058
423F2C31292937303230322C2D3721200F171911151610131915131517111A0E2617171B
1E261A212829272A232B2B222C1D26242419221F140C18121B1615160E110D0E090D0606
030300000000000000000000000000000000000000000000000000000002020404070507
080B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0B0C0C09090C0B0B0C080B0A0A0D0A0B0A09080B0B050B090606050403
0403000000000000000000000001010000000000000002010F2D5997BFD0DFEDE7DED2CD
C6BDC2B8A1827D6A51423623261E17140607000000000000000000000000000000000000
000000000A00030901030C0E0C11102013151A1F1C1F2720242A202B201D2C27231F2124
1D2329201C1B262526262725241A23291C1E201418272030282F252922322F38202B2823
333635332C392B282B282E2E382B29302C2B262E24231B19131A202E212D2F313723231F
221A252E30372E31343B323A433E25463D3F37443A3B373436404A273A3234272E33312D
2E2C332F2A3F46303030253841383C423335434F3B46564C5A4F5551474D493B47393339
4127393C3B3D4C465C6677658476747B7F77886D7B7D7E877D707B6B8267666B63585753
54462E24382F31343A322E253324271F1F1117170F031301180F13170714171F181C2D1A
221C20242D2D282624242718212A1E221A22221C221C1918160E18100F0A08060E060805
01000000000000000000000000000000000000000000000000000201020202040408060B
050708000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C090D0B090B0B0D0B0B090A0B090B0D0B0C0C0B080A080809080707080503
04020200000200000000000000000005000000000400000709192D64A7BFD6E9E3D8DED7
DDCBC8BAB89EA1776A614B2B33292B1F1402000000000000000000000000000000000000
0000000000000007060C050F0C101307161E171118192B2A282F2C2E1E2F2F252B242326
2620212927231C1822171F1A271C191B201E21141E2924292321292826232D2A29282F2D
2C36333A3D322F2A26222E2834342F3633302F291C1F1920191B2B20252D2B2D25282527
1B222325302322272E2A1E263433344E3B303F35322F3B30422D373548362E2C37372E2E
2F35353F303733402D2A2F363932363B3E42372E3E525049604F404A4E4A4543512F3534
343D3D3140414D585F61707A868B8C817C8182948684977AA08A8E85806A6C607B776363
6449424C2942403731382A321D312820201E1614130F1A1715130E09111B14151A1F1C26
1D20192226231E252C2327261F281E2322161519241A170F130C0E0F0A0B0E0406050500
00000000000000000000000000000000000000000000000000000402010304050A0A080A
0A0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0B0E0B080B0C0D0B0E090A0C090B0C0C0B0C0B090A060A0607070407
020503000200000000000000000000000000000000000002000D17306DB0CCF3E9E3E7E8
D3DDD2C8C6B6B4AC8D715C58464637271F15050100000000000000000000000000000000
000000000000000000090E13080F110E0817211912201B2328241D212A25272520232628
2D2321272D251C1C241D2623181B2D1C1A291B161813121D1B23242226282D2B2C2A212A
2C33302E313A24302C2C332E35332F292129252F2F2925142521221A272E3B2D251F2314
252232271E2B2325262F2529342B343634433A2D323637383C3A3D37303149373A3A4036
3029313429332A313B363B443E3A35382F4042343B3F5647453B4742444E3F3E3C353D2C
404241404C585B6771797E7C8B898F7E8B808A9989949E89907892888682776A7B7C6F66
655F4D483438463137313A30271E2516291D1E1C0B0B0C0809100A0D14141D171D1B1D1E
21211D2A222223272A2C2220201E191B1C191D1F201F16140F0C090A0A08010305040501
000000000000000000000000000000000000000000000000000102030304050606070907
070A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0C0B09080D0A0B0A0C0B0B0B0A090C0C0B0B0A0C0B0A090A0807090505
05060502030200000000000000000000000000000000000003000E113575B9D8E8DEE6E0
E4CCCCD2C8C4B7AD93917B79635E4D302D2716060E020000000000000000000000000000
00000000000000000001011108100D11161415151118161F2B16161F2225281C22222821
1B182225341B2923241420172D161923211D13271F17211D2128232F283234302725361E
283636322E2E2F2C2B32382D38292E2733261F302A39222726232B1F30203134352A271D
152A1E1B1E2117282A231E2E352C2F3B2F3535343E3F38414635362D453C3D363042462B
403A34273424342835333E3D40433A4045423E3D3D37483C4D474C434240503A3938403C
3C3A4B444762627981798A92848B968B9D899A848F9088897F888F968D7D837B76757D82
6C59524F5544483F3B3C2F35332130171E172015190F0811180B0D13161C1116211A1C16
201B271E242125232124281F24221922231F1B1619191C10180C0E09080C070508010000
00000000000000000000000000000000000000000000000000020003020406060507060B
090508000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090A0B0A0B0B0C0C0C0E0B0C0A0B090A0A0A0C0B0A0A0B09080A0908080804
04060503050000000000000000000000000300000001000001000C0B274179A8C7E0E8E8
D4E1DADFC6CABABEAF98A284836A6B58472F291A0F051102000000000000000000000000
00000000000000000000000100050E1A201A120E141B15181D1D161414201B27241D2427
24253330212B26271D1721271E241C25241C261B15121D111E1F2C2A2C303B2938372B24
2D23382E302D282B2A2E3E3437363331292D3029312A2F2A31222225222E263229293024
282326131F1F1B191F24112E33373431313D2838374342354141382D3D3C3C3538353232
3225302D2A332B3E31412B333F3242373933443940453D4443363D333A44383C43473F35
3938435C61657273787A8E9093889B7D979288989494A3999D7E84828D8987787A838183
73726D5F55434E413C2D2E3C1F3035272124260B0D010C0F120210140A0E1C141A25201D
20201A28241F1C282123282228241E21221C20131D0F0F0A120A070A0704050402010100
00000000000000000000000000000000000000000000000004010304030508070B080808
0B0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000E0C0A0A0B0C0B0A0D090A0B0B0B0A0B0C0B0B0C0A0C0A0B0A090A08090707
050507030302010000000000000000000000000001000000000006000C214D84C3D9E4E6
F1F3E0E6D6D9B9CCB6C0AAA29C86827F6750402726230E110A0A00000000000000000000
00000000000000000000000003020E161A1917110F19171D0E191A1B1E1B232022271E20
2629271D23262028241C1C1F2327191F2919191B1F1C1E1615141C1E28263B2434392D2A
1A2938363320372B3439352D283D2624272A292D3A34332D34292C2623332D2A2F2F2431
3529201F1B151E221E2224192B303839292C353639373A3E3B3634332E312C21292E2F29
372C352A1F292A192C30332F3C403F3F373243342E29422F2F4B362E2D2E3539432B3932
404F5453636A796E857EA4918B9795968C8D8B9A88939982917D8F8183878588787F7A78
897A6C6A67554A4F3941243C2E262F291F1A140B102C02040F12100C12100F1C1B131C1D
1F1F1B1C231F2120211D261F212521201A1617181219120D0C0D0D0B0501010200000000
000000000000000000000000000000000000000000000000020302040607050709080809
090C09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D09090C0C0B0D090A0B0C0E0B0B0C0B0C0C090D0A0A0A0B080B0808080809
070606020204030000000000000000000000000100000000000105000B0D24598DC4F1F1
F6F4FFE8DED9E0CAC3B2B6B6ABA5978C706D5539452227130E0700000000000000000000
00000000000000000000000000000011081D18170F1E202514151B1921181423271F2628
252823291D2B27201E1A1D23291A1C25192B2B262626261A1B141F1D2528201E2437373D
3B2B2A28322D322E2635352F3A30272A2F252330362A27392C24262628291C2536262C28
341B3324202429242F242729252B2B303C333C393E3B3A3A3A3F3E384130362833322924
222E2B262D312434252D322F32373A3232414B4A3F2D383640372926232432283A373442
2C3D45626B74627478779689849491888E9988A68D8B8483858C7B7D8F778A769786857C
807B868664616651443938322E282E26281317220E140A130703060C0B1417161A1A1925
1319251E231D20211C1D1F241D231B2417131D1912110F0B080D01040103030000010000
000000000000000000000000000000000000000001000101030004050506070707080809
0A0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0A070B090B0B0C0C0B0A0D0B0B0E090D0A0A0B0C0C0B0A0C0B08090A07
0406020505010401000000000000000000000000000000000000030406071125569BC5EC
F0E7F2EDDFD0C6CBCED6C0BFB1A8968C89937C6F56413E1C150800080000000000000000
0000000000000000000000000000010C0E12150F10141D19221A1B181715141821261E29
3122292D261923252C1C1F2227191F111E1C222128292B281E1213171D2B232430272C30
392D3B212B2C34362C36313F34342528362E37242C252B27342C1D28352D2D30242A2923
25211E32291F26142523251D212C33322B27332C36463D3C414034413C3D3D302A313938
272A2C4635242E2424332E353739444436353F3F3B2E2A342E3E3A3F272D373537413632
4345465A6E757878807A80858C8D8D88879A95858787787C7E8E867F868D818491898580
8D7C738173785E604F442D2F2D312E2422201A18171411150F070D0411181C161110201B
191E1C16272223191C1B241E1E131F1B1A1B0F110E130D0E070506070404040000000000
00000000000000000000000000000000000000000000000303040205060707060A07080A
08090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0B0D090B0E0B0C0B0C0B0B0B0C0C09090A090B0A0C0A090A0A08080806
0A06060203040102000000000000000000000000000000000000000000000E0D245099C4
D8DEECF0E9E6D3DCD7D8CCBAB8B5BFA5989786807C634036290C00000000000000000000
0000000000000000000000000000000600001009061C1E172C1F231C12171A2211251D28
29211C2C25272924241E231A27202120161925292530271E281D1B1C2614231E27223533
2F3C32262D2D242E3332352E323126352B37303720272C2F252A2027322B2F3931302A2C
272B302F2A21221E271A2520252B2B2F2B243230313947414246433D413E423E35363232
36382B293C2C2A2A2D3723243F2E354140352C3F3C2B36423C40322B312926323B2F3F38
405249675B76768B7B838591869691858B959790817780746F768D847C8A838E84878A80
868D777F8B6D6B4F5539443E3534331F25221A1C1615090F140B0D150C0E191A19121C11
241B1C2322232018211E131D18181C1A1D131B0D0A090C0D080906060000000000000000
000000000000000000000000000000000000000000000402040307090A08070909090809
0B090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0D0D0D090A0E0C0B0B0D0B0B0B0C0C0E090C0C0B0A0B0A0A0C0A0B050B
040906050607040102000000000000000000000000000000000000000003070B142F5295
C9D6ECEDF1DAF0E8CCD6C5C9C5B1AFA9A7969A89866E5C4A2F1815020008000000000000
000000000000000000000000000000000000000A0D0B12111A221122181F2019171E1F1A
2622232C232127222321192027192729211326191D2D2723242A242124201C1218232132
292A272D25322B2B28202E2B2A2A22313232232E1C1E1C231B2B3533373D3B3738332C2E
2B242C281E202428231B1E281E15221D2A1E2C2B292F413131353F344A483A342D3A443D
3A32283D353D38303532392B322E38313442383F322B28383432372C20261E2C283B4738
444A4F5D6E728884848A8E8F8F848186909B8C7E838061877888847D8B7D6C7C80758B78
987F7F7E7A7C725A5F504930372B29211726121E131710060A0C080B000810151714141A
1B1E1C221F16201C171E1C15211D1B1C1810140E0A090C0E070605020000000002000000
000000000000000000000000000000000000000000000105050506070507090607090B0B
09090C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0C0D0C0B0A0C0B0D0A0E0B0A090E0C0A0A080C090A0C0809080A0A0A0808
060A0908070503030000000000000000000000000000000000000000000005080F142C52
91B1D9E7E3E5DEE4E5DDD6C5C7BEADC9A5B49692868166604D352D130600000000000000
00000000000000000000000000000000000000000102000E161518121A1417212814141D
2420261321201F2418262616281C29181F19201C202C2B31262423211C29221B1E232B1B
2F2832291D22302C3123272620232D2F2B32262111212A2A2F28393F3A3B404546453E37
2A2E28292E1D24191C1D0F131A22271C251B21242C383B383C383C3C45403C3633313138
343645313F373131373B3F3030342C333B3B3B3E292935313C3B392C2E2D2E2927393E41
473C5D576D6C787F9270898E9091A49DA28A9487887E64787A847A6D74817879727E9083
938480808274736E63475241363A291D1E24242117150D070B0F090D0F0D111613131716
211C1F16161917191B16201F1D1716151610100A14080B090F0502000000000000000000
000000000000000000000000000000000000000103010205050707050A08080908090B09
0C0C09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0A0B0E0A0C0B0C0C0B0A0C0B090B0B0A0C0C0D080A0C080D0A0D0C0909
05090A050706070503050100000000000000000000000000000002000000000C01091826
5FA1C7D3E9DFE0E8EEE0DDD8D5CDC7A5BCB5BA879F8C7672585131151002000000000000
0000000000000000000000000000000000000000000007041009110F151A151317102022
241B1E1E151D1C221F1F222925271C2318172424242828292B1D242A281C2C1C2622241D
20262530341E2B33292222202123312F31292A1E2C1622252C323634414C40524A475141
39372E2627211F22161A141227191B1E1B231D23232D2F2D2F342C3E3C4A423632353131
332F3444372F36303C3A352E2837282B373A4436333C2B2D34372F2F361E1920252A3530
3C455D666672717F848C939498889F9E978C838E6D6A76707C7576746C796C6A787B8A82
89817F8D816D7E6A6860564835302D232121201516141C0C0503050F0E0E130C160F1A1C
16191B1E1B1C1B191A191A1D1C190F151515130D0A0C0805090E02050100000000000000
00000000000000000000000000000000000001000103030604050909080A090A0A090B0B
090C0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0E0C0D0B0B0B0B0D0A0A0B0A0B0C0C0B0A090A0B0B09090C0A0A0B080808
090B07060707060403010100000100000000000000000001000000000400000505060511
285FA4C0D5DDE3ECDBD7D5D8DDC3D8BABBB6A9A49C8D937F6A6044402210000000000000
0000000000000000000000000000000000000000000000000908070A080D0C0C1F071E1C
2B1B1A201C141F212720221A202728232323221C2020291C191D271F22242E2E1B1B2622
232D2D22292A2A27242B2B231F222827382A2A2118201F272D2E3F3C46474B4B53524C3E
272B22231B26221819131E1E1F241C1E141B2823222430252E2C2E2B37393833443A3432
3143322F333737263B343137322538343C38293C461C3630382A3B342E2D1F1818282D3A
3B42457367677C89929AAB9C90908088907D7A86757675736D6E707374676D72667E8489
84817F817C6E726E635855474932242A1F221A0F161F000B0205080901060C0B0F131315
13141E1B1B1C191A201D20131215160D101111110E0D090A090606020201000000000000
00000000000000000000000000000000000000040403050504080907060807070C090908
090909000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0E0A0B0D0C0A0B0A0B0A0D0C090C090C090C0B090B0B0A0B0C0B0A0A0B
070B07050905020604030300010000000000000000000000010000020000000000030415
153C72A3C2E7DFE2EEDCEAE1D5C9D3D1C8C1A7ABB79D8F9C7E7F603C3E221A0400000000
0000000000000000000000000000000000000000000001000000030400050E100A090E1A
141815121F1C221E21221D241D1D25182024231B1F161F231B192719212D382D27232227
282921251F1E19362B3030311D23251F2C2B271E1C2318282B26363A34424D4C53434244
3434202B19221A1E311A20142F15241F1F20222521281C282E1A2A3532383E3D36413A43
39433C463A3B4035352E3538312F312B3239392E2E302A28292F2F2F231E221D2A1C212D
353B555D6B7478708785879A939A778E7E6D748870757C726A71606B6E647C707472857C
767B8B6D777F776B79675B4F37382A2735201E1E1C100E0B130904030B080B0F161B1611
121B17201D1B1D1617161F0F1216181011180E0A0E0A0902020600030000000000000000
0000000000000000000000000000000000000203050604070407090709080B090B090A0B
090B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0A0D0C0C0A080A0E0B0C0A0B0B08090C0D0B0B0C0E0B090B0A070A0B0A
070908060706080806040604030000000000000000000000000100010000000000080502
0E1D3B66A7BDCEEBEAE7DDECE0D7CFD9CBBBC1AC97AAA494997B7B625D2C1F160A000000
0000000000000000000000000000000000000000000000000001000000050F080B15100D
151C17141C211A1D221D1F1827261C15281C20221C2927262127292326302E36301E2A38
342E1825242D322D3338342C2820252226292129222027252A1F31292B3D3B434A4B3E3C
35272E2A29231C1C1A161A1C192117221C1C23281E2F222E28283932343B3B343B3A3C33
373B3C344249413A35393B333C382F2A3B40353837363331352F32222A302127191D2527
3A3B46606369726E8178A49DA18D93828786808083797D695E5A73636571787A788C868E
7C8177827C797C68655E574940362B1D241C231F1E110E050A1103050B080C0B0E0B140F
13141616190F191615191B170D1210130F120C0E0A050004000101000000000000000000
00000000000000000000000000010002050303020605030608090609090A0A080A0B090C
080A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0D0C080A0C0D0C080A0A0C0B0C0A0C0A0A0B0A0C0B0D0B0B0A0B0C090B
0C0B09090909040503050102010200000000000000000000000000000000000000020001
00061632649DC6D7EFE3E0F0E6DCDFDBD2D2C2C0AB9EA4A7928D806D584D452C1C140000
00000000000000000000000000000000000000000000000000000000000009000D0C0D06
1212140E15181116221D1B1E1A1A2014202022201E23272A291D282B26352F362A202333
322B2B281F192B282C353D32291D1F251A23272428251E26251D2E1E2C2B363344383338
323016282F231A1A1A231C2021191D20171B1A1B1D22182B2C31301D232235353D353637
42373D423B3A404741323D392E343933383233374036352D2B321B302325221C2C1D322C
35303F54696A717E739295AB9B8B82757E7371807E797B6A5D636C6D716C6D7670857487
917F757B8477767964625D5340252F24281D231E1F170C1509000D0A0608030A13060E15
15080B12101A1A181B161A1914130E0A040C0C0C05040004000000000000000000000000
00000000000000000000000000000000000203030507080706060A0909090A08090B0B0C
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0C0B0B0C0B0A0B0C0A0B0B0A0B0B0B090B0B090C0C0B0C090C0C0C0B0A
0809080A0707080507040204030200000100000000000000000000000000000000000000
00040C17326299C5C6E0E0DBDDE7E1D8D5CCCEB4ADA1ADA295967C8E725451473C231600
000000000000000000000000000000000000000000000000000000000000050905090C08
0A19190B121615111019151B181819221F1C212217262227292D231D1F2924242F292627
312A30361C1E27282F2A2B2F2724241C1F282125252829191D201E2727302A3535362E30
292A2D2B21271B1C1C1C1F1818271E16161B1B1A11222429242A263028342B303D373738
3E3C3B363F363C413E3D3B383C483B2A3539374436342E2937211F24231D171F2B1F291D
2C3E4251525F697480829098AC9A8779777E7E7D928889646D55636F757B79616F667174
82778B7B78737A706F635148473832281B1C20191A1612150C0A0707070B0B0B0B081012
1D0E0D0E0D1510121810120E0B090B0B06050A0709030000000000000000000000000000
00000000000000000000000000000001000807060505080908080C0A070A09080A0A060A
0A090C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0C0A0C0C0B0D0A0D0B0D0B090A0C0A090A090C0C0B0B0B090A0C0B0C0C
0A0B0B09090906060705040503010102000100000000000000000000000000000A060000
0006060717376195C4DAD9D7E4D8E7D7E3CDC5C1BBA8B7A69F919C9776826E5949402911
060000000000000000000000000000000000000000000000000000000000000008060100
06070B18131910180E1612131C1D151622192521251A231B212328262B19232E272B2624
2C2B27252420222D2D332D1F2B1C221C2F272B20232C252329262625251E22312C2A2129
24212025252916111F192018171C1C191B19141C15131F22242E352B2A212D2A2E30333A
3A3F353438333C41403C3D36362E3C31453A362E2C2C2E2D2B292B221B1D1D1D1D242D1E
2C2943524C6563727578879294958E6D78807E758C8E757967657A71676266725D6B6576
868387767F726D5A5E5155553A382B2521272A221A1516140E1406080303010A12060E0C
12120C15120F150F0D10110B100B0D0A0908030504060500000000000000000000000000
0000000000000000000000000102030104040505070808070A090A06070909090A0C0A0B
0C0B07000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090C070B0D0C0B0D0C0A0B0A0A0B0A0F0A0B090A0B090C0B0B090C0B0B0C09
090B0B0708070B080A060704010502030200000001000000000000000000000203000104
050706010817376099CBDED2EBF3EBE8E4D8CCCDC5C4B5B5A69D97967E877B6A6A4C4438
140000000000000000000000000000000000000000000000000000000300000201000000
04090B0C0A091B14101B1B122B1721211E1718251F281D182C2432302F252B2320221D2E
2C3129213118231D1E223222281E1F26262420201F282622251C22232127321F23212123
1E27202A1F1E2A1C1C1F1F201A1E1B271315120C2624211D23212C2B2D252D28272A3D3A
3839392D383936423F363C2F3B3E3A4B31362F2A25232A252D2C382D1B1F1A161219251E
2F3A3E4751446360677385898E82847F747E7B7F848A7D6A5D676F766C6D64656B66716B
737E7D79717C7967645D634F46252422281A1A231E15160E10090E030C010C0D0B061415
1610120E0E130D150F110C100C0C0A090B08030902030400000000000000000000000000
0000000000000000000000000003030306030507080707060B09080A0A080A0C09090B0D
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0B0D0D0C0C0B0C0B0A0B0C0B0A0D0B0C090B0C0C0C090D0D0A0B0A0B
0B0A0B0B0C0A0A0809050806030301040300000000000000000000000000000001000000
000400000E0A152B6696BED9DED4EAE3D5CBE1BCC8B5BAB3B99996988F8384846A6D4E37
37170A000000000000000000000000000000000000000000000000000000000000000600
01120E07060E0B1316101A141F1C23171A25201D29161F202429291F282429221C23281D
232B1F1C291C202623211D2B2528271B1C1A221A23231C2124232F20292D222517252625
2318221D211F1F1B151F1C1927241A191F1E23191C131B22281A1E23221E262B2C2C352F
32362E40473E3B413B3A402D313540403C332F31352A25272A222721281C081F1C20281C
1D2C2B3849444C5E6F70808D8E79767778797C8494987B7E6B6C6F6571626E7169666670
6E7D84737E717163625952453B2B2E2223191D2517161E130E0B0B0C060A0C060F050C10
08100D080C0A0E060E09070D0B0D0C070805030407060303000000000000000000000000
0000000000000000000001000004020404040606070609090909080B090C0A0B0A0C080A
090B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0B0C0C0A0E0C0C0B0A0C0A0C0D0B0A0C0A0C0B0B090E0C0B0B0B0A0C0D
0B0A0A0A0A0A0806070A0703050703020201000000000000000000000000000001040100
00000000000008182F5D93B1D2D8DFDCEDE0D0D7BFC9BEB9BFA3B19C8393918582775E4C
462F22140000000000000000000000000000000000000000000000000000000000000002
00050007090D0C08120F1A1820181520231B1A18181E2423212C2A3426222E252D241E1B
21232621161B212B2426262B2B201D1C231F1C24281E1C1E2029262A1F17222528271D1D
1E22201D241B201D1F1C221C21231C1F1B1E1417251925292526262C232129292A1D272D
30342D312E49403B423C3F383F313C473B322A3326282D28281F231A21171A1015181921
211C20293F3F4F49536978867B75778D807D7E79818E86766170726F666F6871747F6F6D
7278725F78736E6B645152434625272823261A1A212115111C1A0C090705090B080E0A05
100B0A0B090F11140C09140F0B0A05050203030302020000000000000000000000000000
0000000000000000000000010302030505050806070609080A0A080909090A0D090B0D0A
0B0E09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0D0B0A0A0D0C0C0D0D0C0D0D0C0C0D0E0A0C0B0D0D0B0A0C090D0A0C0D
0A0B0B0C080B090A09080807050405030102010100000000000000000000000000020000
00000000020001041526448BBFD4D8D5DACFDBD1D8DCCDC1C7C2A89FA897A7828E8F7573
6B47311F200F0A0000000000000000000000000000000000000000000000000000000000
000004000C090B04050E0C1E1A0E181A1B16291C1E262324242C3620252424272D282226
2623201D1C142123291B25191D1B17201A1926211F251F1E262D2C272122342625302426
222222231F161A211E1E212A23231B1924161D1E1C261D1D1F2820282B252427282D3032
33293C3E413C3C3D453C3D36323B3438353036283238312F25231E20180D10141A14181A
1A1A21262F394754606668737B7F8579837A707B7B8384685F64695E69746F73787C6567
64777A75756E6F595C544A3F32301B201F221A1A191A1516131207070508070903000C04
0C0C050A040B0A0E06090808040A05030300000000000002000000000000000000000000
0000000000000000000100000304040606060808070806070A070B09080D0A0C090A0C09
0D0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0C0B090E0B0D0B0A0B0A0A0B0B0B0D0A0A0A0B0B090B090B0D0C0B0E0A0B
0A0C0C080A0A0B0909090805060304020403050200000000000000000000000000010001
00010000000000020F0F294784BBD8DDDBDDCBDED5D5D5C7C1B5B2AFAA9B90969680797A
635656394F1E211500000000000000000000000000000000000000000000000000000000
00000004070811050C000B100B1E1B1D241B141D131B231D271F23262D25212A2B222730
2718281B281E271C1D22201C19161E1D162222221A2528252724221F292C2220262E2B28
252428271B1F26211D1C1E1B28261D161C1B23191A232125212C282B1B2524252B242621
1E2E2E3A32393E3441393A3B3F333E3D39362F352C2C2A2C24201B1B0C110C1207011A12
1A1D1F2E342B3545506B67766B7184727A7D7478848B826B655E7574707F787670747062
697A6766736E61656048403C2A262E161F1E161719151A131A19100404090E0D0A0E0904
040408090A0E090C0B0804030F0604050004000000000000000000000000000000000000
0000000000000000000004020205040507050C0807070B0A0A0A0A090B08080A0B0D0D0D
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090A0C0C0C0C0D0A0B0B0A0C0B0B0B0C0A0A0A0A0B0D0B0B0C0A0C0B0B0B
07090A0A0D0B0E0808090906050606060407040000000000000000000000000000000001
00000000000000000004121C4778B0C2D3CFE0DAE3DFCFCBC9BBBDBEB99E9B9F888B8184
74845D6C4F47371C08000100000000000000000000000000000000000000000000000000
000000010000030A060D07050E141818171B161B1F1C28231D2D1F2020312C27272A2F2C
2E1A231F1F212321242519141D181A1B261E1B1817181C231715232927231E251F222F28
252621181B23281F27292125261D211D271C1E1D1C1C191F1A131D1521162D1D2226232F
2D272B2E35342C343C3C3A3A3A3B384038363F32322D3636281F120C0D05070D1C101A17
1E131D2B242D3C3B47455F616C696F6E717A7C7E717386796C69756F65747B6B787C686E
6A7359696E5D58524842462B2524201D2A1E19181C1815191C130B171007030A06050F09
0B00080F06070A060D060501030400000500070000000000000000000000000000000000
00000000000000020102040303070407050908090B0A0A080A080908090C0A0A0A0A0A0D
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0C0C0B0A0D0A0B0B0D080C0D0C0C0A080D0B0B0B0C080E0E0D0B0A0D0A
090B0B0D0B0A0B0B0809080C090904040406030201030200000000000000000000000000
00020000000300000005000A254679A6BFD0D2D8E4E2E7D7DDBBCBCEADAFB59E9C8D8D86
8086826E714F4A341E1700040E0000000000000000000000000000000000000000000000
000000010003000806000609131417181A1E16111B1C16201E1C2A2B31292B1E292A2323
2A282320262220251E171C1B17170F1D192020171E14261724221A1C1A2B23161F212B1F
24122D201C28231D1F18251724181A2124251E1E2020221F182418221F21201F20232128
2D2A293033273427373B363C383B362E2F3335493E37242D21150F0D07060808050B171F
14241E271C28263E403E4252606D706B7B6C756F74746C76727E7F727A7B7F747E817274
766866676A5F5E564D343026291D22252425241E251B1D1E12150F0D0E12060B0A070100
020909080503050708050602000200000000000000000000000000000000000000000000
000000000002010101040305050506080807080A0709090909090B09090B080B0A09090B
0A0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0A0A090B0C0B0A090C0A0A0C0C0A0A0B0A0D0A0B0B0A0B0B0C0A0D0C0C
0C0B0C080A09080A0B080B0A090809060603050304000000000000000000000000000000
0000000000000000000100040E1D3A7D98C2D0D1D7DCE6D5D5DADDC7C4BBC2AC99AB928E
8D82945E775F5040412621210E1707000000000000000000000000000000000000000000
00000000000000050201010A0717181813161B1C13101F1B2021212423231F2B2B293027
211F25292125271F211D1F1E16141D241B24202219161A16192A23201A1D211F272A1D23
21212720201F241D262A242023282927281E1F1F252526201C2414171B2626232221282A
262D2D2B2224242C343D31333B462F2E372B3C48383D39281F16171107080109090C0D0E
101A0B1A22202B2F2F39384F4F52605C6262697169757880757070717372767E7E6F6B6D
736762645F5B574D473E2C272021191C1B1C2220172923201B18151E0E120F09070C0602
0B0309030102080604020000000002000000000000000000000000000000000000000000
00000000000001010306010605070807080908080A080A090B080B0A0C0C0C0C090B0A0C
0C0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0B0B0D0B0B0C0C0C0B090B0B0A0B0C0C0C0A0B0B090B0F0B0B0B0E0A0C
0B0B0C0B0C0B0B0B0A09090809060B070506060405020102010000000000000000000000
000000000000000000000000000D1B3B638CB6B7DAD5E1D9E4E4CCCBC7BFB7ADB8A9A397
9883918E6C60644B434F4637331F1C0E0600000500000000000000000000000000000000
0000000000000000040000060A06080E0F0E101414181A1C232621241E1C261F2D262A22
3028241F262A211C211D1518231E1D201B1D1D2220211B1B21221A1F20252325232B201D
1B251D2C2A1826242B2B1F27212720262B2327291E241628212122201E1F24192011291F
29242C25262929302F384030372D28282C4240443A3634212D2214090A060702030C0305
0F1719142122201E28293936435355506D6367676E6E7573746D807A7B736968686F7973
6E685C5E4B46463A373728221A191C1D1A1D21131E1C2521201E13170E0C0F0C0B060705
080500050206060601040003010000000000000000000000000000000000000000000000
0000000001000402010307040706070804090907090A0908090B0A0B0A090D090B080B0C
0C0809000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0C0A080B0B08090B0A0A070D0B0C0B0C0C0D0B0B0C0C0B0B0B0C0B0A0A
0B0B0A0C090C090E0A09090A070605070506070606020404000000000000000000000000
00000000000000000000000000000417335289A8D6C7D3DCD4CED7C9D8D0B9B0B0C49FAD
9E8D90887F816F686254514D414131181002000200030000000000000000000000000000
000000000000000000030304000600060B1110141C19181C201F21222426292623202025
281F211C19252E16221D181B1D2416181C231E2426171D1B18252515272325232224211E
2426291926202E232823211A2C1A1E2027202930282322232024251C241B231F24241D23
30282227242C262D2F2A263434282A2D29334741373D392E27261C0A0D0405010D000C01
0B0D0B171F1B2B251B1F2C2E3239484251585A6465595B5E616D6B686E6869626C596A60
6D675A4949423C242D29201A1E14241E191E1E181F1A1E1B1D161A16100F13150D080E05
080703010100010402000201000000010000000000000000000000000000000000000000
00000002030003040306060507070807080909090907090A09090A090A0B0D0A0A0A0A0A
0C0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090B090C0B0B0D080C0B0A090A0B0A0C0A0A0B0C0C0C0B0B0A0A0B0B0C0C
090C0B0B0B0C0B090E090B0A090708070807080905020406050001000000000000000000
000000000000000000000000000003030D23547EA5B7CFD3DECBDED9D9CBD6C3C2B0C2A3
B39E918C767C6E807B6F69585F4C4E2B2A1F250405000000000000000000000000000000
0000000000000000000000000006000300030A161917171B1E1C1C1C1B1C1D1D151C2322
311B22262916191A1B262B1E1B19141B1C1B18181322141F1E1E241D2220281C1B26252A
241D251F2C241F2324252C221A192B20262529312328262A221C1A19211B171E27232526
2827222B2729372D332D3A2822162E2D34434238302A2B2A2B2C1E151A020A0D00030300
190707111914211D1F1F2229212D393A3E4F595261514C525A646F616869606153535259
524B46413E363521211B23221E1A111A231C1F1B231F26211E19171C10121411100A0B0B
090207090000020000000000000000000000000000000000000000000000000000000000
00000200040403030705070906090A07070B070A0A0B090A0C090B090A0B0B0A0E0B0B0A
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0D0C0A0D0C0B0A0B0A0C0A0C0C0B0A090B0B080D0A0B0B0A0B0B090D0B
0B0C0A0B0B0B090A0A090D0A0B070A0B0706070704060307050101000000000000000000
0000000000040000000000000000000006081E4B6F95BFD6E0D0CFDBE2E0D7DFC8CEBCBD
B190A997968D88898777776C695A505E3A342C281F151100010000000000000000000000
000000000000000000000000000000000012091817141D1E1D14201E1B2213121713231A
291E2222251B161D1E1B1517191126131D1A171A1F1B17211A232022282128252023242E
2828272A22292C1E29212E2727212722262A2C3425222E262120252229261F1E1B221D24
2227191F211D1D252D26342D2C2A2F2F36323A3527322C2C28321E221C10110300080A01
0109110F0F1521161E181F2024242D303524293B3E43503B4A525F6252575B5F544E5841
41484438333F2220222128221A1A2124181E1D211919202520211C1C17110E0C0A110204
090709070100030000000100000000000000000000000000000000000000000000000000
0000000000020505020706050808080A07090C0B0C090B0B0A0D0B0A0B0A0A0B0A0A0B0B
0B0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0B0D0A0C0B0B0D0B0E0C0C0A0C090D090A0B0A0E090B0B0B080C0C0B0B
0A0A090A0D0A0C0B090B0C0D0C0A0C0B0609060705080703040401010000000000000000
0000000000000000000000000000000000030C18366D9ABDD4DBDAD9D6DAE7E1D2CDC8C3
B2B49E97959C9C957E8978686F6C5B5159554A433628270F110300000000000000000000
0000000000000000000000000000000000070C0A05180813171E1318171E1C1E1D22211C
27201417221A1A202322181912121E181C171617111B12191F19242329201D20291E181E
22241A1F2222241F1F2C1E2924242B262C26242E202827241E2E2C2E26272B1A1F242721
182427261E2321261F2327202E262B2B333931292C27241F26242A2D2719140204040506
0D0011090E07121C221A1D181E18272423152A2C322D394148474A45474A4E4F48434441
3C3A322B352629241D25241D1B200F181D19211F1F25211A1E1C1D1C0D100C0B0C090504
000003000002000000000000000000000000000000000000000000000000000000000101
000003050303040504050608080B080509060B070B070A0A0C0B0C0A0A0D0B0A0B0B0A09
09090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0D090C0D0B0B0C0C0C0B0B0C0C0A0A0B0E090C0A0C0C0A0B0B08090B0C
090B0A0C0C0A080B0C090A0B0B090B06090708070B060405060801010100000000000000
00000000000000000000030100000400000000000E2C5D8AB3B1CBC9DAE2F3DCE6D4E5D4
D2BFB6AAAA9099988D798379766765716C6B55423E2A332A190A01000000000000000000
00000000000000000000000000000000000107080E100F0B12121715081F1C170E18171F
281B23172824211E261A1C151A111B151C1918151F20101914161B14191F1C2119272F24
2B2825261B181B0C252125282F27212E28272A23322A1C2D2C2724292F251C20201D271B
222A20251927291F242C252027252F2C3220272A221B2521282D3335231F18110E050201
0A0C0E0C070B131B1217181C181D151C1D261D1F24263136342A323A474A443B3C3B382C
30242C232624282828231E21231C1B191E2519261F1D231F1B201C18151915150D070801
040101000003000100000000000000000000000000000000000000000000000000000102
05020102050405060708060708090A08080A0B0B080A0B0A0B0C0C0C0D0B090B0A0B0D0A
0A0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0C0A0C090B0B0B0C0A0B0B0B0D0C0D0A0B0C0D0B0C0C0B0B0A090A0A0C
0D0C0B0C0C0A0C0A0B0B0B0B0A0B0B090809080907060606070404010000030000000000
000000000000000000000000000000000000000000111A608BA5C1C7D5D8E2DADFD7D1CF
C0D3C6ADB1A8A5AA8B97836F86867D7C7B6C5E584E4A3E32211409000000000000000000
00000000000000000000000000000000000000120C000603160D140E151814180F120F20
171E1E1C20251B10171012190E1A101D182019271F171C0C151C0E181A26221B1F172128
1E24222825251B13161C1B2C2628282E2F2E2E2C241B272D25292E2A2B26211F22222429
252720191D1A22222D2D252F282124232B292A1F212B2D2C2F3031343028201011060907
0C0F1107060402121414141913111F1D0C19181D1E1A191B2726252B2F292F222E242225
2424221D24243520221D182A2217181E191A211F221C18211E221F11171112120F0B0502
000000020000000000000000000000000000000000000000000000000000000000030002
020206030406060707070809080908090A090B0B0C090A0C0A0A0C0A0B0A0A090A0B090C
0B0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090B0D090B0C0A0B0A090B0C0A0A0A0C0B090C0D0C0B0A0B0A0A0A0C0B0B0B
090D0D0B0D0D0A0C0A0C0A0B0B080C0B0B070C0808070A07040305050101000000010000
000000000000000000000000010000000000000000000F193F7CA7B7C8C2E5E1DCDBDBD3
DBC7CBD2BFACA4A69E838C747A86887F636C685658523F39282D19060000000000000000
00000000000000000000000000000000000000000305010D03060E0B0D1D1A17100E1E20
181419211F1B1D161E15191B120D1619181524181C261A17141918271C1C181C261D2C26
21271E1D221A21221A1821291C2A2B272A2824282A2D31262A2C2D31342622241D21221D
28251A171C14261A301F312D2C291E2D2829271F28232833332F2B2C2525262417150A0E
04010700050B0604041217251C17201713141712080E1E1E232C302923241A25291B2C1B
1A1F191C1A221F251A2724182424171C2022211D1E1C1A18191A1F171A170E130B100800
000101000000000000000000000000000000000000000000000000000000000000000200
030604030408070806090808090A0A0A0C0F0A0B0A0A0B0C09090B0A0D0A0A0D0A0B080C
0B0E0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D090A0C0C090B0C0E0D090C0B0B0B090B0B0C0B090D0B0B0B0C0B0D0C0D0C
0B0E080A0A0B0A0B0C0C0A0B0B0C0A0C0D0A090807060707050908050104000001000000
00000000000000000000000000000000000000000000000B14347797BDCDD8D9D5E9D2D7
D2E2D2D3DCD0B6B8A89D9A898E86907B7675685F6B5F5E4644362312180D030600000000
000000000000000000000000000000000000000000000800070D0006080F1513141F0C14
19152120261D1B1D22242625221E1F13161D161F1E1E1D141A161E1D261D19242016211F
1D1E2024221D282323231F1E201D262C2C21282C272E272D323027211E27252928252920
1F242321161B1E23172A2E28282326251D23231A2B2D3124312C34302D1C2325261D1C17
1404060D0D0B09060C0F1B26241F11190B1817130F181F1C1A201D190F1723232422151F
201C19171B1E20182B1D1E20251B23171F1E1D2019261F201C1917192015120F0B0E0506
050100000000000000000000000000000000000000000000000000000000000102000303
0202070503060A0609090708070A080B09090B0B09090A0709090A0A0B08090C0B0A0C0A
090A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0E0C0B0B0D0C0A090E0B0A0B0D0C0C0B0B0B0B0B090C0C0D0D0E0A0C0C0B
0C0D0A0B0A0A0D0E090D0B090D090A0B090A09080A080707070508040703020201010000
00000000000000000000000000000000000000000000000004183168959ABCD8EAE2DDE4
DAE0D9D3CED4D1B6B5A1AC99829E92927B7D70696A66655F5B454037261F030A02000000
000000000000000000000000000000000000000000000004030503020804120810130F1B
1A171A1D171A1D14251C2A28221A1B190F18180F131029171610191E201B1F261B1B1B1D
261D232320251D0E2817222B2126282C26212A282225262A2F2D32252A33252934231F27
2127222726211A24201D1D2A2F2823202A27302727242927282E2B2921202A1E25201E1C
1B11110E0D0F0C0D121214171329181E1A171E19171A131E191813171417111321181818
18161E151A1B1C2416181B2020211F211E1E2122231F1319181E21181618100C12100804
050000010000000000000000000000000000000000000000000000000001000201010205
06060504070807090708090A080C090A090B0A070C080B0B0908090B0A0C0B0B0A0C0A0B
0D0E0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A090B0C0B0C0A0B0A0E0B0A0B0A0C090D0D0C0B0D0A080C0D0E0A0C0B0B
0E0B090B0C0B0E0C0B0B0C0B000C0B0A0C0A0C0B09090808070506050305060406000200
00000000000000000000000000000000000000000000000000010F194472AABFD8EAE8E0
E9DEDCE5D1D5D2C3BEB3B2A7ACAF988F8C8A6A78826E6E646149443E212A131306000000
0000000000000000000000000000000000000000000000000404060E0D0E0B0E0E091012
181E121D1B141D120F181C2214221A1A170F101315201C201919121C191D1A1615202422
2927211D26272321202026261B1B241D24251E2E2B26222A2630292C2727241F252F2D35
2D2B271D172016131B1D1819201E2A2A2C35292322232E312628282A27222C25262A2416
1B17191C12131714181F201C1D1D1A1C201F181A1A160F121A150D04110C100C130A1213
09181414181A1B15130D1A221A1C2018191B2020201E1818181917191811130E0D030801
050000000000000000000000000000000000000000000000000000000102040203030604
0306070906080906080908080B0B0B0A0A0B0A0A0B090B0B0A0A0B0B0A0C0A0C090B0B0A
0B0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0A0A0C0A0B0B0C0C0D0E090B0C0C0B0B0B0A0C0A0B0B0C0D0A090C0A0B
0F0D0B0B0D080C0C0D0A0D0C050A0A0C0A0C08090A0B0808070809090407050400020100
000100000000000000000000000000000000000000000000000000011C296CAEBCC7D9CF
D9DCD9CDE2D4CACBC4C1BEB79FAC9B948C8C868778867F6E645A513C4B3C2E1F0F0C0000
000000000000000000000000000000000000000000000000000000010303050511090614
0C131F191617211D1B1A15141619191519110D0D14151C28211C131B2726181518232118
282726231C1B25201A242C1F1D281E212A251E252521272B2E3A25242625232C252C2A23
262B2A24191D1D1A1C1C181D251B23262D2A312A2830282E2D352D2A292724261F1F2824
25301E241C151F22231F221A181B1E1E17181E1E151518111511100D14180E0B1614170A
1714130711160C130C0E171C191F191C181D27211821191A1B1318121513140D10050700
000001000000000000000000000000000000000000000000000000000003020303030704
0407050607080B0A09090A080B0A090B0A0C0B0B090B0B090A0B0D0B0B0A0A090B0A0B09
0C0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000E0B0B0B0B0C0B090D0D090B0C0B0D0B0D0A0B080C0C090A0A0C0D0A0A0B0C
0C0D080D0D0B0A0D0D0B0C0B08090A0B090D0A0B0C07090B0A0D0A070606050305050201
00000000000000000000000000000000000000000000000000000100060B315485AEC8BE
D6DDD9DFE7DED3D6C7C2C7C2B4AFC2A5998B8A7E8785887D7F675F605F4A4630250C0900
0100000000000000000000000000000000000000000000000000000000000701040C0306
151A1514140E19171A191716200E17111E1720181B162F231B2319151B16171A161B1C26
2F2520201D2122141419282228221F1D2324242422262F262E242C2D24242B2C272D2A2A
292329242524261B18171414141C15272A2F282C2528222824252823233024202C23252C
311E2B2520221A24241F1B1E19171C1C11191D16110F1A1C191A1011171E130F1806130D
1109061007050E130A131515141C1A221F1E15201B171F1D1C1714130D0E140B05020600
000000000000000000000000000000000000000000000000000100000003040203070405
070409080809090909090A0B0A080A090A0B0B0C0C0B0B0C0B0D0A0C0C0C0E0D0A080A0C
0B0A0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A0C0A0D0E0B0A0C090C0B0B0B0D0B0D0D0B0C0C0A090A0B0B090A0B0B0C
0A0C0B0C0A0D0A0C0D0A0D0B0A0C090A0A0B080C0B0A0B07090708080907030805060301
070000000000000000000000000000000000000000000000000000000400001F437CA0AE
CAD7DDD5EDEADBDFDBE3C8C6BAB2B1B5A69E94958D85818482717F6B66544A3D3B211112
020000000000000000000000000000000000000000000000000000000500000005100403
0310150B0D17180E131313141B1B100E0A181F222726231A241814181C2222251D2E2121
242325211F1D121B1B1D272521191F22222023212827292B3024252427232A2724232726
282D26221F21241F231C1C22201C201C241E222923282830322B2A302D272B1F27262622
272229272421231F241F291D181A1D1A1C1F1A1A17171017190F1A191C14151115121416
100D14100C0F070B100E110E111C19231E18191E1B1B1C14150F140C13100C0A09050600
000000000000000000000000000000000000000000000000000101010003040605060607
070507070A0809060B0A0A0908090A0B0B0A0C0B0A090A0A0B090E080B0B0D0C0B0B0C0C
0B0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0C0B0C0B0C0A080B0C0B0B090A0C0A0B0C0A0E0B0B0C0A0C0B0A0E0B0C
09090B0C0C0B0A0B0D0B0B080B0C0B0C0C0A0D0A090B090D0B0A080A0906070406050504
0501020200000000000000000000000002000000000000000000000004000000203B6787
BAC0DACCEAD7D6DDEAD9DEC9BFC9CFAAB7ABB29AA2888A7D847E736C77655853382F2025
120200000000000000000000000000000000000000000000000000000003010000000B00
060809071113120F150E13160E2416081A181F181A172022232B221F181B1D1926211F27
231A251C261A1E191E1B231924241D1F221C1C262722252D2E252E202E26261F2620241E
26222C24202826251E2024191A1D1E242421261F1A282A2A2B272A2529252E28232C2E27
28303126272930292628241B1B21151D1F121515221614151B0D1C1910191B0D13120C12
0410120D0B050714110A1814151A1718201714141B1716131910150B100E060805000000
000000000000000000000000000000000000000000000000010100040005050404080506
060709080A0A080A09080B09090B090B0A0A0B0C0B090A0B0B0C0A0A0C0D0D0B0A0B0B0C
0B0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0B0A0C0B0C0D0B0C0C0B0A0A0A0D0A0B0A0A0D0C0B0C0C0E0D0B090B0A
0B0B0A0C0B0D0A0B0C0B0C0C0A090D0C0B0C0B090B0B0A0B08080A080A0A050806050406
01030400000200000000000000000000000000000000000000000000000000000410364B
78A2C1D2CBD6E9F2D4D6E1E3D3CCC9BACFC8B2B3B6A3937B908388827B6F705A53453737
2A130D0A00000000000000000000000000000000000000000000000000000001000A0408
14040A080A0C170E0918090C1D1A1116271B151A161827181C281E1F1E1D221D15201C1B
172D211B1A12121C1F1E1C26201E261E201F221913212A2323282433292C202C2E292025
2D27241D22231E2D1F242420222220232528281C2121222831292A2D25212C2924292323
2A2F2C2D20292427212B2D23281E2223211D1B20181E1116181013171D1D151F1812100F
0F0D160C0B10060F15110F1415141517111D151A1C14121012120A0E0D080B0300020000
000000000000000000000000000000000000000000000000010103010705070604040709
0708080B0A0A0A0B0A090A0909090A090A080C0A0A0B09090A0C0A0B0B0A0B0B0A0B0B0F
0A0C09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D0B0A070B0A0A0A080B0B090A0A0E0D0C0B0D0B0B0A0B0A0C0C0B0C0A0B
0A0C0B0B0B0B0A0B0D0B0C0C0D0C0A0A0B0C0B090C0B0B0B080C0D0A0809090908070807
040506000100000000000000000000000100000000000000000000000000000000071626
445896B3C1D5D3D3E0E0E7E4E3D5C6CECBC7BFAFB4A5A6A28E95918874775F6E61535453
3D271D0E0C0000000000000000000000000000000000000000000000000000000000000B
0C0B0B060E111916090F0C1408191A191E1F1E1E181821201F1D1E1B232322131A231A22
2320241A1B1C1B24191C1A191C1923272420291D271B242125282D232520262C2A2F282D
2B27222226242628291E27182423211A1C1C1E2B2424242B312C252C2A2D283730312E21
292F2121281E2F2A262C28281C2622201C1D20141E211D1F1814181A19161A181619160D
120D121910110E10090D121015150C171216151715180F13110E0C0E070C010200040000
000000000000000000000000000000000000000000000101020204020404060705070805
08060B0A0907090B0C0A0A0C090A0B0B090B0C080A0A0B0B0D0B0A0B0C0A0D0B0B0D0B0E
090C0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0D090B090B0A090A090C0A0D0C0D0B0B0B0C0B0B080A0B0C0A0C0C0A0C0C
0D0C0C0C0C0A0C0C0B0B0B0A0B0C090A0D0C0C0A0D0C0C0C0A080A0A0B0B0809070A0805
050406040000010000000000000000000000000000000000000000000000000000000007
041D4E84ADB5C1CAD4E8E1E3EFECD8DDCFC2CFBBB7AAAAA4A29B9A958978837569626B53
54442E271907000000000000000000000000000000000000000000000100000000000509
0409060508140F100D160A0E131B161D231A1E1C161314141F1C1E161B1D1E20191D231A
1C1D1A2318171F1B1B21182A23172320291E282121221E22272226242F2B2326292C2D26
2C2521271A2D292321201A2222221B1F19201A2321212426312922272B222D272824252B
2723202726292E252A24272B272A231F27201D1D211A211819161B1B1A1A15151A110F14
160F13110B1312110C10120C070F0F130C0E12111E0B13170C0B09070106050201030000
000000000000000000000000000000000000000000000003020406050508020706080809
0907090A080C0C0B0A0A0A0C0D0708090C090B0C090D0C0C090A0E0C0A0C090D0A0B0A0B
0A0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0B0A0A0A0C0A0C0C0C0B0B0B0A0B0B0A0D08090C0E090B0C0B0B0C0A0A
0C0A0C0A0E0D0A0C0C0D0B0C0B0C0E0D0B0D0C0C0B0A0A090A0A0C0B08090B0906070706
070707050500000000000100000000000000000000000000000400000000000000000004
00051A416487ABBED4D3E3D9E0D6E1E3CDD0CEC4B1B7B4A4AAAD9C96828E8980807D6E76
6762532C2D21070606030000000000000000000000000000000000000000000000000000
00000900000C120F110B0F110D131D181F20181316161E191823292020191B1B1D1F2317
15231D1B1A1A241F20202021282026202920261B1C26292A22222B282B2F272631302E2A
2A27262A2C22292A2B22232B251F22252020211C141D301E2129242C2926292A252A2B28
1E2C262826272C222C2A2B25212420271C261A1F23201C1B1D191917181B1D1219171911
1D171212110F10150F0908080B0C120C0C110B100D0A0E090F0B09060203000000010000
0000000000000000000000000000000000000000000205050504040505060707040B0608
0709090908090B0C090A090B0C0A0E0A090B0A0C090B0C0B0B0D0B0B0B0A0A0A0B0C0D0B
0B0C0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0A0C0C0C0A0A0B0C0A0C0B0A0C0A0A0C0D0D0C0C0A0A0B0A090B090B08
0C0C0B0B0B0C0D0F0D0C0A0A0C0C090C0C0A0B0C0A080B0A0A0D0C080A0C0B0B0B090607
070603040501040100030000000000000000000000000000000000000000000000000000
000000101E467D9DB9CACACFDEE2E6E5DDD6E3D3B6C0C2C1ABAD9FA6978F979280808278
735E5B563B3316160D0B0000000000000000000000000000000000000000000000000000
0000060000060B0E0C11120F11101C1F1F1E1E13161C1D1F252B282C1D1B261D1A181818
1417181A1C1B1D1A1E181D1721241D2321241D202622222C1F2E2022251E282E2B2F232E
313124202227252A252A1D202425201F1B192010211F1D22221E1F1C201C1A2A292B2A21
212B28252A2B27272B212D25222822171A230F1F1D161815181A1D17131A181615161314
160B0F1814110D181009040A0913090F0E090F0E0D0C120A0B0607020300000000000000
000000000000000000000000000000000000000202010103020305050606050707090909
0A080B0B0D0B0B0B0B0C0D0B0A0B0D0C0C0A090C0B090A0A0C0C0C090B090A090B0A0D0C
090B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0A0B0B0C0B0B0A0D0E0D0F090B0B0B0B0B0A0B0B0B0C0D0B0B0A0A0A
0C0C0B0C0B0B0B0D0D090E0C0A0A0C0D0B0C0D0D0B0C080E0D0B0C0A08090A0909070807
070507060806030200000000000000000000000000000000000000000000000000000000
0000000009173F6490A9B6C7C7DAE6E7DDE6EAD4C4BFC1BDBEB3B5A6ADA3A9A093988C7E
7E7076685D443A361F14200F030200000000000000000000000000000000000000000000
00000300010009020F1313111317151B2418191118212619222929222B271A221F251F16
1A21211D1C1A17191917141F171E1B1720191F2B281D2921211D1C20202F2326302B2829
2524283026282C231C2920212621242A21191A22191D241E2121111F2A1E1E1F24242626
2D26262F252622252C272420281E24211D25202426251B26181C1D1B1616131B151B1916
1310120E10141715130C13090C0B0B0C0E0E0D090C0D0603010304030000000000000000
000000000000000000000000000000000001000201030605020606060808070A0708090B
0A0B0C0B0B080B090B0B0A090B0C0D0C0A0C0C0B0C090B0B0D080B0E0B0B0C0A0B0C0C0A
0B0C0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0B0B0B0B0C0B0A0E0A0B0A090A0B0C0D0B0C0C0C0A0B0B0B0B0C0A0B0D
0A0A0C0D0C0D0B09090B0B0B0D0C0B0D0A0B0B090C0B0B0C0A0B0A0C0A09090808080909
070A05060505030100030003000100000000000000000000000000000000000000000000
0000000000090B32497C9EBED3C9DFEBD7E9D1E0E6CDD5D2BBC795ABB8AAA1A796918283
79897D7E696C5B5038392118110A0F000000000000000000000000000000000000000000
000000000000000B0408070917131E1117141A1317161F27212323231C1C22171F241718
19191C1F211C20211A19141B1D221B211C1F1B201A2523202827272322242631262D2A26
202C222A21292D272D2323292722202A2A2620191C19211A1A151E231B1D241C2B1F2324
25292120271D1F2A2A2729282B29291E2624221F1A211A2121101D1118150F1416191712
1217121A121312101011120C0A0E0B050608080B0C0A0907040606010100000000000000
00000000000000000000000000000001040202020105040407050906070707070809060B
0907090B0D0A09090A0A0B0B0C0D090D0A0B0B0D090E0C090E0D0D0C0909080D0B080A0E
0C0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0D0B0C090B0B0A0B0E0B0C070A0B0E090C0B0C0E0C0A0D0B0A0A0F0B0A0D
0A0E0A0E0B0B0B0C0A0B0C0B0B0D0A0D0B0A0A0B0B0B0D0B0A070E0B090D0B0D0A0C070C
070A08090607080504020101030200000000000000000000000000000001000000000000
000000000000000B18325C89A6B3D2D0DED1EAD3D5D0E6CCCFC0C1C3B7B0ADACB6AAA897
A09B8D8C838367614B413C381C240C050E00000000000000000000000000000000000000
0000000000000000060B0106090F161B13191D17111A221F24231E22211E172115171A15
1E1D20231C1E1F1B16151815201A1D261D1E1A171C21272429201F2225272D1F2A282D1F
2E272D2A282C2B2729222B2525282C2B2B26272119232229151D181A241E1E1C2426292C
24282F1F2322261F261A262626202923251A1B1D222520211A221A1D141116101311181C
160B1D0B140E1C0E0C16080E06080F0907040C0509040702000100000000000000000000
00000000000000000000000000000000010001020602030505070609090709090C0C0B0A
090A0907090A080C0A08090B0D0A0D0C0A0C0C0B0C0B0A0B0B0C0C0B0A090C0B0B0B0B0C
0B090A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C090D0D0D0B0B0A0C0A0C090C0A0C0B0C0A0A090C0B0A0D0C0B0C0A0C080B
0E0A0D0A0B0B0C0E0B0C0A09090A0C0D0A0B0B0C090B0D090D0C0C0A090A0A0A0A0A0B09
0B0709080707060706050103030200000000000000000000000000000000000000000000
000000000000000000091943668EA5C4C1DCD8D6D5DAC9E4D1CEC4CFB5B7B4B3ADB1B9B2
A3A6B39287857E826968594E402F1C16170D010000000000000000000000000000000000
00000000000000000005030102050D1013101D1812181A1B22212520161B1C181E14181A
21211F1D222D1F281F2315171D1D1F2411191E1F1D1F1D21262A1C26261F20222A252920
2820242B2E262E2D262D25291D2D232F2B292B261D242013241F1B1E201F211B2527222C
212024242323221C25252523292921251F272426231A211E1D1C1B110E151612130F1613
121217090B121612090C0B0B0D0509060803040201000501060000000000000000000000
000000000000000000000000000000020403030403060606070A0607080909090A080906
0C090A0C0A090A090B0B0B0B090A0B090B0A0E0C0B09090A0C090B0A0E0B0A090C0C0B0C
0B0A09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0B0B0A0B0C0B0E0B0C0B0D0A0E0C0B0A0B0C0C0A0A0B080D0B0B0A0A0C0A
0B0B090A0A0D0D0A0B0D0B0A0B0B0B0C0C0B0C0C0B0C0A0A080C0C0A0C0B0C0D090B0A0B
0A08070B080A040607060204020300000000000000000000000000000000000000000000
00000000000000000000000821417991B1C3DCDAF0D8DEC0E0DCE8CDCCB9BABBBEC0B4B0
B0BBA7A3AA99838C907C746D6157353E24190E090A000000020000000000000000000000
00000000000000000400000100030610141C120C1F1617151C22191E1A161A1614161A1C
23221B1D2824271B1D1A1D171B2415161B1F101C211F1E1E1D21221F241E18202322232B
242A2C252C242521282C2A292722282725252A2325241F1B181D1E1C191820191E242223
322420212124232828211D25201E262B212124211C1A1E1C1A1C1B171216180E15130F0B
0F110C0B0E1211090A0D110F0C0A08070E030B0000010200000000000000000000000000
0000000000000000000000000101010303050203070505070509080A07070A08080A0B0B
0A070B0A090C0B0A0B0C0D0D0B0C09090A0B0B0B0A090A0B0C0A09090A0B0B090B0C0D0B
0D0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0D0B0D0A0A090C0B0D0D0B0A0A0A0A0A0A0D0D090B090A0B0C0A0A0B
0B090C0C0A0C0D0C0D0D0C0B0B0B0A0C0B0B0B0A090E0D0B0C090D0B090B0A0A0B0B0A09
0A0B090B0909080807040403020101000000000000000000000000000000020000000000
00000000000000000000000002172C5C789AB3C8CCDBE3D7DCE0E2D5D4C7BEC0C7BBB8B4
B5C2B9B7AEA49D90929488887864615240322D2019070806010000000000000000000000
000000000000000000030006000D05090616181713131A1E171D1E18151B1C1B1B17221C
2B1918191A2224161D1B1E211A241B141F1C1F1B1D1B1B201D2217191F1F252127252527
262320211E272E242D32272A2925232928232B242125242528211E19151F1C15231F181F
1B26251E1824262324252528222524212726271F251D1B201B191B1B1319101A15170F16
1315110E0B100C070B0B0B090A0804080403030306000400000000000000000000000000
000000000000000000000000020100030105040904060907070907070809080909070A0A
080A0A09090B0D090B0C090A0A0B0B0A0C0E080B0A0C0D0C0B0B0D0B0B0D0B090B0B0B0E
0C0B0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0A090B0E0D0A0C0B0A0B0C0E0C0B090D0A0B0C0D0C0E0A0D0C0B090E0B
0B0C0B0B0B0B0C0E0E0C0B0B0C0C0C0D0D0D0C0A0A0B090D0A080B0C0A0A0A090B0C0B0B
0A0B080B0A06070607050904040505040002000000000000000000000000000000000000
00000000000000000000000000000317355A7FA1C3CEDBD1E6D5E0ECD6D9DDCAC4BECAC0
B4B4C6BEB1BBB1A6A5939B89867D7871564840402D210E12000900000000000000000000
0000000000000000010000010502000302090F0B12110F1416182420201A0F1317141319
1A121A1E181D1E1B1D202017171D1B1B201E1A272918192A2D2A271F212425202923201C
201E22261A292929282E25292820272D1F27242628242E29251E26201C1E171F1518131D
1B1F231F281B2725272926201A271F1F22221D28221D27181E1A15131712141213120E0E
0E05110D12100C09090908070B0A05020308010403000002000000000000000000000000
000000000000000000000000020103040006050405040A06070808090A0908090A0C0B0B
0A0B090A0B090B0B080C0B0D0A0C0C0A0A0B0B0A0B0A0D0A0C0B0A0A0C080A0B0C0A090A
0B0C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B0A0B090B0B0A0B0A080C0C0C0C0C0D0A0B0C0C0C0D0B0A0C0B0B0B0B
0B0E0B0C0B0C0C0A0C0C0B0C09080D0B0D0C0B0A0A0B0A0B090E0B090B0D0B0A090A0C0A
0B090A0A09090A0A090A0605030406020000010000000000000000000000000000000000
000000000000000000000000000000030A213F7087ADBBC7CAE2E1D8CDD2DBD3D6D2BDC0
D1CBC3C6BEC1BAB1AFAFA78F8AA18A876D785D4F463520251C0F07020000000000000000
000000000000000000000004020104060C02110D0E101415101D171E10111B18110F0B15
12171A141A1C1717191E23191C221A1D1A1E1A2421232A191F221F20201A1E1E1E212221
231C21201A1D2B202A20282C242C2025252D2F2A1E29302D261D20211A1C20221B121315
1E19151C2820222B202226201E1E1D212021212322261B1A191C1717111410100E110E0D
0E0E070A0A0B070A0B0A09060A0303030902050100010000000000000000000000000000
0000000000000001000000000001030403050505080707070709090A07080B090A0A0808
090809070C0A080A0A0C0A0A0B0B0A090C090C0A090A0B0C0E0B0D0B0A0B090B0A0B0A0A
0B0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0A0B090C0A0C0A0C0C0C0B0C090A0B0B0A0A0A0A0B0B0B0B0B0B0B0A0B0C
0A090B0D0C0C0E0B0D0A0D0B0C0C0B0B0B0C0B0C0A0D0B0A0B0D0C0D0C0D0D0A0E0E0A0A
0B0A0A0A0B0A080A080A0807090403030505010000000000000000000000000000010000
000000000000000000000000000000000000142A49768FACC4D2E3E3D5DCE0DFE4D7C8C9
DBCAC3C2C8BFBEBAAAB4B5A2A5A09C85797A756C564A3E3534171C0C1A02040000000000
000000000000000000000000030000000507050B0E120D1617161B181C121C0F161A1118
121D18151B231C1A1815171B1D161D1922181920191F161E241C1F17191E1C1B2721271C
2024151F1C29262B26211D222223231B242327221C2926201C211C1C171817161C171321
16161E1C1B172226201C221E24231C22221F281F1E1B17161A161318161514131212100F
0912090B0E070A0909080908080405060902000000000000000000000000000000000000
000000000000000000000301020304040406070A0607080806090A0B06080C0C0A0B0A0A
0B0B0A0A0B0B0E0C0B0C0B0B0A0A0A0B0D0D0C0C0B0A0A0B0B0B090C0C0B0B0C0C0B0909
080C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090B0B0E0B0B0A0E0A0C0C090B0B0B0D0A0B0A0B0C0A0C0C0A0B0A0A0B0B0A
0D0D080A0C0B0C0A0B0C0C0B0D0B0C09090B0D0B0C0B0D0A0B0C0D0B0C0C0C0B0A0C0B0C
0B0B09090A080A0B070B0D09050507070206020200020000000000000000000000000000
00000000000000000000000000000000000000081C28577194AFC8C9D4E6E2D5E2EAE4DD
D5DBE0CDCEC6CBBAC3C1A2BDB2AD9EA099938079716C484C3637382428120E0800030002
00000000000000000000000D0208040A130D0A0A110F1617121C1A13101214160E0D130D
13121B090F131D1419142024181F211317171A14221B1319191F221B121919222129231B
2715222520261A25271E2622192129281F1D21202520211A24221F241819201512181418
1C1D171A1A251D1B1D1920231B1E18201D211D1B1C1F1A1514160E1215181410150C0C0C
13090B090B0D060807030408060300010000000000000000000000000000000000000000
0000000000000000000101030401030106060804080909090B0A0A0C090B090A090A0A07
0D0B0B0C09090C0A0C0B0A0C0C090C0B0D0C080C0B0B0A0A0C0B0B0B0B0A0C0A0D0B0D0C
0B0C0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0A0A0B0C0A0D080B0B0D0B0E0A0C0B090A0C0B0A0A0A0D0A0B0A0B0C0A0B
0A0B0A0C09090A0B0B080A0C0A0A0C0B0B0D0B0B0A0C0C0C0C0A0C0C0D0A0B0E0A0B0D0B
0B0B0B0B080A080A08080708030806060506030101000000000000000000000000000000
0000000000000000000000000000000000000000000919345981A6B5C2CADEE1DBE5E4E8
E4E7EFD5D0CCE3CFD0CCC3B8B6A6A0BBB89B939B92736B604C3C412D2523171305000300
0000000000000000010004000004030009070C0E0D17141013110F0C1C1A11141B171312
0F1711132019170F2112181F1C22191D1D1D1A141C1B181821212018191B161C21221E1C
23261F1F201B1E211F1E1F151F192022281F2327221E1E232119211D1E1E1E1B1E161417
12191C1C191E1D211F1C191E173920191F1B191819121C17130F0F151114110D12100E08
0B080F0A08040A0504060604030105000000000000000000000000000000000000000000
000000000000000002010004030507050407060909090A090A0B06080B0A090B0B090B07
0B0D0C0B0B090D09080E0B0A0A0A0D0A0A0B0C0C0C090C0B0C0B0B0D0A0B0C0B0C0D0C0D
0B0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000090B0B0C0C0C0C0D0A080B0A0A0C0C0C0A0D0C090C0B0A0A0A0C0C0B0C0B0D
0B0D0B0E090B0A0C0B0C0D090A0B0C0C0B0A0C0A0A0A0B0B0B0E0B0C0E0C0B0B0B0B090B
0A0C0A0A090A0A0A0A0809070A0A08070704020304020002000000000000000000000000
00000000000000000000000000000000000000000000010F1E38598A95BFBFD0DCE4EAF3
E6EBD8E9E0DBDADDCFDDC9C7C0B7BDACB3B4A89E93968C726B574A3F3D2F291D11050802
000502000000000000000004000A00040A11090E1011161B150D19161115141212131615
0E1714101514171D1A1A1A170F171A1C18161A1B1A261E17141E1C1E1E16151E1D1A2923
1E251A1820201F201C1F1E22221F1921171B1F222023271A271F1E23141F1717181A1A1D
1B191A191E10181C1C22191F1A18181B17131916131315151314170F0D1110190B0B0C07
080A06090702050603060204030200000000000000000000000000000000000000000000
0000000000000103040305020604070608060A080808080B07090909080B0B0B080B0B0B
0B0A0D0A0C0A0B0B0B0A0B0A0C0A0A070B0C0B0C0B0C0C0B090A0A0C0A0C0B090D0C0B0C
0A0B09000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C090B0C090D0B0A0B0B0A09090C0A0B080A0B0A0C0A0B0E0C0B0B0A0C0C
0B0D0A0D0B0A090B090A0D09090C0B0B0D0B0D0B0D0A0A0B0B0A0B0C0C0A0D090B0C0B0C
0C080C0A0A0A0C090D0B0A0B070809090706060405030303010300010000000000000000
00000000000000000000000000000000000000000000000000111E365A80A4B9C4CFDDE0
E9DDE7E9F9E5E9EBE9DFDCCFD4C0BCC8C2B8B2B3ACA09F967773664B4A512C2E1B0F0F0C
08080002050000000000000A0203090F080B06100E171815150D0C1416110E1F1B0D1A14
0D1A1B171C19221B181D201B201C1F211C1D11180E121816221A1D1F161C191B1D181E18
181F2524231C20231D1C18221618211F201E1E24212621221C1C1D201A1E181B19211D1A
191D191D1B16181A20191E1F161822161B1719171816171A0D100A14110F0B0D10120B0E
070A09040304060205000002000000000000000000000000000000000000000000000000
0000000101050203000106040506080408070609090A09080A0D090B0A090B090B0A0B0C
0A0C0A0B0B0B0C0C0C0D0B0B0B0B0C0B0B0D0D0C0C0D0B0C0B0A0B0B0C0D0C090D0C0A0D
0C0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0C0B0B070C0C0D0A0B0A0A0D0C0B0A0D090B0C0C0B0D0C0B0B0D090B0B
0A0B0B0B0B0B0C0B0A080C0B0C0D0A0A0B0A0B0B0C0C0A0B0B0B0E0C0C0B0D0D090B0C0A
0B0C0C0C0E0B0D0A0D0909080A060708070A060702040103000301010001000000000000
0000000000000000000000000000000000000000000000000000010A274460859FBCC8CF
D4EFE1E8E3EFF1EEEBE1E1DDD8D9C9CCC3B7C3BAACADACAF8F7877715B50453923381A24
241B08051000060000040101030503060A0C0A0A0E0A17100F120B171514181D1C111518
221613181E1A171B13191D1A1F1E211D1D1B1C1C1E1A1A17141B1D1D19101517191B1E1E
231D1E1B1B201E21221A1D191927201F1F201E201F1F1C1C231B1D1E2130241C15191817
1F1A171B18121B151617191C1910191A121B171714161014161A111011110E0A050C050A
030408020404060502020400010100000000000000000000000000000000000000000000
00000100020502040504050505050608070A0A090808080A0A08080B0C0B0A090A0B0B0B
090A0B090B0A0A0B0A0B080A090C0C0C0A090C0A0B0C0B0B0D0C0D090B090C080D0C0B0B
0C0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0A090C0B0B0C090C0E0A090B0A0B0C0A0E0B0D0A0C0C0A0C0A0B080C0B0D
0B0B09080C0C0B0C0A0A0B0D090B0C0A0B0C090A0B0B0D0C0A0B0C0B090C0C0A0C0B0A0C
0E0C0B0B0C0B0B0C0B0C090B0D080A080708070805050306040400020000000000000000
000000000000010200000000000000000000000000000000000000000013243A5583A2BA
C8D0D9DAD9E4E7DED9E1E7EAE6DDD9D7C9C8CBCCB4BDB1BFAE9A94726F6B5A4A3C37412F
231F1A0C0A040F020406050308020C040E0F010F0D10140911140E10190E130B16151814
211F1C11182020261922191B232016171B14181817141A1D1A131315181E221514161714
1D1B1B1A1A181F1A1C1E1D181A1E1B1B1B191C1C1F1D2122201E1A1E17231B1F1A212221
161E1B181816131E1E18111715171C141B15101610161510120B0D11090C080B0A080607
060604050504000200000001000000000000000000000000000000010000000000000201
010202030404040402060507060707080809090C0B090B090B09090C090B0B0A0B090A0B
0B090D0B0C0B0A0C0A0B080D0C0A090A0B0B090B0B0C0E0C0D0C0B0A0B0C090C0C0D0A0B
090D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0D0B0C090A0B0C0B0A0C0B0D0C0C0D0A0B0B0A0A0A090A090E0D0E0D0A
090C0B0A0B0C0D0E0D0E0C0B0A0B0B0D0C0B0B0C0B0B0B0C0C090C0C0C0A0E0E0A0D0D0D
0E0D0B0A0F0B0B090A090A090B09070B0A09080707090607060704060000010000010000
00000000000000000000000000000000000000000000000000000000000009101F395675
99B3C0CAD4EADEF5EBE2D1E6E3DCE0DAD8E2D1DFCCC7C0B6B6B29E9C867B71584655413C
30321C1A1215161A040D0C090904090D070A040A10121111161B100F14191A151C151C21
181E241C1D1C1F1F15211E1B1B1B1A1C1719201C1D1A141917191517161A0F15171B1C1D
212022161D161A211A1F1E1E1A1F1E191C181A19171E1D1D201B1C22181C1A191C21231C
121516191C160E1519110D1211181313171411131012120D0F0E100C100B0B0A09070708
040405030704030100000000000000000000000000000000000000000000010000000001
0100040502030305050608070608080608080B0B0A070909090C0B0A0D0A090A080A090B
0B0B0D0A0C0C0A0B0C0A0B0C0D0B090A0A0B0B0B090C090C090C0B0A0C0C0B080C0B0D09
0B0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B080A0C0A0B0C0C0B0A090A0B0A0B0A0B0C0B0C0E0A0C0A0C0B0B0B0A0B09
0E0A0C0B090C0C0E0C0B0A0C090B080C0E0A090C0A090B0B0A0C0B0C0C0C0A0D0A0C0C0B
0B070C0B0D0B0C0A0C0D0B0A080C0B0B0709080C07080807070702050600010300010000
0000000000000000000000000000000000000000000000000000000000000000000D1635
5775A6AFC8CBDEDFE0F5EBE4E2E6E2DCE7DECDCED2CFCDCABCC1B3A49282836F6D58504D
3B342D2D1E171D1E2117180A0E08060F0A080D1415130F0D071115171615101C11111E18
1F2320261F171D1F201B1E1D181A17211D221C1C181C1E1619191A1518181A121B141819
1B131717191A16181E1B1A191A221B181A171D1D22261D181C1F212021191A1A161E1A1B
1A121C171B151718151816120E121411121712110B150B100C0E08090D090C0609070901
080406040100000000000000000000000000000000000000000000000000020100000000
0405000605070304060706050A090809080A080A080B090A0A090A0A0E0B0A090B0B080B
0A0A0B0C0E090C0C0C0A0B0C0B0C0A0D0B0B0B0B0D0E0B0C0C0C0D0A0B0A0C0D0D0C0A0A
0A0D0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0A0A0A0D0C0D0A0C0B0A0B0B0B0B0B0B0C0C0B0B0C090D0C0B0A090B0D
0B0C0C0B0C0D0D0B0A0B0C0B0C0D0A0B0A0C0A0A0E0C0A0C0C0D0C0A090D090C0C0B0D0B
0B0D0D0D0A0C0C0C0A0D0B0D0C0A090B0809080707080808060708070905020003000000
000000000000000000000000000000000000000000000000000000000000000000000004
1233567B98AEC1C8D3E3E0EBF1E5DCECE5E8E3D2D3E1D0CECCD6CEBEACA2958D87705D48
51493F33302F211E1E1218150B1218161F16121610130D121114171B0F1F1E151B161B1E
1A221F12211B1E201E2018241B25131B1B1E1F0F1F1A1C191816151918181718101F151F
161F1C121C1D191E1C1E18171B191819181D1F1A221D181B211F201A1B231F191C1E2017
16161716131B16191215150F0B11111511180E0F10090D0C0D080D0708080809020A0304
020201000000000000000000000000000000000000000000000000010100020003030105
02020403060207090505060909080808070A070C080A0A090B0A0A08090B0B0D0B0B0B0A
0B0B0B0B0B0B0A0C0C0B0A0D0B0B0C0B0C0C0B0A0B0B0E0B0C0C080C0B0D0D0B0C0A0C09
090A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0B0B0B0A0B0B090D0B090A0B0A0B0B0B0B0D0C0D0B0B0C0B0B0F0A0B0B0A
080C0A0B0B0A0A0A0B0C0A0D0D0A0B0D0C0C0A0E0A0A0B0A0C0A090D0C0D0A0B0F0A0C0C
0A0B0B09090A0B0C0B0D0A0D0D0A0B0B0D090909050C08080B0806030707050502040001
000100000000000000000000000000000000000000000000000000000000000000000000
0013112D466F85A8BEC1D7D7DAD7DCE5E4EAE3E2E0E6E3E1E9E2D8D5BAC3BA919D807576
66524A4840343324282B21201D181C171B161618141D15191C2312181E221A1115141715
1D1618151D1A232427231D211E241D2117181D1E131E1C131A1C1B161518151610151A19
1D181A1911161E181D1C1C1C1B1B1F1F221C181B1E241A1E1D1919221B17181E1C151E17
1A170F121A16191813160F121213120F0D140E0F110C0F0F050706090A07080603060302
040100000000000000000000000000000000000000010000000001000102030202020103
0404040505070704090A08080A090A09080A08090B0A0B080A0C0A080B0B0B090A0B090B
0C0A0B09080D090B0A0C0D090A0C0A0B090B080D0A0A090C0B0B0A0D0D0B0C0C0B0B0B0C
0B0D0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0C0B0B0B0A0C090C0C0A0A0B0B0C0B0A0B0A0B0A0C0A0A0A0B0C090E0B
0D0D0B0D0B0B0D0A0C0C0A0A0D090C090C0C0C0B090C0B0B08090C0A0D090B0C0A0C0D0B
0B0B0B0D0B0C0A0C0A0D0A0D090D09090B08080A08080A07070709080608040504020503
030000000000000000000000000000000000000000000000000000000000000000000000
0000000D1924435E83A2C0BACACBD4DEE3E0D9E2E4F4EAE2E6EBE4EFE5BFBCB0A59B8F84
7E65635D514F40382B2D2E302D27221B2225181C1A1F1D1718181A1C19131D1E1D191420
1F1D1E1E1E1C161D24241D1D191C1B1918171D192116191A1B181B181C12141A1B1D1621
141A19171B19151618161C1C171E1C1B12201F191B1F1C1E21221F1D18221814171C191C
1D151314131614151112100D11100B0B0B0E100C0F130905090B07070A04030107000200
000000000000000000000000000000000000000000000004000200030000040404040205
0703070507040807090809080B09080909080B0C080B0C0C0A0B0A0C0A090B090B0D0B0B
0C0C0D0A090C0C0B070C0C090B0A0A0C09090B0A0B0E0B0C0C0B0D090D0A0B0D0B0A090A
080B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0C0B0D0A0C0D0B0C0B0C0C0A0B0D0A0B0D0A0B0C0B0A0A090A0C0D0A0A
0A0C0B0B0B0B0A090B0A0B0D0D0A0C0C0C0B0A0B090A090A090C0C090A0B0B0A0D0C0B0B
0C0C0C0B0B0B0E0B0C0B0E0D0B0D0A0B0B0B080C0A09080A070A08070908060403050403
010000020001000000000000000000000000000000000000000000000000000000000000
00000000000412233C69898DA6ACD2D8D5DADADCE6DBEEE7EBE6F2E2DCE4CFCDC5B9A5A1
8D88806667635B4E46423B3E3638292A2A23271B1F2129252115211E241D1E211E192118
1E1F1B20201F231F201E251F2523222B1B151D1F1A2021181A191A1D160E141715161E1F
1A1C1D201D191D1A1A191919141A1A1D191B191D1A1A1A1A2119171C211618171A191516
19131A151813140E110C10120E0C0C0C0E090A0C0C0F0D0B060706090505050100020000
000000000000000000000000000000000001010202020101000001040101050602050504
05080805070607090808090D09080A0A0B0A080C0B09080B0A0B0D0C0B0A0A0A0C0C0C0B
0A0B0A0B0C0C090D0A0C0C0B090B0D0E0B090B0B0B090D0C0D0A0B0A0B0A0C0D0C0B0A0A
0A0A0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B090B0A090B0B0C0B0C0C0A0A0C090B0A0A0C0A0B0B0C0C0A080B0A0B0B
0B0E0A0C0D0B0B0B0D0909090B0D0B0C0B0C0A0B090A0A090A0C0A0E0B0B0B0B0B0B0B09
0B0C0C0C0B0A0B07090A0B0B090B0B0B0B0C0D0D090B0807070A09090608060703040703
040201000000000100000000000000000000000000000000000000000000000000000000
00000000000000030B1E39466D7DA6B3BDC9D0CBDBE2D4EEE6E0EEE3E8E2D7DAC0C4C3A8
AF9B9590787964634B544A443F353D35352A2A233322212D2D2125231F202123251F251B
201A18242322252323262C26241E2C2323251E1A251B221B1721201A1A1918191616191B
1A1B1D1B211C1C1720181E15191A1D161B1A1D221B1B19181A1B19141F18161B18111615
1012151212121110100F0F10120C0B0C0E080C0A060807060506060A0403010002000000
010000000000000000000000000000000100010100010103060503040203040408060507
0606070805060606080A070A07070C09090D0A090C090B0A0A090B0B0A090A0B0A0D0D0A
090B0A0B0D0B0D0C0C0C0B0A0B0B0A090A0C0B0C0A080A0A0B0D0B0B0C0B0C0D0A0D0B0C
0E090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0B0A0A0A0C0C0C0C0B0B0C090B0A0A0B0B0A0B0C090B080B0E0A0B0A0B
0B0C0A0A0B0B0D0C0B0E0C0C0A0B0C0D0A0A0A090B0C0A0C0E0D0B0C0B0D0F0C0C070D0A
0C090B0A0B0A0C0D0C0C0D090A0B0A0B0A0B080B0C0909090909090A0606080A04060404
060503000000010000010000000000000000000000000000000000000000000000000000
00000000000000000000010E1E36456A7F9CA4B2BDD5D3E1E2F7E5F4E3E1DBDEE1E5D7C7
C8C3AA9F9F937F77686261655B4F4C473C36333A3032383129342D27241C2727231F1D22
28242326282C26321F2921252E26262722231B23221922171A20201E201C1A191E191619
1B1512161717121816161D1D1A161616161C161D1F1D16131718141A1B121A1417151413
171115151D0E160A1010110C0B0F090D0A07090B07070807030403000003000001000000
000000000000000000000000000100000001040301010002050304040404080507030806
09080A08090A0A09090A0B0A080A0C0B0C0C090B0B0A0A0B0B0A0A0C0D0A0B080A0A080C
0B0D0A0C0B0B0C0B0C0B0A0B0C0A0D0C0B0A0B0A0A0A0C090B0C0C0B0C0B0C0C0C0B0C0A
0C0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0B0B0B0B09090B0E0B0B0B0B0B090B0C0D0A0A0B0D0B0B0B0C0B0B0B0B0C
0A0A0A0A0B0B0B0C0B0B0C0D0A0A0C090D0C0B0C0C0C0D090A0B080B0B0A0A0C0C0B0B0C
0D0D0C0B0B0C0C0C0B0B0A0D0C0B0C0B0D0B0B0D0A0A0B080A090E080909090809060707
080402050403000100000000000000000000000000000000000001000000000000000000
000000000000000000000000000D1425484E688B9BB0CCCECED5DFE3DED8EAE9F1E3D9E4
D5C7CDC0AFA398837F736E666E5A6352494242393D3137353D34372F312A30252D272A28
2326252420271E222B292024272A2625252A2A2125202524231E1E1E1D211E19251C1A18
1716131714161C1A181A1B171913141A161A1819171B151911161317181A121411121113
100E1513120D0E0D0C0E0A0B0D050A0A0A090B0A03080600020402000001000000000000
000000000000000000010002000300010400030303010203040306050305060704060607
0704080607090A09090B0A0C080B090A0D090B0A090A0D0D0C0D0B0B0D0B0A0B0A0B0A0D
0C0D0909090A0C0B0C0B0C0B0A0B0A0E090C0B09090E0A090C09080B0D0D0C0E0B0B0A0C
090C0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0C0B0C0C0B0C0B0A0A0C0A0A0A0B0C0B0A0B0C0B0A0D0A0B0C0B0B0B
0B0A0D0C0D0B0B0A0B090C0B0A0B090D0B0C0D0D090B0A0A0C0A0D0A0A0D0B0A0C0B0909
0C0C0B0A0B0F0B0C0A0C0B0D0A0D0A0B0B0A0C0A0A0A0C0B0B08070A09080A070A060607
030503070702060000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000040E112A3C4B748E9AB5C2C6D5CCE5E0E7E1E3DADE
E3CFD8CCC3BAB0A59888747D7B6E636B5855414041443D44404038322E34322C30212F23
2A242A262A202827282F2B2E2F2A2D292A2B1D23211F221E2321241D1A231D181A1D1B18
1C161411191B1A181B191B1914152014181916161A1916181512171214180E1113161710
121412101013100D0F090C0B080E050B0A060A0406040001020200000000000000000000
000000000000000000000000020100010203030404040302040706050504070505060608
08080A090A080B0C0A070C090A0B0A0B0B0A0D0A0D0A090B090C0D0D0A090C0B0B0A090A
0A0C0B0B0A0B0B0A0B0A0C0D0D090C0B0C090B0F0C0A0B0C0B0A0B0B0B0B0B0B090C0A0B
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0B0B0B0B0B0B090B0B0C0C090C0C0A0B0A0B0A0C0A0A0B0B0C0B0E0C0D09
0C0B0B0A0B0E0A0B0B0B0A0A0D0D0B0B0C0E0C0D0B0A0C0E090B0B0B080A0B0C0B0B0A0B
0B0C0C0E0C0B0C0E090B0B0B090B0C0C0A0C090B0B090A0A0A0C0A06080907080B090807
070605040503050802020100030000000000000000000000000000000000000000000000
000000000000000000000000000000000003000A192E4B54638BA0A9C3CAE0E5E8D3D7CE
D3DBDAD6CABCC0B2B5ADA7918E7B79706A5E545A4F44534A4A404C3F3E413B3D39333233
3229302A2B292629282C2528262B2E28292525262528242327241A261F171D1F191C1817
18151D1919161C131512121214131614181416161B171714141219181611111114111015
12131216120E0C100C0D0F0A070B090A0809040103020300020000000001000000000000
000100000000000002010101000203020006040202050505060605090806060906060A0B
0909090808090B080A0B090A060B0C0A0C0B0B0A0E0A090C0A0B0B0C0B0A0C0B090C0B0D
0D0A0B0C090B0B0E0A090A09080A0D0B0A0C0B0A0C0A0B080C0B0A0A0A0B0D0B090B0A0C
0A0D0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0C0A0B0C0C0A0E0B0C0D0A0B0A0A0A0B0A0B0C0A0A090C0C0B090A0B0B0A
0A0C0B0A0C0A090C0B0E0B0B0A0C0A0C0D0D0E0C0C0A0D0A0A0C0C0B0B0C0C09090B0A0A
0B090B0B0C0B0C0A0B0A0D0C0B0B0C0C0D0B090A090A0A0B0B090B080A0A080A060B0808
060408050604050404060305000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001031B1C294A5A6F829CB6C2C8D3C3C6
C9CED7D2DCD5CAC8BFADABA6888D7E78736C62595D5347484D4F483A4A3C43373A2D2D39
32352F2D332E342A312B2A33342D322631302D292C282927271F27191D1D181B1A1E1C13
161417151C1B18151B1A181511161512150F161618191219160F19151411120E130E1511
0F1312150D0A0E0E090A08080A0604040301020000010000000000000000000000000001
0100000100000103000102050301000403050506070706070506080505080A0A0807090A
07090A080B080A0A0A0A0B0C0C0A090C0A0908090C090C090B0A0C0B0B0B0B0B0C0C090A
0B0B0C0B0B0B0B0B0A0B0A0A0A0B090B0B0E0A0A0B0A0A0B0D0B0C0B0D0B0D0A0B0A0B08
0C0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C090B0D0A0B0B0C090A0B0B0C0B0A0B0A0A0B090C0C0B0B0C0A090A090C09
0A0C0A0D0A0B0B0A0A0C0C0A0C0B0C090B0B0B090D0D0A0B0E0C0C0B0B0F0B0C0C0C0B0B
0C0B0E0B0C090A0C0C0D090E0C090B0C0B0A0A0B0B0C0E0D0B0B0C0A0A0B0A090B060809
080705070507030506070205020102010000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000008071E344248698396A5A8BD
C2C9C7D3DDCFCEBDC3B6A89D8D8F927F756E6F6D635D5F51494C4C423A43443F423D3836
30393838322E2B312929292B252F2F2E2A25282723292627252127211F1E1A171A171B18
1B121E1B1314171716151616191215131811101714180F1213141112120C12110E0D1311
0D100B0A0C0D0F0E0A080B07070203020100010000000000000000000000000100000002
010001000402020402040402030604030407050707040808080906080707090808090809
0D09090A08090A0A0C090B090A090B080B0B0B0A090A0B0C0A0C0A0B0C0A080A090A080B
0C0909090C0D0C0A0B0B080B0D0C0B0B090A0D0B0A0C0D0C090E0A0B0D0B0D0C0C0B0C0C
0C0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0A0B0B0B0B0A0A0C0C0A0A0B0C0E0B0A0A0C080B0B0A0B0D0B0B0D090B
0B0C0A0A0C0B0B0A0A0D0D0B0B0C0B0A0A0B0A0B0B0D0C0C0D0A0D0A0A0B0C0B0A090A0C
0B0C0A0D0C0A0B0B0A0C0C0D0A0C0B0B0D090A0B0D080C0D0B090D0B090A090B0B080807
090708070609060608030502060405000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000050810131F3744607180
939DAEB3C4CFC1C5BBBAAF9E9D90988E8E7B7E7870676566525351484B47484A41363F40
403F38323D36383634342A312B32322A2C2C2C2F2B2A262A2229202423211B1E1B1D1C17
141C121C1715170B141214141715141A160F1612111413150F1512161011140E0F11110E
0B100D0B0A090B090A080603000000000000000001000000000000000000000000000400
000001040204050202030302030505030307050606070707060707090A07060807070A0B
0908090A0B0C0B09090A0B090B0B0C0D090B0B090A0C0C0C0A0A070A0A0B0D0B090B0C0A
0A0B0D0B090C0B0A0B0D0B0C090C0B0D0B0B0A0B0B0A0A0B0A090D0B0B0C0C0B0D0A0C0B
0B0B0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000C0C0A0B0B0D0B0A0A0B0D0A0B0A0A0D0B0C0B0B0A090B0A0B0C0A0B0A0D0A
0C0E0C0C0B0A0A0B090C0C0B0C0B0A090C0B0A090C0B0B0B0C0B0B0D0D0B0A0C0C080A0B
0C0B0D0D0B0A0B0B0D0C0B0A0C0D0D0C0B0C0B0D0B0B0C0A090D0B0A0A0A0D0B0C090B0A
090807070909070809050507040402020201000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000040B12212E46
4869768690A5A6ABACAEB6ADA79A9893858385797F6A68605B5C594C524C49483F40413F
423D3D3D37353B303E413E33303130302E2E252E26212528272723252620151D1E201C1A
1A17161717160F131416141011091213141A110F1512110F1112150E0F0B0D100E0E0D0E
0A0C0C040A07060404040301000000000000000000000000000000000000000101010102
00010203020301070401030105040705040604070706070807050607090D0B0C0A0A090A
080A090B0B0C090B0A0C0A0B0A0C0C0B090D0C080B0C0A090A090C0E0C0B0B0E0B0B0B0B
0D0A0A0B0B090B0B0B090C0D0B0C0E0D0A0A0B090B0B0A080B0C0A0B0C0C0D090D0D0C09
0A0B0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0B0A0A0B090C0B0C0D0B0C0B0A0B0D0D0A0C0B0A0A0C0A0B0B090A0C0C0B
0A0D0C0B0B0C0C0D090A0A0D0A0B0A0A0B0C0C0B0A0B0B0B0D0A0D0D0C090C0B0B0C0D0C
0A0B0D0C0A0B090A090D0B0C0B0A0B0A0A0B0B0B0C0A0D0C0D0A090A0A0C080A090B0708
0B0A08090807050607060305070507060305010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000020108
1721323C485D717F8B98999DA3A39B9C8F8A8580736E626863635E5852524E4848404A48
3E423E3F343940383841303834352D2F29312C2B292A2B2A2D252321222124261914151B
1819131915151515141411080F12140E120E1211140E0E0C140F0D0E0C0F0D0E0C0E0C0E
050908040306020005040000000000000000000001020000000000000201020004000002
0405010003020404050606050606060508060607090909080709090A0707080C0A0B0B0A
0B080B0A0A0B09090C0D0C0B0B0A0B0D0D0D0A0C0B0A0B0C0F0D0C0A0B0A0B0A0A0B0A0B
09090B0A0C0A0A0B0D0E0B0B0A0A0A0C0A0D0B0A090C0D0C0D090A0B0C0C090B0B0C090C
0B0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0B0A0B0C0B0C0D0B0909090B0D0C0C090B0B0C0C0A0B0B0B0C090B0C0B0A
0D0A0C0B0A090A0A0A0B0D0A0D0A0B0A0D0B0C0A0C0B090E0C0B0D0B0C0C0C0A090A070B
0E0A080C0A0D0C0C0D0A09090B0A0D0A0B0A0B0D0B0D0E0C0A0C0C080B0B0B0C0C090909
0A09080B070C08090B080704060905060301050203000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000010B1B1B2F3B48535F6E82897D8F867C7C707C6B6F676365685C5050514F4448494A
4D404244403E3F3E3B363B3D35362F352D302D2A2D282C2627282829272022211F191D16
16151A101613120F110D14100F0F120C100E150F0F120E110F0C13100A0B0D0D0E090905
050406010002020000030000000000000400000000010003020302010002000201020104
040001030604050706050405040707090806060809090806080A070A0707080807090B0A
0B08090C0A0C0C0A0A0C0B090C090D0A0C0C0B090A0B0A0C0C0C0C090A0A0C090B0B0B09
090C0C0B0C0E0A0C0D0B0B0A090A0A090B0A0B0B0C0B0B0A0C0C0D0A0B0A0E0D0B0B0D0B
0A0C0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000D0D0C0B0D0B090C0A0C0B0C0B0B0D0B0D0A0F0C0C0C0B0B0B0C0C090E0A0B
0A0E0A0B0B0B090C0A0C0A0A0B0C0B0B0B0A0B080A0B0C0C0B0C0A0C0C0D0C0B0B0A0C0A
0A0B09090C0D0A0D0A0C0B0B0C0B0B0B0B0B0B0D0A0A0B0A0B0B0A0D0B0A0C09090A0A0C
080D0A0A0B0909070A090909070406030405060603050000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000050B08131828313D4C485255596065636C6D696663696A605F5659544D514D
464B49424042414035413F353B373937322F2E302E2C2C29272A29232423261F1D211A17
19141A1A1415110A121513120F0E100E0F0F100D0E0F0A100A0C0A0A09050A0406030300
000102030001000100000001000200010102000001000101010100010002020201030103
0502060804030605070605040808060808070A09080A070906080A0B0B090B0B0B0B0A0B
0B0C090A0C090A0A0B080909090A0A0C0B0A090A0B0B0C0B0C0B0B090C0B0B0B0B090C0B
090C0A090B0A0A09090A0B0B0B0A0C0A0E0C0D0C0A0E0B0C0B0B0C0A0C0A0C0D0D0C0D0B
0B0C0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000A0C0B0B0D0A0C0B0B0A09090B0C0B0B0A0B0B0C0B0C0D0A0A0A0B070B0B0C
0A0A0B0C0C0B0A090A0D0B0A0C0B090B0B0A0A0B0A0B0D0A0A0E0A0C0C0B0A0C0B0B0A0C
0C0E0C0A080B0A0D0D080C0A0E0B0C080A0A0B0C0D0B0C0A0B0A0C0B0A0C0C0A090E0A0B
0C0D0C0B090C08070A0808080A0905060607060A06010102020001000000000000000000
000000000000000000000000000000000000000000000018000000000000000000000000
00000000000000000000030C0F0E161B1D2D2E433F4C4F5C52545B5E595352615A545653
4F4C424945394742404236383C373735332F2C342E292B272826252624232524201F1C17
161B1617101212120B100D100F0E0B110D0F070D1104090C090905080304050600010101
000200000000000000000000000000000002000002030102020200050303020504030202
0103020406040405040306090908060808090807090B080809080A0A0A0B0B0B0A0A0709
0B0D080B0B0B0B0C0B0C0A0B0B0A0A0B0B0B0C090B0A080B0B0A0D0A0D0C0A0B0C0B0F0C
0C0B0B0D090C0A0B0A0A0A0C0D0A0B0B0B0A0C0B0A080C0B0E0B0C0D0A0A0A0D0C0C0D0D
0B090B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090C0B0A0C0B0B090A0C0A0B0B0A0B0C0A0B0B0B0A0D0A0E0B0C0A0A0B0B
0A0A0C0B0A0A090B0C0D0C0A0B0C0B0B0B0A0D0A0C0D0B0C0B0A0D0A0A0C0A0C0D0A0C0B
0C0D090C0C0A0B0B0C0D0B0B080A0D0A0D090A0B0D0D090C0B0B090B0B0C0B0A0B0B0908
0C0A09090C090A0A0A0709090A090408080A060607040202030301020000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000070D0D151F212425242B333841414D4858485653
484A49463F3E39433D413A38333631322F332D322D2C2B2926242026221E22201F21181C
1214131010101313140C0F110D0B0B080D08090A02060503060603020003020300000000
000002000000000000000200000002000102000002020202020206050403040302060507
030404060408070607070A0909080907090D080A070A0A080A0A08060B080B090B0D0B0B
0B0C0A0B0B0B080C0A0C0B0C0B0C0E0B0C0B0A0C0A0A0B0C0A0B0A0D0B090D0B090B0A0A
0B0C0B0B0B0C0C0C0C0C0A0A0D090C0C0C0B0E0A0A0A0A0A0B0D0D0D0E0D0C0A090A0C0A
0C0A0A000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B0A0B0A0A090B0A0B0C0C0D0C0B0B0B0B0B0C0C0C0B0B0D0A0A0D0B0B090B
0C0C0C0C0B090A0D0D090C0B0B0C0C0D0B0A0B0A0B0B0C0C0B0B0B0C0D0B0A0D0B0C0B0B
0B0D0E0B0A0B0A080B0A0C0C0C0D0D0D0A0C090A0A0C0A0D0A0B0E0E0C0C0B0C0A0A0B0C
0B0A060C09070B0B0A080A0A090909070705060A05050605040702000000000002000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000005040B090C040614141B212A2C2E2F3C
3B383839313133383D3734342E2F27262F2A282D282525232124232422201B1E1A171A10
17110B0E0F0F070A09080A08070903030401050010070500000200020001000400010002
020000000000020002010000000003000002020201030102030204060404030503030604
060405090606050805060A08070A0607080A0A0A0809080B0A0B090909080A0B0C0C0909
0A090A0E0D0B090B0A0C090B0B090B0D0C0B0D0C0A0B0C0B0A0B0E0B0B0D0B09090B0C0C
0B0C0D0E0B0A0E090A0B090D0C0C0A0C0B090C0C0C0D0A0B0C0D0B0B0C0D0A0C0B0A090C
0B0E0C000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090A0B0B0A0E0B0A0A090C0B0A0B0B0C0B090B0A0C0A0A0B0B0B0A090C0C
0A0D0B0B0C0D0B0A090B0A0A090B0A0B0B0A0A0D0B0A0A0D090B0A0A0A0A0A090C0C090A
0B0B0B0C0A0C0A0D090C0B0B0C0C0B0B0A0A0A0C080B090E0C0B0B090B0B090B090A0B0B
090B0D0A090C0B0A0B0B080C08181D0A0808060808060805050404040403000102010000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000030602080F131210
19181C1B1C1E22201C1F241E1B1A1B17191E1B1E19191B18141A1514171B0F131012120D
0B0D07040406060304000001010503000000010101000200000204000100000000010102
000002000001020300030000010202020201010102030403030206030302030502050605
050504050706050905080A09080A0B06090A0708090C090A090C090B090B0D0A090D0A0B
0A080B0A0A0A0B080B0B0B0B090D0A0B090A0A0D0B0C0A0A0B0B0C0A0C0B0B0B090B090C
0A0D0A0C0E090C0C0B0A0D0B0B0C0B090C0A0A0B0A0B0A0C090C0B0C0B0D0E0E0B0C0B0B
0A0B0D000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000B090C0D0C0A0B0B0B0B0D0B0B090B0B0A0B0C080A0B0A090B0C0C0B0B0C0D
0A0C0C0B0A0B0C0C0C0D0A0C0C0E0B0A090C0D0D0B090B0B0B0C0D0B0A0C0D0D0B0F0B0C
0B0A0B0E0B0C0A0A0B0C0C0A0A0A080C0D0D0C0D0A0A0A0C0C0B0C0B0A0C0A0B0B0C0D0C
09090B0A0B0C0A0A080A090A0C0F0D0A0B07090A05060707060506020202040401020000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000002
030103030605080909080704050C0B07070B0D0E0B0A090B0B0708080D0A030709070603
050000050000000301020000000000000300000200010001000001000003000201000002
010000000203020301000200000203000203020204010606030404030606060707050707
0806070808080809070808070A07090A0A0A09080A0D09090A080A0A0B0B0B070A0B0C0B
0A090A0A0B0A0B0B0B0B0D0B0B0A0A0B0B0C0B0C0B090B0B0B09080B080C0A0D0B0A0B0B
0B090C0A0C0B0E0B0B0A090B0C09090B0D0D0B0B0D090B0B090B0A0A0D0B0C0D0B0A0B0C
0D0D0B000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJT;000000802PX:00`02@T900/;
2`0;2`/02PX:00`<300;2`/030`<00T92@0:2PX030`<00L71`0=3@d200/;2`0400P8200<30`02`/;
00`<30802`/;0P0<30`010071`L030`<00/;2`092@T200X:2P0500L71`092@T01`L700L71`051@D0
0P030`<[0000000600410@051@D01PH600L71`0;2`/020P80P092@T01`0820P030`<00P8200<30`0
20P800/;2`0<30`00P0;2`/300X:2P0400`<300;2`/02PX:00T92@802`/;00T02PX:00T92@0<30`0
30`<00/;2`0:2PX02`/;00`<300;2`/02`0000040=7=Z@000`3AcJT;0000000600T92@0<30`02PX:
00`<30092@T02`/;0P0:2PX01@0<30`02`/;00/;2`0:2PX02`/;008030`<00<03@d=00/;2`0;2`/0
1@0;2`/00`0:2PX02@T900`<300200T92@801PH600@01`L700D51@020P800@41<00000002@010@40
10@400H61P061PH02@T900L71`0820P02@T900/;2`0200X:2P0C00d=3@0<30`02@T900X:2P0;2`/0
2PX:00T92@0<30`02PX:00d=3@0:2PX020P800/;2`0<30`020P800X:2P0;2`/02PX:00`<300300/;
2`/00000103AcJT000<0dLfY2`00000400`<300700/;2`092@T02`/;00`<300;2`/02PX:00`<3002
00d=3@0>00/;2`092@T02PX:00/;2`0:2PX03@d=00/;2`0=3@d02`/;00X:2P071`L02`/;00P8200;
2`/200P8200400L71`051@D00@4100820Pl00000010010@400/;2`0?3`l06ATI034a<@0m?Cd0>SXj
04U9B@1?Cdl0FEUI04U9B@1BDU80ATI603/k>`0Q8B4020P85@00000200@4100600L71`092@T020P8
00X:2P0;2`/02@T90`0;2`/01P0<30`02PX:00T92@0:2PX02`/;00X:2P8030`<00<02PX:00d=3@0<
30`00`0;2`/01@0<30`02PX:00/;2`0:2PX02`/;00/00000103AcJT000<0dLfY2`0000001`0;2`/0
2@T900X:2P0:2PX02`/;00d=3@0:2PX00P0<30`03P0=3@d02PX:00/;2`0=3@d03`l?00`<300;2`/0
2@T900X:2P0<30`02@T900/;2`0820P01`L70P092@T01P0820P01@D500P820030`<0000000820P`0
000001X01@D500h>3P0J6QX0410@01XJ6P0F5QH09bLW02<S8`0^;Rh08b<S02d];@0a<C40@4100492
@P0m?Cd0ADE505=CD`1BDU80L71`07=cL`20P800O7al06][J`1/K6`0F5QH03Lg=a80000000H00P82
00D51@061PH01`L700T92@0:2PX200T92@0700X:2P092@T02`/;00`<300;2`/02PX:00T92@0200/;
2`0;00T92@0:2PX030`<00/;2`0>3Ph030`<00/;2`092@T03@d=00/;2`0<30`02`0000040=7=Z@00
0`3AcJT;0000000500`<300;2`/02`/;00d=3@0;2`/00P0:2PX00`0=3@d030`<00`<300500X:2P07
00P820092@T02@T900T92@0;2`/02PX:00T92@0200X:2P0400P820071`L00`<300<30`d0000000H0
1@D501DE5@0G5aL05QHF01PH600G5aL201TI6@0G01dM7@0T92@061PH01hN7P0P8200:BTY030`<00i
>CT0=CDe03Ti>@13@d<0=SHf04];B`1QHF40H61P07]kN`1[Jf/0MgMg07emO@1jNWX0K6a/05IFEP0/
;2`04@00000030051@D01PH600T92@092@T02PX:00P820092@T02PX:00T92@0<30`02@T900`<3080
2`/;00H02PX:00/;2`0<30`02PX:00/;2`092@T400/;2`0300X:2P0;2`/0000000X00000103AcJT0
00<0dLfY2`0000003P0=3@d030`<00d=3@0<30`03@d=00`<300;2`/02PX:00`<300:2PX03@d=00`<
300;2`/030`<0P0;2`/02P0:2PX02@T900/;2`0=3@d02PX:00P820092@T010@400H61P0410@?0000
000>00h>3P0J6QX07AdM01PH600I6AT03`l?01dM7@0O7al06ATI01hN7P0U9BD061PH024Q8@0[:b/2
02HV9P0B030`<00o?cl0<30`03Ph>010@400?3`l04I6AP1JFUX0FEUI061PH01XJ6P0Fe]K06a/K01T
I6@0HF5Q06EUI@1SHf<0?3`l3`0000002@030`<010@400P8200820P02PX:00T92@0;2`/02PX:00`<
300300X:2P0300`<300:2PX02`/;00<030`<00L02PX:00/;2`0:2PX030`<00d=3@0:2PX02@T900/0
0000103AcJT000<0dLfY2`000000100;2`/030`<00T92@0<30`200X:2P802@T900@030`<00T92@0<
30`02`/;10092@T00`0:2PX02`/;00P8200200X:2P0300D51@030`<00P8200d0000002T00P820000
00051@D02@T901PH600P82008R8R020P800E5AD051@D02DU9@0L71`06QXJ01`L700P820061PH01@D
500G5aL08B4Q020P800S8b<07alO02DU9@0X:2P08b<S038b<P0j>SX0@41003dm?@1BDU80E5AD05QH
F01QHF40H61P04e=C@1OGel0Jf][069RHP1^KVh0EEEE03lo?`0=0000000<00<30`0410@01`L700L7
1`0820P02@T900X:2P0820P02@T900P8200:2PX02@T90P0:2PX01`0<30`03@d=00X:2P092@T02`/;
00`<30092@T00P0;2`/00`0:2PX0000000000009000000@0dLfY00030=7=Z@/0000000<030`<00T9
2@0;2`/00P0:2PX200/;2`0600`<300;2`/02`/;00/;2`0=3@d02@T90P0;2`/01`0<30`02PX:00P8
200:2PX01PH600410@020P8030000000;`071`L01@D500L71`051@D02PX:00h>3P0A4A4051@D01HF
5P0M7Ad061PH00h>3P0F5QH071`L00d=3@0?3`l05ADE01LG5`0K6a/07QhN01HF5P0K6a/02@T900`<
300F5QH061PH01/K6`0^;Rh09BDU024Q8@0S8b<0:b/[02h^;P0d=3@0C4a<04Y:BP1EEED0CTi>04m?
C`1OGel0EUIF06IVIP1KFe/0IVIV06=SH`1GEeL09RHV00`000000P030`<01`061PH02@T900T92@09
2@T030`<00T92@0;2`/00P0:2PX00`092@T030`<00X:2P0200/;2`802PX:00@03@d=00/;2`0<30`0
410@2`0000040=7=Z@000`3AcJT;0000000:00T92@0>3Ph02`/;00h>3P0<30`02PX:00T92@0;2`/0
30`<00T92@<02PX:00P030`<00/;2`0820P02@T900X:2P061PH01@D500<30`X0000000L00@4100X:
2P0:2PX01PH6010@400820P0410@00805QHF02/06a/K01hN7P0D51@04Q8B01HF5P0D51@061PH01DE
5@0G5aL06QXJ014A4@0J6QX07QhN01LG5`0P820030`<00P8200?3`l020P800`<300?3`l05QHF00d=
3@0E5AD06a/K01dM7@0O7al0=cLg03Hf=P0k>c/0>SXj04Y:BP1FEUH0@D5105ADE01EEED0G5aL05AD
E01FEUH0GEeM06QXJ01TI6@0>SXj00/0000000/00@4100<30`051@D01PH600T92@0820P02PX:00T9
2@0:2PX02`/;00X:2P0200/;2`0400T92@0:2PX02`/;00X:2P8030`<00<02@T900d=3@0000002P00
00040=7=Z@000`3AcJT;0000000400X:2P0820P02PX:00d=3@802`/;00`020P800X:2P0:2PX02PX:
00/;2`0820P02PX:00/;2`092@T01PH600P820071`L200@410`0000000P01@D500T92@0E5AD02PX:
00l?3`0I6AT051@D01DE5@80820P00<05aLG01<C4`0820P00P0F5QH0800M7Ad06ATI020P800C4a<0
2PX:01XJ6P071`L04Q8B00P8200A4A40000000`<300A4A402`/;01@D500E5AD06ATI01LG5`0O7al0
6a/K01dM7@0P8200:b/[02l_;`0^;Rh0@T92055AD@12@T80@D5104E5A@14A4@0ATI60P1BDU80101W
IfL0Lg=c05IFEP0M7Ad;0000000500<30`061PH01`L700T92@0820P00P0;2`/00`092@T02`/;00/;
2`0200X:2P0300T92@0;2`/02PX:00802`/;0P0:2PX;000000@0dLfY00030=7=Z@/0000000@02`/;
00`<300<30`02@T90P0;2`/020092@T02PX:00d=3@0=3@d030`<00T92@0:2PX020P80P071`L00`04
10@01@D50000000<0000000800`<30092@T051@D010@400G5aL092@T01`L700R8R8201XJ6P0^028R
8P0P82007alO01/K6`0C4a<06a/K01XJ6P0P82009RHV01DE5@0J6QX05aLG00d=3@0C4a<03`l?00@4
100B4Q80410@00<30`061PH010@4018B4P0D51@0000000l?3`0C4a<071`L01lO7`0P82009BDU028R
8P0b<S80;2`/03Ti>@0c<c<0<S8b04E5A@0k>c/0B4Q804M7A`1=CDd0I6AT06EUI@1VIVH0Hf=S00P8
20X0000000<00`<300P820051@D00P0:2PX02P092@T02PX:00/;2`0:2PX02`/;00T92@0:2PX030`<
00T92@0=3@d200/;2`0300T92@000000000000T00000103AcJT000<0dLfY2`0000004@092@T030`<
00`<300;2`/020P800`<300;2`/030`<00/;2`092@T02`/;00X:2P0820P01`L700P820051@D00`<3
00T000000P010@4020020P80000000820P0:2PX04Q8B00h>3P0<30`051@D0P0I6AT07`0V9RH0820P
01lO7`0[:b/07QhN01XJ6P0F5QH06ATI01hN7P0C4a<05ADE01PH600K6a/07QhN02@T900K6a/06QXJ
01HF5P0@41003Ph>00l?3`0E5AD0000000P8200=3@d030`<00d=3@061PH02`/;01HF5P0J6QX00P0K
6a/00`0P82008b<S02@T900202d];@0802/[:`0Z:RX0<S8b03Hf=P13@d<0>SXj04I6AP1>CTh305iN
GP0304A4A0000000000000P0000000D00@4100D51@071`L01PH600P8200200X:2P0:00/;2`092@T0
2`/;00T92@0:2PX02`/;00T92@0:2PX02`/;00X:2P/00000103AcJT000<0dLfY2`00000300/;2`06
00`<300:2PX02`/;00T92@0:2PX030`<0P0;2`/0100:2PX01@D500H61P051@D:0000000800820P0;
2`/02`/;00`<30092@T020P800@4100>3Ph201DE5@0=01@D500B4Q8071`L01XJ6P0X:2P09RHV02@T
900P82006ATI01@D500H61P0:RXZ01HF5P0201LG5`0D01lO7`0H61P0:b/[02HV9P0Q8B409BDU014A
4@0G5aL03`l?00/;2`030`<0000000410@0C4a<03`l?00820P0;2`/05aLG01PH600@410200h>3P0B
00T92@0;2`/071`L01TI6@0/;2`0=cLg03<c<`0a<C40>c/k03Hf=P15ADD0?clo04i>CP1CDe<0FEUI
05iNGP1MGEd0<C4a2P0000000`010@401PH600L71`0200T92@0300X:2P0;2`/02@T900@02`/;0P0:
2PX00`0;2`/0000000000009000000@0dLfY00030=7=Z@/000000`0;2`/01@0=3@d02@T900/;2`0<
30`020P800802`/;00@020P800L71`051@D01@D52P0000003@020P804Q8B01PH600J6QX06ATI01<C
4`0I6AT061PH014A4@0:2PX051@D014A4@0M7Ad00P0D51@0=00K6a/092@T030`<00/;2`0;Bd]03<c
<`0O7al08R8R01hN7P0S8b<0<30`01dM7@0R8R806ATI01@D500W9bL08R8R02h^;P0A4A406QXJ01@D
500C4a<051@D010@400D51@02`/;014A4@0820P00`<300P8200:2PX00`<301DE5@0>3Ph05aLG010@
400H61P07AdM01/K6`0[:b/09BDU02d];@0i>CT0>c/k03De=@11@D40@T92055AD@1BDU80EeMG069R
HP1DE5@:0000000400<30`071`L02@T900P820<02@T900<030`<00/;2`0:2PX00P0;2`/00`0<30`0
2`/;0000000:000000@0dLfY00030=7=Z@/000000P0:2PX01@092@T03@d=00/;2`092@T02PX:0080
2`/;0P0820P00`061PH010@400410@090000000500820P0<30`05QHF024Q8@0M7Ad00P0P8200800S
8b<08B4Q01/K6`0;2`/05QHF01DE5@0F5QH04A4A01TI6@0X:2P092@T02PX:00Q8B40<C4a03hn?P0c
<c<0>3Ph03De=@0Q8B409bLW01XJ6P0P82006a/K010@400Q8B406ATI01/K6`0W9bL06ATI014A4@0L
71`03Ph>0P0F5QH02`0@41004a<C00/;2`051@D0410@00H61P051@D0000000d=3@0A4A403@d=0080
5aLG00P08B4Q02@T900P8200;Rh^02d];@0a<C409RHV03Ph>080@D5100H0EUIF05QHF01OGel0IFEU
05ADE00H61P90000000300D51@071`L020P800802@T900D01`L700T92@0=3@d02PX:00T92@0200`<
300300/;2`000000000000T00000103AcJT000<0dLfY2`0000001P0>3Ph02`/;00`<300820P02@T9
00X:2P802`/;00D020P800X:2P051@D00P8200<30`090000001800410@0A4A404a<C01dM7@0T92@0
:2PX028R8P0^;Rh0:2PX02d];@0O7al07AdM010@400?3`l03Ph>014A4@0I6AT05QHF02/[:`0V9RH0
<c<c02/[:`0h>3P0<30`02d];@0g=cL0<S8b02TY:@0V9RH04a<C02DU9@0Z:RX0:b/[02LW9`0E5AD0
<30`02PX:00M7Ad051@D01TI6@0M7Ad05QHF00d=3@0B4Q802`/;01<C4`0F5QH02`/;01<C4`0<30`0
1`L7014A4@0C4a<06ATI01LG5`0B4Q8092@T028R8P0N7Qh0;bl_02`/;00b<S80;2`/03Ph>00c<c<0
@410059BDP1<C4`0H61P05mOG`1KFe/0>c/k2@0000001@010@401PH600T92@0:2PX020P800802PX:
00<030`<00d=3@0<30`00P0:2PX;000000@0dLfY00030=7=Z@/000000`0<30`200X:2P0700/;2`09
2@T02@T900D51@0820P010@400820P0:0000000]00X:2P0J6QX0820P024Q8@0W9bL09RHV03@d=00a
<C40=3@d02d];@0X:2P0=CDe02HV9P0M7Ad04a<C01`L700D51@07alO028R8P0X:2P0:BTY02HV9P0Y
:BT08R8R03Hf=P0a<C40<c<c02PX:00b<S806ATI02LW9`0G5aL07alO024Q8@0R8R807QhN02TY:@0D
51@06QXJ01dM7@0R8R804A4A01LG5`0J6QX05aLG00806ATI00L05QHF01PH600@41005QHF01PH600K
6a/05aLG00806QXJ00h09BDU01@D500F5QH07QhN028R8P0/;2`0;Rh^02TY:@0Z:RX0=cLg03lo?`14
A4@0Bd];05ADE080FEUI00<0De=C00H61P0000001`0000002`020P8020P800P8200820P030`<00/;
2`0<30`02@T900/;2`0<30`02`/;00/00000103AcJT000<0dLfY2`0000000`0;2`/02PX:00T92@02
00/;2`802@T900@020P800H61P071`L00@412P0000005`0;2`/03`l?01XJ6P0J6QX0:2PX01`L700N
7Qh0;bl_02d];@0`<300>3Ph03@d=00S8b<0?Shn03Hf=P0O7al06ATI018B4P0;2`/030`<01PH600U
9BD0:2PX0080;Bd]00d0;Rh^02HV9P0`<300>c/k02/[:`0b<S80;Bd]02<S8`0R8R8092@T020P800J
6QX0820P00807AdM02@0:b/[01<C4`0L71`07QhN01HF5P0S8b<04a<C020P800I6AT05QHF01@D500B
4Q804A4A02DU9@0H61P06ATI01lO7`0T92@07QhN02DU9@0K6a/09RHV02PX:00/;2`0820P02HV9P0^
;Rh0?3`l030`<00k>c/0De=C051@D01ADE40GEeM05iNGP0=3@d80000000300H61P0820P02`/;0080
2PX:00D02@T900/;2`092@T02`/;00T92@0;000000@0dLfY00030=7=Z@/0000000L02PX:00/;2`09
2@T030`<00X:2P0820P02PX:00801@D500<010@4000000000000200000009P071`L01PH600X:2P0P
82005aLG01lO7`0S8b<0:2PX02l_;`0[:b/0;bl_03dm?@0f=SH0;Rh^03@d=010@400:RXZ02d];@0P
82005aLG01/K6`0L71`08R8R02LW9`0`<300:b/[03@d=00Q8B40<C4a02LW9`0g=cL0:RXZ02<S8`0Y
:BT09BDU01hN7P0I6AT09RHV0P0J6QX01P0Q8B408R8R02HV9P0Z:RX0:2PX01/K6`805aLG01P0820P
01<C4`0B4Q800`<301@D500I6AT05ADE00d=3@0O7al08R8R01PH600U9BD0<30`02@T900O7al07AdM
02@T900[:b/092@T01/K6`0X:2P0;bl_038b<P0o?cl204i>CP0305iNGP1RHV80D51@00T0000000@0
0`<300H61P071`L02PX:0P0;2`/00`0:2PX02`/;00X:2P0;000000@0dLfY00030=7=Z@/0000000T0
30`<00P820092@T02PX:00`<30071`L01PH600D51@020P802@0000007P0410@00`<300P8200B4Q80
410@01/K6`0J6QX07alO024Q8@0K6a/08R8R01dM7@0/;2`0:BTY034a<@0l?3`0@41004E5A@11@D40
=SHf03Ti>@0Q8B408b<S01XJ6P0Q8B407AdM02d];@0I6AT092@T02<S8`80:RXZ00T09bLW03@d=00g
=cL0>3Ph02d];@10@400820P02TY:@0W9bL00P0K6a/02`0S8b<08R8R02XZ:P0[:b/08R8R02/[:`0=
3@d061PH00d=3@0@4100820P00804A4A01D020P801<C4`0K6a/03@d=01hN7P0Q8B406ATI02XZ:P0L
71`0820P01<C4`0X:2P07QhN01dM7@0Z:RX05QHF02LW9`0T92@0?Cdm04=3@`17AdL00P1JFUX00`1H
F5P01`L7000000070000000800H61P0820P01`L700P8200<30`02@T900d=3@0:2PX;000000@0dLfY
00030=7=Z@/0000000@030`<00X:2P0;2`/02PX:0P071`L00`051@D00@41000000080000000C00<3
0`0=3@d030`<010@400K6a/0410@00h>3P0?3`l04A4A00h>3P0F5QH05aLG01DE5@0J6QX092@T02LW
9`0m?Cd0AdM703@d=0020492@P0=0410@00k>c/0@D51020P800U9BD06a/K018B4P0D51@05aLG024Q
8@0K6a/04a<C01PH600202l_;`0C02d];@0P8200<30`03<c<`0P82008b<S02d];@0Z:RX05aLG01/K
6`0U9BD08R8R024Q8@0L71`0<30`01lO7`0M7Ad0410@00T92@0200D51@0>00@410020P802@T9014A
4@0J6QX03`l?01PH600@41007AdM020P800J6QX061PH01LG5`0T92@202<S8`0:020P800X:2P0:RXZ
02HV9P1=CDd0FUYJ05]KF`1XJ6P0GemO020P80P0000000L01`L700H61P092@T030`<00X:2P0;2`/0
2PX:00/00000103AcJT000<0dLfY2`000000200;2`/030`<00/;2`092@T020P800D51@0410@00`<3
1`0000009@020P802PX:01@D500G5aL07alO02TY:@0U9BD07QhN01HF5P0E5AD030`<00H61P020P80
000000410@0=3@d06ATI024Q8@0_;bl0A4A404I6AP1CDe<0=cLg0492@P1=CDd0B4Q803Ph>00e=CD0
;2`/01lO7`0A4A405aLG02DU9@0O7al09bLW02d];@0X:2P00P0];Bd202HV9P0802l_;`0S8b<0;2`/
020P800W9bL0;2`/01dM7@0H61P201LG5`0B024Q8@0];Bd0=cLg02TY:@0e=CD07QhN01TI6@0M7Ad0
5QHF000000071`L04A4A010@400N7Qh051@D01LG5`0F5QH03Ph>0P0B4Q803`0E5AD06a/K024Q8@0U
9BD08b<S02HV9P0J6QX08B4Q03Lg=`0l?3`0De=C061PH01RHV80GUiN03<c<`080000000600H61P09
2@T020P800T92@0;2`/02PX:2`0000040=7=Z@000`3AcJT;0000000700/;2`092@T03@d=00D51@06
1PH01@D500820P070000000Y00<30`092@T07QhN01LG5`0d=3@0<S8b03@d=00h>3P09bLW01lO7`0H
61P05aLG00P820092@T00@4100H61P030`<02PX:028R8P0];Bd0@d=30451@@0k>c/0@D5103Ph>01K
Fe/0?clo05IFEP1EEED0ATI604=3@`0S8b<030`<010@400C4a<05aLG02PX:00U9BD0<S8b02LW9`0P
82000P0c<c<0100e=CD0=SHf02l_;`0b<S8302l_;`0;02<S8`0X:2P04A4A024Q8@0X:2P05ADE02PX
:00N7Qh0410@01TI6@0J6QX00`00000200410@0F00P8200?3`l01PH600h>3P0F5QH0410@01DE5@0@
410071`L01dM7@0O7al08b<S01XJ6P0P82009BDU034a<@1=CDd0C4a<04M7A`1KFe/0JFUY010@40L0
000000<00`<300H61P092@T00`0:2PX;000000@0dLfY00030=7=Z@/0000000<02PX:00`<30092@T0
0P0820P00`020P800000000000060000000?00`<300B4Q805QHF01XJ6P0l?3`0>c/k034a<@0c<c<0
<S8b02DU9@0L71`0410@00h>3P061PH010@400<0000002l0410@03Ti>@0`<300=SHf03hn?P1>CTh0
?Shn03dm?@1CDe<0B4Q804Y:BP11@D40BDU90492@P0Y:BT0;Bd]02HV9P0J6QX0820P02TY:@0];Bd0
92@T01LG5`0Q8B408b<S03De=@0^;Rh0E5AD03Xj>P0i>CT0:2PX01dM7@0S8b<09bLW02TY:@0N7Qh0
6ATI01XJ6P0Z:RX0:BTY01hN7P0W9bL06ATI01`L700;2`/01`L70000000200410@8000000P0;2`/0
4@0P820061PH01DE5@0?3`l05QHF01hN7P0Y:BT05ADE01XJ6P0Q8B407QhN02LW9`0];Bd0@T9204M7
A`1PH600HF5Q00L0000000H00P8200H61P071`L02PX:00`<300:2PX;000000@0dLfY00030=7=Z@/0
00000P0:2PX200H61P0300D51@0410@0000000D0000005/00@410000000B4Q807AdM02DU9@0[:b/0
=SHf04=3@`17AdL0?Shn03<c<`0`<300:BTY01`L700I6AT0410@00d=3@061PH020P800D51@0E5AD0
4A4A02PX:00b<S80;2`/01lO7`14A4@0;bl_03lo?`1>CTh0BTY:04I6AP15ADD0?Shn03Ti>@0`<300
:RXZ01<C4`0?3`l061PH02XZ:P0S8b<0;Rh^02`/;00T92@0=CDe01/K6`0m?Cd0AdM702`/;00Z:RX0
;2`/02DU9@0P82009RHV028R8P0S8b<09bLW01PH600T92@0;2`/03<c<`0];Bd0820P01/K6`0820P0
1PH600l?3`0C4a<030`<00P8200E5AD0410@00h>3P0F5QH05ADE01lO7`0>3Ph0410@024Q8@0R8R80
61PH01`L700I6AT0:2PX02TY:@0/;2`0=3@d03dm?@1GEeL0EEEE00P0000000@01@D500H61P0;2`/0
2`/;2`0000040=7=Z@000`3AcJT;0000000500`<30071`L02@T900H61P020P80200000003`061PH0
5aLG028R8P0d=3@09bLW02h^;P0n?Sh0@D5104=3@`11@D40:2PX03`l?00W9bL07AdM01LG5`0201HF
5P0501DE5@071`L02`/;01DE5@0F5QH00P0D51@200l?3`0f02PX:00c<c<0:2PX02HV9P0g=cL0Cdm?
03lo?`1LG5`0?clo03Hf=P0/;2`0=3@d01XJ6P0;2`/08B4Q02DU9@0[:b/0;2`/02HV9P0_;bl09RHV
03hn?P12@T80;bl_03@d=00/;2`0;Bd]02<S8`0P82009bLW01dM7@0S8b<07QhN02LW9`0`<300;Bd]
02<S8`0[:b/03`l?00`<300>3Ph00@4100`<300L71`0000000D51@0=3@d03`l?01@D500H61P05QHF
01LG5`0E5AD06QXJ0P0F5QH02@0B4Q808B4Q02TY:@0b<S80<C4a03Lg=`19BDT0GEeM04U9B@080000
000300H61P092@T02@T900/00000103AcJT000<0dLfY2`00000010071`L02`/;00H61P020P880000
000A00d=3@0B4Q806QXJ02`/;00e=CD0<C4a04I6AP0m?Cd0?clo03dm?@10@400>3Ph03`l?017AdL0
<c<c038b<P0a<C400`0G5aL010092@T0000000/;2`071`L30000000N01<C4`0@41007QhN03De=@0j
>SX0>c/k03@d=016ATH0Jf][05EEE@0m?Cd0A4A4034a<@0^;Rh05ADE01hN7P0G5aL08R8R03Hf=P0/
;2`09RHV038b<P0V9RH0@41002@T900b<S80:b/[034a<@0];Bd09RHV0P0U9BD07P0@41008B4Q01@D
500W9bL092@T02TY:@0V9RH071`L01hN7P0>3Ph03`l?01/K6`092@T061PH00L71`0I6AT02@T900D5
1@0G5aL051@D028R8P0N7Qh051@D018B4P0:2PX07QhN01XJ6P0I6AT0;bl_02h^;P80?3`l00<0DE5A
0492@P0000001P0000000`051@D01`L700/;2`0;000000@0dLfY00030=7=Z@/0000000<020P800X:
2P061PH0200000006P092@T061PH02<S8`0`<300=CDe02/[:`0d=3@0=CDe03/k>`12@T80C4a<030`
<00i>CT0=3@d04I6AP1DE5@0A4A403/k>`0Y:BT0<C4a020P800D51@0410@000000010@400P820`00
00001@061PH03`l?02LW9`0_;bl0ATI60080BDU900<0D51@05QHF017AdL00P14A4@0300n?Sh0:b/[
01dM7@0I6AT051@D00`<300F5QH0=SHf02DU9@0a<C40>3Ph02/[:`80>c/k02P0>SXj02`/;00m?Cd0
:BTY01DE5@0T92@06ATI024Q8@0?3`l0;Bd]01PH600[:b/0:BTY01hN7P0J6QX04a<C01DE5@0=3@d0
8R8R00h>3P0G5aL04a<C00d=3@092@T05ADE02<S8`0F5QH05aLG00410@0A4A402`/;02<S8`0I6AT0
9RHV03`l?00m?Cd0?Shn04i>CP1JFUX092@T1`0000000`071`L020P80000000:000000@0dLfY0003
0=7=Z@/0000000@020P800L71`0410@00@411P0000003@061PH04a<C01<C4`0W9bL0<C4a03`l?00h
>3P0=cLg03@d=00g=cL0:BTY03@d=00`<3000P0m?Cd0300o?cl0>c/k0492@P1ADE40>3Ph03dm?@0j
>SX06QXJ01DE5@0J6QX051@D00L71`80000002`00@4100<30`0000004Q8B03De=@0i>CT0@T92055A
D@1:BTX0@41004];B`1>CTh0@d=304M7A`15ADD0>3Ph01dM7@0Q8B405QHF028R8P0J6QX0=3@d02h^
;P0Z:RX05QHF02LW9`1QHF40CDe=04A4A00X:2P06ATI01hN7P0X:2P07alO01PH600X:2P071`L02l_
;`0Q8B40<S8b024Q8@0];Bd0:BTY01XJ6P8051@D00X02PX:01PH600000004A4A010@400D51@0820P
024Q8@0820P051@D0P0G5aL02P0>3Ph07QhN02@T900T92@0<S8b03/k>`15ADD0E5AD055AD@051@D6
0000000300<30`0820P0000000X00000103AcJT000<0dLfY2`0000000`092@T00`<300D51@060000
000_00410@071`L06ATI02PX:00b<S80;bl_02h^;P11@D40?clo03dm?@0i>CT0:b/[04I6AP0e=CD0
;2`/03/k>`0d=3@0BTY:04M7A`18B4P0A4A4055AD@0k>c/0>3Ph01dM7@0C4a<04Q8B00H61P000000
2PX:00/;2`0000003@d=00@4100B4Q807AdM03lo?`18B4P0@T9204m?C`1CDe<0ATI604M7A`1BDU80
D51@04I6AP0h>3P00P0X:2P02P0P82009RHV01hN7P0W9bL07AdM030`<00U9BD0<c<c03De=@0^;Rh2
02/[:`0;02d];@0J6QX06a/K030`<00^;Rh0:BTY01lO7`0P8200:BTY01`L700K6a/00P0b<S804P0M
7Ad04Q8B01@D500H61P051@D00H61P0820P05QHF01XJ6P0I6AT0410@00T92@0A4A406ATI010@400I
6AT0;2`/02TY:@<0>CTi00<0BDU904Y:BP13@d<01`0000000`051@D0000000000009000000@0dLfY
00030=7=Z@/0000000<010@400D51@030`<01P000000500>3Ph04a<C01hN7P0X:2P0;Bd]03Ti>@14
A4@0BDU904A4A019BDT0?3`l03/k>`10@400<c<c04i>CP19BDT0?Shn04M7A`0e=CD0@D510P18B4P0
2P12@T80CDe=03De=@0a<C409BDU020P800F5QH04A4A00h>3P00000200X:2P110000000?3`l07AdM
03Xj>P0^;Rh0ADE504=3@`16ATH0B4Q804m?C`1BDU80DE5A04I6AP0a<C40;Bd]02<S8`0X:2P06ATI
02DU9@0;2`/08B4Q01DE5@0e=CD0=3@d02h^;P0e=CD08B4Q038b<P0m?Cd0<30`03Ti>@0d=3@0:b/[
03<c<`0N7Qh061PH03<c<`0X:2P06a/K02XZ:P0V9RH08R8R020P800B4Q8051@D01HF5P0D51@08B4Q
00T92@0I6AT03@d=00T92@0000002`/;01/K6`0R8R808B4Q02TY:@0Q8B40=CDe030`<00g=cL0BTY:
04a<C00K6a/01P0000000`020P80000000000009000000@0dLfY00030=7=Z@/0000000<01`L700@4
10010@401@00000200`<300I028R8P0Q8B40:BTY03Hf=P0b<S80?3`l03Lg=`0l?3`0B4Q805EEE@0g
=cL0>CTi04i>CP11@D40>CTi04I6AP17AdL0@T9203lo?`0l?3`0BDU90492@P18B4P0EEEE0492@P02
02TY:@0403Ph>00;2`/0000000<30`<0000000T02`/;01TI6@0K6a/092@T02HV9P0d=3@0>CTi04a<
C01CDe<00P14A4@07@1FEUH0K6a/03/k>`0g=cL0=3@d02TY:@0K6a/04a<C00X:2P0S8b<07alO02/[
:`0R8R80<C4a02/[:`0l?3`08R8R03Lg=`1:BTX0<S8b03/k>`0m?Cd0;bl_02PX:00W9bL09BDU01@D
500o?cl0<S8b00807alO00H06QXJ01LG5`0>3Ph03Ph>01LG5`0I6AT200h>3P0>00L71`0820P0410@
01LG5`0U9BD061PH02HV9P0Q8B40:2PX02@T900e=CD0@d=304M7A`1:BTXB000000@0dLfY00030=7=
Z@/0000000<01`L700820P000000100000006`010@40410@01TI6@0Q8B40:RXZ02d];@0[:b/0<30`
03dm?@13@d<0?clo04a<C01?Cdl0CTi>04Q8B01CDe<0>SXj05YJFP1GEeL0GEeM055AD@0e=CD0?Shn
03lo?`1ADE40B4Q803`l?00204I6AP0[0410@00Y:BT07QhN014A4@0<30`020P800H61P0000000@41
0000000?3`l02PX:01HF5P0M7Ad06a/K03Lg=`18B4P0F5QH061PH01ADE40IFEU051@D01EEED0CTi>
03Hf=P0W9bL03@d=00h>3P0C4a<061PH01<C4`0d=3@06a/K02d];@0b<S80=CDe04Q8B01BDU80?Shn
04A4A00Y:BT0:2PX02LW9`0202XZ:P0L020P800`<300:b/[02XZ:P0V9RH07AdM01PH600>3Ph03@d=
014A4@0C4a<04A4A00H61P0<30`05QHF010@40051@D07AdM01HF5P0I6AT07QhN01HF5P0S8b<0;bl_
04A4A013@d<0C4a<02XZ:Q400000103AcJT000<0dLfY2`0000000`051@D00000000000040000000?
00X:2P0A4A408b<S01`L700^;Rh0;Bd]03Ti>@0j>SX0=3@d04=3@`17AdL0?Cdm04];B`15ADD0B4Q8
0080EeMG01@0C4a<04Y:BP1@D500Bd];03Lg=`0];Bd0>c/k0410@00g=cL0BDU905ADE00e=CD0<S8b
03dm?@0b<S80=cLg01dM7@0<30`01`L700410@H0000003<05aLG02TY:@0_;bl0CTi>05ADE01TI6@0
G5aL075aL@1RHV80Fe]K0451@@0];Bd0=CDe01dM7@0J6QX09BDU010@400A4A40;Rh^02PX:00J6QX0
=cLg0410@00S8b<0DE5A04Q8B00l?3`0;bl_02PX:00T92@0;Rh^03@d=00f=SH09BDU02l_;`0/;2`0
<S8b024Q8@0J6QX071`L014A4@0G5aL04a<C00/;2`0I6AT061PH00D51@0=3@d04a<C00h>3P0<30`0
0P0G5aL01P0L71`0:b/[02d];@0o?cl0@d=304a<C1400000103AcJT000<0dLfY2`0000000`0410@0
0000000000030000000Q00820P0<30`05ADE02PX:00[:b/0=SHf0451@@17AdL0?Shn04m?C`0g=cL0
@D5104a<C013@d<0C4a<04Y:BP1>CTh0CDe=06MWI`1LG5`0ADE503Ph>016ATH0A4A403Xj>P0_;bl0
=3@d02`/;00l?3`0?clo0451@@0n?Sh0BDU90080>CTi00@0;2`/02DU9@0:2PX00`<310000000:`02
0P802@T901TI6@0H61P0<C4a0451@@1@D500F5QH04A4A01>CTh0DE5A05MGE`14A4@0@41004m?C`0V
9RH0:RXZ01XJ6P0T92@04a<C024Q8@0N7Qh0:2PX02<S8`0d=3@0?Cdm038b<P1:BTX0?3`l02DU9@0X
:2P0=cLg01TI6@0Z:RX0:BTY02l_;`0Z:RX0:b/[02<S8`0W9bL09RHV02<S8`0E5AD00P0C4a<201`L
700>00/;2`0000002`/;00X:2P0=3@d04A4A00l?3`0K6a/06ATI02`/;00_;bl0@T9204U9B@0c<c<@
000000@0dLfY00030=7=Z@/0000000<00@410000000000000P00000030010@401@D500d=3@0N7Qh0
5ADE02/[:`0`<300=SHf03dm?@1=CDd0@T9204e=C@80AdM701/0<C4a04U9B@1BDU80De=C04i>CP1K
Fe/0EeMG04i>CP0n?Sh0AdM702PX:00Z:RX0@d=3028R8P0?3`l0BDU90451@@0g=cL0>3Ph03lo?`1<
C4`0@d=303dm?@0b<S8051@D01lO7`071`L01P000000=00F5QH061PH02@T900l?3`0>SXj0492@P1<
C4`0FUYJ04e=C@0i>CT0F5QH05UIF@1NGUh0:BTY028R8P0L71`03`l?01dM7@0B4Q80<S8b02DU9@0K
6a/0:RXZ038b<P0e=CD0>3Ph034a<@0^;Rh0<c<c02/[:`0V9RH051@D02@T900Y:BT05ADE02TY:@0Q
8B407QhN020P800R8R807QhN01dM7@0L71`0:BTY01@D500:2PX02`/;00D51@0?3`l061PH01dM7@0A
4A4201hN7P0502@T900l?3`0Bd];04A4A00J6QX03`0000040=7=Z@000`3AcJT;0000000300820P00
0000000000<0000002/02@T9018B4P0S8b<09bLW02DU9@0^;Rh0=cLg0410@017AdL0ADE504I6AP1A
DE40CDe=04U9B@13@d<0G5aL04M7A`1=CDd0F5QH05IFEP1?Cdl0GUiN04I6AP0e=CD0:BTY030`<00n
?Sh0?3`l034a<@1<C4`0EUIF04i>CP15ADD0H61P069RHP20P800@D5104A4A00h>3P09BDU018B4P0?
3`l020P800@0000001/07alO01LG5`0^;Rh092@T03Lg=`0f=SH0>c/k04m?C`12@T80De=C055AD@1M
GEd0FUYJ04U9B@0`<3008b<S01PH600R8R807alO028R8P0?3`l04Q8B01/K6`0d=3@0<c<c03Ph>00g
=cL00P0h>3P06P0W9bL08B4Q02TY:@0Q8B4071`L01hN7P0K6a/07AdM028R8P0j>SX0C4a<02TY:@0Q
8B408R8R01DE5@0H61P04a<C018B4P092@T03@d=01PH600<30`05QHF028R8P0V9RH0=cLg0P1<C4`0
0`0l?3`000000000000=000000@0dLfY00030=7=ZA40000000L01`L700/;2`0O7al092@T034a<@0Y
:BT09RHV0080;Bd]00@0AdM702l_;`0h>3P0@T920P1=CDd07P1@D500CTi>05ADE01CDe<0?Cdm05YJ
FP1CDe<0CDe=04=3@`0l?3`0;bl_03dm?@15ADD0>SXj04=3@`1IFET0>c/k01/K6`11@D40B4Q8075a
L@1<C4`0ADE503/k>`10@40092@T01HF5P0N7Qh020P801TI6@802PX:01l02@T90000000=3@d02`/;
01<C4`0N7Qh0;2`/03@d=013@d<0@T9206=SH`1YJFT0JVYZ04Q8B01<C4`0;2`/02DU9@0V9RH05ADE
020P800820P06QXJ02DU9@0X:2P07alO03dm?@0g=cL0B4Q803hn?P10@400;bl_008092@T01X08b<S
030`<00V9RH0:BTY01/K6`0/;2`0>c/k02TY:@0T92@08B4Q01dM7@0C4a<03@d=01HF5P0C4a<01PH6
01@D500K6a/03Ph>01lO7`0V9RH0<S8b03@d=01BDU80DE5A00L71`h00000103AcJT000<0dLfY4000
00003@051@D0410@018B4P0J6QX0:RXZ038b<P0];Bd0=SHf03Ti>@11@D40?3`l03lo?`14A4@00P18
B4P07P1;Bd/0E5AD05MGE`1MGEd0J6QX055AD@18B4P0D51@0492@P1RHV80BDU903Ti>@10@400?3`l
04e=C@0n?Sh0@D5102h^;P0l?3`0BTY:05UIF@1`L700O7al05UIF@1FEUH0Cdm?04A4A012@T80;Bd]
02TY:@80;Rh^02d04A4A00X:2P0000000@41000000010@400P8200d=3@051@D0820P034a<@14A4@0
Hf=S06EUI@1TI6@0GemO04e=C@15ADD0;2`/02DU9@0>3Ph03`l?01@D500:2PX09bLW01hN7P0j>SX0
>CTi04Q8B00/;2`0=SHf04];B`0m?Cd0;2`/024Q8@0O7al0<c<c02<S8`0R8R808B4Q02<S8`0I6AT0
<30`02@T900Y:BT00P0:2PX03@0<30`06ATI01HF5P071`L03Ph>00P8200<30`05aLG020P800];Bd0
ATI604Q8B00d=3@03P0000040=7=Z@000`3AcJT?0000000T00<30`071`L02`/;01TI6@0O7al071`L
02LW9`0e=CD0=3@d02h^;P0_;bl0>c/k02`/;00l?3`0AdM7055AD@12@T80ATI605QHF00f=SH0?Cdm
04];B`19BDT0@T9204Y:BP1CDe<0AdM704Q8B01JFUX0ATI604U9B@0n?Sh0@T9201PH600l?3`08b<S
0P1XJ6P02`1HF5P0IFEU04Y:BP1<C4`0DU9B04e=C@14A4@0C4a<04M7A`0X:2P04A4A0080000001L0
1@D50000000000000000018B4P0F5QH04Q8B0000000T92@0=3@d04U9B@1DE5@0G5aL05QHF01UIFD0
FEUI03lo?`0H61P07alO00h>3P0P82007AdM01/K6`0202<S8`0P030`<00l?3`0?3`l02l_;`0k>c/0
<30`038b<P0Q8B40:2PX034a<@0];Bd0<S8b024Q8@0F5QH0:b/[02LW9`0X:2P0820P01PH600M7Ad0
4A4A01HF5P0E5AD020P800X:2P0C4a<061PH01LG5`0Y:BT0<c<c0451@@0g=cL>000000@0dLfY0003
0=7=Z@l0000001d01@D500L71`0?3`l06a/K01PH600L71`04a<C02HV9P0W9bL0<30`03De=@0k>c/0
<S8b03/k>`0g=cL0CTi>04Y:BP18B4P0>c/k04M7A`18B4P0?Shn04A4A01UIFD0>CTi04A4A01=CDd0
E5AD04U9B@0205YJFP0D03De=@17AdL0>CTi03Lg=`0l?3`0FEUI05eMG@1GEeL0IFEU05ADE01LG5`0
Cdm?05]KF`1RHV80CDe=05YJFP11@D406ATI01PH60051@D60000000900H61P0410@051@D020P800W
9bL0ADE504m?C`1SHf<0HF5Q0080FUYJ00H0?clo02XZ:P0P82004A4A024Q8@0N7Qh201DE5@0?01hN
7P0];Bd092@T03dm?@0c<c<0:2PX01lO7`0/;2`0=SHf020P800V9RH0:2PX01hN7P0S8b<09BDU0080
;2`/0100:BTY02h^;P0R8R806ATI020P800Q8B407QhN00h>3P0C4a<03@d=01PH600M7Ad08B4Q03/k
>`0];Bd0820P3@0000040=7=Z@000`3AcJT?0000000D00H61P0820P02`/;010@400D51@06a/K01LG
5`0L71`0820P02PX:00a<C40:b/[03<c<`0_;bl0<S8b03Ph>012@T80>SXj03<c<`19BDT20451@@0<
051@D01JFUX0BDU905mOG`1DE5@0EeMG05ADE01?Cdl0GemO05IFEP1HF5P0FEUI0P18B4P03`1FEUH0
CDe=06][J`1;Bd/0BDU905MGE`1`L700K6a/05aLG011@D40B4Q803lo?`0Y:BT04a<C01DE5@020000
000300L71`000000000000@0000002405aLG01TI6@0k>c/0G5aL06a/K01]KFd0Fe]K05QHF01DE5@0
FUYJ04=3@`0j>SX08B4Q01hN7P0B4Q803`l?01/K6`0Q8B409bLW02l_;`0m?Cd0=cLg02/[:`0W9bL0
;bl_028R8P0Q8B408b<S02HV9P0R8R80;2`/03@d=00a<C400P0T92@03P0^;Rh07AdM01`L700J6QX0
51@D01<C4`0J6QX06ATI00/;2`0A4A405ADE02<S8`0Q8B40<30`3@0000040=7=Z@000`3AcJT>0000
000f00L71`0;2`/03Ph>018B4P0F5QH05aLG01/K6`0J6QX07AdM024Q8@0P82008R8R03dm?@0i>CT0
;Rh^03/k>`0Z:RX0=CDe03dm?@0j>SX0>3Ph02DU9@0e=CD0B4Q805MGE`1>CTh0JFUY04a<C01@D500
HV9R05ADE01WIfL0F5QH05EEE@1@D500FUYJ05]KF`1MGEd0C4a<069RHP0i>CT0De=C04m?C`1EEED0
L71`05]KF`1ADE40>c/k04a<C00H61P04A4A01`L700D51@020P81`0000008`0I6AT0:RXZ02PX:01E
EED0Fe]K06UYJ@1OGel0FUYJ05=CD`1UIFD0Cdm?0492@P0m?Cd0<c<c01DE5@0R8R8051@D01HF5P0R
8R809RHV02PX:00W9bL09RHV0451@@0`<300=3@d03<c<`0R8R80820P02DU9@0Y:BT092@T02HV9P0U
9BD0:BTY00807alO00D05aLG01hN7P0C4a<03@d=00T92@0200d=3@06018B4P0>3Ph09RHV02LW9`0i
>CT00@41300000040=7=Z@000`3AcJT>0000000900L71`0F5QH06ATI01lO7`0N7Qh0820P01PH600?
3`l05aLG008071`L00`0;bl_02TY:@0`<300;2`/02h^;P0d=3@0:2PX04A4A00`<300ADE503@d=010
@40203Xj>P0Q04M7A`1KFe/0M7Ad06UYJ@1QHF40Lg=c04];B`1ADE40I6AT05]KF`1OGel0AdM704];
B`1ADE40FUYJ051@D01SHf<0DE5A065QH@1YJFT0LG5a061PH01RHV80CDe=01PH600Y:BT06ATI01DE
5@0U9BD05ADE01@D50051@D00P8200<0000000l01@D500X:2P0Z:RX0<S8b0451@@1FEUH0F5QH06][
J`1LG5`0EUIF069RHP1SHf<0DE5A04E5A@0^;Rh00P0I6AT08@071`L08B4Q01hN7P0O7al0=CDe024Q
8@0Z:RX0:b/[030`<00b<S80=SHf02DU9@0S8b<07QhN01lO7`0J6QX08R8R01XJ6P0Q8B409bLW01XJ
6P0C4a<06ATI01hN7P0>3Ph051@D00/;2`0@41007alO024Q8@0R8R80;2`/02@T900<000000@0dLfY
00030=7=Z@d0000000<00@4100d=3@0G5aL00P0Y:BT0A@0W9bL0820P01`L700F5QH04Q8B014A4@0O
7al071`L02LW9`0[:b/0:2PX020P800`<300;bl_03dm?@0g=cL0:BTY03<c<`0j>SX0Cdm?03`l?014
A4@0B4Q805]KF`1ZJVX0L71`06=SH`1UIFD0BDU905MGE`1;Bd/0I6AT0451@@1TI6@0EeMG05=CD`0n
?Sh0@T9203lo?`15ADD0Jf][06MWI`1]KFd0HV9R02`/;00[:b/0<S8b04i>CP15ADD0?clo038b<P0a
<C407AdM01TI6@020P800@4100T92@0000000`<3024Q8@0X:2P08R8R03`l?01>CTh0J6QX06EUI@1R
HV80DU9B05eMG@0204a<C00;051@D00c<c<0820P024Q8@0:2PX07alO01/K6`0/;2`08b<S034a<@0O
7al00P0_;bl0400Z:RX0;2`/02TY:@0U9BD061PH02@T900I6AT06QXJ01lO7`0G5aL0820P01hN7P0T
92@061PH01/K6`0G5aL201HF5P0501XJ6P0T92@0:BTY02DU9@0/;2`0300000040=7=Z@000`3AcJT=
0000000C00820P0C4a<07QhN02XZ:P0a<C40<30`03Hf=P0/;2`09BDU01PH600B4Q806ATI02<S8`0O
7al07AdM01@D500K6a/07QhN02h^;P0202l_;`0f02LW9`0`<300<C4a04M7A`12@T80ADE504=3@`10
@400BDU9051@D01IFET0Cdm?06EUI@1?Cdl0BDU905]KF`1QHF40E5AD04U9B@1:BTX0@D5105]KF`0`
<300@T9204e=C@1NGUh0Hf=S04Y:BP18B4P0=SHf03Lg=`1LG5`0E5AD055AD@14A4@0?clo02<S8`0c
<c<01`L701DE5@0410@00`<300h>3P00000030`<01LG5`0Z:RX06ATI04i>CP0m?Cd0De=C04Q8B01@
D500EEEE0P1PH600201<C4`0AdM702TY:@0M7Ad05aLG018B4P0F5QH05aLG0P0L71`01@0O7al08B4Q
034a<@0^;Rh0;Bd]0080;bl_00X07alO02DU9@0D51@06QXJ01LG5`0M7Ad05aLG01TI6@0V9RH092@T
0P0P82001`0F5QH06QXJ01TI6@0h>3P0=cLg01HF5P0<30`02`0000040=7=Z@000`3AcJT=0000000D
00H61P0@41008b<S02TY:@0`<300?Shn0492@P0h>3P0<c<c02HV9P0S8b<08R8R01DE5@0Q8B40;bl_
02<S8`0M7Ad0;Bd]03<c<`0P820202h^;P0503@d=00m?Cd0<S8b03Ph>016ATH00P18B4P0;01IFET0
CTi>059BDP15ADD0?Shn03/k>`1DE5@0HF5Q061PH01JFUX0FEUI04M7A`0l?3`0Fe]K03/k>`0l?3`0
?clo05ADE01CDe<0EeMG0451@@18B4P0BTY:05mOG`1^KVh0J6QX0492@P15ADD0?Shn02h^;P0Q8B40
7QhN00h>3P0<30`03@d=01DE5@020P80000000T92@0U9BD071`L02l_;`0k>c/0BTY:0P1@D500601I
FET0HV9R05MGE`1GEeL0B4Q8034a<@0T92@05aLG01hN7P0S8b<06ATI01HF5P0O7al0:BTY024Q8@0K
6a/07alO038b<P0/;2`0:BTY02<S8`0Q8B40<30`02LW9`8051@D00`01`L7020P800G5aL092@T02<S
8`0E5AD05aLG018B4P0I6AT06QXJ01LG5`0C4a<;000000@0dLfY00030=7=Z@d0000000D01@D501DE
5@0P8200;Rh^02l_;`020492@P0?04U9B@11@D40?clo02d];@0[:b/09BDU01hN7P0L71`07AdM024Q
8@0T92@051@D01`L700I6AT0<c<c0080>CTi02H0@41003Xj>P0f=SH0@d=304E5A@1CDe<0@41004M7
A`19BDT0ATI604U9B@1BDU80FEUI065QH@17AdL0BDU905YJFP1GEeL0JFUY06ATI01SHf<0@D5104Y:
BP19BDT0CTi>055AD@1=CDd0@d=3061PH01hN7P0FUYJ04M7A`14A4@0=SHf02`/;00N7Qh04a<C01`L
70801@D500h04Q8B00H61P010@402@T9010@400K6a/07alO028R8P0i>CT0EEEE04Q8B019BDT0DU9B
05=CD`80FUYJ01<0B4Q803<c<`0N7Qh05QHF00`<300S8b<09BDU01PH600N7Qh0820P010@400P8200
;Rh^02LW9`0T92@08b<S02`/;00];Bd07alO00806QXJ00`05ADE01lO7`0K6a/06a/K020P800E5AD0
5QHF01DE5@0G5aL05ADE01HF5P0D51@;000000@0dLfY00030=7=Z@d0000000<02PX:010@400L71`0
0P0_;bl0C`0l?3`0A4A403Xj>P13@d<0A4A404Y:BP0j>SX0=3@d02XZ:P0];Bd09BDU01hN7P0V9RH0
9bLW028R8P0^;Rh0;2`/03Hf=P13@d<0>CTi03Lg=`0n?Sh0<C4a030`<00n?Sh0@d=303Lg=`0n?Sh0
:RXZ05aLG01>CTh0IFEU05YJFP1kNg/0Hf=S05iNGP1CDe<0BDU9061PH01TI6@0GEeM05iNGP13@d<0
DU9B04i>CP0k>c/0BDU905IFEP1TI6@0GUiN061PH013@d<0?clo02PX:00S8b<0820P01HF5P0820P0
5QHF00D51@0:2PX030`<000000020P80000000X:2P0T92@0:2PX04a<C01@D500DU9B05UIF@1TI6@0
Jf][06EUI@1QHF40BDU904a<C00h>3P00P0K6a/0100>3Ph0:2PX010@400N7Qh202<S8`0801`L700K
6a/071`L02d];@0U9BD0:RXZ02`/;00S8b<202LW9`0600h>3P0C4a<05QHF018B4P0D51@05aLG0P0F
5QH00`0A4A405aLG01@D500;000000@0dLfY00030=7=Z@`000000P030`<0:00>3Ph09RHV02LW9`0X
:2P0<30`03lo?`11@D40DU9B03/k>`1;Bd/0CTi>04m?C`0j>SX0<30`03De=@0V9RH0:b/[01lO7`0J
6QX0<S8b01lO7`0G5aL0=CDe03Ti>@0`<300:RXZ03<c<`1:BTX0>3Ph04A4A00j>SX0AdM7051@D00>
3Ph0;Bd]0492@P1SHf<0J6QX05mOG`1aLG4205aLG00G05=CD`1VIVH0FUYJ04a<C01KFe/0=cLg051@
D00b<S80ATI603Lg=`1OGel0C4a<03De=@1DE5@0=CDe03Hf=P0/;2`00@4101lO7`0C4a<05ADE00P8
200H61P00`000000;00820P0000000D51@010@403@d=02/[:`0U9BD0BDU905EEE@1KFe/0Cdm?05YJ
FP1LG5`0IfMW04Q8B00`<300=cLg02<S8`0Q8B406ATI014A4@0O7al06a/K01HF5P0c<c<04a<C02<S
8`0b<S80=SHf02HV9P0X:2P0820P01HF5P0M7Ad061PH00l?3`092@T03`l?01/K6`0G5aL04a<C01/K
6`0E5AD03`l?2`0000040=7=Z@000`3AcJT=0000001200P8200>3Ph05aLG01lO7`0P8200<30`02XZ
:P0g=cL0@d=304];B`1ADE40BTY:04];B`1ZJVX0AdM703hn?P0];Bd0>3Ph01hN7P0G5aL05QHF02XZ
:P0S8b<07AdM02XZ:P0[:b/0<C4a03/k>`0a<C40?3`l04];B`0d=3@0?3`l04U9B@0`<300>CTi03Xj
>P1?Cdl0GemO05YJFP1FEUH0JFUY05mOG`1PH600J6QX05EEE@1>CTh0EUIF05YJFP0n?Sh0Bd];04a<
C016ATH0DE5A04A4A01CDe<0BDU904Y:BP11@D40ATI6038b<P0A4A409RHV02@T900`<3003@d=1000
0000:`051@D0000000D51@030`<010@401<C4`0S8b<0C4a<04=3@`1=CDd0ATI605YJFP15ADD0B4Q8
04m?C`0l?3`0:RXZ02PX:00A4A401PH601TI6@0O7al0:RXZ03<c<`0N7Qh0:RXZ01/K6`0W9bL061PH
02XZ:P0];Bd0:RXZ01lO7`0J6QX08R8R01TI6@0?3`l06ATI01<C4`0B4Q805QHF014A4@0=3@d02`00
00040=7=Z@000`3AcJT<0000000<00<30`051@D04a<C01DE5@0J6QX08R8R024Q8@0Z:RX0<S8b03`l
?00o?cl0E5AD0P1CDe<06`1<C4`0BTY:05EEE@1GEeL0?clo02PX:00W9bL08B4Q01/K6`0V9RH08B4Q
02<S8`0H61P0=cLg04M7A`0j>SX0<C4a03De=@0`<300;2`/04A4A00e=CD0?Cdm03lo?`0k>c/0D51@
04I6AP0205UIF@0J07EeM@1dM7@0GemO05=CD`1<C4`0EEEE04M7A`1IFET0CDe=05ADE00i>CT0=CDe
05=CD`11@D40;Bd]055AD@12@T80C4a<03Xj>P0F5QH0820P03Ph>01GEeL0AdM701HF5P0:2PX30000
000E01@D500410@02@T900D51@071`L06ATI02DU9@0n?Sh0BDU9061PH01DE5@0FUYJ04U9B@1DE5@0
@D5103@d=00g=cL09RHV01hN7P0R8R803`l?00806QXJ01<0:2PX02HV9P0G5aL06ATI00h>3P0O7al0
:BTY02l_;`0`<3006QXJ024Q8@0F5QH05aLG01dM7@0F5QH05aLG018B4P0H61P03Ph>00/00000103A
cJT000<0dLfY300000008`010@402@T900d=3@0J6QX08b<S01HF5P0N7Qh0820P02LW9`0i>CT0ADE5
04=3@`1:BTX0ADE505mOG`1EEED0CTi>04Y:BP1BDU80A4A4030`<00Y:BT0;Bd]00X:2P0O7al092@T
02LW9`0];Bd08b<S03Ti>@0X:2P0?Shn05aLG00h>3P0<C4a0080B4Q80240CDe=03hn?P0`<300B4Q8
0451@@1=CDd0DU9B05iNGP1OGel0I6AT06=SH`1DE5@0IVIV05iNGP1ADE40Cdm?03Hf=P1BDU80Cdm?
03`l?00o?cl0AdM704E5A@1JFUX0CDe=059BDP0j>SX0?clo06][J`1bLW80Cdm?03Xj>P0K6a/01000
00008@030`<010@400@4100000004A4A00`<300j>SX0=3@d04E5A@1FEUH0CDe=05EEE@1GEeL0De=C
05QHF00n?Sh09RHV028R8P051@D05aLG01TI6@0L71`07AdM03dm?@0`<3007AdM01`L700N7Qh08R8R
038b<P0^;Rh07alO01hN7P0201@D500501DE5@0H61P04Q8B01LG5`0=3@d02`0000040=7=Z@000`3A
cJT<0000000K00820P061PH03@d=01<C4`0V9RH071`L01TI6@0K6a/092@T02PX:00b<S80=3@d03`l
?012@T80D51@05ADE01GEeL0Cdm?05]KF`1EEED0De=C04Y:BP10@400:b/[024Q8@0e=CD08R8R0080
92@T00P05QHF028R8P0h>3P0?Shn03@d=00_;bl0=SHf03/k>`80?clo0P0];Bd0400d=3@0>3Ph04U9
B@1=CDd0FEUI071`L01jNWX0HF5Q06QXJ01NGUh0GemO055AD@1GEeL0Bd];04U9B@0k>c/20492@P0>
03lo?`17AdL0?Shn06MWI`1HF5P0IfMW05mOG`1TI6@0LG5a06MWI`0k>c/08b<S00h>3P0410@20000
000300410@00000010@400800P8202803`l?01@D500W9bL0;Bd]04E5A@1SHf<0EEEE04E5A@1HF5P0
IFEU0492@P0k>c/07QhN01LG5`0K6a/071`L01PH600M7Ad0820P02DU9@0R8R806ATI028R8P0[:b/0
61PH02DU9@0X:2P06a/K01PH600E5AD071`L01LG5`0@41002PX:2`0000040=7=Z@000`3AcJT<0000
001600D51@0;2`/02@T901TI6@0S8b<09RHV01LG5`0V9RH0:b/[02DU9@0L71`092@T020P8011@D40
?Cdm04Y:BP10@400Fe]K05YJFP1LG5`0GUiN05UIF@19BDT0>3Ph03Lg=`0Q8B406ATI02LW9`0Q8B40
4a<C01PH600O7al09BDU02PX:00j>SX0ATI60410@014A4@0>CTi03<c<`0n?Sh0<c<c02h^;P0o?cl0
Bd];06=SH`1KFe/0EeMG07IfMP1cLg<0GEeM05=CD`1LG5`0De=C055AD@0m?Cd0ADE505]KF`13@d<0
ATI604U9B@1KFe/0Jf][06YZJP1NGUh0NWYj05EEE@1XJ6P0Jf][06ATI080>3Ph00D09BDU024Q8@07
1`L0000001@D50030000000R00d=3@051@D04Q8B01XJ6P0c<c<0>3Ph05]KF`1<C4`0>c/k03Xj>P16
ATH0Bd];02l_;`0f=SH06ATI01dM7@0;2`/04Q8B00/;2`0N7Qh08b<S01hN7P0T92@0:2PX01dM7@0P
82006a/K02<S8`0K6a/07AdM01TI6@0C4a<030`<00410@/00000103AcJT000<0dLfY300000003P06
1PH03Ph>01PH600O7al0:b/[04=3@`0`<3008B4Q028R8P0_;bl092@T02l_;`0[:b/0:BTY0P0[:b/0
7016ATH0DU9B055AD@1LG5`0HF5Q05IFEP1SHf<0FUYJ059BDP1>CTh0=SHf02h^;P0f=SH09BDU01lO
7`0V9RH09BDU02/[:`0e=CD0?clo030`<015ADD0=SHf02XZ:P0m?Cd0?Shn03De=@17AdL202l_;`80
F5QH01/0K6a/05aLG01/K6`0Kfm_069RHP1KFe/0GUiN05=CD`17AdL0De=C04Q8B014A4@0FEUI05EE
E@1YJFT0I6AT06IVIP1LG5`0GUiN06IVIP1OGel0@d=3061PH00a<C40;Rh^034a<@0:2PX020000000
7`030`<04a<C02XZ:P0a<C40@41006MWI`11@D40ATI6061PH01=CDd0?Shn02l_;`0S8b<04a<C01@D
500?3`l04A4A01LG5`0W9bL092@T02HV9P0P820071`L02DU9@0Y:BT061PH01HF5P0I6AT05ADE00X:
2P061PH02`0000040=7=Z@000`3AcJT<0000001=00P8200A4A4051@D01/K6`0`<300De=C03dm?@0Z
:RX0820P02@T900W9bL08R8R03dm?@0Z:RX07alO03De=@0W9bL0@D5104Q8B01>CTh0GUiN05QHF01C
De<0LG5a04Y:BP11@D40BDU904=3@`0h>3P0?clo01lO7`0J6QX092@T02`/;00c<c<0?3`l03Hf=P0h
>3P0=3@d05aLG00R8R80=cLg03Xj>P1:BTX0Cdm?03dm?@1=CDd0BDU9065QH@1aLG40Jf][05eMG@1U
IFD0N7Qh05EEE@1BDU80Hf=S07AdM01HF5P0H61P06EUI@1HF5P0KVi^05IFEP26QXH0N7Qh04];B`1K
Fe/0EUIF05YJFP13@d<0>3Ph04I6AP0n?Sh0:BTY00P820010@401`0000002@0=3@d071`L02@T900g
=cL0@D5104=3@`1:BTX0A4A4051@D00204I6AP0C03dm?@0f=SH04Q8B01lO7`0A4A4061PH01LG5`0A
4A407alO02@T900O7al05QHF01/K6`0L71`092@T01TI6@0C4a<02`/;00D51@0;000000@0dLfY0003
0=7=Z@`0000001d020P800`<300D51@071`L02/[:`1EEED0CDe=03De=@0b<S80;Bd]028R8P0X:2P0
92@T030`<00b<S80=3@d02d];@0T92@0:b/[03hn?P19BDT0H61P055AD@1LG5`0FEUI065QH@1UIFD0
DE5A03<c<`0203@d=00`02`/;00d=3@09BDU01`L700Y:BT0;bl_03De=@0g=cL0?3`l03<c<`0O7al0
=3@d055AD@0k>c/0:RXZ02d];@14A4@0@T92059BDP1IFET0J6QX06e]K@1XJ6P0KFe]05eMG@1HF5P0
Cdm?04=3@`1XJ6P0O7al06MWI`1[Jf/0Ng]k05EEE@14A4@0Ng]k05UIF@1@D500F5QH0492@P0d=3@0
DU9B03Ph>01>CTh0?3`l02h^;P0000000@411@0000007P0<30`08b<S00/;2`0K6a/0;bl_055AD@14
A4@0AdM704E5A@0k>c/0@T9204a<C00e=CD0A4A403Ph>00M7Ad07QhN00<30`0=3@d06ATI020P800K
6a/061PH01@D500O7al061PH01TI6@0F5QH02PX:00410@/00000103AcJT000<0dLfY2`00000200<3
0`0Z00T92@0E5AD05aLG01`L700m?Cd0?clo02LW9`0`<3007alO024Q8@0m?Cd0:b/[02d];@0b<S80
;Rh^030`<00U9BD09bLW03/k>`0n?Sh0=cLg059BDP1MGEd0De=C065QH@1:BTX0JFUY051@D01=CDd0
=SHf02PX:00e=CD0;Bd]034a<@0];Bd09bLW01/K6`0Z:RX0?clo02/[:`0g=cL0?3`l0P10@400201F
EUH0=CDe03hn?P0n?Sh0GEeM04E5A@1@D500CDe=0P1XJ6P06`1JFUX0D51@06MWI`1EEED0M7Ad05MG
E`1_Kfl0H61P06e]K@1dM7@0E5AD05aLG00h>3P0BTY:04I6AP0o?cl0AdM705QHF01CDe<0ADE505MG
E`1LG5`0>CTi01hN7P0J6QX04Q8B00P820040000000L01DE5@0:2PX08b<S03@d=00h>3P0CDe=03Xj
>P15ADD0AdM704U9B@10@400?clo03Ph>00];Bd0:BTY01dM7@0>3Ph03`l?01LG5`0R8R806ATI01PH
600A4A408B4Q01<C4`0E5AD02@T900P820/00000103AcJT000<0dLfY3000000050051@D03@d=01DE
5@0I6AT071`L024Q8@0];Bd09RHV02DU9@0c<c<0;Bd]02XZ:P0^;Rh0;Bd]028R8P0Y:BT0:b/[03@d
=00i>CT0?3`l0P0m?Cd00`16ATH0CDe=05eMG@0206QXJ00Y05]KF`1QHF40GEeM04i>CP1:BTX0>SXj
03@d=00^;Rh08R8R034a<@0[:b/0@T9202/[:`0L71`0=CDe04];B`0o?cl0B4Q803/k>`0f=SH0CTi>
03`l?01ADE40=cLg04=3@`0m?Cd0@d=303hn?P1EEED0?clo05]KF`1VIVH0Fe]K06ATI01LG5`0IFEU
06IVIP1dM7@0Hf=S05ADE017AdL00P15ADD03P16ATH0@d=30492@P1CDe<0EeMG06ATI015ADD0E5AD
04I6AP1@D500?Cdm04Y:BP0b<S802`/;0P000000700410@00`<3014A4@0U9BD0:BTY038b<P13@d<0
BDU903Xj>P0h>3P0>SXj04A4A00n?Sh0<C4a03Lg=`0Y:BT08b<S01LG5`0H61P06ATI00l?3`0F5QH0
4A4A01HF5P0K6a/06ATI01<C4`061PH;000000@0dLfY00030=7=Z@`0000000d00`<300d=3@0F5QH0
6a/K01`L700M7Ad09bLW024Q8@0U9BD092@T02TY:@0];Bd0<30`0080<c<c0180;Rh^02`/;00f=SH0
;Bd]02h^;P0_;bl0?3`l03dm?@14A4@0EeMG05eMG@1HF5P0DU9B05eMG@1/K6`0JFUY05IFEP1JFUX2
04];B`1?03@d=00a<C40?clo038b<P0T92@0<C4a03Hf=P0Z:RX0@D510410@00j>SX0>c/k04I6AP10
@400DU9B055AD@0];Bd08b<S038b<P12@T80?Shn055AD@1MGEd0IfMW04a<C01VIVH0Bd];061PH01a
LG40K6a/05YJFP1BDU80EeMG03Ti>@0_;bl0=CDe03Ti>@16ATH0Bd];065QH@1^KVh0FUYJ04e=C@12
@T80D51@06=SH`14A4@0=3@d03Ti>@11@D406a/K010@400=3@d030`<014A4@0J6QX0:RXZ02d];@0a
<C40;Bd]03`l?00k>c/0A4A404I6AP0h>3P0<c<c0492@P0c<c<08b<S01PH600E5AD04Q8B01<C4`0?
3`l0410@014A4@0:2PX020P800H61P0;000000@0dLfY00030=7=Z@`0000000L01PH600h>3P0J6QX0
7QhN01<C4`0M7Ad09bLW008092@T03P06a/K03@d=00V9RH07alO024Q8@0Z:RX0:BTY02XZ:P10@400
;2`/03De=@0i>CT0?clo0451@@0l?3`0BTY:055AD@1QHF40IfMW06YZJP1_Kfl0K6a/06IVIP1DE5@0
De=C0410@00g=cL0?3`l02d];@0f=SH0:2PX03De=@0Z:RX08B4Q03Ph>01QHF40CTi>04Q8B01OGel0
@T9204A4A01NGUh0?Shn02/[:`0f=SH0<c<c02TY:@10@400BTY:04U9B@1NGUh0IVIV05YJFP1/K6`0
EEEE04M7A`80EeMG02l0EEEE04m?C`1;Bd/0DE5A02LW9`0l?3`0EEEE05]KF`1EEED0D51@04I6AP13
@d<0@D5105YJFP1/K6`0@41001lO7`0b<S804Q8B02<S8`0W9bL061PH00X:2P071`L05QHF01XJ6P0X
:2P0;Bd]03Hf=P0c<c<0;bl_0451@@0o?cl0@D5103hn?P0k>c/0;2`/02TY:@0S8b<061PH00`<300A
4A4030`<01DE5@0<30`03Ph>00<30`0;000000@0dLfY00030=7=Z@/0000003@00P8200@4100=3@d0
5QHF01TI6@0D51@08B4Q01hN7P0P82008R8R02<S8`0U9BD08R8R02`/;00];Bd0:b/[03Xj>P0g=cL0
:BTY034a<@0S8b<07QhN02TY:@0P8200BTY:03lo?`18B4P0=SHf04];B`1UIFD0EEEE06e]K@1cLg<0
JVYZ07AdM01FEUH0BDU90451@@0o?cl0AdM702TY:@0^;Rh0=CDe028R8P0e=CD0AdM703Ti>@0j>SX0
B4Q803lo?`0[:b/0<30`0P12@T80=`0T92@0820P03Hf=P0W9bL0ATI603hn?P1;Bd/0Hf=S06UYJ@1V
IVH0FEUI059BDP0l?3`0De=C06MWI`18B4P0EUIF04I6AP0o?cl0DE5A06IVIP1[Jf/0DU9B05mOG`12
@T80=3@d04I6AP17AdL0GEeM0410@00/;2`0>c/k03`l?016ATH0;Bd]028R8P0K6a/051@D00000009
2@T03Ph>01DE5@0Q8B40<S8b03/k>`0i>CT0>SXj0492@P11@D40BDU903/k>`0g=cL0<30`01XJ6P0A
4A400P0<30`0100820P02@T9000000030`<;000000@0dLfY00030=7=Z@/0000000D00P8200@4100>
3Ph051@D01PH600301LG5`0301TI6@0L71`07alO00808B4Q01l09bLW02l_;`0b<S80BDU906MWI`0c
<c<0:RXZ00X:2P0L71`08R8R030`<00m?Cd0A4A403Ti>@0b<S80>c/k0451@@1DE5@0IVIV06EUI@1A
DE40IfMW06=SH`1GEeL0HF5Q04E5A@12@T80=3@d02h^;P0T92@0:RXZ0080=SHf00H0HF5Q03`l?016
ATH0FUYJ038b<P0V9RH202XZ:P0703Hf=P0i>CT0=CDe02LW9`0c<c<0A4A40410@00205eMG@0W05iN
GP1YJFT0H61P04m?C`1MGEd0D51@06=SH`0l?3`0CTi>0492@P0l?3`0@T9204=3@`18B4P0AdM703Lg
=`19BDT0@D5104=3@`15ADD0CTi>03De=@0b<S805ADE028R8P0I6AT06QXJ00h>3P0<30`01`L70000
00020P80000000L71`0>3Ph09BDU02LW9`0c<c<0=CDe0080?clo00P0A4A403Lg=`11@D408b<S01PH
600G5aL04A4A00h>3P8010@4300000040=7=Z@000`3AcJT;0000001500<30`0000002`/;01DE5@0G
5aL071`L01hN7P0L71`08B4Q01hN7P0L71`07alO024Q8@0X:2P09BDU02/[:`0g=cL0<C4a03Lg=`0^
;Rh0:2PX01TI6@0G5aL051@D02XZ:P0[:b/0CTi>04a<C01>CTh0AdM703lo?`1JFUX0GemO05]KF`1X
J6P0JFUY065QH@1IFET0G5aL04Q8B01JFUX0>SXj03De=@0[:b/06a/K02PX:00T92@0:BTY03Ti>@19
BDT0ADE504A4A00N7Qh0=CDe03Hf=P0a<C40<S8b04M7A`0g=cL0<c<c0492@P1<C4`0?Cdm04i>CP1D
E5@0@41004];B`1KFe/0G5aL0080EEEE01P0BDU905ADE00j>SX0DE5A04e=C@1>CTh0;bl_05=CD`0j
>SX0=CDe04M7A`0m?Cd0Bd];059BDP0i>CT0=3@d04m?C`0Y:BT0>3Ph01HF5P0<30`01PH600T92@01
0@430000000@00D51@0I6AT06a/K02LW9`0f=SH0<30`0451@@1:BTX0@D5103Hf=P0^;Rh0:BTY01DE
5@0<30`01@D500P820`00000103AcJT000<0dLfY2`00000200<30`0800X:2P0?3`l04a<C01<C4`0H
61P06QXJ02DU9@0M7Ad202/[:`0V02XZ:P0W9bL09BDU02LW9`0N7Qh09RHV02d];@0_;bl0>CTi02HV
9P0M7Ad08R8R01@D500N7Qh0;bl_03/k>`0e=CD0?Cdm04a<C013@d<0GUiN05eMG@1LG5`0IVIV05IF
EP1ADE40FEUI06MWI`1RHV80ADE503lo?`17AdL0@D5103lo?`0j>SX0:2PX03lo?`0];Bd204E5A@08
02DU9@0l?3`0@41003@d=00_;bl0>SXj04e=C@0i>CT2038b<P0>03@d=00l?3`0HF5Q04Q8B01OGel0
De=C05mOG`1FEUH0FEUI04m?C`1QHF40F5QH05IFEP19BDT204E5A@0>03dm?@1HF5P0?Cdm05=CD`0/
;2`0@41003Hf=P0e=CD0?Shn04U9B@1BDU80?clo01TI6@0J6QX60000000@00D51@010@407AdM024Q
8@0a<C40=CDe03Ph>00l?3`0>3Ph03<c<`0_;bl0=CDe02/[:`0K6a/04a<C00410@`00000103AcJT0
00<0dLfY2`000000:P061PH00P8200D51@0D51@0410@014A4@0L71`0820P01hN7P0X:2P08R8R02PX
:00Q8B408b<S02@T900O7al0@41002HV9P0P82007AdM01TI6@0l?3`0;2`/028R8P0Y:BT05QHF01lO
7`0V9RH0:RXZ04U9B@1CDe<0?clo03Lg=`0b<S80BDU9055AD@1LG5`0Kfm_06QXJ01GEeL0M7Ad06EU
I@80EUIF00/0?3`l034a<@0n?Sh0<S8b02<S8`0m?Cd0A4A40451@@0^;Rh0?clo04M7A`0204Y:BP0=
02d];@12@T80@D5103/k>`0];Bd0;2`/03Lg=`0m?Cd0EEEE04m?C`1@D500@D5104i>CP0204a<C007
05IFEP1OGel0DU9B04i>CP14A4@0@T9205EEE@0205=CD`0605mOG`1GEeL0BTY:03hn?P0f=SH0>c/k
0P0i>CT01@18B4P0=cLg02d];@0R8R802`/;0080000001800P82000000000000000000@4100P8200
7alO02@T900X:2P0<c<c03Hf=P0^;Rh0;2`/02XZ:P0Y:BT09RHV01`L700?3`l<000000@0dLfY0003
0=7=Z@/0000000<00`<30000000410@00P0D51@0;@0N7Qh08B4Q01HF5P0T92@071`L01LG5`0R8R80
92@T02PX:00M7Ad071`L04];B`0[:b/0;2`/02d];@0K6a/0:b/[02DU9@12@T80=cLg018B4P0T92@0
4A4A01DE5@0/;2`0;Bd]04=3@`14A4@0?Cdm03De=@1:BTX0MGEe08:2PP1ZJVX0JFUY079bLP1SHf<0
Fe]K05eMG@1KFe/0E5AD02`/;00d=3@0?3`l059BDP0202@T900R03`l?00k>c/0CTi>02d];@0[:b/0
9RHV02XZ:P0e=CD0CDe=04m?C`12@T80>c/k0492@P0f=SH0A4A405eMG@1OGel0H61P04E5A@1`L700
CTi>06EUI@1NGUh0Cdm?05YJFP1]KFd0CDe=03lo?`19BDT0?Cdm06=SH`0l?3`0E5AD055AD@80>SXj
00P0B4Q803lo?`1NGUh0C4a<03Xj>P0I6AT03Ph>00410@80000001400`<30000000000000000018B
4P0J6QX09RHV02@T900X:2P09bLW02/[:`0X:2P07AdM02XZ:P0M7Ad04A4A00H61P0;000000@0dLfY
00030=7=Z@/0000001800P82000000020P80410@01<C4`0B4Q8061PH01`L700M7Ad08R8R024Q8@0/
;2`092@T028R8P0Y:BT092@T02DU9@0K6a/202TY:@1203@d=00L71`0=CDe03dm?@0W9bL0>3Ph02PX
:00S8b<061PH02HV9P0Z:RX07alO02DU9@1<C4`0?3`l0410@01GEeL0Bd];06UYJ@1XJ6P0Fe]K05UI
F@1PH600Hf=S04m?C`1DE5@0>3Ph03Xj>P16ATH0>3Ph03<c<`0o?cl0ADE503lo?`0U9BD0:b/[030`
<00m?Cd0:RXZ04E5A@0`<300>c/k03dm?@0o?cl0;Bd]03Hf=P0e=CD0=cLg05MGE`1MGEd0GUiN06][
J`1UIFD0I6AT055AD@1NGUh0EUIF055AD@1IFET0Cdm?04Y:BP1=CDd0ADE503dm?@15ADD0AdM70P16
ATH02@12@T80B4Q80451@@15ADD0Bd];02h^;P0X:2P04A4A00P820020000000@00820P0000001PH6
00820P071`L0410@018B4P0L71`07alO01HF5P0T92@09RHV01XJ6P0D51@0410@00P820/00000103A
cJT000<0dLfY2`00000300820P0D00X:2P0D51@05aLG01HF5P0S8b<06QXJ01lO7`0K6a/08b<S01TI
6@0P8200:BTY02DU9@0X:2P07QhN02TY:@0f=SH0:b/[03Ph>00V9RH2034a<@0^02d];@10@400>c/k
02h^;P0W9bL0;Bd]02@T900V9RH0:2PX0492@P14A4@0C4a<03Hf=P1=CDd0F5QH051@D01?Cdl0FUYJ
07AdM01IFET0CTi>06UYJ@1PH600CDe=04U9B@0j>SX0?3`l03Lg=`0X:2P0>c/k02XZ:P0k>c/0@D51
03<c<`0l?3`0Bd];02PX:00];Bd0<S8b03Ph>013@d<0>3Ph01lO7`0h>3P0De=C069RHP80EUIF01/0
GEeM05EEE@1ZJVX0IVIV05QHF01TI6@0H61P05IFEP1GEeL0E5AD059BDP1=CDd0DE5A059BDP1FEUH0
DU9B04M7A`19BDT0@T9204Q8B01@D500@d=3038b<P0L71`0000000820P030`<00P0000003@0820P0
000000H61P0?3`l01PH601HF5P0B4Q805QHF01`L700O7al03`l?00T92@0410@02`0000040=7=Z@00
0`3AcJT;0000000800<30`0000000@4100D51@0@41006ATI018B4P0I6AT201lO7`0C02DU9@0O7al0
9RHV02DU9@0Z:RX0;Rh^02@T900^;Rh0820P02HV9P0O7al0:RXZ02/[:`0g=cL0<S8b03Hf=P13@d<0
<S8b03Hf=P0201hN7P0A02HV9P0P82008R8R03<c<`0^;Rh0?clo03`l?017AdL0@d=303Xj>P12@T80
GEeM05]KF`1[Jf/0KFe]065QH@1DE5@00P1EEED07014A4@0@d=302XZ:P0^;Rh08b<S034a<@0b<S80
?Shn04E5A@0m?Cd0<S8b03`l?00h>3P0<30`03Hf=P10@400;Rh^03Ti>@0l?3`0D51@04];B`1=CDd0
ATI605ADE01CDe<0AdM7061PH01XJ6P205UIF@0D05YJFP1BDU80GUiN04e=C@1QHF40Hf=S03Ti>@0m
?Cd0B4Q80451@@17AdL0DU9B03dm?@15ADD0F5QH03/k>`0G5aL03Ph>00`<30071`L30000000<0082
0P030`<0000000820P0<30`01`L700l?3`0@41004Q8B014A4@0410@01PH62`0000040=7=Z@000`3A
cJT;0000000F00P820020P8000000000000C4a<071`L01@D500K6a/06QXJ01hN7P0P82005ADE020P
800R8R80;bl_02LW9`0R8R809RHV03De=@0[:b/08R8R020P8080;Bd]01h071`L02PX:00Y:BT0;2`/
02h^;P0k>c/0=cLg028R8P0F5QH0:RXZ01LG5`0e=CD0;Bd]03/k>`10@400Cdm?02/[:`0c<c<0@D51
04A4A01WIfL0Jf][06e]K@1[Jf/0IVIV05]KF`1IFET0ATI60410@01;Bd/2038b<P0;02HV9P1=CDd0
@T9202h^;P1@D500Fe]K04=3@`0k>c/0>3Ph03Ti>@0V9RH00P0j>SX08@0i>CT0=cLg05ADE00o?cl0
Bd];059BDP1;Bd/0ATI607=cL`1aLG40IFEU05aLG01[Jf/0C4a<06YZJP1@D500H61P05ADE00e=CD0
@d=304M7A`0m?Cd0=cLg055AD@1=CDd0A4A404Q8B01ADE40ATI602DU9@0I6AT030`<00L71`060000
000600@410020P80000000820P0<30`00`<3300000040=7=Z@000`3AcJT;0000000800D51@0410@0
00000000000<30`07QhN01/K6`0N7Qh201TI6@0<01PH600F5QH051@D02@T900S8b<07AdM02@T900U
9BD0;Rh^03<c<`0Z:RX08b<S0P0W9bL07`0[:b/0;2`/02HV9P0c<c<0820P02HV9P0a<C40=3@d02TY
:@0^;Rh08B4Q01hN7P0M7Ad0=3@d02l_;`0f=SH0=3@d03Ti>@18B4P0=SHf06a/K011@D40MgMg05mO
G`1NGUh0H61P06MWI`1LG5`0FEUI04i>CP0l?3`00P10@400;`0e=CD0<c<c02HV9P0b<S80>SXj04=3
@`0_;bl0?3`l024Q8@0^;Rh0<c<c030`<011@D40?3`l03lo?`1>CTh0ATI604m?C`1GEeL0De=C06=S
H`1MGEd0GemO065QH@1DE5@0MWIf05=CD`1MGEd0AdM705QHF016ATH0@T9204i>CP0i>CT0=CDe03hn
?P0j>SX0?3`l04=3@`1FEUH0CDe=04A4A00l?3`06ATI00T92@020P802PX:00@000000P020P801004
10@01`L700410@020P8<000000@0dLfY00030=7=Z@/0000000<01PH60000000410@00P0000007`0Y
:BT0:RXZ024Q8@0O7al06a/K01PH600Q8B405aLG01/K6`0R8R807AdM02d];@0W9bL0<c<c02XZ:P0f
=SH0;2`/02PX:00V9RH08b<S020P800K6a/0820P02/[:`0`<300=3@d03De=@0^;Rh0?3`l03Ti>@0e
=CD00P0Z:RX03@0E5AD0;Bd]03Ph>00e=CD0;bl_03De=@1GEeL0CTi>04I6AP1QHF40EEEE06YZJP1/
K6`00P1[Jf/09`1?Cdl0DE5A03<c<`0o?cl0<C4a02HV9P0b<S80820P02PX:00^;Rh0>c/k03dm?@0b
<S809BDU03Hf=P0U9BD0<C4a04a<C016ATH0>CTi03Hf=P1<C4`0D51@05MGE`1YJFT0Cdm?04e=C@1M
GEd0CDe=04];B`1NGUh0JVYZ05ADE01FEUH0Bd];05mOG`1>CTh0<30`03dm?@02030`<00=03hn?P14
A4@0BTY:04M7A`18B4P0IFEU0492@P0R8R804Q8B00h>3P0820P010@400P820030000000300820P00
0000000000d00000103AcJT000<0dLfY2`0000000`051@D010@4000000020000000R028R8P0a<C40
9RHV02XZ:P0Q8B4061PH00d=3@0G5aL06a/K01dM7@0E5AD07QhN02@T900W9bL09BDU02PX:00V9RH0
9bLW02`/;00b<S80>SXj02h^;P0M7Ad08b<S034a<@0W9bL0<c<c03dm?@0o?cl0Bd];03/k>`0h>3P0
6a/K01TI6@809BDU02h0<S8b03Hf=P14A4@0@T9204];B`13@d<0FEUI06UYJ@1MGEd0LW9b05aLG01`
L700Jf][07AdM01OGel0F5QH055AD@1:BTX0<C4a03Ph>00U9BD07alO02@T900c<c<092@T02d];@0c
<c<092@T03@d=00m?Cd0<C4a0492@P0b<S80;bl_04=3@`1;Bd/0C4a<04U9B@15ADD0B4Q80492@P1A
DE40G5aL05IFEP1IFET0EeMG0P1>CTh203Xj>P0B03dm?@0n?Sh0=SHf02TY:@12@T80>CTi059BDP1A
DE40EUIF059BDP10@400?3`l03Hf=P0S8b<07AdM01HF5P0=3@d02@T94@0000040=7=Z@000`3AcJT;
0000000300P8200410@00@410080000000/03Ph>02/[:`0a<C40>3Ph01hN7P0C4a<05QHF01`L700N
7Qh06ATI01`L700201TI6@809bLW02<0<C4a02h^;P0^;Rh0<30`038b<P13@d<0>SXj02PX:00c<c<0
:RXZ038b<P0^;Rh0;2`/034a<@1:BTX0?Cdm03De=@0W9bL071`L01lO7`0N7Qh0<30`02l_;`0g=cL0
@D5105]KF`11@D40?3`l04E5A@1@D500GUiN06i^KP1VIVH0KFe]05IFEP02069RHP0<03lo?`17AdL0
?Shn038b<P0/;2`09RHV01DE5@0X:2P07QhN0492@P18B4P0@4100P0f=SH05@0O7al0<C4a03/k>`17
AdL0=cLg03`l?010@400@D5104i>CP0j>SX0@d=30492@P11@D40>c/k03<c<`12@T80GemO03lo?`1D
E5@0@D5103lo?`0203hn?P0304A4A011@D40@d=30080B4Q800/0BTY:04m?C`18B4P0B4Q804M7A`0]
;Bd0<30`02<S8`020P80000000@4100@000000@0dLfY00030=7=Z@/0000000`020P800820P030`<0
0@410000000410@09BDU03Ti>@0h>3P0:b/[01hN7P0F5QH201/K6`0:01DE5@0H61P05ADE01dM7@0H
61P06QXJ02TY:@0/;2`0;Rh^030`<080;2`/04P0:2PX02DU9@0l?3`0:2PX02`/;00Z:RX0>3Ph03Hf
=P0g=cL0<C4a0410@013@d<0A4A403@d=00J6QX0820P01`L700P8200;Rh^04A4A01EEED0ADE504I6
AP0h>3P0B4Q806QXJ01JFUX0Kfm_06MWI`1QHF40G5aL04e=C@1FEUH0@d=303Ph>00f=SH0=CDe01`L
700V9RH07AdM02TY:@14A4@0<S8b03Ph>00n?Sh0<S8b02HV9P0[:b/0;Bd]04E5A@11@D40>SXj03/k
>`0d=3@0A4A403lo?`0m?Cd0>c/k03lo?`1;Bd/0=CDe04m?C`1EEED0@T9204A4A011@D40DU9B04];
B`10@400De=C03lo?`15ADD204M7A`0;03Xj>P0n?Sh0@D5104A4A00f=SH0:BTY02d];@0J6QX01`L7
00`<30030`<03`0000040=7=Z@000`3AcJT;0000000400/;2`061PH00P8200410@80000002T03Ph>
03dm?@0c<c<0=3@d03<c<`0U9BD06QXJ01dM7@0P82008R8R01dM7@0T92@06QXJ02<S8`0H61P08B4Q
02@T900O7al0;Bd]02h^;P0X:2P09bLW01dM7@0`<300;Bd]01LG5`0K6a/07alO03Ph>00];Bd0=CDe
02/[:`0i>CT0=cLg02PX:00d=3@08b<S014A4@0F5QH0:b/[03`l?00203hn?P0703De=@0b<S80Bd];
05=CD`1ZJVX0IVIV06QXJ00205]KF`0406QXJ01>CTh0IVIV05YJFP80:b/[02H04Q8B024Q8@0L71`0
9RHV03lo?`19BDT0DU9B02XZ:P0_;bl05ADE02LW9`1KFe/0E5AD0492@P0h>3P0A4A403`l?00c<c<0
>3Ph02`/;00Z:RX0CDe=061PH01DE5@0CDe=05IFEP0o?cl0DU9B04M7A`1HF5P0<S8b04E5A@0^;Rh0
>SXj04I6AP1=CDd0?clo030`<080?Shn00L0<c<c034a<@0^;Rh0;2`/01@D500B4Q801`L700l00000
103AcJT000<0dLfY2`0000001@071`L01PH600H61P061PH00@41008000000P0b<S80IP0h>3P0<c<c
020P800K6a/07QhN02<S8`0Q8B40820P03<c<`0Q8B40;Bd]028R8P0T92@07alO02XZ:P0O7al04a<C
028R8P0/;2`0820P02d];@0X:2P0=SHf02LW9`0I6AT07AdM02h^;P0j>SX0=CDe02TY:@0W9bL0=CDe
03/k>`18B4P0?clo02HV9P0[:b/0?Shn04Y:BP0b<S80?clo03/k>`11@D40?Cdm04i>CP1CDe<0EeMG
07AdM01QHF40FEUI06UYJ@1EEED0AdM704Q8B00j>SX0>c/k02XZ:P0/;2`0@41002LW9`0S8b<0>SXj
03Ti>@0];Bd0=CDe02@T900Y:BT0?3`l03dm?@12@T80?clo03hn?P0^;Rh0=CDe02XZ:P0b<S80<30`
0410@01ADE40De=C05EEE@1>CTh0EUIF04A4A00j>SX0<C4a03Ph>00l?3`0A4A40410@00g=cL0>SXj
03dm?@0g=cL0@410034a<@0/;2`0<c<c024Q8@0P82004Q8B00D51@l00000103AcJT000<0dLfY2`00
000010092@T01@D500H61P061PH30000000X01lO7`0g=cL0>3Ph02LW9`0V9RH07QhN02DU9@0V9RH0
7AdM01hN7P0Q8B40;Bd]02LW9`0S8b<09BDU024Q8@0U9BD07alO02<S8`0[:b/0<C4a02@T900Y:BT0
92@T02h^;P0b<S8092@T01PH600I6AT08R8R04E5A@0^;Rh0=cLg02@T900o?cl0AdM704=3@`0a<C40
?clo02l_;`80>3Ph00H0=SHf04e=C@19BDT0>SXj03/k>`0c<c<205QHF00K04Y:BP1JFUX0Ogmo07Mg
M`1ZJVX0E5AD05iNGP11@D40>c/k02PX:00b<S80;bl_02XZ:P0_;bl0:BTY02h^;P0e=CD0=SHf01lO
7`0V9RH0?Cdm0410@00e=CD0?Cdm04A4A00/;2`0=3@d0080@D5101P0C4a<06YZJP1SHf<0C4a<055A
D@1<C4`0BTY:04E5A@1<C4`0BDU902`/;014A4@0CDe=03Xj>P13@d<0=SHf030`<00_;bl0=3@d02`/
;00i>CT08b<S020P800E5AD@000000@0dLfY00030=7=Z@/0000000D02@T900P8200820P010@400<3
0`030000000f038b<P0g=cL0;bl_02d];@0Q8B4061PH024Q8@0J6QX07AdM01PH600K6a/08b<S01hN
7P0K6a/09bLW01dM7@0R8R806a/K01PH600X:2P07alO02XZ:P0`<30092@T02XZ:P0[:b/0<S8b01PH
600S8b<07alO02/[:`0d=3@0:RXZ034a<@19BDT0>SXj03hn?P1:BTX0?clo0451@@14A4@0>CTi034a
<@0n?Sh0>3Ph04Q8B00h>3P0?Cdm0451@@1:BTX0IFEU06IVIP1KFe/0K6a/0P1NGUh0;P1=CDd0AdM7
055AD@0n?Sh0ATI602XZ:P0O7al0;Bd]03dm?@0Q8B4092@T02DU9@0R8R80:BTY03@d=013@d<0ADE5
0451@@1ADE40;bl_03<c<`14A4@0EUIF05ADE01FEUH0FUYJ05QHF00k>c/0Cdm?04U9B@1HF5P0De=C
03Lg=`0b<S80=SHf03/k>`0h>3P0;bl_02h^;P0X:2P0<C4a02`/;00W9bL071`L01@D500>3Ph@0000
00@0dLfY00030=7=Z@/0000000D02@T900P820051@D00P8200410@030000001V014A4@0Z:RX0<S8b
02/[:`0U9BD061PH014A4@0O7al071`L00d=3@0;2`/04Q8B01LG5`0H61P0820P01lO7`0R8R8061PH
028R8P0O7al08B4Q02<S8`0V9RH0:RXZ02d];@0j>SX0:BTY02l_;`0X:2P08b<S02LW9`0K6a/0<c<c
030`<00e=CD0;Rh^03dm?@12@T80@D5104a<C00o?cl0<C4a02d];@0c<c<0?Shn03Hf=P12@T80?3`l
02l_;`1=CDd0Bd];05]KF`1XJ6P0FUYJ069RHP1YJFT0J6QX05IFEP1<C4`0=SHf04E5A@0T92@0;bl_
02LW9`0V9RH0;Rh^020P800C4a<04Q8B02XZ:P0e=CD0<S8b03Lg=`0U9BD0BDU904];B`14A4@0<S8b
02`/;00o?cl0=SHf051@D01RHV80CTi>04E5A@0j>SX0C4a<04];B`1>CTh0A4A403hn?P0l?3`0BTY:
03@d=00e=CD0>CTi02TY:@0Z:RX08R8R01dM7@0A4A402`/;400000040=7=Z@000`3AcJT;00000005
00/;2`0:2PX01`L700@410030`<010000000700F5QH0<C4a03<c<`0_;bl07alO01DE5@0C4a<04Q8B
00/;2`0:2PX06a/K018B4P0<30`06a/K02DU9@0G5aL08b<S01lO7`0F5QH06a/K02@T900M7Ad07QhN
02/[:`13@d<0=CDe02TY:@0X:2P202@T900n02PX:00L71`0<S8b03Ph>012@T80:2PX03dm?@14A4@0
CDe=05=CD`0a<C40A4A403De=@0j>SX0=3@d02`/;00i>CT0BDU903dm?@0n?Sh0=cLg04a<C01EEED0
FEUI069RHP1OGel0I6AT05iNGP1KFe/0E5AD04Q8B010@4008b<S02PX:00V9RH0000000h>3P0J6QX0
:RXZ02LW9`0Q8B40:RXZ03/k>`0];Bd0=3@d03`l?012@T80@D5103dm?@0n?Sh0B4Q804M7A`1DE5@0
BTY:051@D016ATH0AdM703dm?@1?Cdl0Bd];03Xj>P0d=3@203De=@07030`<00Z:RX092@T02PX:00F
5QH030`<00410@0@000000@0dLfY00030=7=Z@/000000P0<30`00`071`L020P800<30`050000000J
0410@01:BTX0=SHf02d];@0I6AT02PX:00L71`0:2PX0000000h>3P0G5aL03@d=01PH600E5AD07QhN
01/K6`0H61P08b<S020P800X:2P0820P01HF5P0X:2P092@T03<c<`0k>c/302XZ:P0?03Hf=P0U9BD0
8b<S03<c<`0_;bl0>CTi03Ph>00b<S80<30`04U9B@10@400DE5A04=3@`0d=3@0<c<c0080=3@d00l0
?3`l03Hf=P0e=CD0=3@d02HV9P0i>CT0?clo04I6AP1JFUX0IfMW06=SH`1QHF40J6QX055AD@15ADD0
0`0k>c/02@0E5AD00P820000000>3Ph07QhN03Lg=`0X:2P0?Cdm03Ti>@0203Xj>P80>CTi01H0:RXZ
03Ti>@0d=3@0@T9204m?C`1EEED0BTY:04Q8B00o?cl0ADE504U9B@0m?Cd0?3`l03De=@12@T80<30`
03`l?00Q8B40;2`/01/K6`0B4Q801`L74@0000040=7=Z@000`3AcJT;0000000400/;2`0:2PX02@T9
00H61P800@4110000000200X:2P0E5AD04I6AP0e=CD09RHV01DE5@010@400`<30P020P80200I6AT0
4Q8B01TI6@0P820061PH01DE5@0W9bL07alO0P0M7Ad01@0X:2P09bLW02HV9P0a<C40;2`/0080<S8b
01`0;Rh^034a<@0X:2P092@T02XZ:P0X:2P07QhN02`/;00m?Cd0<S8b02l_;`0^;Rh0>SXj04U9B@0/
;2`0?clo034a<@0k>c/0>3Ph0492@P0d=3@0=cLg034a<@0l?3`0=SHf02/[:`1=CDd0A4A40P1XJ6P0
1@1PH600L71`065QH@1]KFd0?Cdm0080>3Ph00T09bLW0000000000001`L700D51@0[:b/061PH02TY
:@0d=3@00P0/;2`01`0W9bL0<S8b038b<P0/;2`0?clo03Ti>@11@D400P1=CDd01@18B4P0@T9204Y:
BP19BDT0CDe=0080?clo00L0;Bd]03@d=00e=CD092@T01lO7`0A4A401PH601800000103AcJT000<0
dLfY2`0000001P0=3@d02PX:00/;2`071`L00P8200<30`D0000000D0H61P06m_K`1BDU80?Cdm020P
80040000000;00L71`0=3@d03`l?01lO7`0U9BD05QHF01hN7P0K6a/061PH01hN7P0W9bL00P0Q8B40
B`0U9BD071`L02XZ:P0];Bd0;Rh^030`<00^;Rh09BDU03<c<`0W9bL09RHV02d];@0O7al092@T038b
<P0I6AT0<C4a0451@@0i>CT0A4A404];B`0i>CT0@D5102l_;`0l?3`0>SXj038b<P0Y:BT0>3Ph02HV
9P14A4@0BTY:04e=C@1UIFD0E5AD06=SH`1kNg/0JVYZ06IVIP1>CTh0BTY:02DU9@0>3Ph04A4A01/K
6`0H61P05ADE02d];@0V9RH0:RXZ03<c<`0U9BD08b<S02LW9`0i>CT09RHV02XZ:P0`<300=cLg03@d
=018B4P0>CTi03dm?@0h>3P0@d=303dm?@0l?3`0<c<c034a<@0`<300:BTY02HV9P0F5QH06ATI00@4
100B000000@0dLfY00030=7=Z@/0000000L02PX:00T92@0:2PX020P800H61P051@D00P8200@00000
00H030`<092@T02<S8`0GemO0451@@0H61P50000000600<30`0:2PX03`l?02@T900J6QX061PH0P0C
4a<0:`0Z:RX06a/K020P800];Bd0:b/[02TY:@0O7al07QhN02/[:`0N7Qh0:b/[028R8P0m?Cd0<S8b
02LW9`0X:2P05aLG02HV9P0T92@0<S8b02TY:@0f=SH0>c/k04E5A@17AdL0?Cdm04m?C`0g=cL0;Bd]
03lo?`0k>c/0;bl_02<S8`0[:b/0;Rh^03lo?`0k>c/0@d=305EEE@1DE5@0HF5Q05UIF@1TI6@00P16
ATH08@0j>SX06ATI00H61P0?3`l08R8R01hN7P0S8b<08R8R02DU9@0P82008B4Q01dM7@0G5aL0;Bd]
02<S8`0X:2P0:BTY03<c<`0`<300>3Ph03Lg=`10@400?Shn03`l?015ADD0=3@d030`<00];Bd0:BTY
01lO7`0H61P04A4A00820P060000000300820P000000000000T00000103AcJT000<0dLfY2`000000
1`0;2`/030`<00d=3@0;2`/020P800T92@020P801@0000001P18B4P0^[Zj09VIV@1WIfL0@D5102h^
;PD0000000D020P800D51@0I6AT07QhN01XJ6P0201lO7`0S020P800M7Ad08R8R02h^;P0V9RH08B4Q
02XZ:P0K6a/08R8R02XZ:P0O7al08B4Q02LW9`0f=SH0<C4a04M7A`0X:2P06QXJ02LW9`0/;2`0820P
038b<P0j>SX0@d=30492@P0b<S80C4a<03/k>`0b<S80;Bd]03De=@0^;Rh0:RXZ03<c<`0g=cL00P0^
;Rh0100f=SH0>c/k04Q8B01LG5`205YJFP0405]KF`1HF5P0BTY:03De=@808b<S01`0:BTY01dM7@0L
71`051@D02HV9P0D51@071`L01dM7@0J6QX07AdM02HV9P0M7Ad07alO030`<00V9RH0:BTY03Hf=P0n
?Sh0>CTi03lo?`0j>SX0;Rh^03<c<`0R8R809RHV01`L70061PH010@41P0000000`010@401PH60000
000:000000@0dLfY00030=7=Z@/0000000<02PX:00T92@0;2`/00P0:2PX00`0820P00`<300000005
0000000604A4A03EeMD0W9bL06IVIP1CDe<05ADE1P000000C@0410@01`L701DE5@0S8b<0820P028R
8P0L71`0:BTY01dM7@0];Bd0:RXZ02/[:`0M7Ad07alO02h^;P0Y:BT092@T024Q8@0g=cL0>3Ph02DU
9@0[:b/0;2`/02LW9`0T92@07AdM034a<@0^;Rh0:BTY04E5A@0n?Sh0@d=304m?C`15ADD0>c/k038b
<P0i>CT0;bl_03`l?00g=cL0=3@d03<c<`0^;Rh0<30`04m?C`1eMGD0NWYj06=SH`1:BTX0@D5104=3
@`0j>SX0AdM703Hf=P0g=cL0>c/k02/[:`0Z:RX09BDU02XZ:P0T92@0>c/k024Q8@0R8R806ATI01/K
6`0Q8B407alO02<S8`0[:b/0=CDe02d];@0_;bl0=SHf03De=@0l?3`0;bl_00807AdM00<051@D00T9
2@0000001P0000000`010@4010@40000000:000000@0dLfY00030=7=Z@/000000P0<30`01P0820P0
2@T900P8200820P01PH600<30`80000000X010@40000000000000`<30;6a/@3Hf=P0UYJF08B4Q00o
?cl0410@1P0000001`0410@030`<01<C4`0?3`l08B4Q01TI6@0Q8B400P0J6QX0;00K6a/09BDU02<S
8`0Q8B408b<S02PX:00V9RH09BDU028R8P0W9bL0;2`/03<c<`0[:b/0:2PX01/K6`0T92@09RHV01hN
7P0k>c/0<c<c03De=@0j>SX0;bl_02d];@0g=cL0?3`l03Hf=P0V9RH0>3Ph02l_;`0m?Cd0>SXj02/[
:`0k>c/0ADE505eMG@1XJ6P0JFUY059BDP0n?Sh0=cLg02h^;P12@T80<S8b0P0i>CT02P0e=CD0<C4a
034a<@0c<c<09BDU02/[:`0Y:BT09bLW01`L700=3@d2010@400<01hN7P0];Bd0>CTi02TY:@0];Bd0
92@T02d];@0/;2`09bLW01XJ6P0G5aL03Ph>200000000`030`<01PH60000000:000000@0dLfY0003
0=7=Z@/0000000H030`<00X:2P0=3@d030`<00X:2P092@T200H61PH0000000P06QXJ0=;BdP3Fe]H0
c<c<09:BTP15ADD092@T00<30`@0000000X00P8200000000000030`<01TI6@0G5aL0820P01LG5`0Q
8B409RHV0P0T92@0200P82005QHF01`L700S8b<0;bl_02d];@0[:b/0=cLg0P0Y:BT09@0/;2`0:2PX
02`/;00U9BD0:BTY024Q8@0[:b/0820P02@T900g=cL0?Cdm02`/;010@400?3`l03Ph>00j>SX0:2PX
03<c<`0k>c/0>CTi02l_;`12@T80?Cdm04a<C01PH600FUYJ03/k>`0c<c<0=cLg03Xj>P1CDe<0L71`
06i^KP1WIfL0J6QX05ADE00j>SX00P0^;Rh04P0g=cL0:BTY020P800F5QH02@T901LG5`0I6AT0820P
02<S8`0U9BD07alO028R8P0X:2P06a/K01TI6@0G5aL03Ph>00@410P0000000<01`L700P820000000
2P0000040=7=Z@000`3AcJT;0000000:00/;2`0820P03@d=00X:2P0<30`02`/;00H61P071`L01@D5
00820P@0000000T00P82030`<03clo<0inOW0=;BdP2d];@0G5aL04I6AP0E5AD01`0000001P0C4a<0
3Ph>024Q8@0K6a/07AdM02LW9`808b<S00/09BDU02@T900H61P06QXJ01PH600M7Ad08R8R02/[:`0Z
:RX0<30`02@T900203<c<`80:BTY02P08B4Q02LW9`0U9BD09BDU01hN7P0U9BD0:BTY03Hf=P0];Bd0
=cLg03dm?@19BDT0>SXj02TY:@0c<c<0=SHf03hn?P0_;bl0>c/k04E5A@12@T80?Shn02`/;010@400
Fe]K07inOP2?Shl0P82009BDU01hN7P0PX:207]kN`1UIFD0=3@d03Lg=`0`<3005QHF01`L700820P0
2PX:0P0M7Ad02P0Q8B408R8R02`/;00N7Qh071`L020P800?3`l02PX:00<30`010@46000000040041
0@0410@01`L700L71`/00000103AcJT000<0dLfY2`0000001P092@T03@d=00/;2`0;2`/030`<00X:
2P8020P800<01PH600820P0000000P00000030010@4000000000001IFET0lO7a0?ooo`3Ph>00][Jf
0:FUY@1]KFd08R8R00h>3PH0000002H04A4A01PH600P82006a/K01@D500O7al0:2PX02/[:`0N7Qh0
:BTY01TI6@0V9RH06QXJ01dM7@0N7Qh0?Cdm02XZ:P0b<S80=CDe030`<00U9BD0:RXZ02@T900X:2P0
=SHf03@d=00P820092@T02TY:@0`<300>CTi03Xj>P0n?Sh0=SHf038b<P0^;Rh0<C4a02d];@80<S8b
00D0?clo0410@00V9RH0:2PX0492@P02069RHP0@09JFUP2ATI40VIVI08^;R`2<S8`0MgMg09NGU`20
P800I6AT04A4A00b<S809RHV028R8P0C4a<01PH601LG5`806ATI0P0M7Ad01@0S8b<05aLG018B4P08
20P00@4100T0000000<01PH600P8200:2PX02`0000040=7=Z@000`3AcJT;0000000400d=3@0<30`0
2PX:00T92@802PX:00@02@T900X:2P0:2PX01`L71P0000002P0820P0;2`/0=WIf@3Ng]h0e]KF0;jn
_P2d];@0PH6104e=C@061PH80000000301PH600G5aL051@D0080820P00H061PH02PX:00O7al0820P
034a<@0Q8B4201/K6`0@038b<P0`<3009bLW02<S8`0b<S808B4Q02PX:00j>SX0ATI602XZ:P0^;Rh0
6ATI01<C4`0L71`092@T03/k>`80?3`l02D0<C4a03Hf=P0g=cL0>c/k030`<00k>c/0:BTY03`l?00/
;2`0:BTY0451@@1GEeL0N7Qh08V9R@2TY:@0RXZ:07inOP24Q8@0PH61079bLP2CTi<0PX:206=SH`11
@D407AdM024Q8@071`L02@T9014A4@0G5aL071`L01TI6@0F5QH05aLG01HF5P0D51@03`l?00P00000
00D00@4100L71`0820P02@T900`<300;000000@0dLfY00030=7=Z@/0000000<03Ph>00`<300:2PX0
0P0<30`01`092@T02PX:00X:2P0;2`/02@T900@410010@400`0000002`020P80000000@4101bLW80
gmoO0>[ZjP39bLT0`L7109fMW@1nOWh0?Shn00L0000003h00@4100<30`0>3Ph02@T901PH600L71`0
8B4Q01dM7@0P82007alO02<S8`0I6AT0;Bd]02LW9`0Q8B406ATI030`<00S8b<0:b/[02<S8`0V9RH0
=3@d05=CD`0d=3@06ATI01hN7P0D51@07alO02DU9@0L71`0:RXZ03hn?P11@D40@d=303/k>`0^;Rh0
<C4a038b<P0^;Rh0:BTY02l_;`0M7Ad0;Bd]05eMG@1hN7P0QhN707MgM`1]KFd0MGEe075aL@1TI6@0
M7Ad07IfMP1gMgL0NGUi04m?C`0W9bL07QhN00/;2`0410@02`/;01HF5P806a/K0P0F5QH00`0A4A40
3Ph>00820P070000000400820P061PH01`L700P820802@T92`0000040=7=Z@000`3AcJT;00000003
00`<300;2`/03@d=00802@T900L030`<00/;2`0;2`/02`/;00T92@071`L00`<300H0000000X01PH6
065QH@3IfMT0f=SH0<g=c@2XZ:P0WinO07IfMP19BDT01PH620000000@@061PH01`L701TI6@0>3Ph0
71`L028R8P0U9BD06a/K02HV9P0^;Rh092@T02LW9`0R8R80;Bd]01`L700W9bL0;2`/02HV9P0U9BD0
;2`/02@T900U9BD04A4A01PH600I6AT071`L01lO7`0e=CD0;Bd]030`<00o?cl0<c<c03`l?00f=SH0
ADE502`/;00[:b/08R8R01dM7@0N7Qh0DU9B06=SH`27QhL0SXj>0820P02>SXh0IFEU069RHP1MGEd0
QXJ607moO`1NGUh0EEEE02DU9@0R8R8051@D00H61P010@403Ph>018B4P0?3`l0410@00/;2`092@T0
10@400L0000000<00`<300D51@0820P00P092@T200`<30/00000103AcJT000<0dLfY2`00000400d=
3@0800h>3P0=3@d02PX:00X:2P0;2`/020P800T92@051@D200410@D0000000X00@4104A4A03De=@0
clo?0=cLg037alL0Z:RX08j>SP1[Jf/07alO2@0000007@092@T01@D501XJ6P0K6a/07QhN02@T900P
82009bLW02HV9P0P82008B4Q02DU9@0K6a/06ATI02DU9@0];Bd08B4Q02DU9@0R8R807alO024Q8@0Z
:RX06ATI01hN7P0M7Ad0820P02@T900];Bd0:BTY0080?3`l01L0<S8b03De=@0b<S809BDU020P800D
51@06QXJ02HV9P17AdL0J6QX08F5Q@1jNWX0Ph>306ATI01dM7@0N7Qh06ATI01eMGD0G5aL03lo?`0P
82006QXJ01HF5P0200L71`8030`<00@02`/;00T92@0:2PX00`<3200000001`0410@020P800P82007
1`L03@d=00X:2P0=3@d02`0000040=7=Z@000`3AcJT;0000000400X:2P0<30`02@T900`<30<02`/;
00L03@d=00/;2`0:2PX02`/;00T92@061PH00`<300L0000000X07AdM0<;2`P3Lg=`0eMGE0<C4a02I
VIT0SHf=05iNGP10@4008B4Q20000000<`020P801`L701<C4`0C4a<06a/K02@T900[:b/09bLW02DU
9@0W9bL07alO01@D500T92@05QHF02XZ:P0J6QX09bLW024Q8@0P82007AdM020P800W9bL07alO02HV
9P0D51@09RHV024Q8@0];Bd092@T03dm?@0k>c/0=cLg03Ph>00O7al04A4A00T92@0>3Ph06QXJ02/[
:`0h>3P0H61P069RHP1eMGD0L71`079bLP1nOWh0Lg=c05mOG`17AdL09bLW01`L7002020P800401DE
5@0?3`l01PH600<30`800P822000000200410@@020P800<030`<00/;2`0<30`02`0000040=7=Z@00
0`3AcJT;000000802`/;00@030`<00X:2P0:2PX030`<0P0;2`/01`0<30`02`/;00h>3P092@T020P8
00T92@061PH01`0000002`0S8b<0]kNg0=kNgP3IfMT0`/;20;>c/`2<S8`0P82005QHF00[:b/09BDU
00T0000000@06ATI01/K6`0L71`07AdM0P0R8R80<00I6AT0:b/[01TI6@0K6a/08R8R01hN7P0R8R80
6a/K02@T900/;2`08b<S028R8P0P8200<C4a02HV9P0J6QX05aLG02<S8`0W9bL0:BTY02d];@0R8R80
=3@d030`<00[:b/05ADE00d=3@0000004A4A024Q8@0R8R80>CTi04m?C`1ADE40I6AT06UYJ@1CDe<0
DU9B03hn?P0Q8B408R8R01XJ6P0K6a/08B4Q01LG5`0D51@02`/;00820PX0000000H00`<300L71`0:
2PX01`L700/;2`092@T300/;2`/00000103AcJT000<0dLfY2`0000001@0<30`02`/;00`<300;2`/0
2PX:00802`/;00T02PX:00`<300<30`02`/;00X:2P0820P02@T900H61P010@401`000000300A4A40
Rh^;0=GEe@3Ogml0`<300:f][@2ZZZX0Kfm_07alO01NGUh0?Shn00T92@L00000024030`<00<30`0>
3Ph061PH020P800N7Qh06a/K018B4P0J6QX0820P01LG5`0L71`06QXJ01lO7`0N7Qh09BDU01<C4`0/
;2`0;Rh^02`/;00W9bL0;Rh^024Q8@0R8R809bLW01XJ6P0];Bd0:2PX02/[:`0Q8B40;bl_03@d=00@
41000P071`L020020P8051@D01lO7`0I6AT06QXJ02HV9P0Y:BT0;Rh^0P0T92@0200R8R80:RXZ01hN
7P0O7al08B4Q01lO7`0B4Q801@D52@0000000`020P800`<300H61P0200P8200400/;2`092@T02PX:
00X:2P802`/;2`0000040=7=Z@000`3AcJT;0000000400T92@0<30`02PX:00/;2`803@d=0P0<30`0
2P0;2`/030`<00/;2`00000030`<00/;2`0820P01@D500@410020P870000000;04A4A03Hf=P0jNWY
0>GUi@33`l<0YjNW08n?S`1ZJVX0KVi^04A4A00C4a<02000000200h>3P804Q8B00D07AdM01`L700R
8R803`l?020P800201TI6@0X01DE5@0Y:BT09RHV024Q8@0V9RH07AdM02h^;P0R8R80:BTY02@T900_
;bl0:b/[020P800M7Ad0820P02`/;00R8R809RHV02XZ:P0U9BD05QHF01`L700G5aL0820P01XJ6P0O
7al05QHF01DE5@0<30`04a<C00T92@0H61P04a<C028R8P0H61P0820P01PH600G5aL04a<C00P820L0
000000<00@4100820P0410@00P092@T01P0820P02`/;00X:2P092@T02PX:00`<30802`/;2`000004
0=7=Z@000`3AcJT;0000008030`<01402`/;00T92@0;2`/02`/;00X:2P0>3Ph02@T900`<300=3@d0
2`/;00`<300:2PX03@d=00X:2P0410@01@D500820P060000000=00@4100P8200^[Zj0<c<c03MgMd0
bLW90:ZZZP2b/[80RXZ:07=cL`1HF5P0;bl_00820P090000000;00T92@0B4Q804a<C02@T900H61P0
5aLG02/[:`0H61P09RHV02<S8`0V9RH00P0I6AT08P0O7al09RHV02DU9@0^;Rh09RHV020P800R8R80
:2PX020P800J6QX092@T01XJ6P0[:b/09BDU02PX:00W9bL09RHV030`<00T92@05ADE018B4P0F5QH0
3@d=01TI6@0C4a<010@400/;2`0A4A4051@D01PH600D51@04a<C01DE5@061PH70000000400410@00
000010@400H61P8020P800H02`/;00T92@0;2`/02@T900`<300=3@d200/;2`/00000103AcJT000<0
dLfY2`0000002`0;2`/030`<00`<300;2`/02PX:00`<300;2`/030`<00X:2P0>3Ph030`<00802`/;
00@030`<00T92@0;2`/02@T90P071`L00`0000000@41000000060000000<0451@@2n_[h0fMWI0>?S
h`3>c/h0];Bd09bLW029RHT0OGem069RHP0Q8B401PH61`00000050092@T04Q8B00l?3`0C4a<0820P
01HF5P0S8b<0820P01dM7@0E5AD06QXJ01lO7`0Q8B40820P01/K6`0Y:BT0:b/[02LW9`0`<3009bLW
0P0R8R801P0U9BD0820P01@D500Q8B40;2`/02XZ:P80:2PX00h0;2`/02/[:`0P82009RHV020P800I
6AT06a/K01TI6@0M7Ad04A4A00l?3`0820P030`<010@40802@T92000000200D51@0<00L71`0820P0
2@T900/;2`092@T03Ph>00X:2P0;2`/03@d=00X:2P0<30`02`/;2`0000040=7=Z@000`3AcJT;0000
000700/;2`0<30`03Ph>00T92@0=3@d030`<00/;2`0200X:2P0500`<30092@T03@d=00X:2P092@T0
0P0<30`01P0820P02@T900D51@030`<0000000410@L0000000`0<S8b0;jn_P3[jn/0dM7A0=GEe@2E
UID0XJ6Q096AT@29RHT0K6a/03Ph>00A4A480000000800L71`0C4a<051@D01HF5P0S8b<071`L01lO
7`0I6AT2024Q8@0C01/K6`0Q8B40820P02<S8`0W9bL09RHV02d];@0/;2`0:BTY02<S8`0W9bL0:RXZ
01`L700J6QX08b<S01`L700T92@0820P01lO7`0202TY:@0502@T900Q8B40410@01DE5@0F5QH00P0B
4Q801P0@410030`<00D51@0;2`/01`L700H61PH0000000<010@400410@071`L00P071`L200/;2`09
00T92@0;2`/02@T900/;2`0>3Ph03@d=00T92@0820P030`<00/00000103AcJT000<0dLfY2`000000
2`0;2`/02PX:00`<300;2`/02PX:00d=3@092@T02PX:00T92@0:2PX03@d=00802`/;00<02PX:00/;
2`0;2`/00P0:2PX010092@T020P800@410010@490000000=05aLG02c/k<0hn?S0>;RhP2n_[h0^k^k
0<;2`P2TY:@0TY:B07QhN010@4006ATI00H61P060000000;00d=3@0F5QH04a<C01dM7@0E5AD06a/K
02/[:`0J6QX05QHF024Q8@0D51@00P0K6a/04`0G5aL09BDU02DU9@0S8b<09bLW038b<P0Y:BT0:2PX
024Q8@0X:2P06ATI01DE5@0O7al07QhN02HV9P0U9BD092@T02HV9P0M7Ad00P0I6AT01`0E5AD04a<C
00/;2`0;2`/02@T900P820030`<01`00000200410@0?00@410071`L020P800T92@0:2PX02@T900d=
3@092@T02`/;00P8200<30`02`/;00d=3@0;2`/030`<00/00000103AcJT000<0dLfY2`0000000`0;
2`/02PX:00`<300200/;2`802PX:00P02`/;00d=3@0<30`02`/;00d=3@092@T02`/;00X:2P<02`/;
00H02@T900X:2P0=3@d01@D500H61P020P890000000>05MGE`38b<P0h^;R0>[ZjP3Kfm/0a/K60<?3
``2b/[80VIVI075aL@1<C4`092@T00P820020P830000000F00P8200=3@d03`l?01`L700@41003Ph>
01<C4`0?3`l051@D02@T900C4a<051@D01<C4`0R8R806ATI02TY:@0E5AD09RHV01hN7P0I6AT07alO
02DU9@8092@T01005ADE01PH600J6QX07AdM020P800H61P08B4Q01lO7`0F5QH061PH01DE5@0C4a<0
2`/;00L71`0820P00@411`00000200410@0600H61P0820P02`/;00T92@0:2PX01`L70P0<30`00`0:
2PX030`<00P8200200/;2`0300X:2P0;2`/02`/;00/00000103AcJT000<0dLfY2`00000200`<3003
00X:2P0=3@d03@d=008030`<00D02@T900/;2`0;2`/02PX:00`<300300/;2`0900`<300=3@d030`<
00`<300=3@d02@T900H61P0:2PX010@400X0000000<00@41061PH02l_;`00P3_knl07`3[jn/0f=SH
0<?3``2/[:`0[jn_075aL@0i>CT092@T00P820061PH00@4100D51@0<30`02PX:018B4P0E5AD071`L
028R8P0N7Qh06a/K01XJ6P0M7Ad071`L01XJ6P0M7Ad05ADE01/K6`0M7Ad0820P01XJ6P0I6AT00P0O
7al0100S8b<07QhN01`L700G5aL201/K6`806ATI00P06a/K01HF5P0J6QX04A4A00D51@030`<010@4
00820PP0000000`01@D500@410051@D01`L700P8200:2PX030`<00T92@0;2`/02@T900X:2P0820P4
00`<300300T92@0<30`030`<00/00000103AcJT000<0dLfY2`0000000`0:2PX030`<00`<300300/;
2`0600d=3@092@T030`<00`<300:2PX030`<0P0:2PX00`0<30`02PX:00`<300200d=3@0800`<300;
2`/02PX:00T92@0820P01PH600T92@030`<:0000000L03<c<`2^[Zh0dm?C0?7al@3UiND0dm?C0<k>
cP2n_[h0SHf=04Q8B00o?cl08B4Q01PH600B4Q805QHF01<C4`0D51@03`l?01/K6`0J6QX08B4Q020P
800T92@06a/K00l?3`0L71`05ADE01LG5`807alO00T07AdM01hN7P0K6a/061PH028R8P0Q8B406QXJ
01TI6@0G5aL00P0F5QH0100E5AD04A4A01PH60092@T200P820800P821`0000003@020P800@410082
0P020P801@D500P820071`L020P800/;2`092@T03@d=00X:2P0;2`/00P0:2PX01`0<30`02`/;00/;
2`0<30`03@d=00X:2P092@T02`0000040=7=Z@000`3AcJT;000000<030`<00H02PX:00/;2`0<30`0
2PX:00d=3@0<30`200/;2`0800d=3@0<30`02`/;00X:2P092@T02PX:00/;2`0<30`200h>3P0800d=
3@0;2`/02@T900L71`092@T00`<300410@020P890000000A00@4100l?3`0YZJV0=GEe@3Vi^H0inOW
0>;RhP3=cLd0XJ6Q0820P01KFe/0>c/k03Ph>00S8b<08B4Q01DE5@0T92@00P0N7Qh02P0P82007alO
01lO7`0[:b/07alO024Q8@0J6QX051@D01HF5P0L71`201TI6@0?01@D500I6AT06QXJ024Q8@0L71`0
5aLG01HF5P0E5AD051@D010@400<30`02@T900l?3`071`L01@D500H0000000<00P8200410@010@40
0P051@D0100820P01PH600P8200820P200/;2`0300X:2P0;2`/02PX:00802`/;00D02@T900`<300=
3@d02`/;00T92@0200X:2P0300/;2`0:2PX0000000X00000103AcJT000<0dLfY2`000000100:2PX0
30`<00/;2`0:2PX200`<300800d=3@0;2`/02PX:00d=3@0;2`/02PX:00/;2`0=3@d300X:2P0500T9
2@0;2`/02`/;00/;2`0=3@d00P0:2PX01@0;2`/02@T900X:2P030`<01`L700`0000000l03Ph>04];
B`2JVYX0eMGE0>OWi`3Ng]h0f=SH0;2`/01dM7@0KVi^05EEE@14A4@0@41002h^;P0`<3000P0Z:RX0
1P0W9bL0;Rh^02TY:@0S8b<08R8R02@T90807AdM00T05QHF01/K6`0I6AT051@D01PH600J6QX05ADE
018B4P0A4A400`0@41001@0<30`01@D500H61P0410@00P8200H0000000H00@4100@410020P801PH6
00L71`061PH200P8200800L71`0;2`/02`/;00d=3@092@T02PX:00/;2`0:2PX200/;2`8030`<00H0
2`/;00X:2P0:2PX02`/;00`<300:2PX;000000@0dLfY00030=7=Z@/0000000D02PX:00/;2`0<30`0
2`/;00X:2P0200/;2`0:00d=3@0<30`030`<00X:2P0;2`/02PX:00/;2`0<30`02PX:00/;2`802PX:
00`02`/;00`<300<30`02@T900P8200;2`/02@T900/;2`092@T01`L700H61P020P8=0000000N00P8
200g=cL0P8200:j^[P31`L40[jn_092@T01kNg/0IfMW05=CD`1;Bd/0@D510410@00m?Cd0=SHf034a
<@0Z:RX0;bl_02HV9P0P82006a/K01dM7@0L71`05ADE018B4P0G5aL05QHF014A4@0?3`l05QHF0P0>
3Ph200/;2`0300H61P000000000000D000000`020P802`030`<01PH600L71`071`L01PH600X:2P08
20P030`<00X:2P0;2`/02@T900<02PX:00<02`/;00X:2P0;2`/00`0;2`/200X:2P0400T92@0<30`0
2PX:00/;2`/00000103AcJT000<0dLfY2`0000001`0<30`02@T900`<300;2`/02PX:00`<300;2`/0
0P0>3Ph01@0;2`/02PX:00/;2`0;2`/020P8008030`<00@02`/;00`<30092@T02PX:0`0;2`/02P0:
2PX02`/;00/;2`092@T020P800X:2P071`L02@T900<30`061PH?0000000900/;2`0X:2P0C4a<05UI
F@1/K6`0Hf=S061PH01DE5@0ATI60080@41000P0=CDe03Lg=`0`<300;2`/02TY:@0V9RH08B4Q01@D
50805ADE0P0?3`l01P0>3Ph02PX:00X:2P0410@0000000<30`<0000000X00P82000000010@400P82
00410@051@D010@400L71`0410@020P80P092@T01`0:2PX02`/;00X:2P0<30`02@T900P8200:2PX0
0P0;2`/200`<30802`/;00X02@T900X:2P0;2`/030`<00d=3@0>3Ph02`/;00X:2P0<30`02`/;2`00
00040=7=Z@000`3AcJT;000000802`/;00T030`<00/;2`0;2`/02`/;00X:2P0;2`/030`<00/;2`0=
3@d00P0;2`/02@0:2PX030`<00`<300=3@d02`/;00h>3P0:2PX030`<00d=3@0200`<300800X:2P0<
30`02PX:00/;2`0<30`02`/;00X:2P071`L200H61P0300820P000000000000l000000P0410@07`0D
51@0;2`/03/k>`0a<C40>3Ph03@d=00V9RH0;Bd]02DU9@0S8b<06a/K01LG5`0A4A403`l?00P82007
1`L010@4010@400000000P8200@410020P80000000820P0000000`<300820P030`<00P8200@41003
0`<00P061PH01`051@D020P800L71`0:2PX02`/;00T92@0:2PX00P092@T0100;2`/030`<00T92@0<
30`200X:2P0300/;2`092@T030`<00803Ph>00<02@T900X:2P0<30`00`0=3@d00`0:2PX02`/;0000
000:000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@00T03AcJT00900dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {355.25, 212.25}} -> {-689.508, 785.146, \
3.75948, 3.75948}}]
}, Open  ]],

Cell["\<\
It is possible to save this result to a FITS file for future use:\
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[
    \(\(saveFITS["\<restored.fits\>", \ res\_FITS, \ 
        DataType\  -> \ \(-32\)];\)\)], "Input"],

Cell[TextData[{
  "The option ",
  StyleBox["DataType",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the format according to which the image values are stored; \
available formats are: unsigned 8\[Dash]bit integers (8); 2's complement 16\
\[Dash]bit integers (16); 2's complement 32\[Dash]bit integers (32); IEEE754 \
32\[Dash]bit reals (-32); IEEE754 64\[Dash]bit reals (-64)."
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Inverse Filter Estimation", "Subsection"],

Cell["\<\
The aim of this experiment is to test the effectiveness of the \
restoration when an inverse filter estimate is available by means of a guide \
star. The true image for the guide star is simulated as a small white point \
in a black background:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({m\_\(y, \ star\), \ m\_\(x, \ star\)}\  = \ {127, \ 
          127};\)\), "\[IndentingNewLine]", 
    \(\(f\&^\_star\  = \ 
        Table[If[i^2\  + \ j^2\  < \ 10, \ 1, \ 
            0], \ {i, \ \(-m\_\(y, \ star\)\), \ 
            m\_\(y, \ star\)}, \ {j, \ \(-\ m\_\(x, \ star\)\), \ 
            m\_\(x, \ star\)}];\)\), "\[IndentingNewLine]", 
    \(\(f\&^\_star\  /= \ 
        Apply[Plus, \ f\&^\_star, \ {0, \ 1}];\)\), "\[IndentingNewLine]", 
    \(\(showImage[f\&^\_star];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000FFFFFFFFFFFFFF00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000FFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000FF00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY
R@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZD<000000`3ooom3000000@0dLfY00030=7=ZD<000000`3ooom3000000@0
dLfY00030=7=ZD<000000`3ooom3000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY
R@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY002@0=7=Z@00T03AcJT00900dLfY002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {747.875, 604.875}} -> {-343.407, 1126.19, \
1.87239, 1.87239}}]
}, Open  ]],

Cell["\<\
The extended original image of a satellite is downloaded from the \
Internet [10] and saved to disk as a FITS file:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f\&^\_sat\  = \ \(readFITS["\<satellite.fits\>"]\)[\([2]\)];\)\), "\
\[IndentingNewLine]", 
    \(\({len\_\(y, \ sat\), \ len\_\(x, \ sat\)}\  = \ 
        Dimensions[f\&^\_sat];\)\), "\[IndentingNewLine]", 
    \(\(showImage[f\&^\_sat];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000081204000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000037606559260000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000256D83877F5F0C00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000427A8F928B6F2000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000002F73888C84661700000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000A4F6D7667360000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000051F7119000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000043000000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000034130000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000450000007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001F1C00007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000003C00007100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001C1F007100000000000000000000000000000000
000000000000000000000000000000001B28000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000045007100000000000000000000000000000000
000000000000000000000000000000214500000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000013357100000000000000000000000000000000
000000000000000000000000000022220000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000427100000000000000000000000000000000
000000000000000000000000003122000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007500000000000000000000000000000000
0000000000000000000000004F1E00000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000713A000000000000000000000000000000
00000000000000000000004B150000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000071370E0000000000000000000000000000
000000000000000000004500000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100470000000000000000000000000000
000000000000000013470000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100241A00000000000000000000000000
000000000000001D50000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000046565400000000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100003C00000000000000000000000000
000000000000213600000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000001E007642340000000000000000000000000000000000000000000000
000000000000000000000000000000000000007100001D1F000000000000000000000000
000000000022220000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000012000E0030452D0000000000000000000000000000000000000000
00000000000000000000000000000000000000710000003B000000000000000000000000
000000004021000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000020500000000000000000000000000000000000000000000000000000000
00000000000000000046000048001A005834000000000000000000000000000000000000
000000000000000000000000000000000000408A20000016310000000000000000000000
000000511C00000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000070D26000000000000000000000000000000000000000000000000000000
0000000000000000001D39383E2400003A00515200000000000000000000000000000000
00000000000000000000000000000000000081A4410000004700000000003A0000000000
0000430F0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000B59630000000000000000000000000000000000000000000000000000
00000000000000000013194D7A7C19000033000034330000000000000000000000000000
00000000000000000000000000000000000093A54A000000003A000000003D0000000000
004400000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000004493506300000000000000000000000000000000000000000000000000
0000000000130000003389B2A2AD66190000340019005E39000000000000000000000000
00000000000000000000000000004889BCC6C6C6C6C6B263213A00000000410000000017
4F0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000066934C32000000000000000000000000000000000000000000000000
00000000168E27246E929BB2C2CB7F661900005300001C00383C00000000000000000000
0000000000000000000000002285C6C6D3E1E2E3E2E1C6C67F723E0000003F0000001F4C
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000066644C320000000000000000000000000000000000000000000000
0000000094C69C92929388C5D2CBCB654C1A00260000000033206A000000000000000000
0000000000000000000000319AC6CEE5F7ECFFFFEFFBF4E3A6B899120010330000222D00
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000726F3A3200000000000000000000000000000000000000000000
0000000031C6AD9B8D88A75F7808A1E7864C3C00400000360035003B4C00000000000000
0000000000000000000023C6A3D1CCC29EA3A5A6A5A29CBFB4AFC846003A000026220000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000945D9C18000000000000000000000000000000000000000000
000000003CB5CE629790A4520B3907E7C9684C3E0000001B000003000053350000000000
00000000000000000000558FC3938D979EA3A5A6A5A29C94898DBB8E2B3D004A20000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000022945D81180000000000000000000000000000000000000000
0000000000F2F286647AA470463D0D77E7C968AFAF805757000037001900323C00000000
00000000000000000000A1B87E7F8D979E9B969695A29C948962788D8266621900000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000022945D811800000000000000000000000000000000000000
0000000000B5F2CE4B7CA8A2460F0D3EE7E7E2B2AFAFAFAFAF710C46000000534C3B0000
00000000000000000020CB696C7F85807F84868685837D85817C567CC63F000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000022945B6700000000000000000000000000000000000000
00000000003CF2F2BA8BB9A4200B0770E7E7E7E7E7D2CECBB68E4C000000000028006A0D
0000000000000000001FA6516C686F798084868685837E766B6A69458F33000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000227D4367000000000000000000000000000000000000
000000000000B5F2AACBCBCB620F0D77E7E7E7E7E7E7E7E7E7C9684C380000002C00003C
3400000000000000008794494F63707A8084868686837E776D5E6E656400000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000229331670000000000000000000000000000000000
0000000000003C8F1632CBCB3E2A72B1E7E7E7E7E7E7E7E7E7E7C968555B000022540019
003D000000000000183C3F3D5466727A8084868686837F786F6156524700000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000004493507E00000000000000000000000000000000
0000000000000000000039E7E7C0E7E7C2E7E7E7E7E7E7E7E7E7E7E2644B222200538300
223C000000000000231A293F5969747B8184868786837F79706459316900000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000066935063000000000000000000000000000000
00000000000000000000007FE7E7E7E7E7D9E7E7E7E7E7E7E7E7E7E7C66470553B004453
0000220000000000343E15465C6B757C818486878684807A72675749532E000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000066934E4B0000000000000000000000000000
0000000000000000000005E7E7E7E7E7E7E3B0E7E7E7E7E7E7E7E7E7E7C69E236644314E
22600022000000003653264C606D767D818586878684807B73695A51321A000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000066934C3200000000000000000000000000
000000000000000000000BE7BBE7E7E7E7E7B9DCE7E7E7E7E7E7E7E7E7E7A89468135353
344522000022003B571F3451626E777D828586878684817B756B5E624438000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000049924C00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000066874C32000000000000000000000000
000000000000000000003FE7E7EDE7E7E7E7B0E7E7E7E7E7E7E7E7E7E7E7E78A946B005A
22000053530053583F0C3D566570787E828586878684817C766D61674D14000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000049929295684C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000725D3A320000000000000000000000
0000000000000000000073E7E7E7E4E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7A4625331
3B586000535300701815455967718A99A6A8AAAAAAA8A58F7F6E635551563D0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000049929295BFE7C9824C0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000022945D811800000000000000000000
0000000000000000000000E7E7E7E7CDE7E7E7E7E7CEBCE7E7E7E7E7E7E7E7E7E786623B
3A0060220022731823424A5C7B959DA2A6A8AAAAAAA8A5A09A9377694630360000000000
000000000000000000000000000000000000000000000000000000000000005158582C00
0000246E9295BFE7E7E7E7C6665E12000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000044A0339600000000000000000000
000000000000000000000073E7E7E7E7E7E7E7E7E7E7BDE7E7E7E7E7E7E7E7E7E7E76662
00443F004463002144324E818C959DA2A6A8AA00AAA8A5A09A9389655E1F690000000000
00000000000000000000000000000000000000000000000000000000000092A2B1B1B1B1
B1A29292B4E7E7E7E7E7E7E7A6769D450000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000066935063000000000000000000
000000000000000000000000ADE7E7E7E7E7E7E7E7E7B2BDE7E7E7E7E7E7E7E7E7E7C694
39003E2222006F87054A6A818C959DA2A6A8AAAAAAA8A5A09A9372735A391E0000000000
00000000000000000000000000000000000000000000000000000000499292ABB1B1B1B1
B1A292AADEBEE4E7E7E7E7E7E78D7A480000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000066934C320000000000000000
00000000000000000000000022ADE7E7E7D2E7E7E7E7D6E1E7E7E7E7E7E7E7E7E7E7E7C6
94223F00536A36452C5873818C959DA2A6A8AAAAAAA8A5A09A93857D6E65043100000000
000000000000000000000000000000000000000000000000000049929295CEE7E7E7DDD3
CFC4C8CAD1C1DCE4E7E7E7E7E7E79D790000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000066644C3200000000000000
0000000000000000000000005353ADE7E7E7E5E7E7E7E7E7D6E7E7E7E7E7E7E7E7E7E7E7
8A94552200455318306C79818C959DA2A6A8AAAAAAA8A5A09A93667D6E733B1900000000
00000000000000000000000000000000000000000000000049929295BFD6E7E7E7E7E7E7
E2D9CAD1A7D6D7DCE4E7E7E7E7E7C9350000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000726F3A32000000000000
000000000000000000000022002253ADE7E7E7ECE7E7E7E7E7B69BE7E7E7E7E7E8E7E7E7
E78A6219449F3E53776177848C959DA2A6A8AAAAAAA8A5A09A937E7D6E5FAF9830000000
00000000000000000000000000000000000000000000246E9295BFDDC5E7E7E7E7E7E2CB
D5C8B4A0BFB0D5D7DCE4E7E7E7E773000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000945D9C180000000000
00000000000000000000000044310022ADE7E7E7B6E7E7E7E7E7AEE7E7E7E7C3BBE7E7E7
E7E7A26219637314566A738282959DA2A5C8D5CBA5A8A5A1C8C7877D7E7B3CB859000000
0000000000000000000000000000000000000000246E9292CDE9E6E7E7E7E7E7D4D9D5C0
C2BBC2D5C6B4B0D5CFDCE4E7AD3900000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000022945D811800000000
000000000000000000000022005353005BE7E7E7E7E7E7E7E7E7BED7E7E7E7A2E7E7E7E7
E7E7E7866B5D827848618AA2C5AE84A2A6A8AAAAAAA8A5A09A767C7D6E5A951308000000
000000000000000000000000000000000000246E9292AAC9E6E7E7E7E7E7E7B1B8B8C0BB
BBBBBBC2D5C685A990B2A339000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000022945D8118000000
000000000000000000000022440022530039E7E7E7E7E7E7E7E7E7E7D0CADEC1E7E7E7E7
E7E7E7E79E8389145A6C73949A959DA2A6A8AAAAAAA8A5A09A8A897D72543C4222000000
00000000000000000000000000000000006E9292AAA6C2E7E7E7E7E7E7DED5D59098BBBB
BBBBBBBBC2BEA78AC26B0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000022945B67000000
00000000000000000000000022533100222239E7E7E7E7D9E7E7E7E7E7E4BCDEE7E7E7E7
E7E7E7E7E79E7B37486A77818B959DA2A6A8AAAAAAA8A5A09A69898B785A3C0760000000
000000000000000000000000000000499292B8D2D7E7E7E7E7E7E7CFD5D5ACAAC0BBBBBB
BBBBBBBBBBC1B4542A000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000227D43670000
000000000000000000000000220053220022446BE7E7E7E6EBE7E7E7E7E78DE7E7E7E7E7
E7E7E7E7E7C98075716173859B95796D5F61626262605E6B7783898E6E5A3C0744000000
00000000000000000000000000499292A7D3E9E7E7E7E7E7E7C1D5B8C6AAB8CEBBBBBBBB
BBBBBBBBD2D2C8DE00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000002293316700
00000000000000000000000022530000222200446BE7E7E7EAE4E7E7E7E7CBE7E7E7E7E7
E7E7E7E7E7E7C962848A79816E51575C5F61626262615E5B5563677D6E5A3C1F00000000
000000000000000000000049929295A9E0E7E7E7E7E7E7E7D9BB937B9FD5BFBBBBBBBBBB
BBBBC7C9AB91EF9700000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000044935063
00000000000000000000000000002222002222005395E7E7E7D5E7E7E7E7D6E7E7E7D6D0
D9C6E7E7E7E7E7E2646477744B53595D6061626262615F5C5852484C5D5A3C6200470000
000000000000000000246E9295BFCEE7E7E7E7E7E7E7E7E7E7BCB8AD9FB3BBBBBBBBBBBB
BBCCCFAC9DDADC3700000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000669350
63000000000000000000000000530022220022440022DEE7E7E7E7E7E7E7E7E7CCB29EA8
AAA4A5C8E7E7E7E7C66F4F556D555A5D6062626262615F5C6C534C4130493C07388A3500
00000000000000246E92A3C9E8E0E7E7E7E7E7E7E7E7E7E7E7C9BB98C2BBBBBBBBBBBBBB
CDD6D6A4CEDE000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000006693
4E4B000000000000000000000000530022220022533100CFE7E7E7E7E7E7E7C1868CA9A8
AAAF977FB8E7E7E7E7C6945851575B82848586868685836F5A554F463A323C075A20633C
0000000000246E9292AAE4E9E7E7E7E7E7E7E7E7E7E7E7E7E7E7C9C2BBBBBBBBBBBBBBC8
B6D1A6A2DE73000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000066
934C32000000000000000000000022530000222200532200ADE7E7E7C0E7E79481ABB5CB
CBCBB19054E0E7E7E7E79E44769FA3A5A8A9AAAAAAA9A7A58B8C754A403126071C4F2500
4C3B00246E9292AAD4B9E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7D9C6BBBBBBBBBBBBBBC4CE
E3B9E5A50000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
666F4C32000000000000000000000000222200445300225331ADE7E7E7EDE7A8B0CBCBCB
CBCBCBCB8FD9E7E7E7E7E76A849FA3A5A8A9AAAAAAA9A7A58D9D98926739240750920051
0000819292AAC9C6E7E5E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7D1BBBBBBBBBBBBBBC8BAD4
CEB170000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00725D3A32000000000000000000000000222200004431002222ADE7E7E7E2A8CBCBCBCB
CBCBCBCBA9D9E7E7E7E7E7BD589FA3A5A8A9AAAAAAA9A77F8E9D98928B71421028560000
519292A7E2ECE7E7E7DFE7E7E7E7E7E7E7E7E7E7E7E7E7E7E7C0C6BBBBBBBBBBE9F4CCDD
370000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0022945D8118000000000000000000000000002222002222002244E7E7E7E7CBCBCBCBCB
CBCBCBCBCBD9E7E7E7E7E7E76A88A3A5A8A9AAAAAAA9A792A19D98928B837936036E003B
7695BFE7E7E7E9E7E7B5C6E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7C6BBBBBBBEF2ADD92C
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000022945D811800000000000000000000000000535300222200226BE7E7E7D9CBCBCBCB
CBCBCBCBCBE0E7E7E7E7E7E7BD59A3A5A8A9AAAAAAA9A76DA19D98928B83796D24775876
97E7E7E7E7E7E19EA39787A2A2B5E7E7E7E7E7E7E7E7E7E7E7E7E7E1C6BBD2D139811300
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000022945D7F0000000000000000000000000000225300002222008DE7E7E0CBCBCBCB
CBCBCBCBD2E7E7E7E7E7E7E7E76AA3A5A8A9AAAAAAA9A78DA19D98928B83796D5E5876B1
E7E7E7E7E7E7B7B298AABBAB9782B7D2E7E7E7E7E7E7E7E7E7E7E7E7E1CD8F2699000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000229443670000000000000000000000000000002222004453005BE7E7E0CBCBCB
CBCBCBD2E7E7E7E7E7E7E7E7E7BD70A5A8A98D7D7BA97E5BA19D98928B8379707176CAE7
E7E7E7E7E7B56192AFB4BEB4AE95A8DFE7E7E7E7E7E7E7E7E7E7E7E77353003C00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000002288436700000000000000000000000000000000220022533139E7E7E7E0DD
E1D9E0E7E7E7E7E7E7E7E7E7E7DEACA5A88B698E87508780586679928B87797679E2E7E7
E7E7E7E7E78979C6C6C6C6C6C6C67485E7E7C9E7E7E7E7E7E7E773000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000022931F9800000000000000000000000000000000000000002239E7E7E7E7
E7E7E7E7E7E7E7E7E7E7E7DECEC6B19C98AFB8B0AFC6C6B5A8A3769280BC9892CDE7E7E7
E7E7E7E7E7B0C6C6C6C6C6C6C6C6C6D6E7E7E7E0E7E7E7E7AD0000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000006693506300000000000000000000000000000000000000000039ADE7E7
E7E7E7E7E7E7E7E7E7CFB3B0C68887A7C6C66D88869AC6B6989DAC7F8B9FCBE7E7E7E7E7
E7E7E7E7E7D6C6C6C6C6C6C6C6C6C6D6E7E7E7E8DEE7AD39000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000669350630000000000000000000000000000000000000000000073E7
E7E7E7E7E7E7E7E7B191C1C6C6A6B6C6C6C68A7E7B9FC6757567A7AC979CC6CEE7E7E7E7
E7E7E7E7E7C1C6C6C6C6C6C6C6C6C6D6DED4E9E7AD390000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000066934E4B0000000000000000000000000000000000000000000039
E7E7E7E7E7E7A58FB8C6C6B6B6C6C6C6C6C6C6C6C6C6C6C68DBCC6C6B380A0C69AE7E7E7
E7E7E7E7E7E9C6C6C6C6C6C6C6C6C6B9D8E7AD3900000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000667C4C3200000000000000000000000000000000000000000000
00ADE7E7D6C69DC6C6C6B6C6C6C6C6C69B9B9B9B9B9BB0C6C6C6C6C6C6B6C6CA779CE7E7
E7E7E7E7E7E7DEC6C6C6C6C6C6C6D4C3E78C680000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000666F3A32000000000000000000000000000000000000000000
0065E4C2A58D7E88C6C6C6C6C69B7B818787878787878781909BC6C6C6C6C6C6BE54BBE7
E7E7E7E7E7E7E7E4CFD6D6CED9E6E7884700006E00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000725D6B180000000000000000000000000000000000000000
00004C0D3A759DC6C6C6C68A7F8479756667675E6767716F79847A9BC6C6C6C6C6A62EAD
E7E7E7E7E7E7E7E7D5A3DEE7E7A71B002A00000061400000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000022945D811800000000000000000000000000000000000000
0000325A91C6C6C6C6B078817561695B5D5D5D5E5D5D5D5D626574808AC6C6C692C69D66
CFE7E7E7E7E7E7E7E7D7D4732114373C00580000383C3300000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000022945D8118000000000000000000000000000000000000
00259EC6C6C6C6C6B07A7E5E74656E6B75797979797975645A594C6C7E89C6C6C6AC7975
C6DEE7E7E7E7E7E7735B000022001D00470026000033007A000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000022945B67000000000000000000000000000000000000
006A9999A3C6C6C6757B734C6B747B7F7F64808062807F7F77684C73577A88C6C6C67A00
94C6DEE7AD73367A3C004D00000000320038300000003500382500000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000227D43670000000000000000000000000000000000
00C6627A5BC6C68777485765787C7C467D627E7E627D615F607C7573737675B0C6C6C631
15631845000000384CA40035002100232F00193B2600344E003D20000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000002293316700000000000000000000000000000000
00C6BA78B8C6B07260577176797A5F7B7B7B7B7B7B7B7B7B5F5D7976715E7586C6C6C6C6
551800001E0000003800A4590022000028170000613B0031000044000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000044931F7E000000000000000000000000000000
63C6B1BAC6C69B715A5F7375425A78787879797979797878775C7675735E5B71C6C6C6C6
C63F3B00310000000000003C83330000142C000000000039390004000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000669350630000000000000000000000000000
63759081C6C69B6E5171725A5A7475757676696B67767675757441727171646E9BC6C6AE
AFAC174E005300000039170000937519002C2800003800004A2B2D000000000000000000
000000000000000000000000000000042000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000006693506300000000000000000000000000
94754F65C6C69B6B6B6E6F70717172737371A0A6A7587372727158706E6F6E6B9BC69584
85987D003B00290000004D0000222E873B002F0000003800003C44000000000000000000
000000120000000000000000001D2A1C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000066934C32000000000000000000000000
00B6C6C6C6C69B68716B6C3D6E6E6F6F7097C7CFBC8E706F6F6E556C6B546C6CB0C6AD84
869D003300007D3119000000000000363DA2002300000000240000000000000000000000
001E23000000000000000023210000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000066644C320000000000000000537CA6
8883B0A5B2BCB06871546869536B6C6C99A8F2FCE8B56C6C6C6B3C5468386B6AC6C6C6C6
C6C6453B2646457D42403E7438342F292117A5801C0019460000002F0000000000000017
1900000000000000003A2400000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000726F3A3200000029537CA6A6A6AA
B6919DABA499A960712F654E506768696991D8E8D192696968514E656447699BC6AE8D96
A5631C1B3E000000390733003E19232A3034383B747942447B464766474746454442403F
4F3E4D6753524C3D3B704042000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000945D9C1853A6A6A6A6B5C6DAE7
C057947F9F727CB06C3555624C4E64656550BEC6956E6565644E4E623A476CC6C6A7626F
6D9F0019002D000000000036000000000038001900938B0000170000000000000000001B
2B3400000000000000390000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000022945D8195A6BACADAE7E7E7E7
E75F8FAA9A6BC6C6805E53565F6037616162ADC6946261614B4C5E4D2E71B0C6C6C6BCB4
94314A3A002B2A00003800003C572200000F0A0000004E95393300310000000000000000
00002323000000000000181E000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000004990945D7FC5E7E7E7E7E7E7E7
E7E75E686C7BC6C6C6865359525B5C345D495D5D5D495D485C5B4A3B61B0C6C6C6C6B6D0
A200000068162E000000380024004E3A0018390000002900387870430000000000000000
000000000000000000000000320000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000049929295BA945BA1E7E7E7E7E7E7E7
E7E798A4611994C6C6C68658484F565858465959595858585D455364B0C6C6C6C6A7B6C1
88210000003C3F250000180F000000007500003900000053000091630000000000000000
000000000000000000000000001A1A000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000024929295BFE7E7CF8843A1E7E7E7E7E7E7
E7E7E7966366449DC6C6C69B675854585B595A5A595B5A57615671B0C6C6C663B6C6C6C1
88866400000000693B17003700000022202B220000000000310019392100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000246E92A3BFE7E7E7E7E7CF931FA1E796B9E7E7
E7E7E7E2E786979D79C6C6C6C69B6A645B5D5E5E5E5D6064699BC6C6C66349929FAFBFE7
E7A18664210000002A5E0000360000210053003C38000000341600004300000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000246E9292AAE7E7E7E7E7E7E7E7A093506D4C3DB9E7
E7E7E7E7E7E7B0C6ACACC6C6C6C6C6B09B9B7171869B9BB0C6C6C66324929295BFE7E7E7
E7E7CE888643000000003535001300000000000037320019004A00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000246E9292AAD4E7E7E7E7E7E7E7E7E7E7A0934B645730B9
E7E7E7E7E7E7C9B0C8AEA6C6B39493B1C6C6B1ADC6C6C6C6C6B6796192A3BFE7E7E7E7E7
E7E7E7E7A1866400000000005F5D002300002D370019453C000035003300000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000499292AAD4E7E7E7E7E7E7E7E7E7E7E7E7E7A09361645730
B9E7E7E7E7E7E7A824910094886F6D83C67990899DC6C6B6A7C6C692AAE7E7E7E7E7E7E7
E7E7E7E7E7B9994C00000000003B54200000001A0000006D450004004200000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000499292A7E2E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7A07C616457
30B9E7E7E7E7AD0000000000948A87C6C67B513DA6943131C6B9B7D4E7E7E7E7E7E7E7E7
E7E7E7E7E7E7D1684C000000000000393400190065000000003700370000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000049929295D2E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7A06F6164
575DE7E7E7AD0000000000000000004863636363310000005ED4E7E7E7E7E7E7E7E7E7E7
E7E7E7E7E7E7E7C9684C0000000000000051520000000000003A003B2434000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000049929295BFE7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7AC5D64
64575DE7730000000000000000000047000000000000000000E7E7E7E7E7E7E7E7E7E7E7
B795E7E7E7E7E7E7C9824C000000000000000034343B1900003B1C1B2A42000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000246E9295BFE7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7E7CF9472
64644A3900000000000000000000001A00000000000000000073E7E7E7E7E7E7E7E7B788
888381E7E7E7E7E7E7C6664C0000000000000000002E454A001A00000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000246E9292CDE7E7E7E7E7E7E7E7E7E7DE8FC5E7E7E7E7E7E7E7E7E7E7E7E7E7E7CF94
724D3900000000000000000000001A1300000000000000000000E7E7E7E7E7E7CF888897
B6CF5F81E7E7E7E7E7E7C666330000000000000000000000343C006A0035000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
246E9292AAD4E7E7E7E7E7E7E7E7E7DE90606D62C5E7E7E7E7E7E7E7E7E7E7E7E7E7E7CF
945D0500000000000000000000002E000000000000000000000073E7E7E7E7E78897B6C6
C6C6695FC5E7E7E7E7E7E7C66619000000000000000000000000534F3242000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000006E
9292AAD4E7E7E7E7E7E7E7E7E7DEB8797FB5D76262C5E7E7E7E7E7E7E7E7E7E7E7E7AD00
229443050000000000000000000033000000000000000000000000E7E7E7E7E7B6C6C6C6
B6888DAC5FC5E7E7E7E7E7E7A86619000000000000000000000000003433000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000499292
B8D4E7E7E7E7E7E7E7E7E7DEAC6E73B0D1E6F187627EE7E7E7E7E7E7E7E7E7E7AD390000
00228843050000000000000000002D00000000000000000000000073E7E7E7E7BCC6B697
88A7C6C6AC79C5E7E7E7E7E7E78A66190000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000139295D2
E7E7E7E7E7E7E7E7E7E2B18088AACDE3F0F5F3C76262E7E7E7E7E7E7E7E7AD3900000000
000022931F0300000000000000280C00000000000000000000000000ADE7E7E7E77388A7
C6CEC6C6C6AC5FC5E7E7E7E7E7E7A4661900000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000013BFE7E7
E7E7E7E7E7E7E7E2CB9580A3CAE1EFF5F4EAD9BD8980E7E7E7E7E7E7AD39000000000000
00000066931F010000000000002D000000000000000000000000000039E7E7E7E7CFDEC6
B6C6ADC6C6C6AC5FC5E7E7E7E7E7E7866619000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000086E7E7E7
E7E7E7E7E7E2CB90779DC5DFEEF5F4ECDCC1957FAFE7E7E7E7E7E7390000000000000000
0000000066931F0100000000002E00000000000000000000000000000039E7E7E7E7E7D6
C6C6CAC5C6C6C6AC5FC5E7E7E7E7E7E7864C000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000987E7E7E7
E7E7E7E7CB906B95C1DCECF4F5EEDFC69D8ABAE7E7E7E7E7E77300000000000000000000
000000000066931B010000000C280000000000000000000000000000000039E7E7E7E7E7
CEC6A1A3D6ADC6C67981E7E7E7E7E7E7E7864C0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000037E7E7E7E7
E7E7E7CB838DBCD9EAF3F5EFE1CAA493BFE7E7E7E7E7E773000000000000000000000000
000000000000667C1B0100002D00000000000000000000000000000000000039E7E7E7E7
E7CEC6C1AAC6C6C6C67981E7E7E7E7E7E7C9684C00000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000246E8CE7E7E7E7
A34ABA83B7D6E9F3F5F0E4CEAA9BC4E7E7E7E7E7E7730000000000000000000000000000
00000000000000726F090100330000000000000000000000000000000000000039E7E7E7
E7E7CEC6C6D5CAC6B6975FA3E7E7E7E7E7E7C9684C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000246E9292D2E7E7E768
714A36D2E7F2F5F1E6D1B07495E7E7E7E7E7E7AD39000000000000000000000000000000
0000000000000000945D07002E000000000000000000000000000000000000000039E7E7
E7E7E7CEC6AA9B9788A792BCE7E7E7E7E7E7E7E2664C0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000246E9292AAE7E7E7E7E7C9
71423694F5F2E8D5B6809FE7E7E7E7E7E7AD390000000000000000000000000000000000
000000000000000022945D071B000000000000000000000000000000000000000000ADE7
E7E7E7E7BF9788A7C6CEDEE7E7E7E7E7E7E7E7E7C6664C00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000006E9292AAD4E7E7E7E7E7E7E7
C95F4536EAD8BB8AA7E7E7E7E7E7E7AD3900000000000000000000000000000000000000
00000000000000000022945D0700000000000000000000000000000000000000000000AD
E7E7E7E7B797C6CEDEE7E7E7E7E7E7E7E7BEC5E7E7C66619000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000009292A5D4E7E7E7E7E7E7E7E7E7
E78E71455B9378E7E7E7E7E7E7E739000000000000000000000000000000000000000000
0000000000000000000022945B0500000000000000000000000000000000000000000000
ADE7E7E7E7DEDEE7E7E7E7E7E7E7E7CFBFD6D6D6C59BC666190000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000024A7E2D0A2C5E7E7E7E7E7E7E7E7
E7E7C95645E7E7E7E7E7E7E7730000000000000000000000000000000000000000000000
0000000000000000000000507D4305000000000000000000000000000000000000000000
00ADE7E7E7E7E7E7E7E7E7E7E7CFB4B3D6D6D6C3E7CEDE8A661900000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000024C2E78BB9E7E7E7E7E7E7E7E7E7
E7E7E7C0C9E7E7E7E7E77300000000000000000000000000000000000000000000000000
00000000000000000000260E229331050000000000000000000000000000000000000000
0000ADE7E7E7E7E7E7E7E7CFAEAEBFB8B7D5D5D1C1C0B4DE8A6619000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000065B8E7C96361B3E7E7E7E7E7E7
AD7373E7E7E7E7E773000000000000000000000000000000000000000000000000000000
000000000000000000002C000044931F0100000000000000000000000000000000000000
000000ADE7E7E7E7E7E7AF98C3C1D5AABDD5D5D57ED5B5AFDEA266190000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000055E099636296E7E7E7E7AD39
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000003300000066931F01000000000000000000000000000000000000
00000039E7E7E7E7C7BFB2ADA2C3D578893C48485C8A92AF8CC586660000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000088CBC24941B2BEE7E7730000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000082A0000000066931F010000000000000000000000000000000000
0000000039E7E7E7D6E7A894D5AC3A69717D82827D725E69D2B4C5860000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000098CB4941BB9B7300000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002C00000000000066931B0300000000000000000000000000000000
000000000039E7DEDEDEC7D55154768C9AA3A7A7A39B8D78BFE7ACC50000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000323260579B220000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000340000000000000066642F05000000000000000000000000000000
00000000000039D6DED6DE7C5C829AABB6BEC2C2BEB7AC92CDE7DED60000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000E1A700000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002E000000000000000072871F050000000000000000000000000000
0000000000000039CED6A953829EB3C1CCD3D6D6D3CCC2CCCDE7E7D60000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000111F00000000000000000089931F0100000000000000000000000000
000000000000000073CE81769AB3C5D2DCE2E5E5E2C3D4D3ADE7AE6B0000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000002F000000000000000000000066931F01000000000000000000000000
000000000000000000ADB68CABC1D2DFE8EEF1D3C4D2D5B5C5AFD6A61900000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000002E00000000000000000000000066931D010000000000000000000000
00000000000000000000ADBBACAAC4B0E2E5BEC2D5C0BAA5927381A66619000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000166F4A0000000000000000000000000066931B0100000000000000000000
0000000000000000000000ADACA7D6BBBCD5BCC4BDB6B6C692735F818666000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000352E452F3400000000000000000000000000666F1B01000000000000000000
000000000000000000000000A5CEE7DED6D6D6C7B6A792C6929D5F83A3864C0000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000001D4400001800122B00000000000000000000000000725D09000000000000000000
000000000000000000000000006BCED6D6CEBF92D59992ACAC79AC735FC5684C00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000451D000000000000221700000000000000000000000022945D070000000000000000
00000000000000000000000000000000006B7D5F7E9E5F79A79D79735F5FA7684C000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
2D350000000000000000003B0000000000000000000000000022945D0700000000000000
000000000000000000000000000000000000535F5F695F5F88889D79AC6F5FA782000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000163A
1700000000000000000000003E0000000000000000000000000022945D05000000000000
00000000000000000000000000000000000000A25F5F6973738897AC796F887DA5000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000352F00
000000000000000000000000191A00000000000000000000000000229443050000000000
0000000000000000000000000000000000000039805F887E9DB2C6C6895F745F31000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000001D44000000
00000000000000000000000000340A000000000000000000000000002288430500000000
0000000000000000000000000000000000000000317988A7C6ACACC6C69A5FAE68000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000451D00000000
000000000000000000000000000034000000000000000000000000000022931F03000000
00000000000000000000000000000000000000000094ACAC92839D8888888A5F62000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000002C35000000000000
0000000000000000000000000000112C000000000000000000000000000066931F010000
00000000000000000000000000000000000000000000706F5F92C6C6A788886C00000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000153A1700000000000000
0000000000000000000000000000001F17000000000000000000000000000066931F0100
0000000000000000000000000000000000000000000000278F94C6C6C6B6974400000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000352F000000000000000000
000000000000000000000000000000003C00000000000000000000000000000066931D01
0000000000000000000000000000000000000000000000000098C6C6C6C6C66300000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000001D430000000000000000000000
00000000000000000000000000000000003E000000000000000000000000000000667C1B
010000000000000000000000000000000000000000000000002A8EC6C694310000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000451D000000000000000000000000
0000000000000000000000000000000000191A000000000000000000000000000000666F
090100000000000000000000000000000000000000000000000000943100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000002B350000000000000000000000000000
0000000000000000000000000000000000002D1800000000000000000000000000000072
5D0900000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000017000000000000000000000000000000
00000000000000000000000000000000000000351A000000000000000000000000000022
945D07000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000003C000000000000000000000000000000
22945D070000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000320000000000000000000000000000
0022945B0500000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000152700000000000000000000000000
0000227D4305000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000002914000000000000000000000000
000000229331050000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000018000000000000000000000000
0000000044931F0100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000066931F01000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000066931F010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000066931B0100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000066641B01000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000726F09010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000945D070000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000022945D0700000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000022945D05000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000022945B050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000002288430500000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000022931F05000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000066931F010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000066931F0100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000066931D01000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000667C1B010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000666F1B0100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000725D0900000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000022030F00000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY@`0000000`0g=cL0
IFEU02HV9P13000000@0dLfY00030=7=ZD<0000000<0NWYj09:BTP1_Kfl0@`0000040=7=Z@000`3A
cJU30000000304m?C`1fMWH0=SHf04<00000103AcJT000<0dLfYA00000000`1aLG40000000000012
000000@0dLfY00030=7=ZD@0000000<0LG5a000000000000@P0000040=7=Z@000`3AcJU400000003
075aL@000000000004800000103AcJT000<0dLfY@P0000000`0C4a<00000075aL@14000000@0dLfY
00030=7=ZD80000000<07alO0000001aLG40A00000040=7=Z@000`3AcJU30000000301lO7`1aLG40
00000100000000<0:2PX000000000000<00000040=7=Z@000`3AcJU30000000301<C4`1aLG400000
00l0000000<08R8R000000000000<@0000040=7=Z@000`3AcJU40000000307EeM@000000000000d0
000000<07QhN000000000000<P0000040=7=Z@000`3AcJU400000003075aL@0>3Ph0000004800000
103AcJT000<0dLfYA00000000`1aLG4092@T0000000:0000000301dM7@000000000003D00000103A
cJT000<0dLfY;00000000`1fMWH0=3@d0000000E00000003075aL@0000007alO00T0000000<08R8R
000000000000=P0000040=7=Z@000`3AcJT[00000004018B4P000000000004E5AAD0000000<0LG5a
0000000k>c/0200000000`10@4008B4Q0000000g000000@0dLfY00030=7=ZAH0000000<01`L700d=
3@0000004P0000001P0M7Ad0>CTi03hn?P000000>SXj055ADA<0000000<0Y:BT0000000000000`00
00001@0j>SX00000000000000000@d=303X00000103AcJT000<0dLfY5`0000000`14A4@0D51@0000
000?0000000;01<C4`000000<c<c08V9R@2RXZ80IVIV0000000d=3@06ATI05iNGP0i>CT03P000000
1P29RHT0a/K60<K6aP36a/H0Hf=S03Xj>P80000000@0@D51000000000000Cdm?>`0000040=7=Z@00
0`3AcJTH0000000306IVIP1<C4`0000000h0000000L0a/K609:BTP2CTi<0R8R80=;BdP3;bl/0C4a<
00@0000000<0820P0000000000002@0000003@2JVYX0a/K60>GUi@3/k>`0oooo0?_kn`3Shn<0^;Rh
09VIV@000000<c<c0000000];Bd0?00000040=7=Z@000`3AcJTI0000000309BDU02LW9`0000000d0
000000P0]KFe069RHP2@T900Y:BT00/;2`071`L0bLW904a<C080000000@06a/K000000000000De=C
200000003@1EEED0`l?309>CT`2GUiL0Xj>S0:JVYP2RXZ80U9BD08f=S@2k^k/0:b/[0000000P8200
?@0000040=7=Z@000`3AcJTJ0000000309BDU021PH40000000`0000000P0]KFe0<k>cP1lO7`0Z:RX
04I6AP0=3@d0inOW0>;RhP<0[jn_00D0LG5a04I6AP000000De=C03/k>`060000000;0<_;b`1/K6`0
Ogmo0820P024Q8@0QXJ608>3P`25QHD0O7al05IFEP36a/H0?`0000040=7=Z@000`3AcJTK00000003
07emO@1WIfL0000000`0000000D0l_;b0<_;b`3;bl/0HV9R00d=3@050>OWi`030<W9b@1<C4`00000
0080000000<0?3`l03@d=00000000`0000002`2DU9@0Cdm?06=SH`1jNWX0Q8B408J6QP23Ph<0MgMg
05iNGP1^KVh0I6AT03l00000103AcJT000<0dLfY700000000`2CTi<0OWin0000000=0000000403Ti
>@3WinL0inOW0<;2`PD0inOW00H0h^;R04];B`0R8R80De=C0000000R8R830000000<02<S8`0Y:BT0
FEUI06UYJ@1kNg/0Q8B408N7Q`23Ph<0NGUi06ATI01IFET0JFUY?`0000040=7=Z@000`3AcJTM0000
000309>CT`1>CTh0000000`0000000D01@D50>OWi`3WinL0inOW0;2`/0050>OWi`050<K6aP0S8b<0
A4A404i>CP0R8R800`000000300f=SH09RHV061PH01]KFd0OGem08F5Q@27QhL0Q8B407]kN`1YJFT0
FUYJ038b<Sl00000103AcJT000<0dLfY7@0000000`1VIVH0Ti>C038b<P0<0000000500/;2`2k^k/0
inOW0>OWi`2i^KT01P3WinL01@2DU9@04a<C05=CD`0d=3@08R8R0080000000`0EeMG03@d=01RHV80
KVi^07emO@25QHD0QhN708B4Q01kNg/0Jf][05iNGP14A4@K0000000304U9B@1<C4`0000002400000
103AcJT000<0dLfY7`0000000`1MGEd0<S8b0000000:0000000307=cL`3WinL0i>CT00T0inOW01<0
HV9R034a<@0k>c/0H61P05=CD`00000061PH04E5A@1WIfL0LG5a09VIV@2XZ:P0ZZZZ0:RXZ02?Shl0
KVi^06=SH`1ADE40?Cdm01P0000000D0TY:B09FEU@2o_kl0bLW904a<C00Q000000@0dLfY00030=7=
ZAl0000000<0A4A403<c<`0000002`0000050>OWi`030;fm_@3WinL0inOW00@0inOW0180HV9R0000
000o?cl0A4A400000014A4@0CTi>08b<S02EUID0XZ:R0:RXZ0000000Z:RX0:2PX02CTi<0RHV905iN
GP1YJFTB0000000609:BTP2RXZ80/K6a0;6a/@2RXZ80TY:B103WinL00`2VYZH0WIfM0000000O0000
00@0dLfY00030=7=ZB00000000<0IVIV04a<C00000002P0000000`0R8R80inOW0>OWi`020>OWi`03
0=KFeP3QhN40inOW00@0inOW0180a/K609BDU00o?cl0De=C03Hf=P0/;2`0Lg=c08b<S02EUID0XZ:R
0:RXZ02ZZZX0Z:RX0:2PX02CTi<0QHF506i^KP0410@@0000000304U9B@2BTY80c/k>0080inOW00D0
dm?C0<C4a03:b/X0`L710>CTi0030>OWi`0309fMW@000000000001h00000103AcJT000<0dLfY8@00
00000`1bLW80>SXj0000000:0000000305=CD`3WinL0inOW00<0inOW00<0][Jf0>OWi`3WinL0103W
inL00`1RHV80A4A403hn?P0207MgM`0<08b<S02EUID0XZ:R0:RXZ02ZZZX0Z:RX0:2PX02CTi<0OWin
06i^KP2_[jl0<30`3@000000100T92@0TY:B0;no_`35aLD30>OWi`060<_;b`38b<P0X:2P0;2`/03G
emL0g=cL0P3WinL00`1cLg<000000000000N000000@0dLfY00030=7=ZB80000000<0U9BD0861P@00
00002@0000000`1CDe<0Fe]K0>OWi`040>OWi`030=OGe`3WinL0XZ:R00@0inOW0100Jf][08:2PP18
B4P0RXZ:0<G5a@2^[Zh0XZ:R0:RXZ02ZZZX0Z:RX0:2PX01fMWH0O7al06i^KP2EUID020P82`000000
100T92@0TY:B0:ZZZP3Vi^H30>OWi`090;6a/@2h^;P0^k^k0;^k^`32`/80a/K60:VYZ@2@T900Xj>S
02800000103AcJT000<0dLfY8`0000000`2DU9@0IfMW0000000700000004028R8P0a<C408R8R03Ti
>@80inOW00D0fMWI0>OWi`3WinL0i>CT0=kNgP050>OWi`0?07]kN`18B4P0MgMg08^;R`2EUID0XZ:R
0:RXZ02ZZZX0Z:RX0:2PX01YJFT0RHV907QhN00l?3`0H61P00T0000000@0BDU909:BTP2h^;P0emOG
0`3WinL00`3EeMD0[:b/0:ZZZP040;^k^`030<71`@1DE5@0:RXZ02<00000103AcJT000<0dLfY9000
00000`2CTi<0<C4a0000000600000005028R8P0000008R8R0000001[Jf/00P3WinL00`3Ti>@0inOW
0>OWi`060>OWi`0>0<W9b@24Q8@0NGUi06i^KP1ADE40G5aL065QH@1RHV80HF5Q05]KF`1SHf<0IfMW
06i^KP0l?3`80000000304U9B@2BTY80ZJVY00@0inOW00@0fMWI09>CT`2OWil0_kno102k^k/00`39
bLT0TI6A09NGU`0T000000@0dLfY00030=7=ZBD0000000<0IVIV051@D00000001`000002028R8P03
0000003Ng]h0inOW00@0inOW00@0/[:b0:RXZ02ZZZX0YJFU0P3WinL01@36a/H0Cdm?06e]K@1EEED0
GEeM0080HV9R00P0HF5Q05aLG01CDe<0C4a<030`<00l?3`0>3Ph03De=@@0000000@092@T09:BTP39
bLT0h>3P1P3WinL00`2k^k/0`/;20;^k^`030;^k^`030=KFeP2TY:@0g]kN02D00000103AcJT000<0
dLfY9P0000000`2CTi<0Bd];000000050000000605=CD`0R8R80000005=CD`000000clo?0`3WinL0
1P31`L40S8b<0:RXZ02ZZZX0UiNG0;Rh^080inOW00h0U9BD055AD@1GEeL0PX:208F5Q@26QXH0QHF5
06m_K`1EEED0Cdm?03Xj>P0l?3`0FUYJ06=SH`<0000000@092@T09:BTP2ZZZX0jNWY1`3WinL00`39
bLT0^k^k0;^k^`020;^k^`040<S8b03AdM40XZ:R07=cLbD00000103AcJT000<0dLfY9`0000000`1_
Kfl0<S8b0000000500000009028R8P000000De=C028R8P1CDe<0[Jf]0>OWi`3]kNd0Z:RX00@0bl_;
0100Shn?0>OWi`3WinL0inOW08B4Q02OWil0YJFU0:VYZ@2ZZZX0ZJVY0:FUY@2MWId0V9RH06MWI`0T
92@0D51@0P0000001@21PH40TY:B0:ZZZP36a/H0iNGU00P0inOW102k^k/00`38b<P0e=CD0;6a/@0W
000000@0dLfY00030=7=ZBL0000000<08R8R05eMG@0H61P01`000004028R8P80inOW1P3;bl/30>OW
i`0?06YZJP28R8P0YJFU0:VYZ@2ZZZX0ZJVY09:BTP2MWId0V9RH08^;R`1iNGT00`<30000001fMWH0
_kno00<0inOW00<0]KFe0>OWi`3WinL01`3WinL20;^k^`030;jn_P2][Jd0;2`/02P00000103AcJT0
00<0dLfY:00000000`0R8R80GEeM000000070000000605=CD`0000008R8R0000003WinL0h>3P103;
bl/00`3Bd]80inOW0>OWi`020>OWi`0<06YZJP2UYJD0ZJVY0:ZZZP2YZJT0SHf=09fMW@2HV9P0Rh^;
07UiN@1NGUh0MWIf103WinL01@2b/[80ZZZZ0:^[Z`22PX80d];B00H0inOW00<0hN7Q08n?S`0V9RH0
:P0000040=7=Z@000`3AcJTY00000003028R8P13@d<0000000P000000P0R8R801P0a<C40inOW0>OW
i`3MgMd0hN7Q0>3Ph0D0inOW00T0g]kN0:FUY@2;Rh/0SXj>051@D020P800IVIV07UiN@2;Rh/00P1i
NGT40>OWi`0308V9R@36a/H0a/K60080a/K600<0QHF50>OWi`39bLT00`3WinL00`1cLg<000000000
000[000000@0dLfY00030=7=ZBX0000000<0IVIV051@D01SHf<02`0000000`2][Jd0inOW0>OWi`04
0>OWi`0<0;>c/`36a/H0R8R80:NWY`36a/H0R8R809ZJVP2f][H0WIfM0:b/[02;Rh/0bl_;1@3WinL0
0`3Fe]H0a/K60<K6aP020<K6aP050=KFeP3WinL0inOW0=kNgP2][Jd0;`0000040=7=Z@000`3AcJT[
0000000306IVIP2CTi<0Bd];00/0000000P0>CTi0>OWi`3WinL0inOW0:FUY@2h^;P0a/K60;Jf]PH0
a/K600D0_;bl0<K6aP2c/k<0X:2P09ZJVP040>OWi`030>WYj@36a/H0a/K60080a/K600<0^KVi0>OW
i`2][Jd0<@0000040=7=Z@000`3AcJT]0000000306m_K`0b<S80000000/0000000<0i>CT0:FUY@1n
OWh00`36a/H00`2KVi/0PH6108N7Q`0208N7Q`030861P@2KVi/0a/K60080a/K600<0_[jn0;^k^`3W
inL00`3WinL01@3Ti>@0e]KF0<k>cP3Vi^H0R8R803<00000103AcJT000<0dLfY;@0000000`0R8R80
GEeM01PH600;0000000:038b<P2ATI40a/K60<K6aP1hN7P0MGEe065QH@1KFe/0GEeM05iNGP80GEeM
00L0IFEU07AdM02:RXX0a/K609:BTP2MWId0clo?00@0inOW00P0emOG07=cL`0D51@0?3`l05QHF000
0000>3Ph03<c<bl00000103AcJT000<0dLfY;P0000000`2DU9@0PH610000000:0000000809jNWP36
a/H0a/K60;2`/01nOWh0M7Ad06EUI@1[Jf/307UiN@0406ATI01IFET0C4a<07inOP80a/K600<0NGUi
0<K6aP3WinL00`3WinL00`1KFe/00000000000020000000302HV9P000000000002l00000103AcJT0
00<0dLfY;`0000000`1mOGd0IfMW000000090000000@069RHP1KFe/0a/K607MgM`1GEeL0N7Qh07al
O016ATH0HV9R07inOP1mOGd0GemO07alO01eMGD0Lg=c07EeM@80a/K600l05ADE01PH600000000000
03Ph>02TY:@0=CDe024Q8@0S8b<0000001TI6@0V9RH0=3@d0000000P8200;@0000040=7=Z@000`3A
cJT`0000000309>CT`1nOWh0000000L0000000T0Hf=S0;6a/@36a/H0Vi^K05YJFP1cLg<0@T9205YJ
FP1hN7P00`1iNGT01@1hN7P0G5aL07IfMP1cLg<0Fe]K00<0a/K600<0>c/k034a<@0000000P000000
100l?3`0<c<c0000000/;2`30000000303Ti>@0410@0000002`00000103AcJT000<0dLfY<@000000
0`2CTi<0Hf=S000000060000000609BDU01?Cdl0a/K609^KV`1[Jf/0Kfm_0P1aLG401`1cLg<0LG5a
0:JVYP1HF5P0LW9b075aL@1HF5P00P1^KVh01@2KVi/0UIFE08F5Q@1mOGd0>c/k00@0000000P08R8R
08N7Q`000000;bl_0000000h>3P0000004A4A0H0000000<04Q8B0000000000000`0000000`0Z:RX0
00000000000N000000@0dLfY00030=7=ZC80000000<0I6AT04a<C00000000`0000004`1CDe<0YZJV
08R8R02`/;00/[:b0;2`/01aLG40J6QX05=CD`1[Jf/0K6a/0:RXZ03lo?`0]KFe06a/K01[Jf/0?3`l
06QXJ01[Jf/00`36a/H03015ADD09RHV04I6AP1mOGd0@41007AdM00d=3@0:BTY01LG5`2UYJD071`L
01TI6@H0000000<05aLG0000000000000`0000000`0T92@000000000000P000000@0dLfY00030=7=
ZC<0000000<0U9BD09bLW01CDe<00P2VYZH03`36a/H0inOW0<30`02DU9@0WinO07alO01/K6`0EEEE
04a<C01>CTh0IFEU051@D036a/H0KVi^06EUI@0204i>CP0503Xj>P1/K6`0a/K6069RHP1]KFd00P00
0000100];Bd000000000000f=SH20000000403Ph>0000000000008^;R`H0000000<06a/K03@d=000
00009P0000040=7=Z@000`3AcJTc0000000304U9B@2DU9@0Ogmo00D0inOW00l0GUiN06a/K036a/H0
a/K605=CD`1BDU80Fe]K03@d=019BDT0GEeM04U9B@18B4P0Fe]K04Y:BP1QHF400P36a/H01@2f][H0
XZ:R0000001XJ6P05QHF00@0000000L0>SXj01PH600i>CT0000002TY:@0h>3P0L71`00/0000000<0
<S8b0000000000007`0000040=7=Z@000`3AcJTa0000000609:BTP2EUID0_kno0>OWi`28R8P0XJ6Q
1@3WinL01@1SHf<0A4A40<K6aP36a/H0IfMW0080F5QH00H0FEUI05YJFP1KFe/0EeMG05IFEP1aLG42
0<K6aP040;Jf]P36a/H0R8R806ATI080000000L0JFUY01LG5`0g=cL00000028R8P0[:b/08R8R0080
000000<0<C4a01TI6@0Q8B40;00000040=7=Z@000`3AcJT`0000000306i^KP2SXj<0inOW0080inOW
00@0clo?01lO7`3WinL0^KVi103WinL02`2GUiL0NGUi0<K6aP36a/H0Vi^K06ATI01MGEd0GUiN05eM
G@1TI6@0Vi^K0080a/K600H0BDU909nOW`2o_kl0inOW08J6QP0Q8B420000000;05iNGP0000000000
024Q8@1CDe<0000003Ph>0000000=3@d00000013@d<0;00000040=7=Z@000`3AcJT^0000000306i^
KP2BTY80e=CD00D0inOW00@0X:2P04];B`1GEeL0^KVi0`3WinL02039bLT0b<S80:JVYP2c/k<0U9BD
0;6a/@36a/H0[Jf]0P36a/H0102f][H0NGUi09:BTP2o_kl40>OWi`030:6QX@26QXH0000000800000
00T0GEeM02<S8`000000;Bd]00000015ADD0000003De=@0c<c<0;00000040=7=Z@000`3AcJT/0000
000304U9B@2BTY80h^;R00P0inOW00@0X:2P065QH@1GEeL0<30`0P3WinL0302][Jd000000000002D
U9@0RXZ:0<K6aP1kNg/0?Cdm09BDU00a<C40^KVi0;Ng]`P0inOW00P0J6QX000000000000000003Ti
>@0000006ATI06EUIC000000103AcJT000<0dLfY:P0000000`2BTY80UIFE0;no_`0;0>OWi`050:b/
[01TI6@0I6AT05eMG@1cLg<01@0000000`17AdL0000000000002000000H0inOW00<0]kNg0>OWi`3W
inL00P3WinL00`22PX800000000000030000000503@d=00I6AT0000001`L700Z:RX0;00000040=7=
Z@000`3AcJTX0000000306i^KP2BTY80inOW00D0inOW00<0Shn?0>OWi`3WinL01P3WinL00`2DU9@0
LW9b03Ti>@060000000301<C4`000000000000<000000`3WinL0103?cll0R8R80;Jf]P1OGel40>OW
i`0306IVIP000000000000@0000000<0=3@d000000000000;00000040=7=Z@000`3AcJTV00000003
06i^KP2BTY80e=CD00D0inOW00@0^;Rh07moO`3GemL0HV9R1`3WinL00`0000008R8R04=3@`0=0000
0080inOW00H0][Jf0<K6aP2f][H0SHf=05mOG`35aLD30>OWi`0306IVIP000000000000D0000000<0
=3@d000000000000:P0000040=7=Z@000`3AcJTT0000000301<C4`2BTY80d];B00@0inOW00L0h^;R
0;6a/@28R8P0cLg=0?3`l03clo<0HV9R00D0inOW00H0>CTi0000000000000000028R8P0O7al40000
000302PX:0000000000000D0000000@0[Jf]0>OWi`3WinL0R8R80`36a/H00`2/[:`0aLG50>OWi`02
0>OWi`0306IVIP000000000003400000103AcJT000<0dLfY900000000`26QXH0inOW0>OWi`020>OW
i`090>;RhP2@T900WIfM0<G5a@3^k^h0m?Cd0=cLg02EUID0[jn_00<0inOW00<0>CTi000000000000
100000000`1VIVH07alO000000020000000302h^;P000000000000H000000`3WinL01P36a/H0b/[:
0<K6aP36a/H0[:b/0<G5a@<0inOW00<0C4a<000000000000<00000040=7=Z@000`3AcJTT000000@0
inOW00P0bl_;08f=S@3IfMT0lo?c0?Gem@3QhN40Y:BT0;no_`<0inOW00<0Lg=c0000000000001`00
0000101VIVH06a/K0000000];Bd:000000<0inOW00D0a/K60:ZZZP36a/H0a/K607UiN@030>OWi`03
0<W9b@1XJ6P0000003000000103AcJT000<0dLfY8`000000301^KVh0inOW0>OWi`3WinL0BTY:08>3
P`3Fe]H0lo?c0?3`l03Ti>@0ZZZZ0<C4a0<0inOW300000000`1_Kfl00@4103<c<`0:0000000903Ti
>@3WinL0inOW0<k>cP36a/H0eMGE0<K6aP2GUiL0Xj>S00<0inOW00<0bLW904a<C0000000;`000004
0=7=Z@000`3AcJTQ0000000306i^KP2BTY80inOW0080inOW00L0bLW90492@P2DU9@0l_;b0=GEe@20
P800WinO00<0inOW00<0>CTi0000000000002`0000000`0R8R80GEeM01/K6`0;000000070:f][@3W
inL0inOW0;no_`2GUiL0YjNW0<k>cP050>OWi`030<K6aP1<C4`0000002h00000103AcJT000<0dLfY
800000000`2BTY80e=CD0>OWi`040>OWi`0308j>SP15ADD0Ti>C00@0inOW00<0>CTi000000000000
3P0000000`0R8R80Fe]K00D51@0;000000040:f][@3WinL0inOW0=kNgP@0inOW00H0clo?0=KFeP3F
e]H0aLG50<K6aP0I6AT^000000@0dLfY00030=7=ZAl0000000<092@T0>OWi`2i^KT01P3WinL01@30
`<00inOW0>OWi`3WinL0Lg=c0180000000@09RHV028R8P2CTi<01@D52`0000000`2][Jd0inOW0>OW
i`020>OWi`030<o?c`2^[Zh0^;Rh0080eMGE00@0`L710;Bd]02:RXX06ATI;@0000040=7=Z@000`3A
cJTP0000000305EEE@2IVIT0HV9R00<0inOW00<0>CTi0000000000005P0000001@0c<c<000000000
002CTi<00@4100/000000`3WinL02P2o_kl0[Jf]0<?3``1hN7P0?3`l04Q8B01LG5`0TY:B08b<S026
QXH]000000@0dLfY00030=7=ZB40000000<0bl_;0451@@2KVi/07`0000000`2CTi<00`<30000000:
0000000<03Ti>@3Ng]h0g]kN0=GEe@1DE5@0S8b<0:>SX`2WYjL0Xj>S08f=S@2o_kl0[:b/;@000004
0=7=Z@000`3AcJTR000000030:NWY`000000000001l0000000<0QhN700D51@0000002P0000002`0i
>CT0e]KF05=CD`2NWYh0`L710=?Cd`3Fe]H0dm?C0<;2`P3=cLd0inOW02d00000103AcJT000<0dLfY
?P0000000`0_;bl00000000000040000000309>CT`010@40000000X0000000/0[Jf]08b<S031`L40
gmoO0>k^kP3alO40a<C40=GEe@35aLD0e]KF01TI6@0/000000@0dLfY00030=7=ZCd0000000<05QHF
04Y:BP0000001P0000000`2CTi<00@410000000:0000000:0:f][@2WYjL0^k^k0=GEe@2l_;`0_Kfm
0;Jf]P2BTY80GemO08J6QR`00000103AcJT000<0dLfY?@0000000`0^;Rh0;bl_0000000600000003
06IVIP0K6a/00@4100/0000000D0c/k>0=kNgP3Fe]H0e]KF0;Jf]P0209:BTP0305mOG`2SXj<0C4a<
02/00000103AcJT000<0dLfY>`0000001@15ADD000000000000000008R8R00L0000000<0U9BD05eM
G@000000300000002@1[Jf/0OGem07inOP1OGel0YjNW07UiN@1OGel0YjNW06QXJ00Z000000@0dLfY
00030=7=ZCT0000000<0>SXj01LG5`000000100000000`0n?Sh000000000000500000003028R8P1M
GEd0000000d0000000L0GemO06UYJ@1cLg<0UiNG07UiN@28R8P0OGem02X00000103AcJT000<0dLfY
=`0000000`0M7Ad00000000000070000000303@d=0000000000000D0000000<08R8R04=3@`000000
300000001`0a<C40R8R80<K6aP2/[:`0a/K605mOG`2^[Zh0:P0000040=7=Z@000`3AcJTf00000003
03De=@000000000000T0000000<0;2`/0000000000001@0000000`1VIVH07alO0000000<00000006
071`L01OGel0a/K60:NWY`28R8P0K6a/:P0000040=7=Z@000`3AcJTd0000000303De=@0000000000
01@0000000<0IVIV01dM7@0000003@0000030<K6aP0306=SH`000000000002P00000103AcJT000<0
dLfY<P0000000`15ADD07AdM0000000>0000000301TI6@000000000000H0000000<0IVIV00T92@00
00003@0000000`0a<C4000000000000Z000000@0dLfY00030=7=ZC40000000<05aLG000000000000
400000000`0e=CD00000000000060000000309BDU0071`L0000003T00000103AcJT000<0dLfYA@00
00000`0b<S800000000000060000000309BDU0051@D0000003P00000103AcJT000<0dLfYA@000000
0`0E5AD000000000000600000003028R8P13@d<01@D503P00000103AcJT000<0dLfYAP0000000`0H
61P00000000000060000000304A4A02CTi<00@4103L00000103AcJT000<0dLfYD@0000000`2CTi<0
0@410000000e000000@0dLfY00030=7=ZE80000000<0I6AT00410@000000=00000040=7=Z@000`3A
cJUC0000000305eMG@000000000003<00000103AcJT000<0dLfYD`0000000`0R8R80GEeM0000000c
000000@0dLfY00030=7=ZE@0000000<08R8R04=3@`000000<P0000040=7=Z@000`3AcJUE00000003
06IVIP0O7al00@4103400000103AcJT000<0dLfYEP0000000`1VIVH0Ti>C00410@0`000000@0dLfY
00030=7=ZEL0000000<0IVIV01/K6`000000;`0000040=7=Z@000`3AcJUH00000003079bLP092@T0
000002h00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY002@0=7=Z@00T03AcJT00900dLfY002@
0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {301.5, 158.5}} -> {-343.407, 290.398, \
1.87239, 1.87239}}]
}, Open  ]],

Cell["\<\
An image in FITS format, representing the PSF,  is also obtained \
from [10].  The (known) PSF is employed to form the convolution with the \
original astronomical object. The same PSF is also used to form the \
convolution with the true guide star. In this way we simulate the situation \
in which the observed target and a reference image (the observed guide star) \
are available, both measured under similar atmospheric circumstances.\
\>", \
"Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(h\&^\_star\  = \ \(readFITS["\<PSF.fits\>"]\)[\([2]\)];\)\), "\
\[IndentingNewLine]", 
    \(\(h\&^\_star\  /= \ 
        Apply[Plus, \ h\&^\_star, \ {0, \ 1}];\)\), "\[IndentingNewLine]", 
    \(\(showImage[h\&^\_star];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000000000000000000000000000010000000000000000000000
000000000000000001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000000000100010000000001000000000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000000000
000000000000000100000000000000000000010000000000000000000000010001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000100000001000101000001010000000101000000000100000000000100
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000010001000000010000010100010100000000000000000100010000
000000000000000100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010001010100000000000101000101010100010100000100000000000001000100000000
000100000101000101000001000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000000000
000100010100000101010001010100000000000100000100010100000000010101000000
000100000100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000000000000000000000000000100000000010000
000000000000000100010001010000010100010000010100000000000101010101000001
000000010100000100000100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000000000000000000000000000001010100000000
010100010000010101000101000101000101010101010101010100010100010101000000
000000010101000100010001000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000100000100000001000101
010000000101010001010101000001000101010101010100010001010000000001010101
000000010101000101010001000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010001010101010000
010101010101010100010101010101010101010101010001010000010101010001010100
000001000101010101010100010101000100000000000000000000000000000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000100010101000101010101010001
010100010101010001010101010100010101010101010101010101010001010100010101
010100010000010100000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010100000000000101000101010101000101010100
010101000101010101010101010101010101010101010101010101010101000100010101
010101000101010001000100000100000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001010000000001010001000101000101010001000101
000101010101010101010101010101010101010100010101010101010100010101010101
010101010100010001010101010000010100010000000000000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000101010100000001010100010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101000101000100000100000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000000000000010000000101000000010101010101010101010101010101
010101010101010101010102010101010101010101010101010101010101010101010101
010101010101000101010101000101010101000000000100010100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100000100000101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010201010101
010101010101010101010101010101010101010101010001000100000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000101010101010001010100010101010101010101010101
010101010101010101010101010101020101010101010101010101010101010101010101
010101010101010101010101010101000101010100010100000001000100000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010000010101010101000101010101010101010101010101010101
010101010101010101020101010201010101020101010201010101010101010101010101
010101010101010101010101010101010101010101010001010000010000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000100010101010101010101010101010101010101010101010101
010101010101010201020102020102020102010101020101020101010101010101010101
010101010101010101010101010100010101010101010101000101010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000101010100010101010101010101010101010101010101010101010101
010202020201010102020202010101020101020102020102010102010202020201010101
020101010101010101010101010101010101000101010001000001000000000000000101
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010100000000000100010001010101010101010101010101010101010101010101010102
020101020202020202020101020202020202010101020202020102010202020101020201
020102010101010101010101010101010101010101010100010101000100000100000000
000100000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
000000010101010101010101010101010101010101010101010101010201010102010102
020201020202020202020202020202020202020202020202020202020202020201020201
020202010202010101020101010101010101010101010101010101010100000101010001
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
000000010101010001010101010101010101010101010101010101010101020101020101
010201020102020202020202020202020202010201020202020202020202020202010202
020102010101010102010101010101010101010101010101010101000101000001010000
000000000000000000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000000
000000010000010101010101000101010101010101010101010101010202020101010101
020202020202020202020202020202020202020202020202020202020202020102020202
020201020102010201020201010101010101010101010101010100010101010000010001
000100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000000
010100010001000101010101010001010101010101020101020101020102020102010202
020202030202020202020202020202020202020202020202030202020202020202020102
020202010102020201020101010101010101010101010101010101010100010100000101
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010001
010001000101010100010101010101010101010101010101010102010201020202020202
020202030302020302020202020303020302020203020203030203020202020202030202
020201020102020101020201010202010101010101010101010101010101010101010100
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000001010001
000100010100010101010101010101010101010102020201020102010202020202010202
020202020303030202020302020302030203020202020303030203020302020202030203
020202020202020201020101020101020101010101010101010101010101010101010100
010000000100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000101
010000000001000000010101010101010101020101010201020102020202020202020202
020303020303030302030303030203020303020303030303030302030302020303030303
020302020202020202020102010101010101010201010101010101010101010101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000010001010000
000101000101010100010101010101010101010102020202020202020202020202020202
020303030303020303020303030303030303020303030303030303030203030303030303
030202020202020202020202010101010201010101010101010101010101010101010101
010100000100000000000000000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000100010001010101
010001010101010101010101010201010101020201010202010302020302020202020202
020303030303030303030303030303030302030303030303030303030303030303030303
030303020203020202020202020201020201020101010101010101010101010101010101
000100010100000000000000000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010000010100
010101010101010101010101010202010102020202020202020203020203020202020202
020302030403030303030303030303030303030303030403030304040303040404030303
020302020302020202020202020201020201010102010101010102010101010101010101
000001010100010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000000000001010100
010101010101010101010101010202010101010202020202020203020203020302030303
040303030303040404030303030303030303030303030304030404030404030404030303
030303020303030303020202020202020101010201010101010101010101010101010101
010100010100010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010001010001010101
000101010101010101010101010201020201020202020302020202020202020303020302
030303040303030403030304030403040403040403040404040404050405040404040303
030303030302030303020302030202020201020202020101010102010101010101010101
000001000000000000000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000010001000100000001000101010101
000001010101010101010101010101010202020202020202020303020303030303030303
030303050404040404040304030304040304040404050405040404050404040404040403
030303030304030303030302020202020202020202020202010201010102010101010001
010101010100010100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001010000010100010101
010101010101010101010101010201020202020202030203020303030303030303030303
030403040404040404040404040404040505040504050505040405050504050504040403
030304040303030303030303030202020201020202020202020201010201010101010101
010101000101010101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000001010100010001
010101010101010101010101010102020202020202020203020203030303030303040404
030404050404040504040404040405040505050504050504050505050505050504040404
040404030303030403030303030303020202020202020202010102010201010101010101
010101010100010101010000000001000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100010000000000010101010001
010101010101010101010101010202020202020203030303020303030303030404030404
040404050505050504050505050505050606060505050505050505050505050505050404
050404040404040303030303020203020202020202020202020202020101010101010101
010101010101000101010100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010100010100000100010101
010101010101010101010101020202020202020302030303030303040303030304040404
040405050505050505050505050505050606050607060606050506060505040404050505
040404040304040403030303030302020302020202020203020202010101010101010101
010101010101010101000000010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000101010000010101010101
010101010101010101020102020202030202030303030303030304040403030404040405
040505060505060605060605060605070606070707070606060506050506050405050404
050404050404040304040304030303030202020202020203020102020201020101010101
010101010101010101010101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001010101010101010101
010101010101010102020101020202030202020303030303040303030404030405040504
050505050606060606060606070707060607060706070807070706060605050505050505
050504040505050404040304030303030303020302020202020202010101020101010101
010101010101010101010101010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001010001010101010101010101
010101010201020102020102020203020302030303040303040304040404040404040505
050506050606070707060707070707070707060708070807070607060706060506060505
050504040504040504030404030304030303030302020202020202020201010101010101
010101010100010101010101000101000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000000000000010100010101010101010101
010101010102020201020102020203020203030303030403040405040404040405050504
050605060607060807070808070707070707080708070808070807080706060506050506
060504050605050504040404040403030302030302020202020202020101010101010101
010101010101010101000101010101010000000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000001010001010101010101010101
020101010202020202020203020202030303030303030404040504040405050405050505
060506060706070807080808080709070807070808080809080808080807070606060606
050605050505050405050505040304030303030203030303020202020201020202010101
010101010101010100010101010000000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000101000100010101010101010101
020101020102020202020303030302030303030403030404040404040505060506060605
06070606060707080809080709090907080908080A090809080908080808070606070606
060606060506050505040504040403040404030304030303030302020202020102010202
010201010101010101010101010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000101010101010001010101010101
010202010202020202020203030303030303040404040404040405070506060606060707
0606070608080809080A090908090808090A0809090909090A0909080807080807070607
060506060606050506050505040404040304040403030303020302030202020202020201
010101010101010101010101010101010101010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000001010101000100010101010102010101
010101020202020203020303030203040303040405040405040505050706060606070707
080707080909090A0A0A0909090909090A0A0A090909090A0A0909090909080808070707
080606060606070706060605050404040404040303030303030302020202020202020202
010201010101010101010101010100000000010100000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000100010101000101010001010101010101
010201020201020202020202030303030403040404050505050606060707070706070707
08090908090A0A0B0B0A0A090A0A0A0A0A090B0B0B0A0B0A090A0A0A0909090907070707
070708070607080606060506060505050504030403030303030303030202020202020102
010201020101010101010101010100010000010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100010101010100010101010101010101
020202020202020202030203030304030303040505050505060607070707070707080809
0908090A0A0A0B0B0B0A0B0B0B0B0B0A0B0A0B0B0B0C0B0B0B0B0A0A0A0A0A0908080908
080807070607070707070707050505050504040403030303030203030302020202020202
020101010101010101010101010101010100000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010001010001010101000101010101010102
020202020202020302020303030403040304050505050505060708080708070807080909
09090A0A090B0C0B0B0C0C0A0B0C0B0C0C0C0C0D0D0C0C0C0B0B0B0B0B0B0A09090A090A
080808080706070707070706050506060504040303040304030302030202030202020202
010201010101010101010101010101010001010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000010000010001010101010101000101010101010201
020202020202020203030303040404040404050406050606060608080907080809090909
0A0A090A0B0B0B0C0B0C0D0C0D0D0D0D0D0D0D0D0E0D0E0D0D0C0C0B0B0B0A090B0B0A09
0A0908080708070807070607070605060505050403030303030303030203030302020202
010101020101010101010101010101010100000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000000000100000001000000010101010101010101010101010202
0202020202020202030304040404040404040505050606060707080908090908080A090A
0A0A0B0B0B0D0C0B0C0C0D0E0D0D0E0E0D0E0F0F100D0E0E0D0C0C0C0C0C0A0B0B0B0B0A
0A0B09080808080707070606060605060605050404030303030303030303020202020202
010201010101010101010101010101010101010000000000000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000000000000101010101010100010101010102010202
02020202020202020304040404040404040505050505060707070807080A09080A0B0A0A
0A0A0B0B0B0D0D0E0E0E0E0E0F0F101010100F110F0E0F0E0E0C0D0D0D0E0E0D0D0B0C0C
0B0B0B090907080808070706060605050606050605030403030303030303020202020202
020101010201010101010101010101010100000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010101010101010101010101010201
020202020202030203040404040304040404050506060606070708080908090A0B0A0A0B
0A0C0A0B0C0D0E0F0E0E100F0F10111110121110110F0E0E0E0F0D0E0E0E0F0E0D0D0D0D
0D0C0A0B0909080807080707060605060606060604040304040303030303030202030201
010101010101010101010101010101010101010101010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010101010101010101010101020101
0202020202020203030304030404040404050606050606060707070808090A0A0B0B0B0C
0B0C0D0D0D0F101110101010101012131211121112100F0D0F0F0F0F100F0F0F0F0F0D0E
0D0C0D0C0B0B090909080808070707070606060605050403040303030303020203020302
020202010201010101010101010101010101000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010001010101010101010101000101010102010202
020202030203020303040403040404040505050605060707070808080A0A0B0B0C0C0D0D
0D0D0E0F1011111212131112111213121414131110110F10101011111111100F110F0F0F
0F100D0D0C0B0B090A080807080607070706060506050505040503030303030302030202
020202010202020102010101010100010101010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000101010101010101010101010101010101010202
020202020203030303030404040405050505060506070707080808090A0A0B0C0C0E0D0D
0D0E0F10111214131412151512131514151514131413131311121212141311111111100F
100E0E0E0D0C0B0A0A0A0908080707070707060606050504050404030303030303020202
020202020102020202010101010101010101010100010000000000000000000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000001010101010101010101010101010201020202
020202020202030304040304050405050506070707060709080909090A0C0C0D0D0E0E0F
0F0F1011131315141616161715161617171615151414151416141315151414121212100F
0F0E0F0F0E0D0C0B0B0A0A09090809080707070606050505050404030303030303030302
020102020201010202010101010101010101010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000101010101010101010101010101020101020202
020202020303030304040404040405060506060607080808080A0A0A0B0C0C0E0D0F0F0F
0F1011101314161517171817181818181817161716171516151617151616151413131311
10110F0F0F0D0D0C0C0B0A090A090A090708070706060505050504040303030303030303
020102020203020101010201010101010101000101010000000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001010100000001000101010101010102010101010202020202
020203030303040304040404050405060606070807080909090A0B0C0C0C0C0E0F0F0F10
1012111314151517171718191A1A1A19191919191A191817191618171717161614151211
1210100F0E0F0E0C0D0B0B0B0A0809090807070606070605050504040404040303030303
020202020202020202020101010101010101010001000101010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000010101010101010101010101010102010102020202
0203020303030404040404040505050606070708070809090A0A0B0C0B0D0E0E0F0E1010
1112121314151616191A1B1B1C1B1B1B1A1B1C1C1C1B1A1A1A1918191917181715141213
1211110F110F100F0D0B0C0A0A0A09090909070706060506060505040403030303030303
020203020202020202020101010101010101000001000001010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001010101010101010101010101010101010202020302
020302030303040304040504040505060707080708080A090B0A0C0C0D0E0E100F0F1010
10121414151618181A1B1D1C1E1B1E1C1D1D1F1E1E1C1D1B1B1B191A1A19181917151514
1213111312100F0F0E0C0C0B0B0A0A0A0908080707060605060605050404040303030303
030202020203020202020101020101010101010000010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001010001010101010101010101010102020202020202
020203030304030404040404050506070707080908090B0A0B0C0D0C0D0E0F0F0F101111
121415161918191A1B1C1D1C1E1F1D1D1F212020201F1F1D1C1C1C1C1C1B1B1A19181615
14151414111211100F0D0D0B0B0A0A090908080707060607060606050503040403030303
030302030202020202010101010101010100010001010100000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010001010101010101010101010201020202020202
020303030404040404040505050505060707080809090A0A0B0D0D0E0E0E0E0E10101111
151819191A1B1B1D1C1E202121202021212123232321201E1E1E1F1E1E1E1C1B1A1A1817
1716141413121211110F0C0C0C0B0A0A0A08080707060607070606050504040404040304
030302020202020201010102010101010101010101000100010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000001000000000101010101010101020202020202020303
0303030303040404040405050506060706070808090A0A0A0C0D0D0E0F0E0F1112121315
1718191B1C1D1E1E1F2120222222232223262727272524232320222122201F1D1B1C1B19
1A1716151414141111100E0E0E0C0B0B0B09080807070706070606050505040403040403
030302030202020202010201010101010101010001010001000000010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000101010101010101010101010102020203020203
02030403030404040404050506060606070708090A090B0B0C0D0E0E0F0F111012131516
191A1C1D201E2121232024232324242527282A2D2B292927252625252423221E1E1D1D1B
1C1A1A171515141212100F0E0D0D0C0B0A0A090807070706070705050504040504040403
030302030302030202010102010101010101010101010101010000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100000101010101010101010101010201020202020202
0303030304030405050505050506060708070809090A0A0C0D0D0E100F0F111113141618
1A1C1E1F2022212221252725292727282C2E2F3230302C2A2A262828282624221F1F1C1D
1C1A1A191715151314110F0F0E0D0C0B0B09080808080807070606050505040403040303
030203020202020202020202010101010101010101000101000000000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010100000000010101010101010102020202020203020202
03030403040405050505050505060607080809090A0B0C0D0E0F0E100F1011111315171A
1B1D2021222422242427282728282A2B2F2F34373533332F2B292A2A282826242221211D
1E1B1C1A18161414111211100E0E0D0C0B0B090907080708070706060505040403030303
030303020202020202020101010101010101010101010000000000000101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000001010101010101010201020202030202020303
02030404040505040505050606070708080809090A0C0D0C0E0E110F101012131315181A
1C202121232325252728272B2A2B2D2E353537383B373733322E2D2E2A2B282522232021
1F1D1C1917161514121112100E0D0D0C0C0C0B0A09070808080606060505040504040304
030302020202020202020202010101010101010101010100000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000101000001010101010101010202010202020202020203
030403030403030504040506060708080809090A0B0B0D0E0F0F10111211121516161A1A
1E21202325242727292C2B2D2E2D303337393B3D3E3C3A363633312F2E2D2B2A27252321
201E1C1B1917161515131311100F0D0D0C0B0B0A09090908080706060505040304040403
030302030203030202020201010101010101010101000101000100000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000100010101010101010101010102020202020303
0303030304040405050505060707080809090A090B0D0D0F101012101212141516171B1D
1F2123262728292B2B2A303031303235373A3F403E403E3C373434312E30302B29282521
221F1D1C1918171515151312110F0E0D0C0B0B090A090808080808060504050404040403
040303030302020202010102020101010101010101010101000100000100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000000010000000001010101010101010102020202020202030302
030303030404040506050706070709090909090A0B0C0E0E110F10111213161719191B1E
1F2324282A2A2B2E2F3031353835353B3B3F41434442413F3C3736333433302E2B272524
23211F1E1C19171715161413110F0E0E0C0D0C0A0A090808080807060605050504040404
030303020202030202020101010101010201010101010101010101010100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000101010001010101010101010101020102020202030303
030303040404040505060607070809090A0A090A0B0C0D101011101113151617181C1C1D
2223272A2C2D2D313234383A3C3E3D403F434546474848413F3E3738373635322D2B2A24
2421201E1C1C17161616141312100E0E0D0C0C0A0C0A0907090807060606050404050403
030303030202020202020102010101010101010101010100010101010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001010100000101010101010101010101010101020202020303
03030303040505050506060707080909090A090A0A0C0D100F131212131516191B1D1E1D
2125272B2B303133363A3B3F404545484748484B4A4A47464541413C3B3838343130282A
272522201F1C1A181718151313100F0D0C0D0C0A0B0A0909080807070506050405040404
030303030202020202010201010101010101010101000100010100000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000101000101010101010101010101010101010202020202020303
030303030404050506070606080808090909090A0C0C0D0F101011141416181A1C1E2022
2227272B2F3135373B414446474A4A4B4A4A4C4B4C4E4C4A49444441413F3B3733302C2A
29272522231F1C1B1918161411100F0E0D0E0E0C0B0A0908080807060706050505040404
030403030303020302020202020102020101010101000101000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000010100010001010101020101010102010202020202020303
03030404050405050506060607080908090A0A0B0C0C0E1011101213141719191E1F2122
2327292A2F31363B3D46494B4E4F4E5050524E4C4C4D4E4F4C4A474642403A3A34322F2D
2B2B29272422201D1B17161412110E0F0E0E0E0C0C0A0A09070806070606050605050403
040303030302020202020202010202010101010101010101010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000001010101010101010101010201010102020202030303
030304040405050505050607070708090A0A090C0C0D0F10111113141619181C1F1F2122
2525292C2F34383E43494E4E50555352505050514F504E4F504E494B47433C3C37322F30
2C2B29282424201D1B18161513110F0F0E0E0D0D0C0B0909090808070607050505040404
030403030303020302020202010101010101010101010101000001010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010101010101010101010101020202020202020303
0303040404050505050605060607080909090A0B0C0D0F1010111414151A1B1D1F1F2223
2327292E33343D41474B4E5055555556545352515051514F5051524C4945433E38333231
302D2C2A2823211F1C1A16161411110F0E0F0E0C0C0C0A0A090908070606060505040404
030303030303020302020202020101010101010101010101000100000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000001010101010101020101010201010202020202030203
030304040405050405060606070708090A0A0C0D0E0E0F1011121416181A1D1E1F232322
26292C2F32393E4247505253535655595A585858555256555253514F4B48463D3D393432
322E2C2B2724211E1C1B17171514100F0E0E0C0C0B0B090A090908070706060505050405
040403030303020302010202010101010101010101010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001010000010101010101010101010101010201020202020202020202
03030405040505050506060607070809090A0D0D0E0F101012131415191A1D2122232325
252A2D3137394244494E4E53545858615D626564605E5D5A5752544E4B4B4544403B3534
32302E2A2924221E1D1A1817141412110F0D0D0C0C0B0B09090907070707060505050504
040303030302020202020202020201010101010101010101010000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000101010101010101010101010101020202030203030303
040304040405050605060707070808090A0B0D0E0E100F111113141719191E1E21232427
292C2F32383E42474C4E515456595E656C757576736D69605B5953504F4D4B46423F3B38
33302D2C2825201F1C1B1817161414110F0D0D0C0A0A0A09080808080806060605040504
040403030303020202020202010101010101010101010101010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000101010101010101010101010201010102020203030303
030304040405050506060707080809090B0B0C0D100F0F11121314181A1D1E1E22222526
2A2F31363A41464A4B4E5056575E6C737F87908F8A837A6D655A53544F4C4F4A46423E38
32302E2A2724211E1B1A1818151513110F0D0D0C0A090A0A090A08080706060505050505
040404030202030202020202020201020101010101010101010001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000101010101010102010101010201020202020203030303
030303030404050606060707070708080B0C0C0D0D0E0F10111214171A1C1F202125262B
2B2F34373F42474B4E4F52565D63728495A1A9ADAAA2907E6E605A504F504E4D4A453F39
33322F2C2927221E1D1A1817161413100F0D0C0B0A0A0A09090908080707050404050404
040303020303020202020201020201010101010101010101010001000100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000001010001010101010001010101010102020202020303030303
0403040404050506050607080707090A0A0B0C0D0E0E1010101313161A1D1F212426282B
3033363A3F44474C4F4E5356646E7E92AAB9C7CDC6BAA68F7A655B514F4D4E4E4C48413C
37312D2B282621201E1C1917151412120F0E0C0B0B0A09090A0908080606050505050403
030303030302030302020202020101010101010101010101010101010101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000101010101010101000101010101010102010202020303030303
030404040405050606060707070808090A0A0B0D0D0D100F101314181A1C1F202329282B
2F32383D3E45474B4E52545C687588A3B9D0E1E6E1CEBCA084705E534E4B4E4F4E49453D
352F2D2C292522211D1D1A1715131311100D0D0C0B0A0A09090907060706050505050404
040303030302020203020202010101020101010101010101010101000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000100010101010101010101010102010202020202020202030303
030403040405050506060707080708090A0A0B0C0D0E0F10101215171A1C202226272B2E
31343A3C4143464C4C4F535B677A90ABC4E0F2FBF1E4C8AC8D7560504E4C4C4D4B47413B
33312B27272522211D1D191817151211100F0D0C0C0B0A0A090808070606060504050404
040303030303020202020201020101010101010101010101010001000100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000001000101010101020101010101020202030203030303
03040404040505070606060608080808090B0C0D0D0E0F11111215171B1D21212528292C
3035393E3F43474B4C50535B667B8EADC7E3F4FFF8E8CFAC917660524F4A4F4F4A46443A
342D2929262622221D1D1917151612110F0F0E0D0B0B0A090A0708070706050504040404
040404030302030203020202020201010101010101010101010100010000000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001010001010001010101010101020102020202020202030303
030304040405050606070707070808090A0A0B0D0E0E1010111314171A1C21222427262C
3134383B404448484A4C515564748BA6C1DEF4F7F0E5CCAB8E756053504C4C4C4944413C
342E2C27252320201E1E191816141312100E0E0D0C0C0A09090808070706060404040404
030403030302020202020202020101010101010101010101000101000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000001000101010101010101010102020202020202030303
030304040405050506070607060708090A0B0B0D0E0E0F12111316161A1D20222227282C
2D33383D4044484B4E4B4E525B70829AB2CBDCE6E5D7C0A5896F5F554E4B4C4A49443F37
332D2927252322201D1C181915151311100E0E0D0B0B0909090809070607060604040405
040403030302020202020202020101010101010101010100000101010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101000101010101010101020101020203020202020303
03040304040505060606060707070809090A0C0D0E0E0F11111414191B1D20222225272A
2F32373D40464A4B4D4D50505764768AA6B5C5CECCBFB0987F6D5B514A4B494948443F3A
342F2A2A2521211F1C1B181716151311110F0E0D0B0A0A08080808080607060505040404
040303030302020202020202010201010101010101010101010001000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010101010101010101010202010202020202020303
0303030304050406060707070708080A0A090B0B0E0D1012121214171B1D1F222425262B
2C3236393E45464C4C4B4B50575D6A7B8E9DA9B0ACA99A89756457514849494847443F38
322F2D2A2622201C1C1918161615131210100E0D0C0B0909080908070707070504040404
040403030303030202020202020201010101010101010101000001000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000001010101010101010101010102020202020202020203030303
03030303040405050605070607080808090B0C0D0E0E0F11111315181A1C1F2123262529
2C2C33383C44474B504F4D515359606B7B869095938D8276675A4F4B4948474944413C39
342E2D292423201E1C1B1917141312110F0F0E0C0B0A0A08090708080807060605050403
040303030203020202020202010201010101010101010100010001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000001000101000001010101010201010202020202020203030204
030304030305050506060606070808080A0B0B0C0D0E100F10131418191C1D2121242628
2B2D33323A3F444C4E4E505152555B6067707A7E79776E665D524C4D47474547453D3B37
342E2B2A26231F1D1A181616141211110E0E0E0C0B090A09080808080807060604040403
030404030303020202020202020101010101010101010101010101010000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010100000101010101010101010102020202020202030303
03030303040405060606070707070909090A0B0C0D0D0E1011131516191A1E2021232429
292C3030353C42484D4F524F50505559616167686A68615C554E494846484644413F3B33
312F2A272523201E1A181714131311100E0E0E0D0A0B090A080807080706060504040403
030303030203020202020202020201010101010101010101000100010101010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010001010001010001010101010101010202020202020303030303
03030303040404060506070707070808080A0B0B0D0C0F0F111215151A1C1E2022232524
282A2C30343B40474A4D4F51515052545758575A5B5A59544F4948474846474441393733
2E2C282626211F1C1B1917141311120F0F0E0D0D0B0A0909090808070706050505050403
030303030203030202020202020102010101010101010101000001000000010101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000101000000000001010101010101020101010202030302030303
030403040404040406060607070808090A0A090B0C0D0E0E11121415181B1B1C20222524
27292B2C31393F42474B4C4F4F504F50504F505452514E4F4D4B48484B4945433E393530
2D29262324211F1C1A1816151311100F0D0E0D0B0A0A0909090808070605060505040403
030404030303030202020201010201010101010101010101010101010000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010101010101010101010101020202030202030303
030304030305050606060607080808090A0A0A0B0C0E0E0E0F1112161719181D1E1F2125
2726282C31363A3E4546484E4D4E4E4F4C4C4C4C4B4E4C4C4A4A4949494946403D37302E
28272623221F1F1D1A191615121110110F0E0D0D0B090A09080807060606050505040403
030303030303020302020101010101010101010101010101000001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000000000000000100010001010001010101010102010202020302030303
03030304040505050606070707090808090A0A0B0C0C0D0F1011131415191B1B1D1F2022
252728282D32373A3E414349484C4B4B4B4C474B494A47484A4A4A4B4946433E37342D28
28252322201F1F1B1A1817141212100F0E0E0C0C0B090909070607060606050505040403
030303030203020202020102010101010101010101000001000100000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000010000000101010101010102010102010101020203030303
030403040404040506060607070807080A0A0B0B0C0D0D0E101014151717171B1C1E1E1F
2426292A2C2F34353C3C3F47454B4B4E4C4D4B4C484745484749464744463D39362E2A27
25242321201E1D1C1818141512110F0F0E0F0D0B0A090808070707060605050505040303
030303030203020202020202010101010101010101000101000100000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000001010101010201010201010202020203030303
040304040404040505050606080708080A0A0A0C0B0D0C0D0F121112161617191A1C1E21
232526262A2E323235373A3F4246494A4C4B49464645454847454446403D3735312C2725
2423201F1F1D1C1B1A1715111211100F0E0D0D0C0A090908080706050604050504040403
030203020302020202020202010101010101010101010101000101000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010001000001010101010101010101010101010202020202020302
03030403040404040505060707070708090A0B0C0C0C0D0E1010121315161719191B1B1E
222225282A2C2D313236393B3E43484849484544444342444242413E3A39342F2A282523
2321211D1B1B191918161413100F100E0E0D0B0B09090908080706060505050404040403
030303030202020102020101010101010101010101000100010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000100000000000101010101010101010101010102010201010202020303
0303030404040405040606050707070708090A0B0C0B0D0E0F0F1213151519171A1B1D1E
201F222626282B2D2E3032353A3C40434444434441413E3E3E3C3B373532302C29262424
21201F1B1A1A1917161414121010100E0E0C0D0A09090807070606060504050405040303
030302020202020202010201010101010101010101010100010100000101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000001000000010001010101010101010101020101020102020202020303
030303040404040405050506060607070808090B0B0C0C0E0D10111313141616181B1C1E
1E1F21232527292E2C2F303335363A3B3D3F3C3F3E3B3B3A38383434302C2C2526242423
211F1D1C1A191816141312120F0E0D0F0E0D0C0B080A0708080705060605040504040404
030303030203010202020101010101010101010101010001010000010100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010001010101000101010101010101010102020202020203
030303030404040404050505060606070708090B0C0C0C0D0F0F0F1212141516181A191C
1C1C1F202226282B2C2D2E2E31313336393A3B3A383A373533322F2E2C29272423232522
211F1C1B1A181717151311110F0F0F0C0D0C0B0A09090808070606060505050404030303
030303030202020202020202010101010101010101000001000000010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000010001010101010101010101010102020202020202
020303030303030504040506060606060707090B0B0B0D0C0C0E0F101112141415171919
1A1A1D1F212425282A2C2B2C2C2D2E303332363636353432312E2C2A2825252426222320
221E1C181918151314121110100D0F0E0D0C0B0A09090708070707060505040404040303
030203020202020201020101010101010101010101000101000100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000010101010101010101010101020202020202020202
030303030304040404050505050606070808090A0A0B0C0E0E0D0F0F1112121414161717
17191A1C1F222326292A292A28292A2C2E303334343132302E2B2A262524242323242121
1F1D1A1A17171512131211100F0D0E0C0C0C0A0909080807070607060504040404040403
030303020202020201010201010101010101010101010001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000101010101010101010101010102020202020202
030203040304040404040506060607060807080A0A0B0B0A0C0D0F0E0F10111013141415
1616191B1D20232526262928282829282B2E2F3031312F2D2B292826242323212321201E
1D1B1B181715151213131010100D0C0C0B0A0A0909080707070706060405040404030303
030303020202020102010101010101010101010100010100000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000000000000010101010001010102010101020201020202020202
020202030404040304040505060607070708080809090B0B0B0C0D0E0E0E0F0F12121213
151616181A1E202224252626272726282B2B2C2C2F2D2B2A272524232222221F1F1E1D1C
1A1818161714141311110F0F0E0B0C0B0A0A090908070707060606050504040404040303
030202020202020201010101010101010101010100010101010000010100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000001010100010101010101010202010202010202020202
02020203040304040404050506060606070807090A09090B0C0B0D0D0C0F0E1011121213
14151819191B1C1F212323232524242625272C282B2A292524222122201F201E1D1B1A18
1516151514131313120F0F0E0D0D0B0B0A09080708070706070606060504050404040303
020303020202020202010101010101010101000101010000000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000010101010101010101010101010202020202020202
02020303030303040405050506060606070708080908090A0B0B0C0D0C0D0D0F0F101113
1315171518191B1B1C1F2022202424222526262727262523201F201E201D1D1B1A181616
14151514131211110F0F0D0D0C0B0A090A08070807070707050605050504050403040304
020202020202020102020102020101010100000100010100010000000000000000000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010000010101010101010102010102020202020202
02020203030303030304040505060607060707080808090A0B0C0C0C0C0D0C0E0E0F1112
121415141618181B1C1C1D1E201E2021202323232321221E1D1D1C1C1C1C1B1A18161515
1413121113120F0F0F0E0C0B0A0B0A090807080707070606060505040404040404030303
030202020202020202010101010101010101010101010001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100000000010101010101010101010101020201020202
02020203030303030404040505050606060606080809090A0B0A0B0B0B0B0C0D0E101110
1112131414161819191A1A1C1D1C1C1F1D2020201E1E1E1D1A1B1B1C1A1B191818151513
121111111010100E0E0C0B0B0B0A09090808070708060607060505040505040304030303
020202020202010101020101010101010101010000000000000101010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100010101010001010101010101010101010102020202
02020203030303030304040405050505060506060807080A0A0A0A0B0A0B0B0C0E0F0F11
10111111141516161819191A181B1A1C1B1B1D1E1D1C1A1A191819191919181716141313
13121110100F0E0E0E0C0B0A090A09080809080707060606060405050403030303020303
030202020202010201010101010101010101010001000100010001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100010101010101010101010101010101010202020202
020202020203030304030404040505050505060707080809090A0B0B0B0B0C0C0D0E0F10
1011111213131515151817171718181919191C1C1A1A1A19181916171819161515141411
111010100F0F0F0D0D0C0B0A090908080807070707060606050505040404030303030302
020202020201010201010101010101010101010100000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000101010101010101000001010101010101020201010202
02020202020203030304040404040504050505060607080809090A0A0A0A0B0C0D0C0F0E
0F1011111213141314151515171617151717171919181816171615151615151513131312
12110F0F0E0F0E0D0B0B0A0A090908070807070706060605050505040404040303030203
020202020201020201010101010101010101010101010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010101010101010101010101010101010102020202
020202020203020303030404040404050505050606070708090A080A0A0A0A0A0C0D0E0E
0F0F0F101213121315151313151514151516161717181815151414141514151312121311
11100F100E0E0C0C0A0B0908090808070806060606050506050504040403030403030202
020202020201010101010201010101010101010101010001010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000101010101000101010101010101010201010202
0202020202020303030403040404040405040506060707080809080908090A0C0C0D0E0D
0E0E10111012131212111213141414141514151614151614151413121313111111110F11
100E0E0E0C0C0B0A0A0A0809080707060606050505050504050404040304030303020202
020202020201020102010101010101010101010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010101010101010101010101010102020202
010202020303020403030304040405050504050505060608080809080908090A0C0C0C0D
0E0E0E0F0F10111211111212121312131313121415141414151212111110100F0F0E110E
0E0F0C0C0B0C090A0A090908070707070706060605050504050404050403030302030302
020202020202010101010101010101010101010101010100000001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000001010101010101010101010101020101020202
020202020202020303030403040404040405050506060707080807080808090A0A0C0D0D
0D0E0F0F100F10101010101010121112121312121212121112110F0F0F0F0D0F0F0D0E0E
0D0E0D0D0B090A0908090808070606060605050505040404040404040304020303020302
020202020201020101010101010101010101000101000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000001010101010101010101010101010101020202
02020202020202030303030403030404040404050506060607080707070708090A0B0C0C
0C0D0E0D0F0F0F100F0E0F0F1010101112111110101010110F100F100F0E0D0E0E0D0D0E
0D0C0B0B0A09090908080708080707050606050505040404040404030303030202030202
020202020202010201020101010101010101010001010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010101010101010101010101010101020101
020202020202020303030303030404040404050405060506060708070707080809090B0B
0B0B0C0D0D0E0E0E0E0E0E0E0E0F0F10100F10100F110F0F0F0F0D0E0E0E0D0C0E0E0D0D
0D0C0C0A0908080808080807080707060505050404040404040303030303020303020202
020202020201010201010101010101010101010100010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010101010101010101010101020102
020202020202030203030203030403040304040405050505060607060707070808090A09
0A0A0C0C0C0D0D0C0E0D0C0D0D0D0D100F0F0D0F0E0F0E0E0C0D0E0E0C0D0D0C0C0D0A0C
0C0B0A0A0A07080708070706060606060505040404040403030303030303030302020202
020202010101020101010101010101010101010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000000000000001010101010101010101010101020101
020202020201020202030203030303030304040405050606070707070707060808080908
09080A0B0B0C0C0D0C0C0C0B0B0D0D0D0D0D0D0E0E0D0D0C0C0C0C0D0C0B0C0B0C0B0B0B
0B090A090908070807070707070606060405040404040304030203030302020302020202
020202020202020101010101010101010101010000000000000000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000101010101010101010101010101
010202020202020202020302030304030404040404050505050606070806070708090808
08080909090A0B0B0C0B0B0C0B0C0D0C0D0D0C0D0C0C0C0C0C0B0C0C0B0B0B0C0B0A0A09
0A0909090807080607060606060504050504040404030303030303030303030202020202
020202020101010101010101010101010101010100010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010101010101010101010101010102
010201020202020202020203030303030304040404040405050506070606060707080808
0808080909090B0A0A0A0A0A0A0A0C0B0B0C0C0B0B0C0B0B0A0B0B0B0B0B0A0A0A090909
090908070806070707060506050505040404050404030303030303020302030202020202
020201010101010101010101010101000101000000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010101010101010101010101010102
010201020202020202020202030303030304040404040504040506060606070708070807
0707080708090909090A0A090909090A0A0A090B0A09090A0B0A0B0A0A0A0A0A0A080808
080808080707060706050505050305050404040304030303030303030202020202010202
020201010101010101010101010101010100010000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000010100010101000101010101010101
010201020202020202020202030303030303030304040404050505060606070607070807
0708070807080808080909090808090A090909090A090A0A090A0A080A090A0908090808
070706070606060605050405040504040404030403030203030303020202020202020201
010102010101010101010101010001000101000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000000001010101010101010101010101
010201010102020202020302020302030303030303040405040505050506060606060707
080707070706080708070807080809090909090809090908080909090908080808070707
060707060606060605050504040404030304040303030303030202030302020202020202
010101010101010101010101010101000100010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000101010101010101010101
010101010102010202020202030202020303030304030404050404040504060506060606
060707070607060707080708070807090908080809080809090908080908080708070706
060606060505050505050404030404030404030303020202020202020202020202020201
010101010101010101010101010001010100000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000000010000000001000101010101010101
010101010101010202020202020202020302030303040504040404040405040505050506
060707060606060708070807070707070707080808070809080807070808070808070705
070505050505050605040404030303030303030302020303020302020202020201020102
020101010101010101010101010101010001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000001010100010101010101
010101010101010202020202020202020203020303030303030405040505050404040505
040606070606060707080807070707070808070707070708070608070707060607070607
070506050505050505050403030303030303030202030202020302020201020201020101
010101010101010101010101010100000000000101000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010001010101010101
010101010101010202020202020202020302030303030304040404050403040403040404
050505050606060707070607070706070707070706070707070707060606060606060705
060606050506040404040403030303030303030302020203030202020202010201020101
010101010101010100010101010101010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010001010001000100010101
010101010101010102020202020202020302020203030303030304030404040304040404
050405050505060606060706060606060706070506060606060606060605060606070505
050505050505050404030304030303030203030302020202020202020102020201010101
010101010101010101010101010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000010001000001010000010101
010101010101020101010102010102020202020203020303030303030404040404030404
040404050505050505050606060606050606060506060506060505060505050505060505
050405040504030404030303040303030303020202020202020202020202020201010101
010101010101010101010000000100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010101000101
010101010102010201010101010202020202030302030303030303030303040304040404
040405040505050505050505050606060605060505050505060505050505060504050505
050404030404040304040404040303020303030202020202020202020202010102010101
010101010101010101010001000101000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010100000101010101
010101010101010101010101010201020202020202020203020302030303030303030404
040404040405040404050505060506050505050404040505050505050404050405050504
040404040404040404040303030303020302030202020202020202020201010101010101
010101010101010101010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001010001010101010101
010101010101010101010101020101020102020202030202020302020303030303030403
040404040404040405040405050504050505040505050405050505040404050404050504
040403030304030303030303030303020202020202020102020201010101010102010101
010101010101010001000100000101000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000001010101
010101010101010101010101020102010202020202020202020202020203020302030303
030304040404040404040404040405050504040404040405040404040404040504040404
040403030304030403030303030302030202020302020201020201010201020101010101
010101000101000101010001000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010100010101
010101010101010101020101010102010202020202020202020102020202030303020303
030403030404030404040404040405050404040404040405040304040304040404030403
040303030302030302030302030302020202020202020202010202010101010101010101
010101010001000101000101010100010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000000010001000101
000101010101010101010101010101020202020202020202020202020203020202030303
020303030204030304030404040404030404040304040404040404040304030404040403
030303030303020203020202020202020202020202010202020101010101010101010101
010101000101000000000100010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
010101010101010101010201010101010101020201010202020202020202020202020203
020303030303030303030303040404040404040404040403040403040303020303030303
030303020203020202020202020202020202020201010201010101010101010101010101
010101000100000001010001000000000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000100
010101010101010101010101010101010101020201020102010202010202020202020202
030202030303030403020304030303030303040403040303040303030303040303030303
030302030202030302020202020202020202020202010101010101010101010101010101
010101010100000001010100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
010101010101010101010101010101010101020201020201020102020202020202020203
030302020303020303030303020303020303030303030303040303030303030303030303
030303030302020202020102020202020202020101020101010101010101010101010101
010101000000000100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000010101
010101010001010101010101010101010101010201020102010201020202020202020303
020203020203030202030303020303020302020203030303030304030303030303030303
020302020202020202010201020202010202010101010101010101010101010101010101
010101000000000001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101010101010101010101010101010101010201020102020201020202020202
020302020202030202020203020202020203020302020303030203030302030202030303
020202020202020202010202020101020202010101010101010101010101010101000101
010000000100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000000000000000001
000001000101010001010101010101010101020101010101010201010201020102020202
020203030202030303020202020202020202020202020303030202020303020303020303
030202020202020201020102020202020201010101010101010101010101000100010101
010100000000000100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000101000001010101010001010101010101010101010101010101010201010102020202
020202020202020302020202020202020202020202020202020203030202020203020202
020202020202020202020102010201010101010101010101010101010101000101010101
010100000100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010100
000101000000000101000101010101010101010101010101010101010102010102020201
020102020202020202020202020202020202020202020202020202020202020202020202
020202020202010101020201010101010101010101010101010101010101000100010101
010100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000101010101010101010101010101010101010101010101010101010101010101
010202020102020202020202020202020202020202020201020202020202020102020202
020202020101010201010101010101010101010101010101010101000001010101000001
000001000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
000000010000000100000100010101010101010101010101010101010101010101010101
020202020202010202020101020202020202020202020202020202010102020202020202
010102010102010101010101010101010101010101010001010101010101010100010000
000000000100000000000001000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000010100010101010101010101010101010101010101020101
020101020202020201010101010202020202020202020202020201010101010202010202
010201010201010101010101010101010101010101010101010100010101000001010000
000001000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
000000010000000100010001000001010101010101010101010101010101010101010101
020101010202020201010102010101020202020202020201020102020202010101020201
020101020101010101010101010101010101010101010101010101000001000100010100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000000
000100000001000000000000010100000001000101010101010101010101010101010102
020101010201010101010101010101010101020201020202010101010101010101010101
010101010202010101010101010101010101010101010101000101010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000000000101010101000101010001010101010101010101010101010101
010101010102010101010101010101010102010101020201010101010101010101010101
010101010101010101010101010101010101010101000101010101010101000001000000
000000000001000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010001010000010000010101010101010101010101010101010101
010101010101010101010101010102010102010101020101010101010101010101010101
010101010101010101010101010101010101010101000101010000000100000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000000000000000001000000010101010101010101010101010101010101
010101010101010101010101010101010101010102020101010101010101010101010101
010101010101010101010101010101010101010100010001000001000000000000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000101010101010101010101010101010101
010101010101010101010101010101010101020101010101010101010101010101010101
010101010101010101010101010001010100010100010000010000000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100010001000101010100010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010001000000000000010100000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000000000001010101010101010101000101010101
010101010101010101000101010101010101010101010101010101010101010101010101
010101010101010101010101010001000101010101000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000101010100000101010101010101010101
010101010100010101010101010101010101010101010101010101010101010101010101
010101010000010101010101010101000100010101000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010000010000010101010101010101010101
010101010000010101010101010101010101010101010001010101010101010101010101
010101010000000000000101000000000100000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000001000000000000000100010101
010101010101010001000001010101010101010101010101010101010101010101000101
010100010000000001010100000100010000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000000000000000000000010101010100010101
010101010101010101010100010101000100010101010001010101010000010101000100
000100010000000100000100000101000000010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000000010000000000
010101000101010100010101010100010101010101000101010101000101010101010001
000101000100000101000000000000010000000000010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000101010100000100000000010000000001010101010101010000010101010101010100
000001000000010100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000000000000010000
010101000001000001000001010101010100010101000001010000010100000001010000
010100000100010000000000000001000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000010100
000000000000000101010000010001010001000101010100000100000100000101000100
000000010001010000010000000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010001
000100000000010001010100010100000000010100010100000100000000010100010000
010000000101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000001
000000000000000000010000000000010001010000010001000001000000000101000001
010001000001000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000000000000000000000001000001010100010000000000000100000000010000
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000001000000000100000000000000010000000000000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010001000000000000000000000000000000000000000000000000
000100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000000000000000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJU90000000300410@000000000003d00000103AcJT000<0dLfY?P0000000`01
0@40000000000018000000@0dLfY00030=7=ZCl0000000<00@410000000000000P00000200410@80
000000<00@41000000000000?P0000040=7=Z@000`3AcJTl0000000300410@000000000000800000
00<00@41000000010@400P00000010010@400000000000010@420000000300410@000000000003X0
0000103AcJT000<0dLfY>P00000300410@80000000H00@41000000010@400@41000000010@4:0000
00<00@4100<0000000410@000000=00000040=7=Z@000`3AcJT/0000000300410@000000000000T0
000000<00@410000000000001@0000000`010@40000000410@020000000400410@00000000000000
00<00@410`0000000`010@40000000410@0g000000@0dLfY00030=7=ZC@0000000<00@4100000000
00000P00000200410@03000000010@400@4100800@410`00000300410@80000000<00@4100000000
00000P010@42000000H00@41=00000040=7=Z@000`3AcJTe000000@00@4100<0000000410@010@40
0P010@400`0000000@4100410@0600410@80000010010@400`0000000@4100410@0300410@030000
00010@40000003<00000103AcJT000<0dLfY;`0000000`010@4000000000000700410@0300000001
0@400@4100h00@410P00000500410@<0000000<00@41000000000000<P0000040=7=Z@000`3AcJT_
0000000400410@0000000@4100410@80000000<00@41000000010@406P010@400`0000000@410041
0@030000000300410@000000000002h00000103AcJT000<0dLfY;`0000000`010@40000000410@0W
00410C000000103AcJT000<0dLfY:`0000000`010@40000000410@0200410@03000000010@400@41
00h00@4100<00P8200410@010@405@010@400`0000000@41000000030000000300410@0000000000
02L00000103AcJT000<0dLfY:P00000A00410@800P8200<00@4100820P020P800P010@400`020P80
0@4100410@0200820P0400410@020P800P8200820P800@4100<00P8200410@010@401`010@401@00
00000@410000000000000@4100@0000000<00@410000000000009P0000040=7=Z@000`3AcJTV0000
000300410@0000000@4101000@410P020P800`010@400P8200820P0=00820P0300410@020P800P82
00<00P8200<00@4100820P010@402@010@40100000000@4100410@010@4X000000@0dLfY00030=7=
ZBP0000000<00@41000000010@400P010@400`0000000@4100410@0600410@0400820P010@400@41
00410A@00P820P010@4300820PP00@4100@0000000410@010@4000000`010@4W000000@0dLfY0003
0=7=ZBD000000P010@42000000h00@411@020P800`030`<00P8200820P0200820P0300<30`020P80
0P8200800P8200<00`<300820P030`<01@020P8200410@0500820P010@400P8200410@020P802`01
0@420000000300410@000000000002@00000103AcJT000<0dLfY9000000500410@03000000010@40
0@4100D00@410P020P8300410@800P8200@00@4100820P020P800P820P030`<00`020P800`<30082
0P0300<30`800P8200@00`<300820P030`<00`<32@020P8200410@0300820P010@400@4100P00@41
:@0000040=7=Z@000`3AcJTS000000<00@4100<0000000410@00000020010@4:00820P800`<300<0
0P8200<30`030`<02@030`<00`020P800`<300<30`0200<30`H00P823P010@4W000000@0dLfY0003
0=7=ZB<0000000@00@41000000010@4000001`010@400`020P800@4100820P0500820P0300<30`02
0P800P8200<00P8200<010@400<30`030`<02@030`<01@0410@00`<300@4100410@00`<300800P82
00<00`<300820P020P8010020P8200410@0400820P010@400@4100820PD00@4100<0000000410@00
00009@0000040=7=Z@000`3AcJTP0000000300410@000000000000`00@410`020P800`030`<00P82
00820P0200820P0300<30`020P800P8200L00`<30P0410@00`030`<010@400@4100600@410@00`<3
00<00P8200<30`020P800`020P800`010@400P8200820P0200410@0300820P010@400@4100<00@41
1P0000000`010@4000000000000O000000@0dLfY00030=7=ZB40000000@00@41000000010@400000
2P010@4400820PT00`<31`0410@400D51@0400@410051@D01@D500D51@8010@400<00`<300@41003
0`<010030`<200820P0300410@020P800P8200800P8200<00@4100820P010@4010010@4010000000
0@4100410@010@4S000000@0dLfY00030=7=ZAl000000P010@42000000/00@410`020P8600<30`03
00@410030`<010@4008010@40P051@D00`0410@01@D500D51@0200D51@0300H61P051@D01@D500H0
1@D500<010@400D51@0410@00P0410@300<30`P00P822`010@4R000000@0dLfY00030=7=ZB400000
00<00@41000000010@401`010@400`020P800@4100820P0200820PD00`<300H010@400<30`0410@0
10@400D51@0410@200D51@0300H61P051@D01PH600801PH600L01`L700H61P071`L01`L700H61P05
1@D01PH600<01@D500<010@400D51@0410@00P0410@00`030`<010@400@4100200<30`P00P822@01
0@4R000000@0dLfY00030=7=ZB0000002`010@400`020P800@4100820P0700<30`@010@40P051@D2
00H61PX01`L700<01PH600L71`071`L00P061PH200D51@0600@410051@D010@400D51@030`<010@4
10030`<500820PH00@4100H0000000410@010@400@41000000010@4P000000@0dLfY00030=7=ZAh0
000000<00@41000000010@4020010@4600820P<00`<30P0410@010051@D010@400D51@0410@200D5
1@801PH60`071`L200P820<01`L70P0820P01@092@T020P800P8200820P01`L700801PH610051@D0
0`0410@01@D500D51@0600<30`D00P821P010@400`0000000@4100410@0Q000000@0dLfY00030=7=
ZAd0000000<00@41000000010@400P00000600410@@00P820P030`<010020P800`<300<30`030`<4
00@410801@D500<01PH600D51@061PH00P061PH00`071`L020P800P8200200T92@0300L71`092@T0
20P800<02@T90P0820P00`071`L01PH600H61P0200H61P0300D51@061PH01@D500D010@400@00`<3
00@410030`<00`<30`020P8200410@800P821P010@4Q000000@0dLfY00030=7=ZAh000000P010@42
000000800@4100@00P8200410@010@400@4110020P8400<30`0300@410051@D010@400<01@D50P06
1PH200L71`0500P820071`L02@T900T92@0:2PX010092@T0100:2PX02@T900T92@0:2PX300T92@80
20P800<01`L700P820061PH00P061PH00`071`L01PH600D51@0400@410<00`<31`020P8600410@80
000000<00@41000000000000700000040=7=Z@000`3AcJTM0000000500410@0000000@4100410@00
00001@010@4400820P0600<30`020P800`<300@410030`<010@40`051@D01@061PH01`L700L71`07
1`L020P800<02@T900<02PX:00/;2`0;2`/00`0;2`/200X:2P0400/;2`0<30`02`/;00/;2`<02PX:
00D020P800T92@0820P01`L700H61P0400L71`801@D50P0410@500<30`@00P822@010@4200000003
00410@000000000001X00000103AcJT000<0dLfY6000000010010@400000000000010@42000000T0
0@4110020P8200<30`<010@400<01@D500H61P061PH00P061PH00`0820P01`L700P8200200T92@03
00X:2P092@T02`/;00802`/;200=3@d200`<300300/;2`0:2PX02`/;00802PX:00@020P800L71`08
20P020P80P071`L200H61P801@D510030`<00`020P800`<300<30`0200820P0300410@020P800@41
00H00@410`0000000`010@4000000000000I000000@0dLfY00030=7=ZAT0000000@00@4100000000
0000000010010@401@0000000@4100410@020P800@4100D00P821@0410@200D51@0700H61P071`L0
1`L700L71`0:2PX020P800/;2`0200X:2P802`/;00<03@d=00h>3P0>3Ph00P0?3`l2010@4004014A
4@0>3Ph03Ph>00`<30803@d=00<03Ph>00d=3@0<30`00P0;2`/010092@T01`L700P820071`L200H6
1P0500D51@061PH01@D500D51@0410@00`030`<400820PT00@4100<0000000410@00000070000004
0=7=Z@000`3AcJTM000000P00@4100<00P8200410@020P800P020P8200<30`@010@400/01PH600D5
1@061PH01PH600L71`0820P02@T900X:2P0;2`/030`<00/;2`0200d=3@D0410@00D04a<C014A4@0A
4A40410@00d=3@0200l?3`03010@400?3`l03`l?00<03@d=0P0;2`/00`092@T020P800P8200200L7
1`801PH600<01@D500@4100410@00P030`<500820PP00@417`0000040=7=Z@000`3AcJTL000000X0
0@410`020P8300<30`8010@40P051@D200H61P801`L700D020P800T92@0:2PX030`<00h>3P0200d=
3@0900l?3`0A4A4051@D01@D500E5AD04Q8B01<C4`0D51@05ADE00<04a<C0P0B4Q800`0D51@04A4A
014A4@02010@400300h>3P0=3@d030`<00802PX:00@020P800L71`071`L01`L70P061PH200D51@04
00@410030`<00`<300<30`L00P821@010@400`0000000@41000000030000000300410@0000000000
01D00000103AcJT000<0dLfY7000000700410@0300820P010@400P8200<00P820P030`<300@41080
1@D500@01PH600L71`0820P020P80P0:2PX00`0<30`03Ph>00l?3`0200l?3`04014A4@0C4a<05QHF
01LG5`@061PH0`0G5aL201HF5P0301LG5`0F5QH05ADE00804a<C00H0410@00l?3`0?3`l03@d=00`<
300;2`/300T92@0300P820071`L01PH600801@D500<010@400<30`030`<00`030`<00`010@400P82
00<30`0200410@0500820P010@400@4100410@0000000P010@400`0000000@410000000I000000@0
dLfY00030=7=ZAT0000000<00@41000000010@4020010@4300820P<00`<30`0410@200D51@0300H6
1P071`L01`L700802@T900<02PX:00`<300=3@d00P0>3Ph0200@41004A4A018B4P0D51@05QHF01TI
6@0K6a/071`L0`0K6a/0200L71`06a/K01XJ6P0I6AT061PH01TI6@0H61P05ADE0P0B4Q82014A4@80
3`l?00<02`/;00X:2P0:2PX00P092@T01P071`L01PH600D51@061PH01@D500@410@00`<31@020P84
00410@04000000010@40000000410A/00000103AcJT000<0dLfY6`00000900410@<00P8210030`<0
1@0410@01@D500@410051@D01`L7008020P800L02PX:00T92@0:2PX030`<00h>3P0@41003`l?0080
410@00/051@D01DE5@0H61P06QXJ01dM7@0N7Qh06a/K01`L700M7Ad07QhN01`L700201/K6`0<01TI
6@0J6QX061PH01LG5`0E5AD04Q8B014A4@0B4Q80410@00l?3`0<30`02`/;0P0:2PX200P8200400L7
1`061PH01PH600D51@8010@40`030`<200820P0500<30`020P800P8200410@020P800`010@400`00
00000@410000000K000000@0dLfY00030=7=ZA/000001`010@4500820P800`<30`0410@300D51@03
00L71`0820P02@T900802PX:00h03@d=00h>3P0>3Ph03Ph>010@400A4A405ADE01TI6@0J6QX06a/K
01`L700P82008B4Q020P80808B4Q01808b<S024Q8@0N7Qh07QhN01lO7`0N7Qh071`L01XJ6P0H61P0
5aLG01@D500C4a<04Q8B014A4@0?3`l030`<00/;2`0:2PX200P8200500L71`061PH01`L700H61P05
1@D0100410@010030`<00P8200820P020P8700410@8000000P010@4I000000@0dLfY00030=7=ZA`0
00001`010@400`020P800`<300820P0300<30`<010@400H01@D500H61P061PH01`L700P8200:2PX2
00/;2`0K00d=3@0>3Ph03`l?010@400C4a<05QHF01TI6@0L71`0820P024Q8@0S8b<092@T02<S8`0T
92@09BDU02PX:00];Bd0:BTY02LW9`0V9RH09BDU02@T900R8R807QhN01dM7@0L71`06QXJ00805ADE
00L04Q8B010@400>3Ph03@d=00/;2`0:2PX02@T900<01`L70P051@D00`0410@01@D500@4100300<3
0`<00P8220010@440000000300410@000000000001@00000103AcJT000<0dLfY6P0000000`010@40
00000000000400410@<00P8200<00`<300820P020P800P030`<00`0410@01@D500D51@0200D51@07
00H61P0820P02@T900X:2P0<30`03@d=00l?3`02010@4005014A4@0E5AD06QXJ01/K6`0P82000P0R
8R806P0T92@0:2PX02PX:00X:2P0:b/[02l_;`0g=cL0<c<c02l_;`0Y:BT0:RXZ02PX:00V9RH08R8R
024Q8@0N7Qh071`L01PH600F5QH051@D018B4P0@41003Ph>00`<300;2`/02@T90`071`L010061PH0
1@D500@4100410@300<30`@00P821`010@430000000300410@000000000001H00000103AcJT000<0
dLfY6000000010010@40000000410@00000500410@D00P8200P00`<300@410030`<00`<300D51@04
10@01@D500H61P8020P800D02@T900/;2`0=3@d03Ph>00l?3`02014A4@0O01DE5@0F5QH06QXJ01hN
7P0P82009BDU02LW9`0Y:BT0:b/[02h^;P0];Bd0<c<c03Ti>@0m?Cd0?3`l03Hf=P0c<c<0<C4a02h^
;P0[:b/09bLW02<S8`0P820071`L01TI6@0G5aL05ADE01<C4`0A4A403`l?00d=3@0200/;2`802@T9
00H020P800H61P051@D010@400<30`0410@400<30`<00P821@010@400`0000000@4100410@0J0000
00@0dLfY00030=7=ZAL0000000<00@410000000000000P00000500410@@00P8200D00`<300820P03
0`<00`<300@4100200D51@801`L70`092@T0:00;2`/03Ph>00h>3P0?3`l04A4A01<C4`0G5aL06ATI
01hN7P0O7al092@T02XZ:P0[:b/0;bl_034a<@0h>3P0=CDe03/k>`0o?cl0@d=30492@P0o?cl0=cLg
03Hf=P0d=3@0<30`02/[:`0U9BD08b<S01lO7`0L71`06ATI01LG5`0F5QH04a<C00l?3`0>3Ph03@d=
00`<300:2PX200P8200400L71`061PH01@D500D51@8010@400<00`<300820P020P800P020P830041
0@0300820P010@400@4100@00@416@0000040=7=Z@000`3AcJTI000000800@4100<0000000410@01
0@401@010@4300820P<00`<30P051@D200H61P0;00L71`092@T02@T900T92@0:2PX03@d=010@400C
4a<04Q8B01DE5@0I6AT00P0M7Ad0200Q8B409bLW02/[:`0a<C40=SHf03/k>`10@400ADE50P18B4P0
0`1;Bd/0BTY:04I6AP020451@@0803/k>`0h>3P0<C4a02PX:00W9bL08R8R01lO7`0L71`201PH6009
01<C4`0@41003@d=00d=3@0<30`02`/;00T92@0820P01`L700801@D50`0410@200<30`@00P821@01
0@420000000500410@0000000000000000010@405P0000040=7=Z@000`3AcJTJ000000L00@411@02
0P8200<30`8010@400@01@D500H61P061PH01`L70P092@T00`0:2PX030`<00h>3P02010@400Q01<C
4`0G5aL06ATI01lO7`0R8R808b<S02TY:@0_;bl0=SHf03dm?@19BDT0CTi>04m?C`1@D500DU9B04a<
C01=CDd0Cdm?04Y:BP17AdL0@T9203Xj>P0d=3@0;bl_02/[:`0Y:BT092@T028R8P0M7Ad05aLG01@D
500A4A403`l?00803Ph>00<030`<00X:2P071`L00P061PH00`051@D01PH600D51@0300<30`@00P82
00<00@4100820P010@401@010@4J000000@0dLfY00030=7=ZAX0000020010@4400820P800`<30140
10@400D51@051@D01PH600D51@061PH020P800T92@0:2PX030`<00l?3`0@41004A4A01@D500J6QX0
7AdM01lO7`0202<S8`0502TY:@0c<c<0?Cdm04M7A`1>CTh00P1EEED04`1FEUH0De=C055AD@1ADE40
Cdm?055AD@1BDU80BDU904=3@`0h>3P0<S8b030`<00/;2`0:2PX02<S8`0O7al06QXJ01HF5P0A4A40
0P0?3`l01@0>3Ph030`<00X:2P092@T020P800801PH600<01@D500@4100410@010030`<300820PL0
0@410`0000000`010@4000000000000D000000@0dLfY00030=7=ZAP0000000<00@41000000000000
1`010@4300820P<00`<300<010@400D51@0410@00P061PH05P071`L020P800X:2P0<30`03Ph>00l?
3`0@41004Q8B01HF5P0J6QX07QhN02<S8`0R8R809RHV02`/;00b<S80?Shn04M7A`1BDU80De=C05IF
EP1IFET205QHF00D059BDP1EEED0De=C055AD@1;Bd/0ATI603dm?@0d=3@0<S8b02`/;00W9bL092@T
01hN7P0K6a/05aLG01@D500?3`l03Ph>00`<300;2`/200T92@0300P820071`L01PH600<01@D500@0
10@400<30`030`<00`<30P020P8700410A/00000103AcJT000<0dLfY600000000`010@4000000041
0@0700410@0300820P030`<00`<300<00`<300@010@400D51@061PH01PH60P071`L0:00820P02PX:
00d=3@0>3Ph03`l?014A4@0C4a<05aLG01TI6@0N7Qh08b<S02LW9`0Y:BT0;bl_03Ph>012@T80C4a<
055AD@1FEUH0FEUI06EUI@1eMGD0MWIf06e]K@1PH600FEUI05=CD`1?Cdl0Bd];0492@P0k>c/0<c<c
02d];@0X:2P09BDU01lO7`0K6a/05aLG01@D500A4A4200d=3@802PX:0`0820P200H61P<010@40P03
0`<300820PT00@416@0000040=7=Z@000`3AcJTJ000000@00@4100@00P8200410@010@400@410P02
0P8500<30`0300@410061PH01PH600801`L700/020P800/;2`0<30`03@d=00l?3`0@41004Q8B01LG
5`0L71`0820P02DU9@0202/[:`0M03@d=00o?cl0AdM704i>CP1BDU80GEeM06=SH`24Q8@0XJ6Q0:f]
[@2RXZ80OWin061PH01JFUX0Cdm?04i>CP1:BTX0?clo03<c<`0_;bl0:BTY02LW9`0N7Qh06QXJ01LG
5`0D51@0410@00d=3@0<30`00P0:2PX02P092@T020P800L71`051@D010@400D51@0410@00`<30082
0P030`<400820PH00@416`0000040=7=Z@000`3AcJTI000000P00@410`020P8300<30`8010@400<0
1@D500H61P061PH00P071`L06`0820P02PX:00/;2`0=3@d0410@00l?3`0C4a<061PH01`L700P8200
:BTY02/[:`0_;bl0>3Ph03hn?P17AdL0CTi>05ADE01XJ6P0MGEe0:>SX`3@d=00i^KV0<k>cP2PX:00
L71`05iNGP0304i>CP0:04E5A@0e=CD0;Bd]02TY:@0U9BD08B4Q01dM7@0G5aL04a<C014A4@803@d=
00<02`/;00X:2P092@T00P071`L300D51@0300@410030`<00`<300800P8200<00`<300820P010@40
1`010@400`0000000@410000000G000000@0dLfY00030=7=ZA`000001P010@400`020P800`<300<3
0`0200<30`8010@400@01@D500L71`061PH01PH60P0820P06P092@T030`<00d=3@0?3`l04A4A018B
4P0G5aL07AdM024Q8@0X:2P0;2`/030`<00i>CT0?clo04M7A`1<C4`0De=C06IVIP1kNg/0[Jf]0>?S
h`3oool0j>SX0:b/[01fMWH0H61P0P1?Cdl0101:BTX0A4A403@d=00Y:BT202HV9P08028R8P0M7Ad0
5aLG01HF5P0A4A403`l?00h>3P0;2`/200X:2P0400P820071`L01@D500D51@<010@400@00`<30082
0P020P800`<30P020P8800410@03000000010@40000001H00000103AcJT000<0dLfY600000001001
0@40000000000000000500410@@00P820`030`<0100410@01@D500D51@071`L200H61P0@00P8200:
2PX02`/;00h>3P0?3`l04Q8B01<C4`0F5QH07AdM028R8P0W9bL0;2`/02d];@0h>3P0@41004Q8B080
CTi>01H0Fe]K071`L02JVYX0bl_;0>KViP3GemL0YJFU06m_K`1OGel0CTi>04a<C019BDT0?clo03<c
<`0Y:BT09BDU02<S8`0P820071`L01TI6@0E5AD04A4A0P0>3Ph0100;2`/02@T900T92@092@T300H6
1P0400@410051@D010@400<30`D00P821@010@40100000000@4100410@010@4H000000@0dLfY0003
0=7=ZAX000001`010@4500820P<00`<300<01@D500H61P071`L00P071`L01@0820P02PX:00/;2`0>
3Ph0410@00804Q8B02D05aLG01dM7@0R8R809BDU02/[:`0/;2`0=SHf03hn?P16ATH0C4a<04];B`1G
EeL0GEeM07]kN`2MWId0/;2`0:VYZ@29RHT0I6AT05MGE`18B4P0BDU904M7A`0o?cl0<S8b02d];@0V
9RH08R8R01`L700I6AT05QHF01DE5@0B4Q80410@00h>3P0<30`02@T9008020P80P071`L010051@D0
10@400@4100410@200<30`@00P821P010@4K000000@0dLfY00030=7=ZAT000000P010@401P000000
0@4100410@010@400P8200410@<00P820P030`<00`0410@00`<300<30`0200D51@801PH601d01`L7
00P8200:2PX02`/;00d=3@0@41003`l?01<C4`0H61P071`L024Q8@0T92@0:2PX02/[:`0c<c<0>SXj
04A4A01>CTh0D51@059BDP1EEED0H61P071`L01nOWh0MgMg06IVIP1BDU80C4a<04M7A`0204E5A@0:
03/k>`0d=3@0:b/[02HV9P0S8b<07AdM01PH600F5QH04Q8B014A4@803Ph>00<02`/;00X:2P0820P0
0P0820P200H61P0300@410030`<010@400800`<310020P8800410@80000000<00@41000000000000
500000040=7=Z@000`3AcJTJ0000000300410@0000000@4100@00@4110020P8400<30`0300@41006
1PH01PH600801`L70P092@T02@0;2`/03@d=00h>3P0@41004a<C01HF5P0J6QX0820P02<S8`0202TY
:@05030`<00e=CD0@T9204e=C@1BDU800P1@D5001`1IFET0HF5Q06QXJ01XJ6P0G5aL04i>CP19BDT0
0P16ATH02`11@D40>c/k034a<@0Z:RX09BDU02<S8`0N7Qh061PH01@D500C4a<0410@00803Ph>00<0
2PX:00T92@0820P00P071`L00`061PH01@D500@4100400<30`@00P822P010@4G000000@0dLfY0003
0=7=ZAT0000000<00@4100000000000010010@401@020P800@4100820P030`<00P8200800`<31004
10@200H61P0500L71`0820P02PX:00T92@0<30`00P0>3Ph03@0B4Q805ADE01/K6`0L71`08R8R02@T
900W9bL0:b/[034a<@0o?cl0AdM704a<C01?Cdl00P1@D5005P1?Cdl0E5AD055AD@1?Cdl0Bd];04Q8
B01;Bd/0ADE503hn?P0e=CD0;Bd]02HV9P0T92@08B4Q01`L700H61P05ADE014A4@0?3`l03Ph>00d=
3@0:2PX200T92@0700P820061PH01PH600D51@0410@00`<300@4100200<30`<00P822@010@4I0000
00@0dLfY00030=7=ZAD0000000<00@410000000000000P00000300410@04000000010@400@410041
0@@00P820`030`<0100410@01@D500D51@061PH200L71`0I00P820092@T02PX:00`<300=3@d03`l?
014A4@0D51@06ATI01/K6`0O7al08R8R02DU9@0X:2P0;Bd]03Lg=`0n?Sh0@d=304Q8B01<C4`0Bd];
04a<C01;Bd/0BTY:04Q8B00204Y:BP0A04U9B@13@d<0=cLg02d];@0X:2P08b<S020P800O7al06a/K
01PH600D51@04Q8B00l?3`0>3Ph030`<00/;2`092@T00P071`L010061PH01@D500D51@0410@400<3
0`800P821P010@401@0000000@4100410@0000000@4101P00000103AcJT000<0dLfY600000001001
0@40000000000000000300410@0300820P010@400@4100800P8210030`<200@410801@D500<01PH6
00P8200820P00P0:2PX00`0;2`/030`<00d=3@02018B4P0M01HF5P0I6AT071`L024Q8@0S8b<09RHV
02XZ:P0b<S80=CDe03Xj>P12@T80ATI604Y:BP1;Bd/0ATI604E5A@18B4P0ADE504A4A010@400=cLg
034a<@0W9bL092@T020P800O7al07AdM01/K6`0G5aL00P0A4A401P0?3`l03@d=00d=3@0:2PX02@T9
00P820801PH60P051@D00`0410@00`<300820P0500820PP00@416P0000040=7=Z@000`3AcJTG0000
000300410@000000000000L00@410P020P800`010@400P8200820P0200<30`8010@400<01@D500H6
1P061PH00P071`L0500820P02PX:00`<300=3@d03Ph>00l?3`0C4a<05ADE01LG5`0K6a/07QhN020P
800R8R809RHV02/[:`0^;Rh0<S8b03Xj>P0l?3`0@d=30P14A4@02P11@D40?Shn03`l?00k>c/0=CDe
030`<00Y:BT092@T024Q8@0O7al201XJ6P0;01LG5`0D51@04Q8B010@400>3Ph030`<00d=3@092@T0
20P800L71`061PH00P051@D200@410800`<31@020P8600410@04000000010@40000000410AP00000
103AcJT000<0dLfY6`00000800410@<00P820`030`<200@410801@D50P061PH02P071`L02@T900`<
300<30`03@d=00l?3`0B4Q8051@D01HF5P0J6QX201`L700501lO7`0R8R80:2PX02`/;00^;Rh00P0a
<C404`0f=SH0>SXj03Xj>P0j>SX0=CDe038b<P0_;bl0;2`/02LW9`0S8b<09BDU024Q8@0L71`06QXJ
01PH600G5aL04a<C014A4@0?3`l00P0<30`01@0;2`/02@T900P820071`L01PH600801@D500<010@4
00<30`030`<00P030`<400820PD00@4100<0000000410@0000000P010@4H000000@0dLfY00030=7=
ZAT0000000<00@41000000010@401P010@4500820P800`<30P0410@300D51@0;00H61P0820P02@T9
00X:2P0<30`03Ph>00d=3@0?3`l04Q8B01@D500F5QH00P0G5aL00`0J6QX07alO02<S8`0202TY:@0?
02PX:00Y:BT0;2`/030`<00d=3@0<C4a030`<00[:b/0:RXZ02DU9@0T92@08b<S024Q8@0O7al06QXJ
00805aLG0P0B4Q801`0@41003@d=00`<300<30`02PX:00T92@0820P00P071`L010051@D010@400@4
100410@200<30`<00P8200<00@4100820P010@401P010@4K000000@0dLfY00030=7=ZAL0000000@0
0@4100000000000000000P010@400`0000000@4100410@0200410@H00P8200H00`<300@410030`<0
10@400D51@061PH200L71`0500P820092@T02`/;00/;2`0<30`00P0>3Ph02@0?3`l04Q8B01<C4`0E
5AD05QHF01XJ6P0P820092@T02HV9P0202LW9`0702PX:00[:b/0;2`/02d];@0Z:RX09BDU02@T9002
028R8P0901lO7`0M7Ad06QXJ01PH600G5aL051@D01<C4`0A4A403`l?00802`/;00@02PX:00T92@08
20P01`L70P061PH01@051@D010@400@4100410@00`<300@00P821P010@401@0000000@4100410@00
00000@4101T00000103AcJT000<0dLfY600000000`010@4000000000000700410@H00P820P030`<0
0`0410@01@D500D51@0200H61P0600L71`0820P02@T900T92@0:2PX02`/;0P0=3@d0200?3`l0410@
01<C4`0C4a<05aLG01PH600K6a/071`L0P0P82001`0T92@08R8R02HV9P0W9bL09RHV02<S8`0O7al0
0P0P82003@0M7Ad06QXJ01HF5P0D51@05ADE01<C4`0B4Q804A4A00l?3`0=3@d02`/;00T92@0820P0
0`071`L400D51@<010@40`020P8010010@400P8200410@020P8200410@80000000<00@4100000000
00006P0000040=7=Z@000`3AcJTJ000000800@4100<0000000410@010@400P010@400`020P800@41
00820P0400820P<00`<30P0410@01`051@D01PH600H61P071`L020P800T92@0:2PX00P0<30`00`0=
3@d03Ph>00l?3`02018B4P0801DE5@0F5QH061PH01`L700M7Ad0820P01hN7P0Q8B4202<S8`03024Q
8@0N7Qh07AdM008071`L00T06a/K01PH600E5AD051@D018B4P0C4a<04Q8B00l?3`0>3Ph00P0;2`/0
10092@T01`L700P820071`L200H61P0400D51@0410@010@400@410800`<31@020P8800410A/00000
103AcJT000<0dLfY6P00000300410@03000000010@400@4100@00@4110020P8300<30`8010@40P05
1@D200H61P8020P80P0:2PX200/;2`0A00`<300?3`l04A4A010@400A4A4051@D01HF5P0H61P06ATI
01PH600K6a/071`L01/K6`0N7Qh071`L01XJ6P0H61P00P0I6AT02@0H61P05QHF01<C4`0C4a<04A4A
010@400?3`l03Ph>00`<300200X:2P0400P820092@T020P800L71`801PH600H01@D500@410030`<0
0`<300820P030`<400820PL00@417@0000040=7=Z@000`3AcJTI000000H00@4100D0000000410@01
0@400@4100820P0200410@@00P8200@00`<300@4100410@010@40`051@D010061PH020P800P82009
2@T200X:2P8030`<00@03Ph>00l?3`0A4A404Q8B0P0D51@01`0E5AD05aLG01HF5P0E5AD05aLG01TI
6@0H61P00P0F5QH00`0E5AD05QHF01DE5@0201<C4`08018B4P0?3`l03Ph>00l?3`0=3@d02`/;00X:
2P092@T300L71`801PH60P051@D200@410<00`<30P020P800`010@400P8200410@0800410A/00000
103AcJT000<0dLfY7000000:00410@@00P8200<00`<300@410030`<00P0410@200D51@0300H61P07
1`L020P800<02@T900@030`<00d=3@0=3@d03Ph>0P0@41000`0C4a<04Q8B018B4P0401@D500401HF
5P0E5AD051@D01@D50804a<C0P0A4A400`0?3`l0410@00h>3P0200`<30802PX:00@02@T900L71`06
1PH01PH610051@D0100410@00`<300<30`030`<400820P800@4100<00P8200410@010@4010010@4M
000000@0dLfY00030=7=ZA`000001`010@400`020P800@4100820P0400820P800`<3100410@01005
1@D01PH600L71`071`L300P8200500X:2P0<30`03@d=00d=3@0?3`l01@0@4102018B4P0301<C4`0B
4Q804Q8B00804A4A0P0?3`l00`0=3@d03`l?00h>3P0200d=3@0500/;2`092@T02@T900T92@0820P0
0P061PH300D51@<010@400<00`<300820P030`<010020P8700410@04000000010@40000000410A/0
0000103AcJT000<0dLfY6`0000000`010@40000000410@0700410@0300820P010@400P8200800P82
10030`<200@410<01@D500H01PH600L71`071`L01`L700P820092@T200/;2`0300`<300=3@d03Ph>
00<03Ph>00D03`l?010@400?3`l0410@014A4@0200l?3`0400d=3@0>3Ph03@d=00h>3P803@d=00<0
30`<00T92@0820P00P0820P200L71`0300H61P051@D01@D500<010@40P030`<00`020P800`<30082
0P0300820P0300410@020P800@4100D00@4100<0000000410@0000006`0000040=7=Z@000`3AcJTN
000000L00@4100P00P8200410@020P800P8200410@020P800`<300820P<00`<300@010@400D51@06
1PH01PH60`071`L300P8200300T92@0:2PX02`/;00<030`<00H02`/;00d=3@0=3@d03@d=00h>3P0=
3@d600`<30802`/;00@02PX:00T92@0820P020P80P071`L200H61P0300D51@0410@010@400@00`<3
00<00P8200<30`020P8010020P8700410Ah00000103AcJT000<0dLfY7`00000700410@L00P820`03
0`<300@410801@D500<01`L700H61P071`L0100820P00`092@T02`/;00X:2P0300X:2P0400/;2`0<
30`02`/;00`<30@02`/;0P0:2PX200T92@8020P800D01PH600L71`061PH01PH600D51@0200@41003
00D51@0410@00`<300@00`<310020P8800410Al00000103AcJT000<0dLfY700000000`010@400000
0000000800410@H00P8210030`<300@4100400D51@061PH01PH600H61PD01`L70P0820P010092@T0
20P800P8200:2PX300T92@D02PX:0P0820P00`071`L01PH600H61P0200H61P<01@D50P0410@200<3
0`0300820P030`<00`<300@00P822P010@4O000000@0dLfY00030=7=ZA`0000000@00@4100000000
000000001`010@400`020P800@4100820P0200820P0300<30`020P800P8200<00`<300@010@400D5
1@051@D01@D50`061PH010071`L020P800L71`071`L500P820802@T900<020P800T92@0820P00`09
2@T200P8200300L71`061PH01`L700<01PH600@01@D500@4100410@00`<30P0410@300<30`030082
0P030`<00P8200<00P822P010@4N000000@0dLfY00030=7=ZB4000002@010@4500820P<00`<300@0
1@D500@4100410@010@40`051@D200H61P0300L71`061PH01PH6008020P810071`L0200820P01`L7
00T92@0820P01`L700P820071`L020P80P071`L300D51@0300H61P0410@010@400@00`<300<00P82
00<30`020P801P020P8800410B000000103AcJT000<0dLfY8`00000700410@D00P8210030`<200@4
100300D51@030`<010@4008010@40P051@D200H61P0300L71`061PH01`L700P01`L70`061PH01@07
1`L01PH600H61P051@D01PH6008010@41@030`<200820P0400<30`020P800P8200410@800P821@01
0@401P0000000@4100410@010@40000000410Ah00000103AcJT000<0dLfY8000000200410@030000
00010@40000000T00@410`020P8500<30`8010@400@00`<300@4100410@010@40`051@D300H61P03
00D51@061PH01@D500801PH62@051@D200@410D00`<320020P8700410B<00000103AcJT000<0dLfY
8P0000000`010@40000000410@0:00410@@00P821P030`<600@4100300D51@061PH01@D500801@D5
0P0410@300D51@0400@410051@D01@D500D51@H010@40P030`<200820P0300<30`020P800P8200<0
0P822@010@4S000000@0dLfY00030=7=ZB00000000@00@4100000000000000002@010@4900820PD0
0`<31`0410@01@051@D010@400@4100410@01@D500L010@40P030`<200@410@00`<31@020P800`01
0@400P8200820P0400410@04000000010@400@4100410B<00000103AcJT000<0dLfY8@0000001@01
0@40000000410@010@40000000T00@411`020P8020030`<00P8200<30`030`<00P8200<30`020P80
0`<3100410@00`030`<010@400<30`0400@410800`<30P0410@400<30`X00P821`010@4010000000
0@4100000000000200410B400000103AcJT000<0dLfY900000000`010@4000000000000900410@03
00820P010@400@4100800P8200<00@4100820P020P800P020P800`030`<00P8200<30`0700<30`80
10@410030`<0100410@00`<300<30`030`<300820P0300<30`020P800P8200D00P822P010@420000
00800@418P0000040=7=Z@000`3AcJTR0000000300410@000000000000h00@411P020P802@030`<0
0P8200<30`020P800`<300820P030`<00P8200<30`0300820P<00`<300<010@400<30`030`<00P03
0`<500820P800@4100<00P8200410@020P802`010@430000000300410@000000000002400000103A
cJT000<0dLfY:000000:00410@0500820P010@400@4100820P010@401P020P800`030`<00P820082
0P0300820P800`<300<00P8200<30`020P800`030`<00`020P800`<300820P0400820P0300410@02
0P800@4100800P8220010@400`0000000@410000000W000000@0dLfY00030=7=ZBL0000000<00@41
000000010@400P010@400`0000000@4100410@0900410A000P8200@00`<300820P020P800`<32@02
0P8800410@03000000010@400@4100800@419`0000040=7=Z@000`3AcJTY000001800@4100<00P82
00410@020P8020020P800`010@400P8200820P0600820P800@4100<00P8200410@010@4020010@40
1@0000000@4100410@0000000@4102P00000103AcJT000<0dLfY;@0000000`010@40000000410@08
00410@0400820P010@400P8200410@800P820`010@4700820P<00@410P020P8200410@0300820P01
0@400@4100T00@4100D0000000410@000000000000410@0Y000000@0dLfY00030=7=ZB@0000000H0
0@410000000000000@41000000010@430000000400410@0000000000000000P00@410P020P800`01
0@400P8200410@0600410@<00P8220010@4200820PT00@4100<0000000410@000000;00000040=7=
Z@000`3AcJT[0000000300410@0000000@41008000004`010@400`020P800@4100820P0E00410@03
000000010@40000000@0000000<00@41000000000000900000040=7=Z@000`3AcJTa000002<00@41
00@0000000410@0000000@410P00000010010@400000000000010@4[000000@0dLfY00030=7=ZBh0
000000<00@410000000000008`010@42000000<00@4100<0000000410@000000;@0000040=7=Z@00
0`3AcJT`0000000400410@0000000000000000P00@4100<0000000410@010@4040010@4400000003
00410@000000000003<00000103AcJT000<0dLfY<`00000010010@40000000000000000800410@03
000000010@400@4100`00@41100000001P010@40000000410@010@40000000410C400000103AcJT0
00<0dLfY>P00000400410@03000000010@400@4100@00@4100<0000000410@010@4010010@420000
00800@4100<0000000410@0000000P0000000`010@4000000000000a000000@0dLfY00030=7=ZC80
000000<00@410000000000000`00000010010@40000000410@010@420000000300410@0000000@41
00800@4100@0000000410@0000000@410P0000001`010@40000000410@0000000@41000000010@40
>@0000040=7=Z@000`3AcJTh000000800@410`00000500410@8000000P010@401@0000000@410000
000000000@410080000000@00@41000000010@400@41>00000040=7=Z@000`3AcJTk000000030041
0@000000000000D000000`010@430000000300410@000000000003d00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJU60000000300410@00000000000080000000<00@41000000000000>`000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY
R@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@00T03AcJT00900dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {541.812, 398.812}} -> {-343.407, 740.358, \
1.87239, 1.87239}}]
}, Open  ]],

Cell["\<\
To form the observed blurred and noisy image, the convolution is \
performed between the satellite and the PSF images and Poissonian scaled \
noise is added:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[BoxData[{
    \(\(g\_sat\  = \ 
        Re[InverseFourier[
              Fourier[f\&^\_sat]\ *\ 
                Fourier[
                  RotateLeft[
                    Map[RotateLeft[#, \ m\_\(x, \ star\)] &, \ h\&^\_star], \ 
                    m\_\(y, \ star\)]]]]\ *\ \@\(len\_\(y, \ sat\)\ *\ \
len\_\(x, \ sat\)\);\)\), "\[IndentingNewLine]", 
    \(\({\[Beta]\_sat, \ \[Gamma]\_sat}\  = \ {4, \ 
          1000};\)\), "\[IndentingNewLine]", 
    \(\(noise\_sat\  = \ 
        Table[Random[
              PoissonDistribution[\[Beta]\_sat]], \ {len\_\(y, \ sat\)}, \ \
{len\_\(x, \ sat\)}]\ /\ \[Gamma]\_sat;\)\), "\n", 
    \(\(\[Rho]\_sat\  = \ 
        Apply[Plus, \ g\_sat, \ {0, \ 1}]\ /\ 
          Apply[Plus, \ g\_sat\  + \ noise\_sat, \ {0, \ 1}];\)\), "\n", 
    \(\(g\&~\_sat\  = \ \((g\_sat\  + \ 
              noise\_sat)\)\ *\ \[Rho]\_sat;\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]\_sat\  = \ g\&~\_sat\  - \ g\_sat;\)\)}], "Input"],

Cell[TextData[{
  "The blurred noisy image ",
  Cell[BoxData[
      \(g\&~\_sat\)],
    FontWeight->"Bold"],
  " ",
  "and the SNR are respectively:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(showImage[g\&~\_sat];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<SNR: \>", \ 
        computeSNR[g\_sat, \ \[Delta]\_sat], \ "\< dB\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
020102010202010400030004020202010200030202000300010301030200000402020104
010303030303030101030302050003020205030304030304040401010802030505040404
060302030404040405060207030302060302040203040604040306030505030406050304
050503040505050404030502030707090404050505050504060604070404050508030305
070303050506040603040604030504050604050206040504060305060303030203060304
020305050204060403030203030602020403020203030304020305060103070105020404
030202020404020202010202030302020205020103020301050101030101000104010204
010204
020202010103040204040301010302010303020303030404020102020002020001020303
040302020104050302020103050503050503010604020303040308050403020304030104
040403050407030505050204070402050306020405040904030805050502030605030304
050504050505030406040306060405080404040305030406060509040405070604050603
050404030503030206030704030507030506020404040303050206030305050303040505
030205040302050302050302030404040206040404020504030201010405010303010302
010205030102010502010101030501010406050201030104000201010601010103010000
040104
040501040203010202030301010302030004020305000203000000050202030201030502
040102030301080304010304040504040203060201050602030503040305030604040502
050503030503030605030305040404030704020304060303040303050506070603050502
050404060605040504060705070606060406070704040407050402040705060505050703
050303040403030403060705040607040404030507040305030303040503060304030804
020402030302050303040404030303020202040504040302030203050101030303020504
020102030404030401010102020302030202030105010301030002020301030302000301
030101
020103010101020200030200020502020302020302020702000202010304030303010103
010103020203030303010302040402010605030303040304020404030506020402060403
040304030403020702040404050506060705050406060806040504050705040506040604
020507040306040304080404060406050605040807040505070605040603040406030407
070605040404030503070506040303040402050405060404050206030505040404060205
020507030505030402050502030406020401020202010203010202020102040301030502
030306010003030303030202030202050205020202020301030303000305040105010105
010403
000304010201020201020304020303000003020300030205000403030203010101010201
040203010502010205030303040404040202030302010203020503020303040503040203
040503050305050202050405060602040404050503050504050704050504040505050606
060606040405050603050605050506060605050405060505060806030506040405030507
040506040404050707040205040404040505070304050404030305030602030302040304
050305020203050504050303030304030303030203040203030303030301030304010101
020202030301010202020303020302010403030200020202030404020503030103020101
010303
010100010301020302020203040203050303020302020200010202040201060104030202
040103020102020304040403040302030303030303050502030503050303010304040306
050506030403050503040505050404060503040503050305040604040605050505030606
060505060405030504060705070706050505040607050503040606040705060606060604
070904020605070406040503050506030602030302030306030302060304020504030303
040404030504030205030303050303030204020404030402010402050101030301030103
020104010602020201030305000402000403030203020203020203030100010201010202
010201
020102010102010301010501020404030003020202020100000202030404020303030203
010402040102040303030403020101040302040105030303050305040403020803060404
050503050405050404040403050504050604040505050604060604050508060704060506
05070703060506050A030705040505070505070705060504080705040505060605050805
040305050506060603070405030205040505060504030603030304040504050604040403
040404020401060303040202020304030301020405020402030305020303050402050403
010201010302040203050105010102030202020301020201050102010103020303030103
010200
010401030103020101030203000203010203050302020204010202010403030403040101
030302050203020100020102040604020503020202030602040504020202030303050307
030504050404030504030405050405040504050304040404070503040508060504070504
050507070705050606040806060607050406040704060606060406070607050404060505
050405040405040404060605050503050705050405030402030505070503030504040402
060604030202050503020304020304040305030204020501040302030302030402010101
020501020601030102020400020102020503030202020302020302000203030500000004
010402
030201030103020004020302030101030400010305030200020101010102030101040403
020303010203030203010202020401020203030505040402040605020303030505030304
040403040405060405030403070405080506040403060306050506050405030905050607
06050407090603060807030806060406050B040606060506030404070406040404060405
060403060504080405060505050504050507030505030603060605040405050206060304
030306040504050304030502040301040204020402040402040204020404010102030101
040101020302010302020202030002010301020002030100030204030502030002040202
030401
010303030202000302030203020300050202010200020101030302020202020301030503
030504040204040201010302030307050505030303030404060304040404020305040402
040404030504080603030404040505060403050506050705050405050507050506070309
05040605080A080705060306080507050505050707060507060607060606080605080705
050604030305070504060504060406060406060305060606040305060405050403020303
040404030306040204020402030606030602020404020603020203020102050203020201
010202030101010402010102040303050402030302000203020301050002000003020403
030301
030402020002020002020303020100030202020403030202040401010402030402010601
050505020302030205040504010405040203020505030204060403040302050304040504
040408040303060504060507050405050305060505070304040504060704040706050607
05070A050406050405060508050504050505070607070507070905050606050505070405
080609070505040506050606030504050404040403040306030503070403020405040305
050605030305040202040402010503020304020403020504040201030202020202040501
010603040402020201010202020002000002010303030102020302020302040202020103
010103
030103030002040202030101030303010202020403010101050402020503030403040203
030003030204020302040303030405020302040307030204030304030304030405060607
040306060608040506060407050506060507050505040605040707060508050A06050504
04070505070707080507040609080604060B08040407070A0B0405070505060705050605
050504040605050405060504050504040405060504030304020507030404050206050207
030205040304030201040704010401030303030303040203020403050102020401030201
010002030303040104030302030401030203040302040303020402010002020101030302
020302
040301020002010502030202010305010003020202010206020202020306010201010404
060204030503030103030201050204040302040302060504030506060302040506040405
080505030504060605050305050604050507060606040607060604070705050805070506
07090B0506050506040A0707060607080805060A07050606080606060604050706040605
080706050406050406050707050405050304040605040705050403040404060302030703
040604050404020305040204020305020304080503030103010303030304030303020301
030603050402030102040203020105000402020201000502020002020303030202040203
010302
030202030101020403020102010402030402020201020401020603020104020203020205
020204020206020403040303050405030405040603040302020305050504040204050404
040705030503070404050504050906050606040505030807080405070504060609070906
0707050505050509070505050805070607090607070606050807050A0706040404060704
050504070705070404040608050505080504050705060506040505030504050804040302
040505020504030303040403050102020204030203030202030403020302020502030303
030303030205010203020501020302010302020102040302030102030201010203030102
020402
020202020101030203020202040402010201030105040303030202010301030304040102
050504010404010104060303070401030304030504050304050504040907040404020406
0404040407060605050305040604070606050505050504050A0807080505090608050705
050807070707060706060606060706060606060906060907060606050708050706060406
050807060406050506050506060707050804060705060605040603030403060604060404
020205050206060504030303020303020402030302030501020302020202020304020502
030303010403020304020203030101020203040304020402020301020202040302050201
040402
030201020002030202010402060303020101030501010303020403010102040303020501
040302030303040303020502020303020602040403050404040403060308050405060504
050404040505060604050404060404050605060809060707060807060507080808060707
060508070709060707070708050808070505080706090508050806060709060809060405
080706070706060506070605060704070807070303050608040605040404060305040406
040603020307030203030402020402040403020306040503040403030204020302020303
010403030203030102060302020107060102030200040000040002020202040102020202
030202
020205020102000201020501040502010303010401050403030304050305040302020402
030202020404020304040305020204050403050303020502060504060303040504040706
040405060507070604070805050506060504040409060506070607070607080509080808
0708070606070706070B060807070706070B08060707090709070707070A0606060B0907
080606060606060604050708050605060606040505050407050406050405040303050504
050604040204030305050303020403040505020305030402020303030208010303020502
020303030305020103030404020202020202020404000202020204050502020302030203
030201
020200030302000201000302010102010203020203040102040201030204020202040204
050402030306030202020304020403030606020205030504060405060405030604050603
030605070406060605060705060406060506050704090707090604080807070507080808
05090706090806080908080A09070807060A060608060708080609070808080808060508
090806070808050706080705070707080504040405070405050406050504050704040605
040503050305020405050603030403040403040403070405020304020104030302050402
020203040305040101050102040302010406040202000101020303020404040104030303
040102
030001020102010205010202020202020202030303030302040302040301020304040401
010303030406030402030103030405040505040506050406060403040404060604070605
070403070406060405070506060608080506060605060708060607080507050808080908
07060B08070A0908070807090B0808090B0A080607070808090A08090806090707070808
070A06090705080806080506060806060707060405050305070506050504070503050503
050503040505040404040303040504060304040402020503030305040404030202030205
050303010302040303010401010301020204030104020201040300010103010202020202
020001
000101020402040403020103020102020103030203020301030203030304040405030402
030303030303040304030603030303030404040404060604040504060703060505060705
040506040603080605040505080607060906040808080606070708060807090808070808
08090D0709080C0806090A07080807070A070708080A08060907080A0709080706050806
070708060707070706070A06060606070507040505060504070406070406040403040405
050505030407050602040405030305050104030406030204030403040104040401030201
040204020404020304020104030303010204060202020202020004010302020204040203
020102
030002020203040101010401040202030203030203010303050202020302020103020305
030405030202020504010403040604030204040304040703070503060605070804050406
060606070604060604070707050506070607070806060709080808070608070906090907
0A09080808070A0A0807090B09090A09090B090C09070A0A090808080707090709070708
0B0807090708080808080905080606070805060504040507040507080606040403030403
040506040405030204040503040207030403050304030402030305040101040404030403
030304020402050202040201050102030401030401020002030101060404020402000002
020402
010203040202010401030102010301020202010203030103030203050204030202010303
010202030506020603030603050304040404070304050505040404050505040605090505
07070708050608070808060507070B08060709060907080A0708090C0607090807080807
0909090908080A08090C08090808080908080908070A070609080908070A0A0C09090908
0807070A0706090806070808070606060606060607060707050405070907050406050604
030404030503070505040406040406020405030504020404040503030204030403010104
040302040203030503030103050303010401030202070202030201030203020403010202
030202
020402010702020402040402030301010404050302010302010202070104040203050103
060305040204020404040404050404040505050403060506040505050807060605050804
06080606080505050706070608050C0608060808080908080A0B0B0707090A0B08080809
0A08090907080B0A090909080A0909080A0A0A0808080809090B0A09090A0B090A090808
0708070708080807070708080907080607080A0806060606050805040604050705060704
050407060704070704030404060304040305060505030304040202040304030403040403
030303040204030202030303060301040303040101010104040203010204010401020302
010302
020305020202040202030203020103030205010402030302030503040302030301040304
040404020304040303070206040204030705070507030607040509060707060606080606
0508080705060908060606090608060607090909090A0807090A0809080A090B08090907
0C0D080B0A0909090C0A0908090A0B09070B09090C0907090C080B09090B090808090907
0A0A09090A0708070B09080D050807070807090707060606060607060705050506050705
060505060606040404050606060303040306050204040204050204020503030503040305
040303040304030402010305020004040203030604010401010202020203040302030104
010302
010305040104040006040303030203040405060305040202050202020502030305030505
030202060403030304040602040405050504040406060505050605060805040506090505
0707070706070706070909080A07090706090807090A08070B080A090A0A0909090B0A0A
0A0B0809090B0A090B0D09090C0B0A0A09090B090A090D0B090A0B090A0A09090B0A0908
080B0C09070A080708080708070707070808060407050808070508060605060805060405
060506080305050704050503050406060303040502040305030304040204050405020103
020402040203040502010302040301030301020403040202030101020202020202020302
020302
030403010301030403030304010105030304030402020402030301020403030202060403
020504050402030204050505080305050405040403050609070608050507060406050806
070B0608070709070708070708060807080809080A080A0A080809080B0A0A0B0A0E090A
0C0D090A0B0B0A090B0B0B0A0B0A0D0A0C0B0A0A0A0B0C0C0A0B0C0A0C0B0A0A09090808
0A0C080D0D080A0909090609070606060707080806090707070A06060606060807070604
060605090305060406050305030505030406020405070303030302020205030503030302
030604040402040302020202010402020505040203030301010303020202010301020302
010202
010202020403040103030202030105020305030302040202020304030305050303020402
020204040302020302040603060503050507040408060604070607050606080507060905
080809070608080707060706080808090A0A09090909090A0A0B0A070A080C0B0A0D0B0B
090B0B090A0C0E0B090A0B0A0B0B0D0A0D0B0D0B0B0B0A0B0A0C0C0B0B090C0C0B0C090A
090A090A09080908070908090609080707080A0707080708060604040705060706060708
060604060507040406030505040505050504030602020407040403030304020204030304
020501020303040203020302000502000302010401030301060403040202030204010101
040104
010103030204050102040103020303040303030303040204020304060504040503040403
03030104040504060306030305040404060506050407040408070406060A070706050707
07080606080708090808080909090808080A0A0A0B0A0909090B08090A0B0B0A0A0A0A0C
0C0D0C0B0C0A090E0C0C0D0C0C0D0D0C0D0B0C0B0D0D0B0C090D0B0E0B0C0A080B090A0A
09090A0A090909090A09080C09090C06070A080607080508060606050805080605060606
060705060407060506030606040604050505050304020304060305020404020406030305
030405020102030504010102040402020102020301050504030201030301030404060302
010102
010104010305040103020301040403030100030403040202030403020505040503040204
030404030404070405050504040604030503050404060505070408050707080708090607
070A0707090A09070908080A0A09090A090B0A090A080A0D0A090B0B0B0A0C0C0D0C0B0D
0A0B0D0B0D0C0B0F0B0C0C0F0E0D0B0B0C0C0C0D0D0D0A0C0C0B0B0B0C0C0F0B0A090A0B
0A0A090909090B0B0A0A0A080809090A090609070709070909070507080506080B060606
070707070706040505060705050406070504050305030304030403050305030306060304
030303040402040404010402040403030205020203010103010303050202030203020107
030303
020203020404030101040103020303040500020405020402030608060402030404030303
030503040406070504050404060504050405080606050706060606060507070708090606
0A070B080A0B070B080A09090B0A0C090B080A0C0E090A0B090C0B0A0A0D0A0B0E0F0D0D
0B0C100D0C0C0D0E0C0C0C0B0D0D0B0E0C0D0F0D0D0D100E0C0C100B0D0D0C0C0B0C0A0B
0C0A090A0B0B090D09070908080A0806080D090807070806070607070807060706070406
050707050606080605050405070406040405040506030404050405020206050304040404
050305030404030504030204020103030102030202030103030102010402040100040303
040402
040303030302010305050102050103020401040302020102030303030502030206030302
070204050302050406050603050505060604080506040706070906070709070708070908
070A080A090A0909080A0A090A0B0A0B0E0B0A0A0A0B0B0A0A0C0A0B0C0A0D0D0C0C0F0D
0A0E0C100B110C0E0E0D0E0D0D0F0D0B100F0F0D0E0D0E0E0D0D0D0D0C0D0C0E0D0B0C0C
0B0B0A0B0B0B0B0A080A080C090A0A09080808080807080606080608070A070507070605
080707060705050405040604040505050605030503020504030407050407050503040204
050204020304030302040402010204030302020303030201030203060203010201010201
070403
030203020405040103020203040104030301030203010405040403030504040302030205
0304040305040706050404030606070608080505080606070706080709090A0808080A09
090B0B070A070A0B0B0A0909090A0A0C0A0B0B0A0D090C0C0A0B0D0D0C0B0B0E0C0D0E0E
0C0C0D0F100F110E0D0F0E110D0F0F0E0F0E0F0F0E1010100D0E0D100C100D0C0B0C0B0B
0A0D0C0A0B0A0C0B0C0A080B0B080A0B0A07080909090607080A08060708080707080807
070805070807070505040604060404030505040604050503050604040503050304020202
040605070303030302030502030402040403030302030303030303030202050201030101
030503
010302020302030401030202030204020201020302030203050405030303030403050703
050403060504070605060604050407080507070608050706050808070808090806090709
09090809090A0A090A0A0B0D0A0B090C0D0A0B0A0E0C0C0C0C0B0B100B0D0D0F0E0C0F0F
0D0E100D0E0F0F0E0E120F100E110F10130F10110F0E10110E0F120F0F0D0D0E0D0C0C0E
0C0C0D0B0B090A0A090C0A0A0B09090A070C0B080909090807080A060907090808070706
080606060806060506070608050506070507060406040403060703050704050305050304
040405040203020303030403040304040404040200040304030203010203030305020403
020101
030303020303030403020202030404030404020403030104030104030203020403030504
060403050305070706030705050405090606050709060606050807080B07080907070909
0B0709090A0A090C0B0A0C0C0B0B0C0B0C0B0B0D0D0C0D0C0D0C0C0C140E110D0E0F0D0F
0F0E100F0D0E101010120E100E1112100E14110E110F10100D0E140E11100E0F0D0B0D0D
0C0C0D0B0C0B0C0A0B0D0C0B0B0C0C090A0D0A09090C080D0709090A0907060807080607
080706060607080707060707070803070705070406090607070404050606040302030603
030306040305070304050303040304040103020307020202030103030201030203020203
030702
010302010203010302050002030404030302030303030309040506060203050305030603
04050305030406050507050504040506040807090608080809070807090A0A0A0807090A
090E080A09090B0A0E0B0D0C0B0B0C0C0C0B0C0D0C0C10100C0D110E100D0F0E11101010
10100F0F0F1013110F101412100F0F10100F111310101210101110120E0F0F0E100C0E0D
0F0B0D0C0D0A0F0B0B0C0A0E0C080B080B0B0C0B0B0909090C090A0808080A0606090A06
060907050706060507070508070A05060505050505050505030507050504040307070403
030603050704020304060405040304030104020202040403040302050402020301020304
020004
030202030202030403020403040303020203030403020305050406030404030406030506
0405040604030703070406050406070807080607070808080707080A0708090A09080C0A
0A0B090B0C0E0D0B0B0B0C0D0F0B0E0E0E100C0C0E100E0E0D0D0E100E0E0E0F0E121211
0F120F13101312131315121112131112111211101012111014120F1010140F0F100C100D
0D0D0D0E0F0D0C0D0E0D0D0B0D0C0B0F0A0C0A0A0A0B090A090A070B08070A0808080B07
080807060708050708050705060607050505070606050706030705050503040606070505
030403040204030403050302030605040306030404070401030203030205020301010503
030106
010201030202010402050402040304040603040503040405030404030803040405030605
080503060304050706060604060809070608070608080809090C090B0A0A08080E090A0C
0B0A0B0A0A0C0B0A0C0F0D0C0E100C0D0D0D0C0E0D100F0F0F0F130F0F11111012121013
0F12101213131111131413131213131214131411141412111310111214110F110F100F0D
0E0D0F0E0E0D0F0D0D0D0C0B0D0B0A0B0C0D0D0B0A0A0A0B09080B080C0A070908080908
080A08050906080706080507080705060707050605060505070506040305030806050204
020306030303050304050302050303060504030602020203020103020503030502050203
020303
030203020402030402020302050204040101040303050204040404030503060404030504
040606050507040405040706070706060A07070808070608070808070A0A090C0A0B0A0A
0E0E0D0B110D0C0C0C0D0D0F0D0C0D0F0F0F0D1011121010131312101410111411131010
111414121312151315131212151413151513151513121414101213111113131211101110
10110E0F0F0F0E0F0D0D0F0B0C0C0B0D0A0B0B0A0B090B0B0909090709090A080B0A0A07
080809070705070607080806060706060A05060504050604050703060406050505080204
040405060303010403040304040502040306030604060304020404040603040503040302
050502
030300050304010306020203030304040304020207050204030302050504030406030506
050606080407060705040705080708070506080507070C080A090809090A0A0A0A0A0C0B
0B0D100B0C0D0D0C0C0D0D0F0E0C0E0F0E0F1112120E0F11111010111014131214121213
121312131312131314161315161513141615141616131616131313131112111113111311
1314120E0E0E0F0E0E0D0F0D0C0E0C0F0A0B0A0C0A0D0A0A090C0A080C0A0A0909080A0B
0808080A0709070705090A0A080507090806050606060606040405050804030408040304
030404040305030606030403040203040405030304030206030104030202030302040002
030304
020404020102020201030303030302050502030404040503030502050305060503040503
060605050606040604080606080506080807070708080B070A0A0A0B0C090A0A0D0B0A0D
0B0B0F0C0D0F0E0C0D0F0F0D0F110E0F1011110F11111110121113151513111514111315
13131414151416151316141516151617171816171816161615141312151213131412100F
100F1110100F0E0D100C0F0D0D0D0D0C0D0C0A0D0C0F0D0C0B0B09090B090B090B080C0A
080909090A070809070608050807080809050A0705040408060606050705080605040405
030304050302050206070402020402040301020103030502030302040203030303030603
020504
040405040402020403040503040303050205060504040102050502040704050505060604
0705050407060606060806060806070A09090908070B0A08080A0A0D090C090C0D0E0D0C
0C0E0D0E0E0C0F0E0F0E11120F1110131012111111141310111112131312141318161614
151414151615141515161616161716181917181719171717141814141414131113121313
1113121010110F0E110F0F0E100E0E0C0D100C0B0F0D0C0B0C0D090A0A090B08090A070A
090709080B0707070B070709070707080606070708060709070604060605040406040505
050204060405050304030103040405050203040303050504040503040201050305040402
020601
020204020504040301010405020404060404020204040208030404040405050404050605
0907080505050806080708070806080908080B09090B09090A0E0A0C0E0D0C0C0B0C0D0D
0D0D0D0E11100E0D10131212100F11141111101211141212141413141515131514161417
18171618171717171718161718171B1A1B1A1C191A1B1A17181514151415151615141314
11121210110F110E110F11100E0D0F0E0C0E0D0D0C0E0F0D0B0B0C0C0D0A0D0B0909080C
0B0C08090A080A0B08080A070B0B07070608060805070607050605050605050505080504
040803050304050203050403060203020305050402050303040402040403020403040502
030304
020204040302040301030102020403040402050502040303050404040303050403060604
07050505060A06060606060608060809090B0A090908090A0B0C0D0A0A0D0C0D0E0D0D0E
0D0E101010100E1010101313141210131414131211131314161714161315141516141616
171717181A1919181A191A18181B1A1B1A1B1B1B1C1A1C1A191917161818161617141213
14141315131211120F100F0E0F0F10120E0F0C0E0E0C120B0E0C0B0A0A09090A090B0B09
0B080B0908090A0A08070908080807080707070706080705070707050605040504050406
050606040404040708040604030502040403020203060503040201010304030103020302
020202
040301020301010302020502020302050202010305050409020404060504050505030605
050506060606070607070906080807080B070A0B0A0D090B0A0B0C0E0E0B0C0E0D0E0E0E
100F0E0F121010111111111312141415141415131317151515161516161518161A181817
181A19191819181A1C191B1E1B1D1C1D1B1E1E1D1C1F1A191A1718181718161916161519
161515131514110F131410130F12110F0D0D0F0E0E0E0D0D0E0A0C0B0D0A100A0E0A0C09
0B090C0A0A0908080B090A09080808080807080707060707090408070508070605050303
040305050505020503030303030303040503040503060304020506030303050302040301
040302
030101040404010205030202030205030202020502030404040405060705050603040505
060706050707060707080809090807070C0A0A090C0B0A090B0D0D0E0E0C0E0E0E0F1010
100F11111112111113111412131317141514151615161615171618171617191818181B18
1C18171D1A1C1B1A1A1B1E1B1D1C1B1E1F201F1F1F1F1D1B1B1A19171A18191918151716
181715131312121410121012110F1111100F13110D0E0D0D0C0D0D0B0E0B0B0B0D0C090B
0A0B0A0B0A08090A090A0709080909080807080707070704060505060409080706040705
050604020405060505050405030503030305030303040305050502040303030204030503
030404
030304030604020102050305020206040203030504050506040506040406050505080506
0407060804060506070807080707090B0A090C0A0A0A0B0A0B0C0B0C0D0D0D0D100F1011
121111131111121214161513151415171516161816191816181818171918171B1A19191C
191C1C1D1E1C1B1B1C1D1D1B1F1D1E211F1F20222123211D1D1B1A191A191A1716191B15
1516161415131313111212111210100F1210101210100F100F0D100E0F100D0C0E0D0B0B
0B0C0C0A0B0909090B0A0A08070809090708060607070908090905070607040606050505
060306060505060603030506030305030403040402050203030503030502030304010403
030501
030403030504040203030404020404030405040402030504050403040606050404050606
0408050606060708070B0A0709090B0B0C0D0A0B0C0C0D0C0D0E0F0D0D0F0E1113111011
111013141212131314151516171617161719171818171A1A191B181B181B1C1B1B1A1B19
1C1D1E1D1B1F1E1D1E1F1E1E1E211F21202122212224231E1C1C1B1B191B1B181A191618
171917171516131415141213131210101113100E120E0F0F0F0E0F0F0C0E0D0D0C0E0C0D
0C0B0B0C0E0B0C0B0E090A0B0A0B0A070908080907080905080607070708070407060504
040605030604040404060404050405050204050503020404020301030305040302020301
030304
020305050305050304040403020304040503040305050605050507050405040506070608
06070906070708070809090A0B080A080B0B0B0C0B0E0F0E0F0D0C0E0F11101012100F13
14111314131417191816191515161A18191819181A1C191A1C1C1C1B1C1C1D1C1D1B1E1D
1D1B20201D2020201F211F1F201F22242423242322222023201E1C1C1D1C1B1A1A1A181C
1A18171618141616151514141612121311121210130F110F0E0F0E0E0D0E0F0E0E0E0D0E
0D0D0A0A0B0D0A0C0A0C0A0A09090809070B070A08070906090708060707060605080508
070504060605070605040305040503040302050301020402020403030301040405030301
020402
030104030302030403050506040405030205040506050505040606050705050606070608
08090707090607090A080A080A0A080B0B0A0C100A0C0C0C0C0E10100F10101511101314
1113151314141A151618181A17181A181B1B191A1B1C1B1B1C1C1D1C1F1C1E1C1E1E1D1D
1E1E1F2120201F211F2222212222212225242423232122201E211E1D1E1C1B1C1C1B1A19
1A1B181B191718171615141614141314161111101112130E1111100E110E100D0E0F0D0D
0E0C0C0D0D0B0D0C0B0B0D0B0A0B090A0A09080808080B0A080609060805040606070408
040407050506040203030403040604060505040303020404020204020303030203030501
050303
020203040406030203060304030305030302040403030704020405050504080508050608
08080908080908070909090B0A0A090A0A0B0B0E0C0B0E0D0E0E10101211101212171414
12151515171616181818191919181B1C1A1C1B1B1D1D1D1D1E1F1C1D1F1F20201E1F1F20
1F202121242320222122222423232325262726282624242322201E1E201E1C1E1D1B1C1D
1C1B1919171A18171616141616171215121315141311111012100F121110100F0E0D0E0F
0E0C0D0C0C0D0C0B0C0C0B0A0C09090A090A090B0A090A06070706090807070705040606
050705040404070405050303030405040305030403040502050504050304040402020303
050504
030302030403040404040402050105030306050605020704040506050604050908060709
06070808060806090809080A08090A0D0B090B0F0D0E0E0D0E0D10101011131415171414
16181517171A17191C191B1B1C1B1E1E1C1E1C201E201F1F1F211F1F1F24202120222221
222224222224242326252726252726262528262A2A25252623242222201F1E1F1E1F1D1E
1B1D1C1A191D191817181616171715151414131214141412120F0F0F110E10110F0F0F0E
0F0E100E0D0F0E0D0C0A0E0A0D090D090A080A09070A080A080707060A07070807070706
060506060405040404050604060304030504050303030305040404030403030203050305
040401
040502020304050604040303030305020205030504080405050405050506060607080605
0708070B080A0809090C0B0C0B0C0B0B0C0C0B0E0E0E10100E1110121214111313171516
17161817171A1A1A1A1B1D1C1C1D1E1F1F201F1F1E211F21212121222223232221222424
2525242725292927262629252928282829272B2828292527252325242121231F22221D1D
201C1C1C1B191A181A1717171A19161616151414151413121412141212111110110F0F0E
110E110F0D0E0E0D0C0B0C0B0C0C0B0C09090C0909070A08090909080705060609090808
060506050504050608040705050403030304060303040103050204020407050204050503
020305
030502050204040506050403050304040406050503060406060704080705060507060508
090A080708080C0909090C0B0A0B0C0D0D0C0C0E12100E0E0F1211141414141416151717
17161B1C1B1C1C1B1D201E1D1F1E1E1F2120212326252421232525232623232624242626
272426262528292826292B28282A28292A2B2D2A28292829272624242425222022202020
1D1E1D1C1D1D1B1D1A191A181A191817171816151316121511131413121212110F101110
0F1011100F0E0E0D0E0E0C0C0C0B0C0D0A0C090A090A0907070B08080707060608070807
060506070405040507060604060603030404070204020303030605040304040203040504
040504
040203040403030403020305050505030404020405060406040707080606060606060608
080808080808090C0A0A0A0B0B0C0C0C0E0C0F0C0F111010111112121312131515171A15
19171A1B1E1D1D1D1E221D1D212222232123232423272525242727272625252628262627
262829292A2A28282B2B2B2B2B2D2D2D2A2D2D2C2B2B2B2927272627252623242320211F
1E1E1F1E1B1D1E1D1C1B191A1A1817191717141517161513151411141414111014111311
100F11100E0F100E0E0D0C0D0D0E0B0C0D09090B090B09080A0A08090907080507090607
080504070703090407050607040505040404070407040505030404020304040504020505
030403
040502030206040403050302030406040403050504060804070606070708050607060906
07090C09070909090B0D0B0E0D0B0D0C0F0D0E120F0F1113131213131517151516151718
1A1C1B1A1D1E201D1F20202122242326242723272528242728262828272929292B282A29
2A29292A292B2A2C2E2C2A302C2D2E2E30302F302C2E2C2C2B2A28282826252626262223
2321211F201F201D1D1D1C1C19181A191919171918181515141515161414141313141312
121210100F0F120F0E0E0F0D0D0B0C0C100B0C090A0B0C090A0909070908080806060906
070506070707070605050704060504030403050404020703040503040602040204040407
040203
050305040303050405040703030406040603040707050305040A0504080806070A070707
0A0A090A0C0A0A0C090B0B0B0A0C0C0C0D0F10100F0F111112121614141617181718191A
1B1D1C1D1D1F202224222524242428272528272729292829292A28292A2A2C2B2B2D2D2D
2D2D2E322E2C2E30302F2F2F30323030303131323231302C2C2B29292A28292627272426
2223202123231F1F1C1C1D1D1D1D1B1A1A1A1C1819151717171616171614131314131314
141113111111120F10100E0F0C0E0E0E0C0B0D0C0B0C0A0B0B0909090809080708090607
070606070506070506050505060403030505040306040405030306010205030504030503
040304
020205030303030504060805040603050504060604060504040606080806060507080707
0D090909090A0B0C0A0C0B0D0C0B0E0F0D0F0E11111012131413141415151918181A1B1C
1B1D1D2021222525222525252627292727282C2B2C2C2B2A2D2C2B2C2F2D2C2D2F2F302D
2F2F2E2E30302F303231333134313435353433333534312F2F2E2D2C2F2A2A2B28282727
252424242323201F20211F1F1C1D1B1C1B1A1C1B1B19181A171918151719151818121512
141312121211121211120E110E0C0E0E0D0B0E0D0C09090C0C0A0A080907090809070807
070606070805050705040404050606070305060504040404030303050303060502020504
040302
050405030307030206050305030406070405060405070609070507070706060808080709
090C080B090A0A0C0C0C0E0E0E0D0D0D0E101310111114131513161718181818191B1C1C
1E1E1F20212323272326272828282B2C2B2B2C2D2C2C2F2E2F312F312F302F3330303231
313034343433333334353433363634353535373433333232332F2F2F312D2D2B2A2A2827
272724242323212120201E201E1E1F1F1C1A1A1B1D1A1C1718181918161A171714151613
1512151213111313111212120E0E0D0D0F0D0C0D0D0D0C0B0E0B0C090A09070807080707
0A0606050508070605050309050604060605030505020604050505030506010703040907
020605
030304050404040607050503040605030505030405050405060507070B08060805060808
09080B090C0B0C0A0C0B0D0E100D110F12101212141212131414161618191A191A1C1F1E
1F202421232625262829282C292B2F2E2E302E302F3031302F3032313332323532353236
323433343536363635353637363B393739393937373835343332313532302F2E2D2C2A29
29282725282723252320222220211F1F1E201F1C1D1B1C19191B17171819191618181515
15131514121214121113100F130E0E0D0F0D0C100E0C0F0C0A0A0A090807090A0A070809
0806060706090A0605060309040506070304040304030204040206020303060301040603
050303
040505050303050505050405050505060405080807060707060804050607070708080909
0B090A0B0B0C0B0D0E0B0E100E0E0F110F121012131214171614151818191B1C1C1D1E20
22212525262729282D2B2C2C2C2E2F322F2F333234343435363435343538373435363638
3537393A3638373938393A3B3A393D3B393A3A3B3B3A3938373536343330312F2E2E2C2C
2A2928262625252524242321232121201E1F201D1E1A1C1C1B1C1A1B191918161618181A
161514151315131312131212120F0F0E0F0F0D0C0D100D0B0B0C0B0B080D080809080808
090706070607090508060604060604060606030503050504040405020306050503040304
040502
02050207040404040303030503080307040606060605070707070808060607070A07080A
0A080C0C0B0B0B0B0D0F0D0E110F101112111212151314161516171C1C1C1F1F1E212022
2224242729292C2B2D2D2F303031323334343536353738363A36383838393A383939393A
3C3D3B393A3B3B3B3E3D3C3C3F3E3F3F3E413F3E3C3D3C3C38393837373433323430332C
2B2F2A292927282826252422222422212120221D1E1F201F1C1D1C1B1D1B181A19181A18
17181615131515141414131211130E120F0E120D100E0C0C0D100C090B0B0C0B0B0B0808
080607080609060706050504070406030405070405050503020404040705030305040502
050303
02030503050503040405040307050602060405040605070407080C080506090809080808
0A0B0A0A0C0C0B0A100D0D120F101010111212151618151717181B1A1B1F1F1E20222323
24262729282A2B2E2E30333435353835363937393A373A393A3B393C3B3B3A3A3B3A3B3C
3C3C3C40403E3D3E3E3F403E414241414042414144403D3C3D3B3D38393438333432312E
2D2F2B2D2D292A2829272725242324252221212220201E201E1E1B1B1D1C1B1C1C191B1A
1A1B171817181717171414111212121311120F130F100D0D0E0E0F0C0A09090B090A0909
060709080807070708060606050605070605040405060505040406020204030303050105
030305
060305040405060606030403060402060507040706070705080706070709070808090B0A
0A0B0D0C0F0D0E0F0D1010100F101211111314151617171617191C1B1B1F1D2024272323
27282A2C2C2D2D2F34333433383A37393A393A3D3D3C3E3E3C3E3D413E3E3D4040414141
414240404442414242434344434244454646444643454240403C3C403B393B3736373434
31322F2E2D2B2A2A2928292726242624252423222022222021211F1E1E1E1D1A1B1C1D1C
1C1919191719151515141414131213111311140F10100C0E0E0C0D0C0B0A0B0B0908080A
0A0A09090A07080607070704080604060605060905040503060406040502030303030402
040503
040503040403060604040402070504060604040507070608050907070809080908090C0A
090C0C0D0C0E0D0E0E0D111010101211141313151615171719191C1C1B1F1F2422242527
28292C2C2F313234333737393B3A3B3B3E3D3E3E3F4143423F4141424243434342444347
4343454644484546454646484649474849484849484645454241403D3F3C3B3A3A373736
3432322F322E2D2C2C2B2C2A2B26272723252222222121212121201E1F1F1E1F1D1C1C1B
1B1A1A1B191918191617151515151412111511101211100D0E0F0D0C0C0A0A0B0A0A0907
090B090A070A070707050706040604040605060606060505030603060506070403050302
030303
060405040305020604050305050604060306060508060608050507070A080809090A090C
0E0D0D0C0F0D0D0C1111120F1312131512141516171817191A1D1C1C1F2020212526262B
2B2A2D2D31333336363B393A3D3D40414342434443454546454648474745464547464645
4546484747494B4A4B4B4A4B4A4D4B494C4C4C4D4C4A484947454443413D403C3D3A3938
363533333132302F2E2C2B2C2B2A28262A2726272424252323232222201F1F1F211C1C1D
1C1C1C1B1A1B191A181817171717161414141311111110100E0D100C0E0B0D0B0B0B0A0B
0A0A09080707090608070506060605050605050304060403050606060405020504030504
020505
02040402020305050605070703040406050704030807060608070A07090807090B0A0A0B
0D0B0B0D0D0D0C101010111113111412171716171518181C1A1B1C1D2022212427262829
2B30302F32343539393D403F3F434443454447494746494A49484A4B4A484A4949494B4B
4A4B4C4B4D4C504C4D4D4E4F4F4D50504F4D4E504D4F4C4A4B484743424242413C3C3B3A
39373736333232342F2F302F2C2D2A2B2829272925252425242123242223212220201F1D
221F1D1C1D1B1D1A1B171A1916151513151318121212110F10120E0F0E0E0C0C0D0C0B0B
0B0A09090A08070707080706080705050404030705040504050503050504060404040307
040505
04040405040603040403050405040405050406050606050608070708080908090C090B0A
0B0D0D1010101011100F1211131513151516151719181A1A1B1D201F2023232528282A2E
31303132363A373C3F40424445454848484A4B4A4C4B4C4C4E504D4E4E504D4F4E4D4E50
5051504F504F5250525352525354535354565354515253514D4D494846474443413F403F
3D3A39393636333531322F33302F2D2B2C2C292A26282728252527242625252223212220
211F20201D1D1D1B1A1B19181A17171B1314141412121310100D120E0D0E0C0C0B0F0A09
0A0A0B07080808070A090705060806070405040506040804050503040304040603040705
050404
03050303050606030404040403040605040406060506090605080806080A0A0B0B0A0B0C
0D0B0E0C0F110F10111111121315141515151819191B1A1D1D1E1F212324242A28292D2E
3131333539393C3F41434449474C4D4C4C4D504E4D4F5052515455535253535454525255
545353545458555556575657565A575656585A575655555251514D4D4C4A494544404140
403B3B3B3B3936363534333130312E2E2D2F2C2A292C2D29272A28272625252425232425
2121211F211F211C1D1C1E1B191A17191A1615151312131212110F0F100C0D0C0B0C0B0B
0B0B090B0A070807080B0908070607060705050506060405020307060406040406060406
030405
0404040403040503050504040605050704050706060605080C0609080A090908090C0D0E
0D0D0D0C0E0F11111014141512161615151718181C1B1D1C1D212021242527292B2C3031
333539383B3C3F4145484A494D4C505352525153525654565655565658585858565B5559
585B585A5B59595A5C5B595F5B5C605E5E5E5C615C5B58565755524F504C4A4A45464344
41433D3F3C393B3A353535343132342F2E2E2E2D2B2D2B2C2B2B292B2728272925242623
21232423221F1F1E1F1D1D1C1D1B191919191716151514121210111010110E0D0B0C0E0D
0A090B090908080A0A080808060609050605060705060503040505050605040506030502
040505
060204030605050507040703040505060606050406090707080A07070A080A0A0C0A0C0B
0D0E0D0F0D0F0F1212121414151515151919191B1D1D1F1E1E2322232427282B2D2E3332
3336393A3D3F4145474B4D4E505557565955585958595A5A595B5C595C5E5C5C5B5A5A5B
5B5C5C5D5C5D5E615D5F5F60636062636263646163605F5E5B5A555352514E4B4B4B4746
444342413E40393B38393637353435332F2F2F2E2E2D2B2F2F2C2A292B2B282828262827
2625262623212221231E1F1F1B1C1B1A1919171615151414131112110D0D0D0D0C0A0D0C
090B0A0B0A08080908080806050609060405070503050407080505030405050406060304
050403
0605040404050203050504040505070604060407080806080607070809090809090C0C0D
0D0C0F0D1011121214151416171616171B1819191D1D1E1F1F21242426292C2E2F323233
35383A3B3F42464B4C5053555658585A5C5D5B5D5F5F5F5E605F5F5F615F625F5F605E61
6260626060626363636563656667666767696867696363625E5E5A58575353514E4D4B48
4B434344433F3C3D3E3A3A3A393734343132333131312F2E2F2F312D2D2B2E2C2B2A282A
292927252525262421232120201D1D1B1A191A18171615151613130F1013120D0D0B0C0D
0C0C0C0A090A080709070808080708070606070505050506060605040502040906060604
030409
06050603050404050605060406070606060407080609070908070809070B0908090B0B0D
0D0D0E0E12111313151515161617181918191B1C1F211E2121232426272C2C2D30313438
383A3F3F4348494D5054545A595C5F5F6161626560656262656665676464646567656465
666766656467646766696B696C6E6D6E6E706E6C6D6C69686563605D5B565653524F4F4A
494946464642423F3D403B3D3A383A363834343332343231333130302D302E2C2D2E2E29
2C2A2628262627242623212423221F1D1E1A191818161514141412121110100E0E0D0D0D
0C0A0C090B08090D080A0709050606050607070704060505050405030504060304040503
040304
030505050305060407040406060504080704070607080706080E07090909090A0A0A0D0C
0D0F0F0F111214131414161919171819191B191E201E1F2123242628292C2D2F31343439
3C3E424447494F5255595B5C5E606264656668686A68696A686A6A696B6A6B6B686A696A
6C6A6C696B6A6B6C6D6F7071717272747277747671716E6D686964615F5D595A5955514E
4D4C4A4946454242403F3C3C3B3A3A3A39383737363736353333323034333030302F2D2C
2C2B2B2A2A29262827252425221F21201E1C1C1B1C1917161615151111101210100F0E0E
0C0D090C0C0A0A080A0A0609060706070705060505050605060605060303030503030305
030606
07040505060304040404060605050606050506070705070808090A0B0A0A0A0B0A0A0D0B
0E0F0D1011121412141716181A1B191A191B1E1E1F1E1F2325252927292D2D2F3433383A
3B3F434549515255595D5F61656668696B6C6D6C6E6E6F6F6F6E6E706F6E706F706F6E71
6E7170707070747175757473777A797B7A7C7C79797776726F6D696765605E5A5A565651
504E4D4B4C48474443413F3E3C3E3E3C3A3A3A383837383635373536333333323334302F
302E2D2E2C2C2B292B27272426232221201E1C1B19191A161613151311120F0E0E0D0D0F
0C0D0D0B0B0A0A0809070A0A060606070A06040607060605050607040704040304030403
040304
05040503030502050507040505040705050706080906070807070A09080A0C090C0C0D0D
0D0F110E1010131315171919171A1D1A1D1E201C1D1F2123252627292B2D2D303537373B
404145494C51555A5C606268696C6D6E6F71737373757576757574747476767674757676
7575737475757575777A7B7B807E807F8181827F7E7B787876726D6A6764635E5E5A5957
55524E4E4B4C474746444243423F3E3E3E3B3C3B3C3C3B3A3A3738393836363634353335
32322F30302E2D2B2E2B2D2825252424211F1D1D1B1B1C1815191712131211120F100E0D
0D0C0D0B0C090B0B09090908070809060905060606050505050305040507050403040706
060503
040605050604040405040507050605050406050606080706090A0909070A0A0A0B0B0B0C
0D0F100E101114151817181A191C1D1B1B1C1E20202221242526292A2B30313334373941
3F44494F4F54595C6165676B6C6F73737477777A7C7A7C7C7D7D797C7C7B7B7B7A797A7B
797B797A787E7A7D7B7E808082858586868589878280807B787773706B6A646363605B58
575354534E504D4E47494547424243413E41403F3C3F3C3C3C3C3B3A393B3A3937393736
393535323532312E302B2B2D2927272423231F1D1D1F1B1918171415141311101110100D
100A0F0C0B0A0B0A0808070A090906070606080607070804060608050405040403040303
040503
050304040505050404070605060604050607080A0607070A09070609080A0B0A0D0C0D10
0D100F11111114161519181D1B1D1C1D1D1E211E21232223262A2B2B2E30353336393C3E
4048495154585C6363666A6F747276797A7C7E7F828384808384827F7F7F807F817F7F7F
817D7F7F7F7F7E8184848386868A8A8A8D8A8D87868585837D7A7874716E6A6965605D5D
5B585754534F504C4D484748484746444241424241424041403E3F3E3F3B3D3F3A393A39
3837383834333231322E2F2C2A2C27252425221F1E1E1B1C171917181614121212100F11
0E0D0B0D0A0B0B0A0A0A0809090A09080806070509040504050607050404050205050404
060504
050304050503040604060506070505050708070507050908090C090D080D0B0B0D0C0C0E
1110111010151314171A191A1E201F1E201E202020242426252A2A2C31323537373C3C40
434A4C51555B5E63686A717374767A7D7F818587868888898A8889888687868587858685
858483868389858A8689898C8C928E90918F8E8D8E8B8A87827F7E7774716E6966666260
5B5C5859545352504E4F4D4C4B484A4747444545454347454342433F41423F3F3D3D3D3E
3B3C3A383837343431312F2F2D2D2928262322201F221E1C191817161615121412100E0E
100E0E0C0C0B0B0A09090A0B080608070806060706080506060505080603070505050405
040505
040404040507040708050705080606050605050608090808080908090C0B090B0A0B0C0C
0C0F0F11121213141417191B1C1F1E1F202021252322242828292D2D313334373A3B3F43
45494D525860626668707275787B80818588898D8F8E9091908E8E8D8F8B8C8D8D8A8C8A
8A8B8E8B8A888B8A8D8E8E909193949893939290908D8C8B8583807C797573716D696663
615E5A5B5854555356524F4E4E4C4D4B49484C484747474847494545444744444240413F
403F3E3D3A3A3836373331302E2C2F2829252522211F1D1C1A1A19171813141211130F11
120F0B0E0B0C0B0B0A090908080908050708060706070507050405030505060506040403
040506
030607050405040405030307050606050705050708080809090B0A09090A0B0B0F0C0D0D
0E101210121214151818171B1A201E1F2222212125242728282B2D2E313538383A3B4044
46494E54595E61676C7074797B828386878B909394949999959996959492939492938F8F
8F928F8F8E9191919294959697999B989697969593928E8C898785817B7A79736E6D6864
64605F5E5C5A5956555253504F50524E4C4E4A4D4D4D4C4B494B4A4A4948484745454844
41444442403B3E3936353333342F2E2C2A2B292322221E1F1C1D181A1718141412121312
0F0E0D0C0D0C0B0E0A0B0908070B07070905050706060507050607050504050503040404
060403
030304080405030606040508040604050707070607090706080A0C080C0A0D0A0B0B0E0D
0D0F1012111315151417191B1C1F1F202222242425262627292A2D2F343436393D3F4445
464C4F53595D646A6E73767B7E83888A8E9094999A9B9C9B9E9EA09D9A99999B98989495
959494969593989795989A9B9B9E9D9E9F9B999B979592928D8B8986807C7B7472706C69
69666360625D5B595959555654535252504F5051514F4E4E504E4E4B4F4B4B4C4A4A4D46
4843454342423D3E3C393A3435332F2C2E2A262624211F1F1E1B1B17171615141313110F
1011110B0D0B0D0C0C090B09080A07070508050807080706050806050606060706050306
060505
050607060608030803060404060405050606080608070708080B090A0B0C0A0D0D0C0C0E
0E0E1110121416131816191A1B1C1F2123232324252726292C2B2D2F313437393B414246
494D53565B63656A6F74798082868A909295989D9FA1A3A3A5A2A4A3A09F9D9D9D9C9B9A
9D9C9C9A999A9B9C9D9EA09FA2A1A0A2A19F9D9D9A989894918E8D8A87847C7875726F6E
6A6865666262625D5B5B595A59565659575354555552515153535350505152504D4D4D4D
4A4847484546403F3E3F3836383330312E2C28262523221F241B1A191916141416121010
1410110D0C0C0D0A0909090C070707090805060707090405060504040407050603060706
020506
0405050506070505050505050605060506050706080607080809090B0B0B0D0B0B0C0D0F
0F0E0F1210111315151517181D1D1F2021252525252828292A2D2D313134393C3E3F4347
4B4E52555A6266696F757B8183888E929598A0A1A4A7A8A7ABA9ABAAA7A6A4A6AAA3A1A4
A2A0A1A0A0A0A1A3A0A3A2A6A4A5A5A3A8A3A2A0A39D999895918F8D8885817E78787273
706B6B6968666261615D5D5B5C5A585A5859585856595758555656565455535252514F4E
4F4C4F4B494845424242403B38363332312D2C2827232520201F1E1A1D1A171514111214
0F100E0E0D0B0B0B0D090A09080809090807060709070706070606040505030605050505
030306
05060505030604070507050605060706070A06080709070609080A0A0B0B0B0C0B0D0C0D
100E10121111121617161A1A191A1E1F21232627272A2A2C2C2F2F343336403A3F404347
4B4E535A5D61686A71787B82878C9097989FA0A5A8AAABADAEAFAFAFAEAEACAAAAA9A7A7
A6A5A4A6A4A6A6A4A7A5A8AAA9AAA9AAA8A6A8A6A4A1A09F9A99948F8B8886837D797673
77706F6C6B6868646361605F615E5E5B5E5B5D5B5B5D5C5E5A5A5B595859565755565852
5250504D4E4B4C464644413D3B383634302E2C2A2A282421211F1E1A1B18191414141313
11100C0E0E0B0C0D0C0A090A090A08080808070707080806070507050405050505030406
080406
04040604060806050505050608050406060809060809090808090C080A0B0A0C0C0C0F10
0E0E1211141215141416171B1C1D1D21202224262A2C2A2C2E30303335383A3C3F434449
4C5055585B61676B71787E868B9093989DA5A5AAAFAEB0B2B4B6B5B6B3B3B3B1B1AFADAD
AEAEAAAAAAAEABABABACACACADAFB0AEAFACAAADA7A7A2A29D9C9A93908D8885847E7979
7774716F706B6C686A67676564646662616362615F61615E5F5D5E605D5F5C5C5B5A5A5A
5756555351514C4D4A474543423A3A3734302D2A2928262222221F1D1818191816161211
12110F0E0C0E0C0B0C0D0C090907070807090708070A0806080505040705070603050905
060506
060405050306050505060505060708060808070707060508090A090D0A090E0B0E0D0D0D
0F101113131413151517161C1B1D1E242123262728282A2D302F31333538393C42454549
4C5054575E61676C72787F848C90969CA0A5AAABAEB2B6B5B7B9BAB9BABDBAB7B7B5B3B3
B1B0AFB2B3B1AFB0B1B0B1B1B3B4B4B1B1B2B2AEACAAA9A9A1A19C9793928B898583807C
7C7A7773726F6C6F6C68696B6866656866656765636563666264626362626161615F5F5D
5B595A585A565451534C4A4645403B3B36312E2D2C29262522201E201B19181715131511
11100F0D0F0D0C0D090D09090A0A0A070707070808060606060707050605050505050404
060504
0305040405060806070404080607080605050807090706060A0B0A0C0A0A0C0A0C0B0E0E
0C0F111214121214141716181A1D1D1E23232426282B2E2F2F2F3133353A393E40434A4B
515156585C64676F737980858D9399A1A5A7AAADB1B4B6BABBBEBFBFBFC1BEBEBDBBBBB8
B7B4B6B6B5B5B4B5B4B6B7B8B8B8B6B6B5B6B6B4B1AFAFADA8A2A09C9B94908E8A84837E
7D7C7A79757673716E70706D6D6D6C6B6B6A6A6A6A696A68696A6768666A676564636363
615E615C5A5B59585351504B4A433F3E393430302D2928242120201E1D191B1916151912
11100F0E0F0E0C0C120A0B090D080709070A060808060506060807050604050505070604
050606
050506050506060504060606080806080606070A070909070A080C0A090B0B0B0B0B0D11
0E0E0F10131414141619181B1A1B1E1E20212528282D2E302F33343636373B3E4342484C
4E5257596062676D747A81888F969C9FA4AAADB1B3B7BBBDC1BFC1C3C2C5C5C4C1BFBFBC
BFBCBBBEBBBBB9BABBBBBBBDBCBCBCBBBCBCBAB8B5B4B1AFABA6A5A19C9894928F8B8883
81807E7E7C7A7676767370717270706E6F6E6E6D6E6D6E6C6F6F6F6B706C6D6C6A6C6A66
666462605F5E5E5C5B5952504845423F3838342F2F2927252422221C1B1A1C1716141412
11100E0F0D0C0C0C0B0A0A090B0909070908080907060806050507080307050606070505
060406
05080605050505050305050604050609060707080909070A090B090A0B0A0A0B0D0C0F0F
101110121213161316161817181B1A1E1F212625282E2B2E31313436363B3C3F41444B4C
4F5559595E64676B727B7F888F979CA5A6ADB1B2B7B9BEBFC0C3C9C7C9C9CBC8C9C8C6C7
C2C0BFBDC1BEBEC0BEC2C0C2C4C1C1C0BFC0BEBEBBBAB7B4B2ADA9A6A49C9798938D8C87
878581817F7B7C79797876767679757774757476747471747574747672747173726F716C
6A6967656563625F5E5B56524F4B45403C37343230302A272624201E1C1B1B1616171414
12100E0F0D100D0C0B0E09090A08090A0808080905070505060604080506060504060504
050506
05040803050305070506060705050406050506050908090809080B09090A0B0B0F0D0F0E
0F10120F121314131716181A181C1D1E212222242A2B2C2F30323437393A3E3F4045484D
4D54585B5E63696D737A81898D969CA2A7AEB0B6B7BABFBFC3C7C7CBCBCCCDCCCECCC8C9
C9C6C8C4C4C4C4C4C3C4C7C5C8C6C6C6C6C3C2C1BEBDBAB9B4B0ACA9A6A29D9B96928F8D
8A8987868382807F7E7C7B7D7A797879797979797878777779797978777B7C7877767574
726E6D6A68686764635D5B56514D46413D3B3532302C2A29272225201E1C191719151514
131210100F100C0C0E0B0D0A07090B090809080706070507060706070807040604040404
030605
0506060507050505050706080508080707090807080A0A080708080B090B0B0B0E0F0F0E
0F120E12131113141516181A181A1C21212125262A2A2E2E313337373A3B3D3F4244474C
5052585C60656A6B747984898E989BA2A9AEB2B4B8BCC0C3C6C7CDCECDD0CFD3D0CECED1
D1CACCC9C8C8C8C9C8C8CBC9CBCDCCC9C9C8C8C5C2C2C0BCB8B6B3AFABA8A29D9A979590
8D8D8887888483848282807F7F7D7F7E7E7D7C7D7C7E7D81807F7F817E807D7D7D7E7A79
7575746E6D6C6B6964635E5A544E49473E3C3635302E2C272622221E211C1C1818161413
12110F100D0F0F0C0C090A0A080709080607080907080606050605080505050505050307
050505
06050707060304050507080505070605050506050608090809080B0A0B090C0A0C0C0F0F
110F10121313131617191819191D1C1E20222325262A2D2F313536383A3B3D424446474D
5154585B5F66686F777A7F868F959FA3A8ADB3B7BBBFC1C3C9C9CED1D2D2D4D4D6D5D3D4
D4CFCECECECECDCDCCCCCDCFCED1CECECDCDCCC9C9C4C3C0BFBDB6B2AEA9A7A39D999995
938F8E8E8A8A898786858385838383838282838481828284848386868486838484817D7E
7A7C767271716E6A6764605854514D44433A3A35302F2D27272522211E1E1C1816151413
11110F0E0E0E0D0C0E0D0A0A09080A090907060608090908060607070507050605030304
040704
05050604050706040605050607070605050607050607090A090A0C0A08080A0C0C0D0E11
11110F121213141617171A17191C1F1D1E212427272A2930313537363B3C3D404244484B
4E54575D6263696F73797F878E959CA3AAADB3B7BCBFC2C6CACDD1D2D5D6D7DAD9DBDAD6
D7D4D3D3D3D3D2D2D4D2D2D2D2D4D3D2D1D0CECDCDC9C6C3C0BDB9B5B3AEABA7A3A19B99
979394948E908E8D8A8A89888A878D86888988898A8B898A8A8C8B8B8A89888A86878582
7D7D7B7876706F6B68645F5E5A514C46423D3835322F2D2C2727241F1F1E1A1717161413
121011100F0F0B0F0D090A0E090809090907060807080807080605080508050805070708
030705
0405050505040706040505050504060405070705060809080B0808090A090A0C0C0E0F0E
0E110F11111115141817171A1D1B1F1E1F20232625282D2D3233363A3B3C40414548494E
5254585B60646B6E727A7C848B92999FA7ABB3B7BDBFC3C9CCCED1D3D6D7DAD8DBDCDDDE
DDD9D9D9D7D5D5D5D6D7D5D6D8D6D7D7D4D5D3D2D1CCCCC9C3C1BFB9B8B2AEA9A7A3A09F
9C99999895949090908E8D8D8D8F8E8C8E8F8D8D8E8F8E909194919093908E8C8B898687
807F7C7B7774706E6964605C585049454341393732302D272725201F221E1B1918161416
140F1011110C0D0F0C0B0D0C080A0B09070B070707070B06060607060606040604050506
030505
07080504050609040504060507060905050708090808070809090A0A0E0C0C0B0D0D0D10
110E0F1112131415141617181A1C1D1F1F21232427262B2D32343439393C3F404245494E
5053595A6264676E72787E828992989EA9ABB3B6BEC1C5C9CCCED3D4D7D9DCDEDEE2DEE0
DEDEDEDDDBDBDBD9D9D8D9DBDBDCDAD9D8D7D7D4D4CFCECCC9C4C1BEBBB7B2AEABA8A4A2
A09F9D9A999898969493929693919194929495959698979596969798979594918F8D8B87
87827F7C7A736F6C68646059544F4C45413C3C3733302C2A28232322201F1B1A18171615
131213100E0E110D0C0C0C090B0A08080A09080807050908080608050605080604050405
050703
030504050504040506050606050706070707050707070708080A080C0C0B0A0C0B0D0D0C
0D111311111115131819181B1A1A1D202020222325292B2C2E3036393C3E42434648494E
5054595D6063696D72787E82888F979BA2AAB2B6BBC2C5CACCCED3D6D8DBDBDEE0E1E2E2
E2E3E1E3E1DEDFDEDDDDE1DFDCDDDDDBDCDAD8D8D4D2CFCFC9C8C5C3BEBAB6B3B4ABA8A7
A6A4A19F9E9C9B9B999B989C97989A999C9D9C9D9E9E9D9D9A9A9D9D9998959391918B89
8583807B7875716C67645D5A534F4A46423E3A35322E2E28272523231D1C1D1A16161612
1414110F0E0C0E0F0E0A0C0C0A09090B0808070607080705060808070507040705070507
060504
0805040607040504060605050806060505060808060807080707080B0A0C0D0C0C0B0D0D
0F0F1210121112141517191B1A1C1D1D1D2223242528292B2F30343A38403E4245474A4D
5054585B5F65666E73767D82868F949AA0A9AEB3BAC1C4CBCDCFD4D7DCDADEE1E1E2E5E4
E8E5E4E5E6E3E3E1E1E1E1E1DFE1E1E3DDDCDAD9DAD4D3D0CCCAC8C6C1C0B9B8B6B0AFAE
AAA7A3A6A3A1A1A0A09D9D9EA09EA0A0A0A0A2A1A3A0A4A1A3A0A19D9B9897979393908B
8886817E7B75716B66625E59524C4A443F3B3936342E2D2A272522231F1F1C1A17171416
12121010110E0F0E0A0B0A0A0A0C0A09070B0C0808070807070806050705060506040508
040406
0508040606050607040607050705060707070706080707080608080A09090A0C0B0C0D0D
0E0F0E1113141414151618181A1E1C1E1E22212523272A2C2F3034383A3C414244464A4C
5252555B5F626A6E71777B80898B93989EA7ADB2BCC0C4C8CCD2D4D7DADDDEE2E5E6EAE7
EAE8E8EAE9E7E7E6E6E5E3E4E4E5E5E4DFE0DEDBD9D9D6D5D0CECBC7C5C3C0BBB9B4B3AE
ADABAAA7A6A8A4A6A3A4A4A2A7A7A4A8A6A5A7A8A8A9A8A6A5A4A5A0A29D9B9797928F8C
8B85847E7A74706E67615D5651504B43403C3837332E2B2A2926221F1F1D1B1818151614
1510110F0F0E0E0C0C0C0B0C0B0A080A0807090908060906070505050506060706040509
040504
0407050505040406040508050704060705060707060709070B09090A0A0A0B0E0C0E0D0E
0F100F1312121515151616191B1C1C1C1E2123222527282B2F313136383B3E43454A494C
4F5258596163686A70737A80858A90949CA2A9AFB7BCC2C6CDD0D5DADBDDE0E3E3E6E6E8
EBEAECEBEBEAE9E8E9EAE6E6E5E7E5E3E3E1E2DEDCDBD9D4D4D1CDCCC8C5C4BFBCB9B7B4
B1B0ACACADAAA9ACAAABAAACACAAAAABACADACADABABACA9AAA7A6A4A29D9C9A96939090
8A86807F7B746F69665E5B534F4D46433F3D3935302F2C29272422211F1D1B1A19151613
1311120F0E0E0C0E0B0E0C0A0B0A090A07070A0707060609070806070606060905060505
050704
070505040505060706060605070405080808070706070908080A08090B0A0B0A0B0E0F0F
0E10111311101314141718181D1A1C1D1E2225262629272A2C2E3134393A404144474A4D
505257585D61676A6F747A7C82888E969A9FA7ADB8BCC0C9CCD1D5D9DADDE2E3E7E5E8EB
EDEEEFF0EEEEEDEDECE9E8EAEBE8E7E8E6E8E3E0DFE0DAD9D7D3D1CFCBC9C8C4C0BDBCBB
B6B8B3B0AFB3AEB2B0AEB2B1B2B3B2B1B2B2B3B1AFAFB0AEACA9A7A4A29E9C999A93908F
8986837E79757068635E57554D4A4843403B3833332D2C2827252320201F1C1817161513
121312120F0E0C0E0D0C0C0B0A0A0808080A080A0A070907070705060505040605060504
040704
0407040604070606060508060408080706070607060708070709080A0B0B0B0C0B0C0E0D
0D0F111113151313161716171B1A1A1E2221222626262A2C2D303633373B3D424545484E
52555C5C6060666E6E72797C83878E90969FA4AAB1B8BEC5CAD0D2D7DADDE1E2E3E7E7EA
ECEDEFEFF0F0EEEEEEF0EEEDEFE9EAE7E8E7E7E4E2E0E0DADBD6D5D3CFCDCAC7C6C2BFBD
BEB9B7B8B6B7B5B4B8B6B6B5B5B7BAB7B8B8B7BAB6B2B3AFAFACA9A6A3A19D9A9893928C
8A86837D78736D68635D5752514844443E3B3835342F2E2927262022201B1B1816161715
111112110F0E0B0B0C0B0A0B0808080A0707080806080808050608050604070407070705
070606
0806050405060706060605060604050706050709090708070A090C080A0C0A0C0D0C0F0C
0E0E10101312121413151818181B1D1C2021232423262A2A2E2C30323A3A3D4145474C4D
515755595F61656A6F74777B84888B94999BA2A8ADB6BDC3C7CDD2D6D9DCDFE2E5E6EAEA
EDEFF0F1F3F2F4F1F2F2EFEFEDECECEAECECE8E7E5E3E2DFDED8D7D9D1D0CDCCC7C7C2C1
BEBEBEBBBBBCBBBBBDBFBDBABBBFBDBABABABAB8B9B6B3B4B0ABAAA9A4A19D9B9894908D
8985817B756F6A64605B54504B4845403F393736312E2D292828211E1E1E1C1B18151614
1312100E100E100C0C0F0A0B0A0D070A0707070907050706050606060608050404070405
050704
0705060A080706060606050506060608060607070909080807090A09080B090D0C0E0E0E
0C0F0F12121215131616161A1A191C1D1F20222424272A2D2C31313136393C404344484E
515656595C6166696E73747B80878A8F929A9EA7ACB1BCC2C5CAD0D5D8DDDFE1E5E8E9EB
EBF2F3F1F2F5F6F4F5F3F4F1EFEFEFEEEEECECE9E7E7E4E4DFDFDBDAD4D2D1CECBCAC8C5
C3C2C1C3C1C2C1C0BFC4BFC1C4C0C1C0C1BDBCBABBB9B6B5B1AEABA7A4A29D9D97958F8C
87837E7B736F68655F5A554E4A4743433E3A3632312F2929252322201F1D191A15181514
141210100D11100D0C0B0D090A0D09090908070907070806070706070707060404060604
070505
050505040606040506080507080506050805090709070808080C07090A0A0E0C0E0C0E10
0C0E0E11101112131418181918181D1E1F212322262627292D2D2F3335363D3E4043474C
5151565A5C6063696C75747A7F85878C929A9DA4A8B1B5BCC2C9CFD3D6DBDEE3E4E6E8EB
EFF0F0F2F5F6F8F7F6F8F6F3F1F1F5F1F1F0EEEEEBE9E7E6E4E2DEDCD7D5D4D4D0CDCCCB
CACAC8C6C8C5C8C5C6C7C6C6C7C7C3C3C4C2BEBEBBBBB8B6B2B0AAA9A6A29D9A96918F8C
85807B77726C65605C57534E4C4743403B3B3632312F2D28252422211F1B1A1A18181614
131110120F0D0E0E0E0B0C0B0A0A07090908080906070806060606060705060607060704
050307
05070605060704060606070504080707060A0B0707080B09090A09090C0D0A0C0C0C0C0D
0E0F10120F12131316141719181A1B1D1D1F202426242A2A2B2D303234393B3C4045474B
4E52575B5B6264666B7175797C82878B8F979CA0A8B0B3BABFC5CCD3D6DBE1E2E2E7E8EA
EFEFF3F7F6F7F6F9FDF8F7F4F5F6F5F1F0F1F2EFECEDECE8E6E4E4DEDDDCD9D5D4D2D0CE
CCCDCDCBCECBCCCCCDCACBC9C9C7C9C6C3C3C0BEBEBAB9B4B3B0ABADA5A29E9996908F89
82807773716967625A555150494644413D3934332E2D2A2527242120201B1A1A18181315
111210120E100F0C0B0B0C0A090A090907080708070705070709080705050B0604070505
030508
0706070705040607060606080706060906060707090707090709080A0B090C0D0B0D0C12
0E0E110E101313141516161A19191A1C1F1D21222427272A2D2D2F3134373B3D4245474B
4E5255595D6064666A6D747B7C81858C8E939A9EA4A9AFB5BDC3CACFD1D7DFE0E4E4E8EB
ECEFF4F5F8F7F8FAFAFBF8F7F9F5F5F4F5F5F2F3EFF0F0EBE8E7E4E3DFDDDDDCD8D6D6D5
D4D2D2D1D2D1CFCFCFCECCCBCBC9C8C8C6C3C2C1BFBCB9B4B1AEAAA9A2A19E97938E8B84
827D76716C67615E5A57504C494441403B3834322E2C2B27242420201D1A191B18151513
1012130F0E0F0D0D0B0A0B0A0809070A08070A0807060706070706040508050509070707
080506
040505070609040505050607040507070706080909070807090A0809080B0D0D0E0C0D0C
100D11101013111414161818191D1C1C1E1F22232525282A2D3130303535393C3F43474A
4E5157585B5E62686A6C73767C7E83888D96999BA3A8ACB2B7BDC5CDD2D8D9DDE2E7E8EB
EEF1F1F4F6F9F9F9FAFAFAFBF9F7F6F8F6F4F7F5F2F1F0EDEDEBE7E3E3E4E1DFDBDCDAD8
D9D8D7D5D5D4D4D2CFCECECDCCCBCCC8C8C5C1C0BFBCB9B4B3AFADAAA29E9995918B8682
7D77726D69655F5C55514F4A4643413D3B3833342D2B28272322221F1D1B1A1916151612
110F0F100E0D0E0D0D0C0B0C0B080A08080807080A060607080505090705050507060605
040503
04060607050705060707050607050505060607070B0708090B090A0A0A0B0A0D0D0D100D
0C0F110F1111121415141A16191B1B1D1C1E2023232627292B2E2F3135363B3C3D414848
4C5054595B5E6265686C71767B7E81878C9094989FA3A9B0B7BCC2C9CED2D6DDE0E3E8EB
EDF0F3F4F6F8FAFAFDFBFCFCF9FBF7FAF8F7F9F4F4F3F1F0F0EEEBE8E7E5E5E0E1DEDDDD
DEDCDADBD9D6D7D5D2D3D0CECDCDCCCBC8C9C4C2BEBCB7B3B1ACABA3A09A97928E89837F
7973706B675F5D5A54504D4A46413F3C3734312E2D2B292623211F211D1A1A1616141312
131310100F0F0D0D100B0C0C0B0C090B07080A0909070807060606050707070606050406
090506
0607070707070508050707060509040707060707080707090C09090C080B0C0E0D0F0B0D
0F120E111012131214151617191B191C1D1E2022242527282D2D2F313436393B3D414446
4C4F53575A5E61646A6B73737A7E83868A8F93999CA1A9AEB2B9BFC6C9CFD5DBDEE2E7EA
EDEFF3F6F6F7FAFAFBFAFDFDFDFBF9FBF9F7F8F6F5F3F2F3F2EFEDEAEAE8E5E6E4E3E2E0
E3DFDFDDDCD9DBD6D4D7D3D0CECCCAC8C8C6C1BFBEBBB7B0B0ABA8A29D98978F8985807B
75716B67645F595550514B4743413E3A383832302C2A282522201F201C1B191916151514
110F150F0E0C0D0D100C0C0A0B0909080909070806070607050606060705050706060505
070507
04050506060404050805070A0606070808080907060B08090C0A080C0A0B0F0C0B0C0C0E
101110111011141213141617171A1A1C1F211F2423262A292C2E2F323336393A3C404345
49505056595F63666B6C7174777C8088888D91979F9FA7ABB2B5BDC2C7CCD0D7DDDFE4E9
ECEFF2F5F6FBFAFAFBFEFEFDFCFCFDFCFBF9FAF8FBF5F6F6F3F4EDEDECE8E9E7E7E5E6E6
E3E3E0DFDFDCDBD9D7D3D3D2D1CCCCC9C6C3C0C1BDBAB3AFACA7A1A09C97918B86837B78
736F6A64605D5855514F4A4642403C3A3534312D2D2B26252220201C201A181816151512
111210110D110E0D0B0A0B090B0C0A0A0A08080607060807060606070506060404050404
040505
050507070407060406060507060607050606070907070A080B0A080A0B090B0B0B0D0D0E
0F0E10111013121413161617171B1A1E1D2021222325272B2C2C30313335383B3C404245
484E53545A5B6065696C7074767C8283858C91949CA0A3A8AEB1B8C0C2CDCFD4D9DEE3E8
EAEFF1F5F5F7F8FCFCFCFEFDFDFCFBFCFBFAFBF8F7F6F5F7F5F2F2EEEFECEDEAE9E7E7E9
E7E6E6E2E0DFDADBD7D5D4D3CECFCCCAC6C3C3BDB9B5B3AEA9A4A19B958F8D88807E7876
716E67605E5A57534F4B4947443F3D383733322E2C2A272725231E201C1A191716131213
12100F130F0E0D0B0D0C0B090B0A09080708080909070606060405060705070408060507
040704
0608050507040404060705040604070506050609070A080A090C0B090A0C0C0A0F0B0D0B
0F0D111211141315141416161A181B1D1C1F23232324272A2B2C303332353A3E3F3F4348
474B52535A5D5E64686B7074787A7C84888A8E96979CA2AAAAB3B6BCC0C5CDD1D8DCE5E5
EAECF2F4F7F9FBFBFDFEFCFEFEFEFDFEFBFBFCF9FAF6F9FAF3F2F5F1EFEEEDEDEBEBEDEB
E9E8E6E6E4E1DEDBDBD6D4D1D1CDCBC6C6C2BFBBB7B6AFAAA7A19A97908E88837D7A7873
6C6964625C5856514D4A464540403A3634302F2E292A2626251F1E1B1B1A181715141213
1310120F0E0C0C0C0B0A0A0A090D0B090A08070A08060606080906070508040404070605
070706
0A03050504050505060505040408060A08080707070A0909080A08080A0B0C0C0C0B0D0E
0E0E0E1111121313141517191C1A1B1E1E1E2121232726292C2E2E323335383A3E404445
4A4D4F54565C5F636A6C6E7475787D8084888F95969CA2A5A9AFB3B7BDC5CCCFD3D7DEE4
EAECEEF2F6F8F8FAFBFBFDFBFCFDFBFBFBFCF9F9F8F9F7F7F4F6F3F5F1EFF0EEEEEEEEEF
E9E7E8E7E4E1DFDCDAD7D6D4CFCCC9C5C3C0BEBAB5B1ADA8A39D96968C8985807B75736E
6B65615E5A5852504C474643403B383634322E2B28282624211F1E1C1F19171715141414
120F100E100D0F0E0C0B0A090908090A0709070608060806050905040506050406080804
050605
05040407040508050805080508050605080707060807090908070A0B090B0B0C0B0C0E0D
0E0E0F1012121512131516171A191C1C1E201F202425272A2A2D2E313437373A3D3F4447
494A4E52585A616266686E73797A7D8085878C96979B9FA2A8ADB0B7BBBFC4CACFD5DCE0
E3E8ECEFF3F4F6F8FBFBFDFAFCFFFCFBFAFBFAF9F8F8F9F8F4F4F4F3F2F3F0EFEFEDEDEF
EDE9E8E6E4E1DDDBD9D8D3D1CDCCC9C3BFBFB9B7B1ADA7A49F99948F8A84817C7B736F6D
6864605D5855534F4C4A44433B3A3935322E2C29292726221F1E1D1C1A19181616141613
120F0E0E0C100E0B0B0A0C0B090B08080807090909090805050707080506080707060409
050606
05090507070405080608070507070806090907060A0708090809080B0A0A0C0C0D0C0C0E
0C0F0E1010131512131516171B181A1E1E202021252527292C2E2D313435373A3D404345
484C4F53585C5C62656A6F73757A7E8188898D91959B9CA0A6AAB1B4B8BDC3C9CFD3D8DF
E1E8EDECF0F3F4F8F9F9F9FBFBFAFBFAFAF9FBF9F9F8F6F7F5F7F4F4F4F2F5F2EEF1F0EB
EBEBE8E7E3E1DEDCD9D7D2D0CCC8CAC2BFBCB4B2AEAAA29F9894918E85807D7A76716C6C
65605D5A57524E4E4B45413E3D37353331302D2A29262422211E1C1E1817161414151213
1011110F0F0F0B0A0F0A0B0A090A080908080A0806080807080409040805080409040505
060505
04050705060404050405040609060807090709060709080A08090A0A0A0A0B0A0C0F0D0E
0E0F100F111114171415161617191C1C1E2120222328282A2C2D2E313235373B3E404445
484A4C5357595E616669707374787E8082868C9194999EA1A7A9B0B3B9BCBFC3C9CED4D9
DDE5E6EDF1F3F4F3F7F7FAF9FAF8FDF8FBF9FBF7F9F8F9F9F7F6F5F3F5F4F7F0EFEFEDED
EBE9E7E6E4E1DEDBD9D3D2CEC9C7C5BFBBB8B4AEA9A4A09C98908D8883807A76736F6C68
635E5D58535151494846403D3D383733302B2C2929252122201D1B1A1916161415121412
11101210100D0B0B0F0C090A0A0906080707090608060907050809060505060505060506
060405
05050606050705060706060705060505090608080707080B0A0B0C090A090B0B0C0C0F0E
0E0D10111115121213161716191B1B1E1D2025222525262B2B2C2F313235373A3F414344
484D4D5054575B61656B6C72737A7E8082888C8F93999EA0A7ACAFB6B7BBC0C3C7CED2D8
DBE0E6E9EBEFF0F2F7F6F5F9F6F9F7FBF8F6F9F8F7F6F6F8F5F4F5F5F3F3F2F2EFF0EDED
E9EBE8E6E3E2E0D9D6D4D0CBCAC4BFBCB9B3B0ADA6A19C97938E8B867F7D7A75726F6864
645D5C57524E4B4945433F3B3B353432302C2C27292423231D1D1D191A16171614131110
100F0E0E0E0D0C100B0D0B080A0A0A0A0909070707060606090608040606060407060709
050304
04060506070508060605070706080806070A06060809070708070B090B0C0D0D0E0C0D0D
0E0F0F0F13121216141819181B1D1A1C1E1E2023242729282A2C2F303336393A3D414346
474C4E5055585B6163696C7178797E8084898B8F94979DA1A4A9ADB1B6B8BCC3C6CAD0D4
D9E0E4E9ECECEFF2F2F6F5F7F3F6F5F6F6F6F5F7FAF4F6F4F5F4F5F3F4F6F1F0EFEDEEEC
EAE8E6E3DFDDDBD9D2D0CFCAC6C0BBB9B5AEACA5A29C9B94928B86828079747370686661
5F5D5754514F4A4743423E3C3834312F2E2A2828262224211D1C1C191918151613141213
110F0E0E0C0B0B0C0B0C09080809090A0906070607060706080506080704050505050504
040607
0505050604040406070504050806080807050808070906090708090A0C0A0B0C0B0E0D0D
0E0F0F111212131914161717181A1A201E1E242324252828292F2F3233363A3C3C444246
4A4C505155585F6163666C7173787E8086888B9094989EA0A6ABAAAFB4B9BBC0C4C9CED2
DBDCE2E4E7EDEFF0F0F1F4F2F4F4F6F4F3F6F6F7F6F4F3F5F5F5F2F2F3F0F0F1EEEFECEB
EAE7E6E2E0DED7D6D3CFCDC5C5C0BBB6B0AEA8A6A19897918B8982817C78726E6C6A6363
5D5855514E4B4944413E3A373635302E2F2A27262522241F201C1C181915171613141312
0E110F0D0C0D0D0A0C0A0B0B0A0807090607060B08060606070606070606070607050407
040504
040404070406060608070509040607060607060607070B0B08080B08090B0A0C0B0E0E0E
0D0F0F101315151315171917191B1A1C1E1F1F24232627292A2C2F303335383C3F414346
494D4E5053585B5F66666E71767D7E82868B8D8F92989BA1A5AAAAB1B5B8BDBFC5C7CED1
D6DADEE4E5EAECEFEDF2F0F0F1F6F2F3F5F4F4F3F3F3F4F4F3F3F2F3F1F0F1EEEDECEBE7
E9E4E0E0DBDBD6D2D1CCC9C4BFBDB6B4B2AAA5A19C9792908B88847D7A79716F6B666262
5A57534F4C4A4743403D3B383833312F2B2B2728252221211D201B1B1716181414141111
110E0F0B0D0D0B0A0B090A0908080B08090A0A0905060705060805050405080406040503
050705
06060706070607070605070706050707060807070707080A09090A090B0C0C0B0B0D0F0F
0F0F0F1212131614141617191A191E1D201F20222626272A2B2D313335373B3A3F434446
4B4E5054585A5C6063676B6F78767D82858A8D9096999B9FA8ABADB0B2B7BBC0C6C6CAD0
D7D8DFE1E6E8EAEDEFEFEEF0F1F1F1F1F3F2F1F3F3F2F7F1F3F0F0EFEFF0F0EDECEDEAE8
E5E1DFDCDBD7D2D0CAC8C3C0BCB7B6AFA9A7A0A09A96918C88857F7F7776736B67646260
5755554F4E4947423E3B3A363332302D2C2A27232320211D1C1D1B181718161512131010
0E0D0E0F0C0C0E0D0C09090A090809080607080809070706080604060605040606040708
050705
0505050607050808060605080808050706060A090709070909090A0C0B0A0C0E0C0E0C0C
0E101210111315141317181A191A1B201F1E232125262A282B2E3334363B3C3C40414448
4A4F5153565B5E6062686A70777A7C83858B8D91959A9BA2A3A9ACB0B4BABBC2C3C7CBCF
D4D8DCE2E3E7E8EAEAEFECEDF0EDF0EFF0F0F1F1F3F2F2F1F0EFF0F1EDEEEDECE9EAE8E7
E2E0DEDAD8D3CFCCCAC5C1BEB9B8B3ADA8A3A09A97948F8A8682807C76716E6A67655D5D
5757504C4946443E3C3C383634312F2E292828242220201D1E1A19171717151613141010
100E0E0E0D0A0C0B090B0C0B0908090A0908090906070706060505040505060604060507
070507
040407090406050506050505060A0B07080907060A0607080A0809090B0A0A0E0B0C100F
0F0E1310131113121715171A171A1D1E1E2223242428292D2D2F323436373A3E41414349
4C4D5052575A5E6164696D7077788083868C8F95969A9EA0A5A8ACAFB6BBBDC0C3C6C9CF
D3D7DBE1E3E6E7EBE8EAEFECEDEFEEEEF0F2F2F1EFF0F1EEEFEDEFEDEDEDEBEBE9E8E6E5
E1DEDBD6D5D0CECAC5C4C0BAB7B3ACA8A5A09F9A94938D8886817B77726F6C6965605E59
5552504B474646403C3B3635322F2D2B2A2626242222211C1B191818191513151312120F
0D0D0E0F0D0F0C0A0D090B080A0609080908070806050706050705060607060506060604
080604
060404060403040706070506050606090807080609080A080C0A0A0A0D0B0C0D0B0D0D0D
0D0F0E10111313131515181B1A1B1D1D201F202526272A2B2D2F323335393A3C41434748
4B515156585D5D606A686D72767C7F83878B8F93989C9FA5A6AAACAFB3B6BBBEC2C8C8CF
D3D8DADDE0E4E8E5E8E9E8E7EBEDE9EEEEF0EFEFEEEDEEECEEECECEEECECEBEDE8E9E8E5
E0DFDBD8D3CCCAC7C3C2BDB7B5B1ACA7A29D9A97968F8A87837E7A77746D6B65615E5956
54504E4C4744423F3C393733302F2D2C2825252424201E1D1B1919181615161514100F10
10100E0E0D0D0F090B080A09080A06090907060A08060506080606060606060609050704
060607
04040506050505060806040506090707080A06080907090909080808090C0C0C0C0D0E0E
0D0F0F12111213131615181819191D1D212024252626292B2E31343436393D3E42434548
4D4F53575A5A6162666D6F73777A8083888E9195999CA0A3A5A9ABB1B4B7BBC0C3C7CCD1
D4D5DADEE0E1E4E8E6E7E8E7E9E9EBEBEBECEDEFEFEBEDEAEAE9EAEAEBECEBE9EBE6E6E0
DFDCD5D4CECCCAC5C1BEB9B7B5AEADA5A19E9A97918E8A87847E7974726C6965615B5A55
54504C474642403C3A353834312D2C2A282725232220211C191A1816161415141011120E
0F0D0D0E100B0C09090B0A0A080B08090808070907060708090405050A06060507070705
060905
07040507070605040306050707070706070807070A0A090A080B0908090B0D0A0B0E0E0E
0F0F0F101513141614171A1C1C1C1E20202124262729282C2D313535363D3C3F4144474B
4C5155585B5D63666A6C7173797E8286899092959A9D9FA4A7ADAEB3B7BABDBFC2C7CCD1
D2D6DCDBE0E0E2E4E3E5E4E5E7E9EAE9ECEAEBEBEEEDEBEAEAE9EAE9E7E7E8E9E9E5E2E1
DCDAD5D4CDC9C8C3BFBBB8B7B1AEA9A4A19E9896918C8784807B7B746F6965625E5D5654
524D4B4943423F3A3A36343231312B2B272722221F211C1B1A1A18161513121114131110
0D100D0E0D0A0A0A0A090708080908090807070708060808070606040505050606050506
050707
0705050504060406050806040608050707070907090A070807090A0E0C0B0C0C0D0D120E
0F1112121313171518171A181C1B1D1D1E22252627282C2C2E313536383D403F4345474A
4F51565C5D606566696E71747B7B80868A8D91969B9FA1A5A7ACB0B3B6BCBEC4C5C9CDD2
D3D6D8DCDCDFDFE0E1E3E4E4E3E4E6E7EAE9EBEAEBECE9E9E7E7E6E7E6E9E6E6E8E3E2DF
DDDAD6D2CDC8C6C0C0BAB7B4B0AEA7A39F9996918F8E8683807A76746D6865625D5B5652
4E5048454444403A383435312F2E2A29242523221F1F1C1B191916151515121111110F10
10100B0B0E0B0B0B0A0B0808080706060807090A06080706060706050505030607060705
060506
0504040706040505040706080807040906080706090A0A08090A0B0A0D0C0C0B0E0F0C0D
110F0F111315151418191A1B1B1B1C1E21222425282A2C2C30313437373B404143474C4D
515359595D63656B6C6F75797C7D82868D9094999D9FA4A6ADAFB2B7B9BFBFC5C6CBCECE
D3D7D7DCDCDCDEDDE1DEE1E3E3E1E2E2E4E6E8E6EAE8E7E5E7E6E5E5E5E7E7E5E5E4E4DE
DCD7D4CECBC6C6BEBCB9B7B4AFACA6A39E9997918C8A867F7E7777716B66616159585454
4E4C4C4543403C3E38383432302D2B26262523201F1D1C1A1918171415131510130F0F0E
100D0D0B0B0C0D0C0B090A09090808070607070606060605060507050806060504050307
050605
05050404040506070A05070508050507070608080908060B080D0B0C0D0C0A0F0F0D0D0F
0E101011131314161818191B1C1D1F1E222125252A2A2C2E31323336393E3F4144474C4E
5155575B6063666A7073777C7C81868A8B9195999FA2A6A8ACAFB4B8BBBFC1C4C9CCCED1
D4D4D7D9DADBDEDFDEDFDDDFDEE0E1E0E3E2E5E6E9E5E4E3E4E3E4E4EAE6E6E5E3E2E1E0
D8D6D3D0C9C5C2BEBBBBB3B3AFAAA5A09E9A95908C8981807C77726F6969655E5C555551
4C4A4745413F3A38383630302D2B2A282423221F1D1D1D1A181716181714121410110F0E
0F0D0D0D0D0C0C0B0A080B08080A08070806070606050908060805050604060604040605
060504
050404070807030805050506080708090607080709090907090A09090B0B0B0B0D0C0D0F
10111013121215161618171A1D1B201F202325262A2A2C2F2F3434393C3D4042464B4D50
53585B5D6165686C7172797C7F8287889095959C9FA2A8AAADB2B9BABDC2C4C6C8CECDD2
D3D5D6D8D9DAD9DBDDDBDCDCDEDCDEE2DEE0E2E2E1E2E3E0E2E3E1E2E1E2E2E5E2E3E0DC
D9D6D0CCC8C4C1BEB9B9B5B0ACA7A49D9A98938E8D8882817A75716E6867625C5753544F
4C4B4643403D3A393632312F302C2727252521201F1E1B1C171B14151515141310110F0E
0D0F0C0D0C0D0D090B080908090608090A06070907070506060708070406030605060505
060504
07060505070708050505050606060706080A09090708080A090A0C0A0B0C0E0B0C0D0F10
100F0F121513141617191A1C1B1C2120232323282A2E2D30303636393B3F4045474D4E52
535A5B5E62676A6F72767C7B8085898D9097999CA3AAA9AEB3B4B6BBBFC2C5C8CACBD0D1
D4D4D4D7D7D7D8D9DAD8D8D8DCD9D9DDDCDEDEDFE2E0E1E1DEDFE0DEE1E4E0E2E2E1DEDC
DAD5CFCDC8C5C1BCB9B5B5AFABAAA29E9994918F8985837D7976726E67625F5C5856514D
4D494843413E3B3B3432322E2D2A2A26252221211C1C1A1A18181516131612130F100F0E
0D0B0D0D0C0C0D0B0A080907080807060907080607070504060706050704060505090705
040606
0505050A0706060707040B060605090808090B0A070908080D0A0B09090E0B0C0C100D11
101110111516141517171B191D1E1D22232528282A2D2F313333383A3D3F42454C4B4F53
565A5D6166696C7274797C7F85888A8F92979CA0A3A8ACAFB2B6BABEC0C3C8C9CBCECED1
D4D2D4D7D6D6D6D6D6D6D7D6D5D5D8D8DBDBDCDCDBDEDDDFDCDEDDDDE0DEE3E1E0E1DDDC
D8D6D1CCC8C3BEBCB8B5B2AFA9A5A19E9A94918F87837E7B77736F6969645F5A5652514D
4C4543423D3D3A373232302D2B2926252322211D1C1B1C19171616161212130F13100D0F
0E0C0E0B0A0C09090B090809080609090708090707050805040708070304060504070508
050607
04070407050504040505050406060506080607090909090C0A0A09090A0B0B120C0C0D11
10110F1217141617161B191C1D1D2222222727292A2E2F333335393A3E4145484A4E5256
5A5C6067676A6C72767A7E8288898B90969B9EA3A6AAB0B1B7B8BBBDC1C5C5C9CDCCCFCF
CFD4D3D2D4D3D4D4D3D5D4D4D5D6D6D5D6DAD8D9D9DBDCDADADDDADADEDFE0E0DFDDDBDA
DAD4D1CBC8C3BFBCB7B4B0ADA9A6A19D9992918F8788807A76736D696661605A55524E4E
4946433F3E3B393532312C2D2C2727242222201F1B1A191917161614131312100E0D0F0E
0C0F0A0B0D090A0A0B0B0A09080707070608070605070707040706060406050405070505
060505
080606070706040404060506060607060706090807080908080A0B0B0B0A0D0C0D0E0E10
110F1212131316181619191B1F1D20202427292B2A2D303034363B3D424545494E4F5655
5C5D6268696C7173777E7F83898E90959A9FA0A9A8AEB1B8B7BBBFBEC4C4C4CACBCBCED0
CED1D1D1D1D3D2D1D1D0D0D1CFD2D2D3D2D2D4D5D6D7D8D8D9DBDDDADADCDEDFDFDCDCDA
D9D5D0CBC9C4BDBCB7B2B0ABA6A3A09A96928D8A85807E7875706C6665615B5854514E4D
4644423F3E383733322E2C2A2828262322221F1F1A1A181A1A1814131113120F10100F10
0D0C0D0D0A0A0A0C0807080C07070A080506060707070607050606040304050407040404
070805
050705040605080607050607070506070806060708080708080A0A090B0B0C0D0E0D0D10
121313111315161718181A1C1D201F22222628282C2E303336393B3E40454A4B4E52555B
5E6163666C7074767A7F83888E9195989DA0A6ACACB2B4B6BABCBEC3C3C4C5C8C8C8CACA
CDCDCECFD0CECFD0CECECDCFD0D1D1D0CFD1D1D3D4D4D5D7D7D7DAD8DBDADCDCDCDDDBDC
D7D6D1CCC7C4BEBCB7B2B0A9A6A1A29897908F8A85807C7974706F6763625D5855514B4A
47443F3E3C393536312F302A2C252321231E1D1D1B1A181A1816131414141210100F0F0D
0D0D0D0B0C0A0A0B0A07090A0A0807070607080907050806080605050404050506040305
060505
03050407040408080605050706080506080706070708090A080C0A0B090D0C0D0D0F0D11
0F1214131315171616181A1E1F1E1F212625292A2C2F3134363A3D4044484A4D5156575B
60636569717276787F81858C8F9499A0A1A5A7ADAEB4B4B8BBBCC1C3C2C4C4C6C7C7C7C8
C9CCCBCACBCACACBCBCACAC9C9CBCBCCCECFCDCFCFD1D5D3D7D7D7D8D9DBDBDADADBDAD7
D6D3D3CEC9C4C2BBB7B4B1ABA6A49D9996908F8885817C7773706C67615E5C5654504E48
4644403B3B3836342F2F2A2B2A25242223221E1B1A1A1A181717131414111111100F0E0C
0E0C0A0D090A0A0B0C0B0907080708070708090909060607050305040406080504060503
060607
0504070805040606060406050608080606080609070C090D0B0B0A090A0C0A0D0E0E0F0F
0E12121214171616181C1A1C1E1E22232427292D2E313535383A3E4045474C5052565A5D
6264676B7176797C80878B9094989CA0A2A7ACB0B3B4B7BABEBFBEC0C1C5C3C5C6C7C6C8
C6C6C7C8C6C9C7C7C6C8C5C5C7C5C6C6C9C8CCCACDCCCDD0D2D1D4D9D8D7DBDAD8D9D9D7
D6D4D1CDCBC5C2BCB7B5AEACA7A49D9C94928D89837F7D7675726A6764605B5753504B49
43453E3D3B37353130302D2829282422231E1E1D1A191816151513131210110F100D0F0C
0F0B0B0C08080A0C0B0A080A090806070707070606060705060506060604070507050606
040706
05070504040504050707080806050709080707070A07080909090B0A0B0D0D120E0D100E
100F1112151617191A1B1C1C1E20222526282B2D2D3036373A3B4143484A4B5253595C5F
6466687071797B8388898C92969A9FA4A6ACADB3B4B6BABBBDC0C1C1C1C3C2C2C2C2C2C2
C2C6C6C4C4C2C3C3C1C6C3C1C3C2C1C5C3C5C6C6C9C8CACFCECFD2D4D7D5D8D9D8D6D9D6
D6D5D2CECAC6C2BDB9B3AEA9A8A09E9A93938B8784827A7A756E6A66625F5855504F4947
43423E3B373733302F2D292827262423231F1D1B1D1918151716131413110F100F0F0D0D
0F0C0C0B0D0A0B090C08080807080B080606080508060708080405050905050708040405
060604
07050605060705060707050506080707070907080A060908070909090B0C0D0D0D0F0F0F
131213131317151A191C1B1D1F212224252A2B2F303133383B3D4143474B4E51585A5E62
65676D7075798083888F93969B9FA2A6A9ACAFB3B5B9BBBEBCBFBFC2C5C1C0C1C0C0C0BF
C1BEBEC0BFBFBEBCBEBABABBBDBCBEBEC0C0C0C2C2C6C7C8CACFCFD2D5D4D8D5DAD5D7D6
D3D4CFCDCBC7C4C1BAB5AFABA8A19D9792908C8A827E7C76746E6A6761615B58504F4B47
43413E3B383934312D2E292826252322221E1E1C1C1B1B1617151415131212100F100F0B
0C0C0B0B0A0B0A0A090A09080807090709070A0506070504080507060505050704060605
050506
06060307060505060605040704080607060808080A07070B080A08090B0A0D0C0F0F0F10
111311111414171719191C1D1F21222429292C2F2E3435383B4145464A4E5158575D5E65
696A71747B7E86878D9296989DA3A7A9ACADB1B5B6B8B9BABEBEBFC0C1C1BFBDBCBBBEBB
BCBABDBABBBAB8B7B6B6B5B6B7B8B7B9BABCBCBBBEC1C3C6C8CACDCFCED4D3D5D5D4D3D2
D0D2D1CFCAC9C3C1BDB5B1ADA9A19D98978F8B8783817E7A726D6965635C5B55554D4A48
4143403B373634302F2D2C2726252424201E1E1B1B181717161313111212100D100C0F0E
0C0C0A0C0B09090907070609070908070806050609040507060604070705070506050606
050504
0405050405050507070307070405060907070606090A090B0A090A0C0A0C0B100D0F0E0F
0F111513151418171B1A1B1D1F2024252B292D2E3235363A3D40444A4D4D5256595F6266
687074797B80888A8F93999EA0A2A6ADAEADB3B3B6B7B9B9BCBDBBBDBEBDBBBBBAB8B9B8
B8B9B5B5B6B5B1B5AFB0B0B2B0B3B2B2B4B4B5B6B7B9BEC0C2C4C9CBCECFD1D2D2D3D4D1
CFD2CECBCCC9C4BFBDB8B2ACA7A29E9994928A87847E7978726D6A66615D5955534B4946
44413E3B3737332F2E2D2A282524241F20221C1C1B1C17161313141512100F100D0F0E0C
0E0B0C0A090A090908080707070607060707050606080605060606080505050507040505
050403
04030507070506050604080607070706060807090B08080A0A090B0D0E0C0C0D0D0E0E0E
1113141514181716191C1B1E20222325282B2C303234393C3F41494A4D5054595B616469
6E71757A85858C8E9396999EA4A7A7ACADAFB1B1B4B8B6B9BBBCBABCBDBAB9B7B6BAB4B4
B2B0AFB1AFAEADACAAAAAAA9ABADABAEAFAFB2B1B3B6B7BCBDC1C4C6CBCACDCFCFCFD0CE
CCCDCDCCCACAC3C0BFB8B3AEA9A4A09795918C87827E7C76766E6D66615E5B54524D4A45
43403E39383630302E2C282626212121211D1B1A191618151314111011110E1010140F0D
0C0F0B0D0A0B090A08090808060607070807070807060705050604050707060606050404
060405
06030608070504040609070504050806060607060608090A09090B0B0B0A0C0D0B0C100F
141011121517171A1A1B1B1D202424262A2C2E3234373A3D4144474A4D54555B5E63676C
6F76787E838A8C9195979DA1A2A5A9AAACAEB0B2B4B5B5B6B9BBB8B7B9B7B9B6B3B1B0B1
ACAEACABAAA8A5A7A7A7A5A5A3A8A7A8A9ABABAEB0B0B0B8B9BCC0C3C5C8CBCCCCCCCDCA
CACAC9C9CBC7C6C2BCBEB6B0A9A49F9893948D8784807976736E6B68615D5A54504D4C48
423F3E3C3634342F2D2C2A2B2824261E1F1E1B1B18171617171513141211100F0E0E0B0D
0C0B090B0C090B0B0A070907080706060507060807040505050604070505050706040606
030305
05030504050504070508060706060506080708080A080908090A0A0D0D0A0B0B0E0D100F
0F13131214151A181A1C1D1E23222626282E2F3134383C3F4046474C5354565B61646C71
747C8383878F8F93959A9EA0A4A5A7ABACADAEAFB0B2B3B4B5B6B6B7B4B4B1B1AFADACAA
A9ABA6A6A6A3A3A0A1A29FA09FA1A4A5A6A7A7A7AAABACAEB2B7B9BEC1C4C6C9CAC9CBCA
C9CAC6C8C6C3C2C1BFBAB9B1ABA7A29C94918C86837E7C77746D6B66615C5854514E4944
423F3D393635352E2E2B2828272322221E1C1B1B1B1718161512121111100F11100B100B
0E0C0A090A0A0D0908070705080A08080506060905050607050605050704050305030408
070304
0407060604060504050506080706060708090707090608070A090A0A0B0B0B0B0C11100F
11121214151619171D1C1E1E202324292B2B313335373A3F41454C4C5153576063686D73
767A808789909193999D9DA1A4A5A6A8A9AAABADAFB0B1B1B2B3B2B2B0B1ADADAAABA9A4
A5A3A2A2A09E9D9C9E9B9B9C9CA09D9D9F9FA0A2A6A5A7AAADB2B6B9BDBFC7C7C6C6C5C5
C4C5C8C8C5C2C4C1BFBDB7B1AEA7A69E96918B8984807C77736F6B67625D5754534C4A45
423E3D393636322F2D2D29282823231E1D1B1D1C181816171314141213110F100E0F0D0E
0B0B0C0B09090B0A0B080809090508060A06060606050606040408070806040403040504
040407
0604060505050507060505070806070708070706080808080A080A0B0B0C0A0E0E0D0F0D
11121513171517171A1E1C2121252626292D303236383D3E43464B5053565B61656B6F73
7D80858B8D8F9398999B9FA1A3A5A7A8A9A9AAADABAEAFAEADADB0AEACACA9AAA3A4A39F
9EA09B9C9B9A9A999798959597989799999E9D9D9EA0A4A8AAACB1B4BABCC0C1C2C4C5C4
C5C6C3C1C2BFC1C0BDBBB9B4AFA9A39F9A948D8884827C77746D6967615B5952524C4945
413D3C3A363434302D2A272826221F1E1E1C1B19191A1917141612101011100F0F0D0D0D
0E0F0B0A090A0B0809090A08060806060705060704060504040706060604060403040706
070606
050405030604060706080905070508060706070709080A0A09080A0B0C090C0E0C0C0F10
10131314151716181D1B1D20222324292D2D313637393F3F43474A4F53585B62676C7476
7F8487898B919396999C9D9FA4A2A3A6A6A7AAADABA8A7ACABA7A7A8A8A4A4A19FA09B99
999A96969494939392929193939393999795989A9A9B9DA1A4A6ADADB3B7BABCBDBFC1C2
C2C1BFC1C2C0BFBCBDBAB7B4AEAAA6A09B96918885817B76716D6A66615D5B55514B4948
43403F393735302E2E2928252524251F1D1C1A18191717141314131211110F0E0F0E0B0B
0E0C090A0A090C080A060707080708070506040606070304050407050706080408060507
040407
0504060604060707040406080606050906060707070607080B0B0A0B0C0A0D0E0E101011
0F121315161517191B1B1D1F232326292F2D3435373A3C3F44494B4F545961646B6F757A
7D8186898D8F93959A9C9C9EA0A0A5A6A4A5A8A5A5A9A4A5A7A5A4A1A19F9D9A9A999592
9294918F8E908F90908E8D8D909090939195929696969B9D9EA1A6AAACB2B4B9BABCBFBE
BFBFBEBFBDBEBCBDBCB9B6B2B1ACA8A19D98928C86817B76726D6867635D5B574E4E4947
413F3D39373432302B2D2926262421211C1C1B1C161815131512121110100F100D0E0E0B
0B0C090A090909080709070707070A070506060707070606050805050505060303070506
060505
040507030506040506040505050706050608070807060708090A09090E0D0A0D0D0F1010
0F141213171518191B1B1F1F212527282B3132353A3A3F4346484C51575960686A71737A
7E8287898F8F9597969B9BA09EA1A3A1A2A3A2A3A4A2A1A2A09F9F9C9B9898959391908F
8E8E8C8B8A8B8A8B8A8A8C8B8A898A8C8E8F8F92949396979A9D9FA3A8ABB1B3B4B9BDBC
BDBDBEBCBDBDBBBABAB8B7B2B1ACA9A29D97948D86827E76746D6967635C5954554D4A45
423F3D3836322F2F2B2A26262322241F1D1B1A191817171312121415110F110E0E0E0E0A
0A0B0C0A0A09080707080809060607090608070607040705050607030804050707060303
070505
030506060606050405050805050606070606080807080707080B0A0A0B0F0E0C0D0F0D0F
0F121314161518171B1D1E232226292A2E303035393A3C42464A4E53585C62686B73767C
808186878D8E91949596999A9C9DA09EA0A0A19F9F9F9C9C9C9A96959292918C8E8C898B
8887878787878685878684868887898B8A888A8F8F8F929596979A9EA6A7AAACB0B3B7B9
B9BABBBBBBB9B9B8B9B7B6B4B0AEAAA4A098928E88817D7B75706B66615E5857514D4945
44413C3A3635312E2A2B262623202020201C1A161815191515111113100F100E0E0D0D0A
0B0B0A090A0B08070A090707090707070606080806060407050506060605050503060404
040405
0606060606030405080707070509060607090709070908080A070A0B0C0D0C0A0F0D0F0F
111012151815191C1B1C1E21242429282B2F3234383B4245474A4F52596163676C72767A
7D818487898E909094969998999A9A999B9A9A9C999996969392928E8B8B888786848487
828481848382838482858281828384838489888A8E8D8D91939696979BA0A5A7ADAFB1B6
B6B9B8B8B6B8B7B7B4B6B3B3AFABA9A6A09C96908A847F7C73706A666160595650504844
44423E383733302F2B2B2B272221221E201B1A1919161514121212100F0E0D0E0C0C0B0C
0F090A09070A0A090707070B050807070707060506060506050504050506050605040406
050505
0406060706040505040608050608050807070808090B08080A080A0A0D0A0B0D0F0E0E10
101211141515161B1C1B20212428262A2F313136373C4143484D5156595F646A6E72777D
7E808386898B8C909192949698969798979894939292908E8D8B89898886858480817F7E
7D7D7F7E7E7D7E7E7E807D7E7D7F7E82808083838587888C8C8E9193989C9FA2A8ABADB2
B4B2B6B7B5B8B4B5B5B3B1AFB0ADABA4A19E97928B847F7B756E6B69625C5954524E4845
45423B383732332E2C28282625201F1F1D1A1918191714141413140F0E0F0D0E0D0C0C0A
0C09080909070A0B08070808070807070606060707090407040604040706040405040505
090504
04050405040605050506060405060707070A0709060B090A0A0A090A0B0D0A0F100D0F11
1213141313181819191E1F20212426282D2F3135393C40444B4D53555D61656B6F737679
7C7E81838789898F8D909192929194929191908F8E8D8C888686858180807E7C7B7A7C7A
7B7777777979797A7B7B7B7A7B7A7A7B7C7F817F81848388898B8E909195989EA0A4A8AB
AEB2B3B4B4B4B3B2B1AFB1B0AEABABA6A29C99938C89817B736F6D67625D5958544D4A45
423D3D3A3735322D2B2C272323231F1E1B1A191815141614141010110E0E0D0D0E0B0E0B
0B0A0A0A090B080707090808070806040607050606060405040406050604050405050205
030505
050503050307050506060506050709050906070606070909090A0A0C0B0D0B0D0F0D1012
111014151618171A1A1D1F1F242625292B2D3337393F3F464C4F52565C63676A70717477
7D7C7D83848586888A8C8C8D8E8F908C8B8D898A8787848381807E7E7D7D7C7977767775
73767673737675757675757476797676797D7A7C7D7F81828387898C919197969A9FA3A6
ABADADB1B2B1B1AFB0ADADABABAAA8A4A19E99978D88817E77736E69635E5957514D4847
45453C3836322F2E2B2B2526241F1E1E1A1B1B1618151613131110120E110D0E0E0B0B0D
090E0D08070807070707060807090808060A070506080505050806040405050404050405
050505
05040506040605030705060506070908060707070907060C080C0A0A0C0B100B0B110E10
10101215141619191A1B2020212326282B303139383E44444C5054585E62676C6D717576
76797C7D8182868587898C8B898A88878A84868482827E7D7C7B7C777475737373746F70
6E6F70706E6E70727070717172727271747275787B797C7E828386878A8D8E92969A9FA0
A3A7AAABAEADB3ADAEABADAFABA8A8A4A29D99958E87857E77756C6864605955514F4B45
423F3F3A363430312B2A272421221E1E1B1D1A1816141613131214100E100F0D0F100B0A
0C090E0A0908080A07060707070606050606070605050505050405070704040305030704
030605
04050407060406050506050605070406060608070907060A09090A0C0C0A0A0C0D0D0F10
0F1213131716191A191C1F22222725262C303035373C40464C5054596061676A6E717374
75797A7B7D7D8181848484848584848081807D7D7E7B7879767875727373726D6D6D6C6D
6B6B6B6A6B6C6A6D6C6E6E6B6C716E706F6F727473787B797D7E80838287898E9095979D
9FA3A4A6A9ACADABAAACACA8A8A7A5A2A09E98948E89877F7A736F6964615855524C4845
463F3C3936332F2C2B28262423211E1E1E1B18171616141212101210120F0E0D0D0B0B0F
090A0B090809080608060608060906060606060406050503060605060504040506030306
050305
05040507040504050507060806050607090706080609060B09090A08090E0A0C0E0C0F0F
0F12121513151617191C1C1F222526272A303134373D4243494D54575B6264676D6C6E6F
72737679777A7A7C7F7F7E7D7F7E7E7E7B7B787876747273706F70706C6D6C6C696C6868
68676667686667676669686A6B6B6B6D6E706D6F72707877777B7D7E80828489898E9398
989EA0A2A5A9A7ABAAAAA7A6A6A3A2A19D9C96928E89847E78746E6765605855554F4B49
423F3C3835332F2C2C2828262421201E1A18191815151514131210100F110D0D0D0D0B0C
0C0C0A0B0A0A060608080706080808060507060406040505050406050605050404070403
040305
05040406050603050405060606060504060506070609070709090B09090C0D0D0E0E0D0E
0F0F1012161718191B1A1E1F20242627292E3233363A4044474D53565A5F646567696B6F
6D707173727876767A7A7A7A79777575747271706F746C6C6A6B6A6A6B686B6665666464
6366656463636263646565656767656A6A69696C6E70737573777C797C81818387888E93
91989C9CA0A3A5A6A7A8A6A5A3A1A19D9A9895918F89867F7B75716964615956524F4948
453F3B383631322C2C27252720211E1E1C1B1717141315121111100E100E0E0F0E0B0B0D
0C0A070708090A0906080A06050506050608080505060505060405040405050503060603
030504
07050604050304060505070404040506060807070709090709080B0B0C0A0D0A0D0E1011
0F1112131516151B1A1E1D201F242529282D3034373C3F45474C4F55595C5E6267666869
6C6C6B6E6F6F7275707275757272716F6D6C6D6A696A6B68676967656565616362615F60
61605E5C5E5D5F625F6061626164626466696669686B706E70737575797B7F7E8186868A
8D9094979C9D9FA2A3A4A0A09F9C9C999996948F8D8A84807A766F6A655F5958534E4C46
433F3C3838342E2C2B27272522201F1C1E1919171415141412100F100F0D0C0C0E0F0B0B
0A090A0909070B0A07070605090609070605060605050507040606050505060604030505
040505
0307050605040405060505060906070705060706070A0908080C090A0C0B0A0B0B0D0F0F
0E11101416151718191B1D201F22242528292D3233393C4048474E515459595F605F6265
64656869686A6B6F6C6E6E6E6B6C6A69676766666664636461636162615F60605E5D5F5B
5B5B5B5B595A5A595B5B5C5D5F605F61636364656566696B6D6F71747576787C7B808085
888A929597999C9D9F9E9D9E9F9C999A9594958E8B8A86817D78736C685F5A56514B4846
423E3C3A3732302E2A2827272321201B1C1A1818161513151110110E0E0F0F0D0D0A090B
0D090808070A080808070607060506060806060404050605040405040304070505060506
040503
0404030504040606060606050606050604050707060A0808090A090B0A0B0C0F0C0E0C0F
11121213151616191A1B1C1E22202227282A2C3132383A3D41484B4F5153565A5B5B5D5D
606061626267656766666966686564656362616462616061615E5C5D5D5B5D595A595659
585557555558575657575A595B5F5E5F60606263626467656A6A6C727172767877798080
8384888E9194969799999B999A9A969492928F8C898884817B76706D675F595651504945
433D3B383532312B2A292524221F1C1D1C181A1A151313121214120D0D0E0B0E0D0C0C0A
0D0A0A0A0708090808070606050606050808060504040608040504040303040505050804
040205
0204030305040704060705040507050708060708070A080708090A080C0A0C0D0C0C0E0F
1110101416141616181A1C1F2022252628292B303132393B404347494F4F515355585758
5A595B5D5F605F626062626260605E5F5F5D5C5D5C5C5D5A5B5A59585958565756575557
535453535453525254535655565A595B5B5C5C5D606162626568686B6D6E72727876777A
808085878B8F91929696989596959492928F908A8A8585817979706B655F5C54514D4B44
413D3B3935332E2C2A28252321201B1B1E1A17181516131313110E0E0E100E0C0D0A0B0D
0909090A0809070506080A06050509050604040507030606050504060306070508060704
060603
04030506050405040306030804060504060706050909080609090A080C0A0A0E0F0D0C0C
100F131612141619171A1A1F1F2122252728292E3133373A3B3F44484A4E4C5150515156
565658575B5A5C5B5B5E5E5B5A5B595B5A5A5B5A5A57595956565455535252525051514F
4E515050504F5151525053555455565658595A5D5D5C5F61616364666A6E6D6F72747677
787B7E8185888C8D8E91909393919290928C8A8B8684817E7975706D65605A544F4B4745
423D3B3635342F2B2A272321211F1F1A1C19171715131010120F0F100C0D0F0C0C0C0C0A
080907090709080907070707080605080709050505050406040704040303050504050306
050406
07060405050503040604040704090404060606090808060509090A0909090B0A0C120D0D
0E0D1011131416161C1B1C1B1D1E202623252A2D2E2F3336383A43414546484B4C4D4E4F
505051535354565758565656575655555457545555545556525152514E534E524D4F4B4E
4E4D4E4D4E4B4E4D4D4E514F5351515456565559595B5A5B5F6261636869696D6E6E7173
7678797C81818488898C8C8E8F8F908D8C8B89878783817B77756F6A645F59564E4A4643
403E3A36322F302C2928242320211D1A1D181615171316131010100F0D0D0D0A0A0C0B0A
0B0B08070A080A0909060909060805050506050404060607040705060504060805060603
030204
0606050305050504060406050706060707090708080808070B060708090A0A0C0C0B0C0D
110F121111141416161A1B1B1C2021222625282A2B2D2F3336393B3F4044464748474C4A
4C4D4D5150525352515353515551535254515251504F514E4F504E4C4C4A4C4D4949484B
48494A4A494749484A4C4B4E4D4F50505054525654575A5A5C5B5C5E62626766686B6D6E
71737678797D7F83848589888B8D8C8C8889888785817E7C77746E68655D57534F4E4642
3F3B3A3632302F2B28252424221E1F1C1C171815141213150F0F0D0E0C0E0B0A0D0B0B09
0B090A090B070A0708090606060705060504040505050404050305060503050503030404
040402
05030306030505050607050707050505050506090807060A06080A0C0B0B090B0A0D0E0E
0E0F0F10111213141619171A1C1E1E202325292A2B2E2E3131353A3A3E40414342474647
484A4A4A4E4E4E4D4E514E4F4F4F4F4F4F504F4E4D4A4B4A494A4B474749474947484545
454446474646484A4847484A4A4A4C4D4E50505456525557595C5B5B5E615F626768696B
6C6E71737577797D7F8084878786868886858383817F7C7875717068635D59554D494A41
3E3D3B353230302C2A272422201D1C1D1B1917191514121410110F0F0C0C0D0E0B0B0A09
0A090B080908070706060806070505070608050704040405050604080403060404060307
050506
03030504030704040605050606070607050606070608090907080808070A0C0A0B0A0C0D
0E0E101111131216141518181C1D1C212321242629292E31353534373A3A3E3E403F4243
464647484B494A4A4A4A4B4A4A4B4B4A4B4A4B4A48484748474746474544434442474342
44434643474343444643444746464847484D4C4E52535352545559575A5B5E6062626569
676D6B6F73757576777A807E8283828283838280817B7776756F6E67645C575250494541
3D3C3834332E2E2B29272421211D1D1A1B19171715121111110F100D0F0C0A0C0A0B0A0A
090809080808060708050809040604060404030809050504050303030304030504040305
040603
030305030303030405050704050505040704080806080609050808090A090A0A090C0C0B
0E0D0E1311111212151616181A1F1D1F2023232527272C2C2D3233343639393A3F3D3F42
42414544464647494646494847474647484848454746454343434341423F3F403F413F40
423E4244454144434142424344474645464B4A4D4B4D4F515152555656585B5D5D616163
6568686A6B707372737678787E7C807F80817D7D7C787872706C68655E5A56504F4A453F
3B3A393531302D2B282525211F1D1C1C181A1616131212110F0F0F0D0B0E0D0B0B0A080B
080B09060A06060707090707050504070505040406040405050405040604040703040603
060706
040404050605030504030606080405040909080508060A07080808090A0A0A0A0A0C0D0D
0D0E0F0F10121212141517191A1C1A1C1E2022252828292A2E2C2F3434353739383A3E3F
3D3E4242404042454143444443444443444041434343404240403F3E3F3F3C3D3E3D3D3E
3C3E3E3C3E3F3F3F40413E40433F42424344464A4B4A4C4C505052515354565A5C5B5D60
64626565686C6A6D6F717474757777797B797A77787672716F6A67615E5A55514C484540
3C3A3733322E2A2828262320211D1E19191915151211120F100F0F0F0B0F0C0C0A090809
090B070708060807070A0506070605060605060604040505030404040404060506040504
030504
05040405060302030408060407050506050704070707060705060A0908070C0B0C090B0B
0F0D1110111214151214171716181C1E201E2221222528272A2D2E2F3034343536393C3C
3A3C3C403E3F3F403F3F42413E413F3F404140413E3D3F3C3C3C3C3B3D393A3B3B3B3A3C
3B3C3D3B3D3A3A3D3D403D3E3E3F3F3F414243454849484C4B4F4E4F51545358555A595C
5E5F61626363656B696A6B6E6E7274757575747573716D6B6B6A64605D5A53504948423F
3A393633302C2A2C252421241E1D1C1A1B18161315101111110F0F0B0C0C0C09090C0908
0A0809080907060609060707050807060705040605050705060304030205030503030403
020304
040305030504040403050303060505070406050608060609070707090A0A08090C090E0C
0F0D0E0F121310101714141517181A1B1D1F2020242526282A292B2D302F33323636383B
3838393B3C3C3B3B3A3B3D3D3B3E3C3C3B3C3C3A3A3C3C393C393A3A373A3838373A3839
3A3B3B38393939383A3B3B3D3B3F3E3C3D3E404242444946484A4F4D4F5151535354555A
595B5C606261646366656A686B6E706E71716F706E6C6A6A666763615A5754504A46433F
3D3837312E2F2B29262422241E1C1D1717151414161211100E100D0C0F110C0B090A0809
090A070706080A0606050706050405050504050603050504040604070403040507020504
050504
02040406030406040603070707060705040707070704090608080707090D090B0A0D0B0D
0D0C0E0E0F0F141214131315151A191A1C1F1D202024242627292B2A2E2D303130353533
3934353837373738383839393A3939383937393838363937373537373538373535373537
35353736373639363B3B3C39393B3A3C3E3E3E3F41404244454949484C4E4E5251535454
565A595B5C5C615E62636465666966696A696A6A6A6868646462635D5B55554E48444040
3B3733312E2B28252521211D1C1C1A19171615121210100F0F0E0B0D0B0B0E0B0B090909
0908090B0605060907040707050507050304070504060504060405040503040402030504
050505
04050507040406050405050503060504060605060508060709060808080909080809090B
0A0C0E0D0E10101211141313151818191C1A1C1E211F2022262727272A292E2D2E2E3130
303235343334363335353737363535363435353535333634353536343434323433333335
353532333534353634363A37373936393A393D3E3D4040404346454849494B4B4D505052
5153565A58575B5A5A5D5D63616264636564646763646462635F5D5B5753514C4745403B
3C35362F2D2A2A2523211F211C1F1E19191814131310110F0F0E0D0F0B0A0C0B0808090A
090608060806060805050706060604060504040205040503050402020203050305020304
030402
0505020505030503050404080504040405060505070607050A09080707090B080A090B0A
0A0E0D0C0F0E0F1214141415131416181A1A1A1C1D1E21212224242528272B2A2C2C2C2E
2F2E33323232333232323232323132323336323431333132333331333131313133333131
32333030303433323432343538353437383A39383B393C404240414447464749484A4E4E
4D5254555454575959585A5E5D5F5D5E6060615E6160615F5F5E5E5955534F4C47423E3C
3535302F2C2C27262421201C1E1B19181714161415111010110F0D0B0D0D090B090A0909
080906060807060707040607060504060904040206060404040304040504030503040507
040305
030405040405060606030504050403080704060508060606070607090708090B09090C0B
0C0A0E0D0F110F101211151213141616161A1B1B1D1E21211F2222232527292929292D2C
2F2F2D2E302D2F2E2F3030302E2E302F31303030302F30332F2F2E30302F302F2F312E2E
2F30312E302F2F312F3332333333333736373636373B393F3E3D3F4341454645494A484B
4B4D4F50515252535557565759595B595B5C5A5B5C5A5A5C5A5A595555534C4B44403B3A
36332F2D292A29222222201D1E1A181615141312120E0E0F0D0D0F0C0E0B0D0A0A09080B
08070809070A070607090604060605060604050503050404040405050203030303040503
050503
030204040507060204040404050509030504060505050805070607080A0809090A0B090A
0A0B0B0C0F0D0F10111212131414141319171A1A1B1C1E1D1E1F222123262425282B282A
2B2B2C2B2D2C2F2C2D2F2C2F2D2F2E2F2B2B2D2E2D2C2C2C2D2E2D2D2E2C2D2D2C2D2C2D
2F2D2D2D2F2D2C302E2E31313332313132333535373837373C3B3E3F444243444445484A
494A4B4D4D4D514F515253555553555456555857555A565857565555514D4C4744403B39
34322C2D2828252324201C1D1A18181914161411100F0F0E0E0D0C0C0C0C08090A080B09
080708080606070605040605050705060703050504060402020502030504030605040504
030503
0503050503050603030603030504060606050404050506080606080607070A0707090B0C
0A0B0A0B0D0F0F0D0F101110101315171714191A1B1B1B1F1E1E1E222322222525272727
2728272A292A292C2B2D2A2C2A2C29292A2A2C2A2C2B2A2B2B2C29292D2A2C292A2A2B2A
292B2B2A2C2B2C2E2E2F2D2D2F2E302F313233353233333636393A3B3D3E414042434344
434649484A4B4B4C4E4E4E51505151515351535452555354535353504F494843403D3936
312E2F2A292924231F1D1E1D1B181B16171413131110120D100D0B0D0B0A0C090A090808
090A07060407080607040704060606050404060406070406020203050203040403030403
040405
06030306050304040504040306040705040405030807090509060807070C080B0909080C
0B0A0A0B0C0B0D0D0F0F10101211151514141719191A1B1D1E1D1E1F2020222126242223
252625252628282728272729292A2A2A28292729282728292A282B292929282727282729
2829282A2D2A282C2B2B292B2E2D2D302E30313130313332363736393C3E3B3E3E3F4441
434546454645484A4A4C4C4D4D4C4D4C4D4D4D4E4D514F4F514E4E4F4B4744413D393834
302D2C2A29252221211E1D1C1B17161814151312111010100D0C0C0A0B0C0A0C0A090906
0A0807060807080605050906070405060504030506050405050306040203020605030203
050304
0403050305040305020503070505050706060507060305060507070A0706070708090808
0B0C0A0B0F0E0F0D0E110F0F101010121313161519181A1C1A1D1C1E1D201F1F22242321
23242526242628272524262A252624262926272525272925282725252625252525242825
2B272828252726292A2A282B292A2A2D2D2C302E2F2E333032333336373B3D3C3C3D4042
4044434245464748474A4B4A494A4C4A484A4C4B4A4B4A4C4B4B49494644413E3C383432
2E2B2B282625232221221C1C1A18151514151213100E0D0C0F0C0C0C0A0B0B0B09090709
080609060705060604030505040706070504030304050304040403060203050302030405
060404
0603030405050303040406030404050404040406050506040605070708060707080A0807
0A0A0C0C0C0B0D0E0D0D0D110E0F121112151514151A1717191A1B1B1D1B1F1F1F222021
212320222421232324222323232522222525242524252626232725242426232724262525
242426252526252425282727272B2B2C2D2E2D2E2D2D302F2F3430343536383A3A3D3B3D
3D3C3F414040444446474346484A4A484647464948474646474646454240403D3735342E
2D2B2A27252222211E1D1B191A1A1715141214120E110D0D0D0B0B0B090D0A0B09080A08
08070509050A05050504040B060308050503040502050503030304030203040106030301
030303
040402050504030305040204040305030504060605040605070607060B08060708080809
0B090A0B0B0E0D0E0F0F0D0F0E10111110141313161516171A1817181B1A1C1C1E1D1E1F
1F2020202122202023222323232123232222232323212224212323232323222223212323
24242427242423252725272729252728292A2C2D2D2B2C2C302F31303236353738393B3E
3C3C3D3F3D3D3F43404342444343454442444244434642454042443E403C3A3635322E2C
29282726212320211D1C1C1F17151716131311120E0E0E0E0B0B0A0C080A0A0B090A090A
060809090708050506060705050505050503030606030307050403020304060604050203
030303
04040303040502030502040605060307050404060504080507060705050707090708060D
090A0C090C0B0C0B0D0C0F100F110F1311111312141316141818181B1B191C1C1C1B1F1E
1E1C1F1F1D201E20212020211F1F1E211F22201F222220201F212121222220221F1E2120
242322222320222326232223272626282627282B28292C2C2B2C2D2D2F30343434383938
39393A3C3B3B3A403C3C3E3F3F434040424140413F413E3E403F3B3C3B39353431302E2B
2928262723231F1D1B191D1916151713131313110E0E0D0D0E0D0B0B0A0B080808090707
060706050606050504040403040505050606040404030302040606060304040406030304
040404
0105060304030502040505030505040503050704050A040506050504080807090606090A
09090A090A0B0B0A100D0C0F0E0F0E1111131214131416141816171918191C1A1A1C1C1D
1E1B1C1F1C1C201C1E1F1D20201E1F1D1E20201E201D1D1F21211F1F201F1F1F21201F20
1F1F212022211F2024222123212424232526252829292A2B2A2B2E2B2E2F313432333635
373838383839393C3C3C3C3B3C3E3E413F3E3E403B3C3D3B3B3B393837353331312E2C28
2825242223201E1C1C1D1918181413131211120E0F0F0C0E0E0C0C0B0809080808070808
070506060406050506050504060705060505040404040505050404040401020302030405
040402
02040405040403010505050403060504060504050305070503060406070508070808070B
0909090A0A0C090A0C0C0C0F0E0C0E0F141310101213121316171616161518171A191919
191A191C1B1B1E1C1A1A1E1D1C1C1B1C201B1D1F1C1E1C1E1F1B1F1F1D1E201D1D1D1D1F
1C1E1D1F1E1F20212222212020232322252427282629292728292B2B2A2C2C2F2F313234
3336373637373937363838383B3C3B3C3B3B3B39393D3638363635343535302C2E2B2929
24252420201D1D1E1918171617161714101410110E0E0D0B0B0C0B090B0A090808080A09
070609090605050404070407070405060405040505030305030203050404080504050505
040403
020302080304040404030403050406030707070403050403040405040607070605060A07
0709070B090B090B0A0B0D0D0C0D0F0F0F110F101113121113121414141515171816171A
19191919181C1A191B1A1F191B1B1C1E1B1E1C1C1C1E1B1C1D1B1D1B1D1C1C1A1B201D1A
1E1E1E1C1D1F1D1E2020211F1E211F24222224262525242828282829292C2A2B2D2D2F2F
3133333337343735363738373836383938383737363637353635333232302E2B2A2A2927
2423211E211D1A1A1A1B1617171314110F100E0E0F0E0C0C0B0A0C0A090B0A0A080A0806
070708070605070607050604050406060404030206030506030405020503010401050303
030404
030503030301020403050406030503060505030504040503080605060606050806090809
0B07090B0909090A0D0D0C0C100C0E0F0E1010130F0F0F10111613131615141618171716
19171A18181818191819191A191A1B1A1A1C1A1A1A191C1A1B1B1E1B1D1D1C1A1B1B1B1C
1B1D1C1B1B1A1C1E1E211D1E1D1F1F212021232324222427252527272627292B2B2B2C2D
2F31333235333234333335353833343437373635343433323034312E2D2D2B2B2A272626
242221201C1C1D181919161514151311110F0D0F0E0E0C0D0C0A0B090A09090B06080707
060707090906060405080404050605040604020305040401030502020302040502030203
040304
020402040406040404040505040204030608040204050605050606050707050605060708
07070A0909090A0A090C0C0E0D0B0B0F0C0D110F0E111112121213121113131516151516
15161619151717171B171A18181917181818171A181B1A1A1819191C18181B1A181B1C1C
1B181B1B1B1B1C1E1B1D1F1B1C1D1F1D1D1E2221242224242324242427272727282E2B2A
2D2F31333032303131313132313131333332333231312F30302F2C2C2B28272625262522
2320201E1C1A181716171814131113101214100D0F0C0A0D090C0A090A0A0807080A0707
060806060508060505050605040604040503050303030404060305020403020403040303
020502
060305030503040603030302030402060403040403040404050605070506080805060709
0908080B0809080A090A0C0B0D0D0B0D0D0C0E0F0E121011111010121214101212131316
14161A151716171716171519191719161818191A1816181617171819181A1A171A181A18
1B1D171C191A19191B1B1B1E1C1B1B1C1D1E1E1E20202125222223222325242426262928
2C2E2C2F2E2F2F302F303230312F3031313130312F302D2E2C2D2C2B2A27262425242221
211E1F1C191A181818171312120F111010100C0C0B0B0C0F0A0B0B0A0908080908080608
050607060606050405050303030604050504060603030403030406050401030303030303
020407
040302020405020303040303050503020204060505040406030404060505040609070808
07080709080709070A0B0A0A0B0C0B0C0B0C0C0D0D0F0E0F11130F111112121215101213
141313151413191515151613161516161A16181815171717171617181616171719191917
1718181A181B191819191C1B1C1A1B1D1C1B1F1E201E1E1F212222212225232328262528
27292B2B2C2C2F2D2F2B2F302D2D2C2E2C2E2C2D2C2B2D2A2C2B27282726242323222020
1D1D1C1C191A16151415131011131010110E0C0C0C0D0C0C090A090B0709070905090808
080906050806050405070705040404040305030503060406030707040303030306030301
040505
030302030403020505060205030405040504040205060504040405060504050706050509
0707070809070B0907090A0A0D0D0A0C0C0E0E0E0F0F0F100F0E100F110F111212131012
131515141312121213131413171316161417151815141416171515161614151615181516
16181617191A1B18181A1A181A1B1A1B1E1C1B1E1E1F1D1F201E221F2221242323232326
282729272C2B2B2B2A2E2B2C2B2D2B2B2B2C2C292A2A2A29282728262524232221202120
1B1C1A191918171514131213140F0F0D0F0F100D0B0B0A0B090B0B09090A070707080607
060707050703070606050503040306050503050404030402080404050204050103050205
050503
020504040303030203040403040306040409020405030303050405050706050506060709
08090807070A0907090A0A0D090B090B0B0D0D0B0E0D0C0D120E0E10101010110F130F12
101214111413111116131614171514161313121213141213171613171413171614161814
14171515181716161917171A1A19181D1B1A1A1A1C1E1C1C1E1D23212020222222252225
2525252829292A2A2A2C2A2B2B2B2A2A28282A26292828262925252421222221201F2020
191B191718161613131415101011100F0D0D0C0B0C0D0A090A080B0A0909080807080707
060507080806060605070405060604050303060304030404030203040303050501030302
010301
030503020202020404040602050304030603030505030505040404050504040707050607
090608070A09080A07090A080B0A0A0B0B0A0B0E0D0D100D0F0E0D0F11101012100F0E11
1212110F1113111112111214131310121414121212131213121414131517141312161614
141417141516161416191718171716181A191B191B1A1D1D1D1B201E201F1E2020212123
242324252925282727292B2929282A292925272626262425262323252320211F1E1D1E19
1C1C1A161817131412121010100E0F0E0E0F0E0D0A0A090B09090809080806090B060907
060405060704040606050403050402040305060403040205050404030603030302040103
030306
010703010303040604040203030404060504050604030407040402070606050805080507
08050708050809090908080A0908090C0B0B090D0C0C0D0C0D0C0C0E0E0F0E0F120E0E11
100F11131211110F10101313121213111417121214131113121212141314131412131416
141516141516151316141615161816181917191D1A1A18191A1C1B1D1D1F1E1E201F1D1E
212223222425242528252526282728272426242424232323252222231F201E1E1D1C1A19
1A16171616141312111111110F100D100E0B0D0B0B0B0A0809090C080607090708080506
060408050606040404040503050505040504050205040404030404010405040403030704
040403
0201020307020305030503020302040404050304050204030503040505060706050A0506
0808070607050808090B0709080C0D0C0A09090A0A0A0C0C0B0C0B0D0E0D0E0E0D0E0E0D
0D0E0F0F100E0F0E100F11111312100F1011131114111210141410131213131311131212
121414121212121513161516141816151716191818191919191B1B1A1B1C1D1D1C1F201F
2020202120222326242323262425242427242421242023211F20201E201E1F1B1B1B1B19
17161614131414141111110F0E0E0D0D0C0D0B090D080A0A0A090A080909060706050605
050604090603060706070404020403050303020201020406050304060103060102030404
020203
050404020404030305050205050504050404030302040305030504050403060305040605
07060406090808070A0708080909080C090A090C0C0A0C0C0A120D0C0B0C0F0B0D0C0D0E
0E0F0D0F0D0E10100F1112130F1110110E1010111111101010120F111011111314121113
131311111412141312151414151315171616151517181817191A1A1E1E1B1D1C1F1D1C1B
1C1F1F1E201F21202123242523242224222021212020231F1E201E1D1D1C1C1A191C1B17
1515161415121210110E10100E0D0D0D0D0E0B0A0A0C0A0B08090A070806070604050705
060705070606060504070306030403040403020404020302060301020203020304030703
030103
050504030302040203030302030205060504040603060404040205060705030605050606
050507060609060709050807080C07090A080C0B090B0A0A090B0B0C0C0B0B0B0E0C0D0E
0D0D0E0D0F0D0E0F0F0F0E0E0F0E100F1010100F110F0E101013100F12120F1110101211
0F101013111112121315131212161713141417161718151619181A1819191A1C1D1B1C1D
1D1D1E1E1E1E201D2121232323232421202020201F20201F1E1D1C1B1A1D1A1819181616
16161412131213110F100E100E0D0A0D0C0B0C0A090B09070807090B0908080607050706
040806060506080404060503020405030305050504030203030403030406030303020401
020307
040204010504020403030303060304010402030304050503050403030605070405050507
0507090707080707050609070709090808070A07080A09090B0C0A0A0E0A0C0C0E0E0E0C
0D0C0C0B0D0C0D0C0D0E0C100E0F0F0F0F0F11101010120F1310110F100F0F0F10121010
120F111310121310120F13141313111316131514151515141616171617191A1B1B1A1C19
1F1E1D1C1B1E1C1C1F1F221E221F20232020201D20211E1A1F191D1B1C191A1817141715
1516131213111210110E0C0D0F0C0B0D090A0A090A08090B070706080708060506060506
060804080506050506050305050403030305050206030303030303030604040402050301
020202
040103030401050603040303020404040304040303030305040307030602030404050607
050604040805060807050806090A0909060A0A090909080B090B080B0A0C0C0C0D0C0E0D
0F0D0B0E0F0E0C0D0D0D0C0E0C0E0C0F0F0F0E100F0D0E0D100E0E0E100F120D0F0F1110
10111111121411120F1210121112151212141113161413161516151417181917191B1A1A
191A1B191E1C1C1E1B1C1E1D1F1F1E1E1C1E1D201C1C1C1A19181B181718161619151513
1311121411110F1211130E0D0E0E0D0B0C0B0B090B080706080608050607060506060606
050506040503020306060602030603070204060505060303030304020402030201030401
040302
010302030204020104030403030303050303050203040305030203040304030404030506
0606040805060608080709060708080A070809090B080807080A09080C0A0C0A090C0E0A
0C0A0B0B0C0D0C0C0C0D0C0C0C0E0D0D0C0D0D0C0D0E0D100E0E0D100E0F0F0E0D0E0E0D
110F1110100F101010100F111310151312121313131213141515141618161816171A1919
191A1A1A1B191A1A1B1B1F1D1D1D1E1B1E1F1E1E1A1E19191A1818191919151616161315
11111212101010110E0E0E0D0C0B0B0C0B0A09080B090708090607070607080605050404
060606040305050303050405030406030505020405040604020402020202030105030102
040501
040401060205020103040305020402030204040306010503020305040704040405050604
050706080505090606060506060A070607080A09090707090908090A080B0A0B0C0B0A0B
0C0B0E0B0B0E100C0C0E0D0B0B0E0C0D0F0F0F0E0B0D0D0C0D0E0E0E0C0F0E0D0E0F0F0D
0E0D0E0E0E0E0F100F1011100E130F12141012131212141312121413161414161616161A
18181717191819191C181B1D1C1D1B1D1E1D1B1A1B191A18161918151616141515141213
14120F120E0D110F0E0E0B0C0C0D0B0A0809090A08090707080B06060608050607040904
050404050406060606030505040304040102030202010301050401020406020204040204
020404
010203020002020407020304040303040305040304040104040304030403030405070505
06050707060605060909050507080808090808070708070A0908080A070A0809080B0B09
0B090A0A0C0B0B0E0A0D0B0B0D0C0B0C0C0E0B0B0D0B0C0E0F0B0B0D0D0D0D0D0C0E0C0D
0E0C0F0C100E0F0D0E0E0F0E0F0F0F111311131013141313121416141414131515151716
15161618161817191819191B1B1C1B1A1A1A1A1A1B1B1916181715151617171413111113
1210110F0E0C0D110D0B0D0D0C0B0A0A0C09090A08080606090A06070608070608070405
050405030406030306040203030405040404070205040503030302020204020202010101
020302
03020402020305020401030703040404020304040204030404030403030404080405030A
040605040804060508070608060707070A0906070807050808080908080907070A0B0A09
090A0C0A090A0B090C090C0B0B0B0A0A0E0E0A0B0C0A0C0F0C0D0C0C0B0C0D0C0C0C0F0E
0B0E0F0E0D0F0F0E0E0F0E0F0E0D120E0E11101211111110121312131314151316131416
1615151616161517181918181718181B1A19191A19171515181415151414131413121210
10100F0F0C0D0C0E0C0E0A0D0B0C0A09080806080808070A080A07060707060605080506
060403050607020304040503040401040804030204040402040304050603040403010103
030301
050305030401020402020406030202020405010202020406020304030303040406070505
0405050406070505060703050606060506060A07060706070909080A07090709090B0708
08090A090D080B0A0B0B0B0A0D090D0B0C0B0D0A0A0B0C0D110A0A0D0A0A0C0B0C0C0D0E
0C0C0E0D0D0B110D0E0E0D0D0E0E0D0F0F0F110F0F0F0F11121211111113121714121314
14151718171414161614181A181618191818171818161914141412121312151313100F11
0E0D0F100E0D0D0B0A0C0B080B0D0A0B0809080707070707040608070507050605050605
050403050405040403030305020503020502010404040202020302030404040102030302
020302
060203020203030401020103030402040303040303020202030504080603080306060605
0403050607060305060608050507060607070605070707070608090808080907090A0A0A
0807090A0A0A0D0A090B0A08090A0C0B0B0C090A0A0E0B0B0D0E0D0D0A0C0E0B0D0C0B0C
0E0B0C0E0B0C0D0D100D0D0C0C0D0D0E10100E120D0F13100F0F10131013131111121312
121213161313161714161715171716161718171816151415141314131211141210100E0F
0E100E0C0D0A0E0B0A0B0B0A0A090B0B07060A0709070808070706060806060407030605
040606050305060403030206040404030505020305040304030503010202030302040303
020204
020302030403030202020403020403050304040306030303050406060602030505050503
05030304040405070408040505050506060508070706060709070607080508080807080A
080A0708070908090A090C090B0C0C0C0D0C0A0B0A0C090C0E090A0B0E0B0D0D0B0A090C
0C0B0B0D0D0C0D0C0D0D0D0D0D0D0D110E0F0E0D0D0F0F0E0F0F0F10100E11100F121113
1211141412131314171415131514151614151616141514151313131011101110100F100D
0F0D0D0C0D0B0C0C0B0A0F0B080B080908090806060508040607060706060A0804040904
030306040404030303040303020504040303040403020403020105010302030302040202
020503
030303050203020203020202030304030402070103050103040204040404030306040702
04030305050704050403040406070607090506060507060608070608060806070A08060B
080909080909080A090B0B090B090A0B0A0B0A0B0B080A0B0A0A090B0D0B0D0B0B0C090A
0C0B0B0B0E0D0D0D0B0D0B100D0D100D0E0E0C100D100C100F0E100F1110121211111212
1310131211131312141314131512121813151313131612121212110E100F1010100F110D
0F0D0E0B0D0D0C0F0A0C090A0B070A090809060507060508070605060707060605070403
050604040302030304060203050304040103020503030404050402030303020202030603
010201
010104010103020202030304040104040405020405040403050305040406040303030204
040303050704030703050505040805070604070604080705060807070707070807090707
070A0908090A07090907080909090C070B070A0A0909090909090A0C0A0A0A090B09090B
0A0C0A0B0B0D0B0A0A0C0B0D0F0C0C0E0D0C0B0E0E0F0F0C0D0D100F100E0E0F10111310
11101011101511131110111314141211111312151215121212120E0E1011100E0D0F0D0E
0C0E0D0C0A0B0A0B0B090B0C070909090808050706080708040804060706060804040208
030703030503030403040304030403030306030202030302020302020302020302030305
050602
030200040207030201030407050103040204060203040605040305020303040403050505
04050206030703050504040609060407060507040607040605050907060508080709080A
08070807090909070807090908070A080B0C0C09090709090B0C0B09080907090B090A0A
0B090B0A0B0A0B0E0B090A0B0C0A0B0B0C0F0C0E0D0E0C0D0C0E0E0F0E0E0D100D0F0D0F
100F100F0F1010111111100F1012111012101111121210140F0F10100E100E0E0F0D0C0D
0D0C0D0B0D0B0A0C090B090B0C0809070908060709060405050605070504060604040406
030504050303030203050202020205030401020204040502030502030204010205060002
040301
010003040302050502030003030302020203020205040303050404030204040405040506
030304040605040307070807030405050806060405040805040806070506050606060507
060608090707070906080709070809070B0809090A080A0809080C09090B0B0B080A0A09
09080B08090B090A0B0B0B0C090B0B0B0C0C0C0C0C0A100C0D0A0C0D0D0D100C0F100F0E
100F0D11120E1010100E1013120E101110111011121111100E0E100F0D0D0D0D0E0B0B0C
0E0A0C0C0A0A0A08090A0909080809080606060606060607060405030406040705060404
040405050306030304040603030303030205020303070401020306020103030602010302
000302
040403010202030202020502040202030505020103060404030102040204040306030406
020303030303030305030405040404060705060603050507090909060808080606070708
060707090609080707090709070908080807080C07090B07070709080A08080B0A090B08
0A090A0C0909080C080C090B0E0C0B0B0A0C0B0C0C0C0C0C0F0B0B0D0E0E0B0E0E0F1010
0F110E0F100E12110E100F0F0E100F110F110E0E100E0E0E100D100F0C100F0F0B0B0C0C
0D0B0A0B0A0A08090A090A0709070B070806050606050607060504040407020505040304
050203030304020504030301040503050201030204030203050301020404010202020302
030201
020102030202040203030201020302010102010304050303030402050203030403060203
060305030505050603070304060406050606050405070506060607050607090606070906
07070608080808080809070A06070808080909060707090A08090907090A0C09080B0A09
0709070E0A0A090C090A0A080C0D0D0C0A0A0E0A0A0B0B0C0A0D0B0C0D0B0F0D0C0D0D0E
0D0E0D0F0C0E0E0F100E0E0D100E100E0D0E100F100F0E0C0E0C0C0C0C0D0D0C0C0C0B0B
0C090B090A0C0B090A070807070607060906070606070407060505060705040403040607
050304050406050303020403040403040402020203040202050303030103040104030104
020303
010303030304030102040103040303030304020304030206030104030502070304020504
040403030305030404030505050802030706030605050408060409070605070606060508
0706050807070505060A09060709090608080B0908070A0606090A070807090708070B07
0B08070A080B08080A0A080D0A0C090B090B0A0B0C0B0C0B0D0A0B0C0D0B0C0C0B0D0C0D
0D0E0B0F0D0C0D0D0E0E0F0F0E0E0D0D0F0C0E0E0E0D0C0F0C0E0B0B0D0C0C0D0A090909
0A0B0C0B0A09080807070708090705060509060604080405050504060605060406040405
050604040406030503010103060404040202070202030203030304010403030102030304
020403
010203030304010201020303010303040402020205040204040303010603030405020503
040403040604020207060604030504040406090505060305060307070605070707060406
06050705060607070907070706070807070609080808080707070607090708090A090908
0907070708080808090A09080908090A0A0708080B0A0A0B0D090A0B0C0D0D0A0B0B0C0F
0D0B100B0C0B100C0D0E0E0E0E0E0E0D0F0E0E0C0E0D0C0C0B0C0B0B0E0B0B0D0B0B0B09
0C07080C0807080907080607070608060607060507040703060406040506040404030302
030603040402050305050103010402020204010305030403040303050103030301030301
010401
050307010104020203000304030401020703030404030404040504040402030302020304
040204030403080405050406020505030405050604050604050505060708050508050406
090606060608080707060B0609050708060507070609060A07070A080808060707070609
07070807070707090A08070A090A07080B090D0C0B090C0A0A090B090B080A0B0C0D0A0D
0B0E0B0D0B0C0B0E0D0C0C0D0F0C0E0C0C0C0C0E0C0C0B090C0C0B0A0B0E0A0A0B0A0C0A
0B080808090A08080A060607070708050507070806040704050705060203040402050302
040202050303030506030304020404040203030202030202030301030204030302020105
040302
010201040301020202030402040101030104030202040105010205010302030305040302
020404040604040305050504050405040404030705060506040404080505050606060605
08050A070604080805060505080605060708080708080907090709080608060905070A08
070C0A080908080A0A090808080B080A0B09090B0B0809090B090A0C080C0909090A0C0C
0D0B0B0A0F0B0B0B0A0E0D0D0C0D0C0E0B0D0B0D0B0C0B090B0E09090A0C0D0C090B0807
0C080A070907080707090606050804060704040505040604050602030604040503040304
030403030403030603030304040302030102050303030301020402040301010402030201
020101
020200010402020203020302040403010103030304020302020403020202010403050303
040206020404030405030503040402070304070405040507060405060406050405050608
0706070806060706040505070508070809050608070906090806080B0507090706080808
0A0807090507060B0808090709080707090A080A0909090B0A0A08090B090809090C0A09
0B0B0A0A0C0C0A0B0A0B0D0C0C0D0C0C0D0B0C0B0B0B0A0A090C08080A080B0A08090B06
090907080906080707080605050705040606050505040504060504060704050505040404
040504030502020203050404020203040301030104020103010303010202020501020202
030101
020101020202030203010104030403030303020602060205050402030302030206020303
030304040404030403040305040502040604040306040306050304040605070505070606
070806050405050505040506070808050806090707070606070707090706060807070507
080706070909070807070908090808080808070907060808090A070B0A0B0B09080B0808
09090A0B0C0C0B0C0C0C0A0B0B0A0A0B0E0A0B0A0C0B0A090B0A0B0A0B0A090A070A0B08
080908080807060708080705040507060406050604060504050606050604050303040202
020403030105040405020203020203040304030301010303060302010403020106020103
020103
040102060204020203040301030004030300030204020203000205040402040207030103
030302040403040305010304050503050304050403060503060505050403060405030506
050504070508060505040705050606070606060604060908070508050606060806060707
0808070807060806080809070A070B0708070808080A0B0809080A0908080B090A0A0808
0A09090C09080A0A0B090B090C0C0C0C0B0C080A08090C0909080A09080808080907080A
080708060907070707050606060707060506060508050405050405040502030506010404
030204050603010206050404030305020403030204030103030202030204020202040204
000202
030104040202020403040102040202020303020303030101010302020402050306020401
010104040303030106040305060106040305070604040306030405030504040306050305
0605040705060407040504040808060805070508070606070A0705080708040907070908
070706080608090A07070807080A07080A060708080808090C0A070A0907080A08090A09
0A09090D0B0A0C0909090A0A0909090B0A09090B090A0A09090808080909080608080907
060607070709060706050805060906090305040805060505040506070705040304040405
050307040402040502020202030302020406030101030101010601020204020201020101
020404
040204020302020102010201020402040404010303030103050502030203050204020307
030306020303060404020405050304030505040302040803050302020305030504040406
050406050705050407080508040705080405050607090807050705060606080607060706
060706060606060A0807070607070608060607080809080707070709090A0C0907090909
0A08090A0907090908090B080B090A0908090A0A0C0A0C080809080809080A0708060606
090807080706070807060706060705040604050707030406020407030305030204030303
020306030301030203050103020301030104040203030203020102020101010402010602
010204
040103010202010304010101020104010202030102020102030103020503020300020202
030302010505030503040304020305040305040803040405050203050503050604050404
040405060405080603040508050405050603060605050505050407070A0607090906050B
0705080705060506080808080708050607060607080906070B0907080B080708080A0809
09070808070B08070908080A09080A08090A0A0B080B08080809060708090A0606080807
070609050506050507060606050606050607060505040304030203030204020203060303
010203040202040203050304020503030202020301020102000103020300050202000202
040104
040204020202020200020103020301030102010203030402030101050203030302050305
040203020403030503060404040604040303050606040302020406060305040706050605
0406040207040503030804030706050406070A0507040406060507070608050706090506
070607060806070505060707070808080B08070607090608080808060907090A090B0708
070708090708070909080A070B090807070909070809080907080A0B06070907070A0906
060507050606080308070605060505040503050603030505050503040403020403030402
050102050201030602050402020103030403030101020406020203000002010004020204
020103
000302010302010204020403030102020302020104030103040403020502030102010402
020402050403040504050503060603060704040505040203040506040603030503040404
030402050406040604040405060505070704040406070706060608050507060604070505
06060506060504060706050704080606070507080707060706060A0A09090A0807080905
070909090909060A07080B080A080B080608060A0909070A080608060907070608050708
080706060705060503050505050406040506040706050503070303050205050302030304
040204030202030302020303020202030102030204010402010407040103020204020303
020102
010203030402030502020305020100020202030402040303020204030205020304030204
020302020101040303020205030403030105030403030605050504050505070403040604
060505030606040506060406070606040404060707050705040706050403050606050904
060605080606060506070707070805060608090708070907070A07070908060707090709
080606080807070C090907080809090A08070808070707080706060606080906060A0707
090509070508050408060305040507050305030405050305050403010404020403060602
020301040504070202010303020301030404010402040103010201050203010201020204
030002
010401010202020002020405020001040504020201010201040102040303050301020203
030205040302030303030503030203040503040505070403030504030503030504060404
030606050305030604050506070604050305070605060505050706060505060704080705
040407070A06070A060706060808060807070A080707060706070609060507090A070607
050707070709080806070806080806060708080707070709070508060705060706090706
070506050606070404040404060304060306030304050404040406020202020205040405
020403020105020503010402010304010102030101020401000402000603010002030203
010202
020103030204010302030202010402010102030402020202040103030302030402020203
010304020501050303040302030305030203030405050303050304050603040404040203
060704040605070709060605040504070404060606060605070705080404050404050605
070605050605060707070704080706050807080508070507090709060606060807080708
070806070805060709070A080A0905070807080706090608070605060505080705050908
050607060504040304040704050306060408060303040603020707040306050303040402
040405030204010201020101010201020202020401020202020302010003020304020203
030201
020206030200020104020402030200000403020301040102030301030203030302060400
030204050404020203040604050204050303020302040303040304030504030303050404
040405040606040305040406040305040505040405060806040505050505060405050505
050506080606060605070608050605070708060605060805080605050507070708070607
070605090906080708080806080708050808090707060705050707050506040705060505
060406050804060604040705030403040207020605040404020302030202030304010304
040402020303020205020304040402020403040604030201010400030201030203030203
030403
010401040100020200030302010102030302030205040303040403030304000103010203
020404050402020204030304050305050304050404040402030404030404040506070202
020404030504040403070204050304030405070504060604040505040506040605070405
050606050608070704040805080605050608050505040507060606060506060708050706
080606050607050906070906070507070707080807060506080408060606070605040705
050305060604050603060404030504050503040304020402020702030303040302040202
010005020204020504030304030402020201040102020205020202030402010301030203
020004
020303010102020301010001020102000301030204030303020604030303020402020203
030204030500020102020303030204050104030205030204020202050303060501070304
040504040402030404050307050507030504020405040506070503040505060607060606
050506060703060606060406060404060406050705040604070707060707040806090805
070708060709070707090507080506050906060607060606080707070507030406070706
060604050704070303050405040505060206050403020602040303030403030302040204
010602030601030103010306010301020202020405020201040301020402020202020402
020403
040402020004050304000203020103010204010204020202000203010403040201030303
030303020204030202020204030303030305040303030204050404030402060303050504
030303070504050504020403040407050803080505040407050307070606040404060604
060506050604070404070604060706040604060706050607070807050507070405070509
060406070709080906060606060706060609070505050605060505050604040505050603
060604060507050504060204050505060304040405020404010203040302040102020404
020300030101020201010303010501010303020003020202020202020202000201020202
040201
010103000102020201010301020302010203000404040302020305020101030405050403
020103030602030402030402030505030304030403050301020405040203030503040405
040505030707040404030604030403060203050206040304040505040505030603040404
060304040608050508060503050409070406070509050604050506070505050605060706
070507060707070507050405060505060507050804050606050607070504040506060304
040505050605040605040504040506040604050202020504050302010104040202020604
040301020504010204030202040201020302020202010202030302010304010505010302
000403
050102010303010001010203050202030002020402020201020107030402030303010104
030303020302020202040402030304030403060401020405030302040404020304050302
060305040302050503050607050405040305050205070406050505040405030504060405
050504040406050507060405050405080805050506060507050408060705050508060504
060507050708050707050807060509050606060606040606040706050507050606060503
030505060406060304040403030504050505020202020406020301010404020502010303
050205030102030304020103030300020306040302040101020202020201020302050101
050101
020101020503010103020301020302020201020102010204030501020301030404040504
030103010105050103040302010403060203040103030502050303010504040602050604
020303050504040503070404040403040406050404030505050604020504070404040406
070704040403050806030604050305040606050705050409050507060705050604050505
060508040406060507040505060706070606050405040706070708050604050407040406
040405030606030604050303040503040503050305030403030402030306060302020302
030202040407030301030300020402020004020003030303000102030101000101020101
020203
030203010303000106030304010202040302000302040204040204020102030101040602
000203020104020303060504040402020302030103030304030205030303040404030405
0504040403040304060305050407060404050406050405080505030405040A0605030303
020404050505060603040306040406050603060505070605050505080504060406070605
040607080505070508060407060706070407040605080505050505040403060204050403
050505030405050406050303040304040302020403040303040105020202020403030003
050302010302020201030304020203020101020303020200030501050103030205040103
020101
010101040203020201050302020300020303000201010305040403010201010301010202
030202040303020303020303040304020202040403030303040101030503040203020304
040403030303040308050206030507040404030402040605040504040405030304050204
070603070505070505040806020504040603040305050506050505070708050505060505
050408040604050404060505050508050605050405060406060504060404050503050404
040404060506050504030406040403030403050403050303010301030204020404020304
010302030302020402020002010404040401030701030601040103020103010305010101
030201
020301030203020301030104030202030002010203030300010502020301040302020304
020304010201030303020203030204020401040303040304020503030505040402040402
040205050603060303040405030402030405040404030504040706040506070304040405
030604040503080604060404060604060403040506060704060705060406050306030506
070403070603060407050603040504040305050404050405050504050504050505020504
040404030406020703030504040504050203020303030301040404040205040501030002
020402030202020105010401010100010001010204020104020303010101020101010301
010103
040103010201010103020201010201030004040104030302000205000202030403040102
030304030303000303050200030202050204030102010303040303050304030305050203
030402040204040305040305020305060503040405040303040203050404040404060405
050505050604030307050307040507040204040305040605080505030405030904060A03
060403060609060605060703040406080406050702030507040705030407050403040604
050303040403040504030704030304030503040504020602020604040403020102020102
050403040102050101020503000201000204000500030302000300030601010203030103
030104
030201040302020101020300020203040003040301030303020202040204050402020103
030503040302030103030402010202020302020302050204030704050504020403020304
030207030504040404040302030505030302040402050306050504050603050603040306
080505050505020305050503060505050705070506040606060604040404040305050406
060606040604070603060403040404060307030604040507050406050603030606040605
050305060403040203020602040407030403050404010205020403010303040602020504
040304020102060302020403010202030205020301020303010303010002030303010400
020302
010103050305010103030202020304030304030503020302020106020301030103020202
020402030304030304030402030204040502020402040402050403030306050303030603
050502030604060404010304050304030403050402050504030605060303050304030505
040303050306030603030405070305050508060404060406060604040507070405060506
050607040606030605060607060305050404060406040405040504040407040502020405
030205060505060406040402040503040105010201040302040405030106010401030203
030301040203010402040202020502050200020102020102030500020201000301020201
030201
010102030105050203010502010303020202010301030303040201010302010201020101
040403030202020301030306020503040302020202040102030603030304020402020304
010306050407040402030404040301020304050303030304030204050402050204060304
050503040403040304060305030505060505060504050504050204060406030506030303
050404040606050505090704070805050603040302030408040502050402040303020406
030203030306040303050303050203030302040302020202010102010302030402020103
020104040501010203000401030503010003020203010103020101030200010103000100
000002
040001010201030103030304030103030202020202020203030201020101020202020302
020101030403020102060502030303040302020202010406040104030403020203030304
010204060404030404040404050402030105050304030403030305040504040604030604
040505030406060603050505050405030605030405050402060705070404050203050405
040405040405050707070307030805080606060806040404040306040304040403040303
030505030304020303040305040303030304020302020404020301030704060103020301
040504020201030205040402030203060302030501010103010102010400030304010401
010400
010102010201010403000102020101030201050301000003030202020202020202020101
010204020301060302010505030302030202010004040605040301030203010505030206
030505030704040303060404040404060302050204050403030205050404020407040405
040704060806060504030405030205070705050508040307050405040504050504040406
070406060705040307050303040305060505060404040405050705050504040505050205
030404040406040307040203030403040303020504030102030503030505010105020503
030302040101020401020203030203020303030003010302010301030002030304040200
010103
030203040303010101030204020301010303010303020305000301000204040401010105
020201040304040104030101040305020304020202030602040604030502050206030502
020505050402040403040403040405070404060505020305050204050205050305030705
020403060406030304060804050505050506080403050305030407050604050504050504
050603070607030505030303050603040604040504060404060204040203030503060304
040202020404040403040203030303040303020201030503020204020304010402010103
000202030301020203030205020102020302020301010101010203020202010403030400
020301
010301060202010302010200040301030503020305020302020202020404010202030302
020402040301020103030304010202030102010403040202010404030304030205010803
050504050404040602060304030304030404050305040507030403030402040304020204
030604030404050604070606040406050304040506040402050405070308070305030204
030503050304050304030403050505040405050305050505040804030305050603040304
040604030202050303030203050303030304040302020204040203020301050102030403
030102020202020405050100010202030202010205030204010201030001030301010303
040301
010201060202030103010000000103010100020202000300020202000305040305030302
040305020303030602030305010002050301020203020404030304030406020303030303
030303030503060204020303060404020304030505030503030504020404040706040305
070504050603030603020404060405050406040505050306050605030505040405050305
050404030405030506070206040304050504030404050305040305040305050503040405
020402020303020402030601030302030203020404040405040202040305020103020201
010101020402040300030103010203040303010301010503010103010103040201040303
010101
030202030101010301010001010301010302010205020001000502020503010202020102
020304020302030503040203030505020302040401040302040404060104030103040503
040505050204020202020405030306050304050506050504030506050203050402030205
050202060404040304050404040604050405060304050604050506050303050505040702
030404040605040305030405060404030504030503020305070505030301040304060604
040303030602020405050106040302030402040201020403020503010204020303040102
030301060102020305000201020100030101030102010203030302030301010003010304
010603
000503040301010104020304010302030104010001030202000303020202010002040201
010105020101030204030208040303030302020302030403010205020602030401040204
020503020404020403060202030403020303080303050604030504040504040504040304
070606040404060404060605030304040406030503040706030503040506040303060404
030606030507060405040605040205040303040306030305050403040604030203060403
040504020404030603030202040106030503030304030102010302010301010104030404
000304020101020302020102020303020303030205090502040101010301030302030201
010003
020101040101010402010603010203050200000202030003030203030301020401030201
050202010301030301020301020304020303030303040203030304030203020401010304
040304030204020504060703060303010501030305020404020505040902040404030402
040604020506030507060403060305060607030404060504060204040303030503040505
040405050404040406040306020405040604050605070303040403050303040303040403
020506050203030503030203050104040405020303020202020202020104010303010404
030101010502040202050202000201040303000201020102010101020104010607000203
040202
030003010104010103020001010000040100000102010203030003020201020103020201
020202010103020403020405030201030202030202030202060104020403030303020303
050503050404060403070502030602060403050402030202030304030405040403060604
060605040404030604040206080605050403060303030305040404040306040506050405
060505080405060603040603060304050504030406050605020203050503030504050404
040401050503050301030603080304040202040505020202020301030203020101040202
010202030401040305030302030002060203010401030301000101030101020001010302
010101
020402010303030201030201020201030201010303000502020002020202020402030103
040103040203030103030303010301020302030302030205030204060204030504050403
030304070502020404040404060309040504050502040703040404040504030604060404
040504060403050304050506020404040403030508040503050504040304050305050304
050405060304040403030504040404020403050602030405040206050404040303040402
040203020302040202040203030302040105040204020002010203010401040103030402
010403040704040201030301010202000202010403000201020104020201060001030103
010003
030402020301020602030101050004010403010601020101020203020201010204020402
050201020004030204020302030005030204040102020403020404020201010403040303
040404040405040404040503030401010204060305060405070402030404040406070404
040404040406050706060303060507030504050505040304030605030503070305030603
050507020303040404060402040205060606050503050605040306050302040304020303
030204030302030402030406040204020201020503050403020303010403040303010102
010402010304020201040203040100020002010101020603010202010203010101040301
010303
030101020200030204030005020101030100010100030202020202040302030203020302
010102030401010303020301030101020404020402020402050203030101030103040505
050404040705030505040404060403070503030704050303050204040503040406050403
060303030306030305030508050303050706060603030406030703050303080505080405
060603030603040406070304050202050406030202060503030704030305030603060203
040507040208050302010102060203050402020102020203030301050303020202020101
020203020300020102030202030100030103030103010201010103030301010301020100
020101
010101010102000300010303010203020201010202030101010203030004030100030402
040201040206030304020302030405030405020204020302040503030305040404040203
020502060306050404040304060502030306030405030402040403020304040404050706
050606050307050405050404070402030507050503030506050405030504030603050605
030406040504040403030406040606050804050607060503050505070303040302020104
040302050304030504050403040205030305020202040203030301040103030503040402
030305040103030303040200000201020402020101030203030003050301000103020301
030002
030402000202030203030303030101030201030002020302020202020400020001020401
020103030404030202030504040503020505010204030202030303040303040302020503
020202010303030404040204030304050505050405040202040406020307050405030506
050703030604040503050405050404050505050405030304030407030408050503040405
050602020804040503030404020604030505040504050306020503060204060305030406
050403050203040204060302040202020304020604020301060402010402030101020104
020103020502020201010202010201020200030101030202020203030200020101040402
010303
010302000403030202000103030101010200020103030302020000020302010001020402
020403020104020101010303030203050504020404020303020305020203030206030204
030204040404030504030503040505030304030204060304070504050403040606030605
040403030802080305030705050404030404060404040805020606050306060404060805
050405050503060404030605040302020304030505040306030304030405040603050403
020404020503030306040303040406020204020201010301080205040101020202020403
020304020104020100030401000205020302020003040301010103030101010200020102
040101
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=Z@0300820P010@400@41008010@400<00`<3
00410@020P8010030`<00`0410@00@4100820P0200820P0900410@030`<010@400820P010@401@D5
00<30`020P800`<300801@D500X00`<300H61P0410@00`<300@4100820P010@400820P0410@00`<3
0P0410@070051@D01`L700D51@051@D00P8200L71`020P800`<300820P051@D02@T900@4100820P0
1@D500820P061PH00`<300@410051@D010@400D51@030`<01PH600<30`061PH010@400P8200410@2
00<30`0P00H61P051@D02@T900@410071`L010@400H61P051@D010@400D51@030`<00P8200<30`04
10@01@D500<30`061PH00P8200@410030`<01@D500H61P030`<01@D500<30`0410@01@D500820P04
10@00P8200<30`020P8200<30`0>00@410020P8010@400@410020P8010@400820P010@401@D500<3
0`010@400`<300410@051@D200410@0A00820P010@400@4100D51@010@401PH600820P030`<010@4
000000010@401PH600410@030`<0000000@410010@40103AcJT000<0dLfY02001@D500@410020P80
0@4100820P030`<00@4100820P00000010@400<30`0000000`<3000000051@D00P8200<30`010@40
1@D500@410020P800`<300P820030`<00@4100@410051@D010@400<30`020P800@4100H61P@00`<3
0P0410@01@020P801@D500<30`030`<01PH600800`<30P0410@00`071`L00P8200@4100300<30`08
00D51@061PH01PH600D51@020P801@D500@410061PH200@410801`L70`061PH04@071`L010@400L7
1`0410@00P8200L71`061PH01@D500L71`051@D00`<300@410030`<010@400H61P051@D01PH60080
10@400<00`<300L71`030`<00P030`<010051@D01PH600<30`030`<200@4100500<30`020P800`<3
00<30`0410@00P030`<010020P8010@400@4100410@200820P0500D51@010@400`<300820P051@D0
0P020P801@0410@00`<300410@010@400P8200800`<300H00P8200410@010@400@4100<30`020P82
00<30`0400820P030`<00`<300410@@0dLfY00030=7=Z@0900<30`010@400P8200820P010@400`<3
00820P030`<0000000<00`<300@01@D500@410030`<00`<30P010@401P020P8010@400<30`051@D0
0@4100820P800`<30P0410@00`020P800`<300820P0200820P800`<300@010@400<30`0410@00`<3
0`051@D03@020P801@D500@410061PH00P8200@410051@D00`<300D51@0410@01`L700D51@0410@0
0P051@D300H61P0400@410051@D00`<300H61P801@D500T01PH600D51@0410@01PH600D51@0820P0
1PH600D51@0410@00P051@D01`0410@01PH600@4100410@01`L700@410051@D00P0410@01`051@D0
1`L700@4100410@00`<300D51@061PH00P030`<200@4100500<30`020P800`<300D51@0410@00P03
0`<01@0410@00`<300<30`030`<010@400<00`<300@00@4100<30`010@400@410P020P800`030`<0
0@4100820P0300<30`0300410@030`<00P8200800P8200<00`<300@410051@D00P030`<200410@03
00<30`3AcJT0dLfY0080dLfY00030=7=Z@D00@4100D01@D500820P0410@0000000<30`0200820P0;
000000020P800`<300@410020P800`<300820P010@400P8200410@0410@00`030`<01P010@4010@4
00820P010@401@D500<30`801@D500D010@400820P030`<01PH600@4100300D51@<010@400/01@D5
00@410061PH010@400D51@061PH010@400H61P051@D020P800L71`0200H61P0>00D51@071`L01PH6
00H61P0:2PX01`L700@410051@D01`L700D51@071`L01PH600@410071`L200D51@0400H61P051@D0
20P800@410801@D50P061PH02P071`L01@D500820P0410@01@D500H61P0410@01PH600<30`0410@2
00D51@0600H61P0410@00`<300@410020P800@410P030`<200820P0400@410030`<00P8200D51@80
0P8200H00`<300820P030`<010@400D51@0410@200410@0@00<30`0410@00`<300410@051@D00@41
00<30`020P800`<300820P010@401@D500820P010@400P8200<30`800@4100<00P820=7=Z@3AcJT0
0P3AcJT000<0dLfY00D00P8200<30`010@400P8200@4100200<30`0300410@0410@0000000800`<3
0140000000410@010@400P8200<30`010@4010@400820P030`<00P8200<30`020P800@4100820P04
10@00P8200<30`0200D51@8010@400D01@D500<30`030`<01@D500<30`0300@4100500D51@0410@0
0`<300@410071`L00P051@D0100410@00`<300<30`061PH300D51@0900T92@051@D01`L700H61P04
10@02@T900<30`0820P00`<300<01PH600@02`/;00H61P061PH01PH61P0410@00`061PH00`<300D5
1@0200@4100700H61P051@D01@D500D51@071`L00`<300D51@0200H61P0700D51@0410@01@D50082
0P061PH010@400<30`0200@4100500<30`0410@01@D500@410010@400`020P80300410@00P820082
0P020P8010@400410@030`<00@4100@410010@400`<300410@<00P8200X0000000410@010@400000
00<30`0000000`<300@410051@D00`<30P020P800`030`<010@40=7=Z@030=7=Z@000`3AcJT00`04
10@00P820000000200820P0300<30`020P80000000800P8200T010@400<30`020P8010@400410@02
0P800`<300820P061PH00P051@D200<30`0300820P0410@010@4008010@400D00`<300D51@051@D0
0P8200H61P0200<30`0300D51@0410@010@400<010@400<00`<300D51@061PH00`051@D03P030`<0
1PH600D51@030`<010@400D51@061PH010@400L71`051@D01`L700D51@0:2PX010@41`051@D01P06
1PH01`L700L71`092@T01@D500H61P801@D500<010@400P820092@T010051@D00`061PH01@D500D5
1@0200@410@00`<300P010@400820P0410@010@400D51@061PH00`<300D51@800P8200X010@40041
0@030`<00`<300820P030`<00P8200@410020P800`<30P020P801`0410@01@D500410@030`<010@4
00820P010@400P020P820000000300820P030`<00`<300<00P8200<00`<300@410020P800`010@44
0=7=Z@000`3AcJT010030`<00P82000000010@4200820P0700410@051@D0000000<30`020P800@41
00H61P0200820P0G00H61P010@400@4100@410061PH010@400D51@030`<00@4100<30`010@400P82
00@410020P800`<300820P051@D00`<300H61P030`<010@400H61P0410@00P051@D020030`<010@4
00H61P051@D00`<300D51@0410@01@D50`061PH03@071`L01PH600L71`051@D020P800L71`061PH0
1`L700/;2`061PH01@D500@410071`L00P061PH0100820P01@D500X:2P051@D400H61P0<00D51@06
1PH01PH600P820061PH010@400H61P0410@01@D500L71`0410@01@D50P0410@01P051@D01`L700D5
1@030`<010@400H61P<00`<300D01PH600D51@0410@00`<300D51@0200820P0300D51@030`<020P8
00D00`<300<010@400<30`020P800`030`<01`0410@00`<300820P020P800`<300410@0000000P02
0P80100000000P8200820P020P8200<30`800P8200<00@4100<30`3AcJT00`3AcJT000<0dLfY0P02
0P801@010@400`<300<30`020P8010@400800P820P010@400`0410@00`<300820P0200410@0400<3
0`0410@00@4100D51@8010@40P010@402`061PH00`<300@410030`<010@400D51@0410@00`<300D5
1@0410@02@T9008010@400/00P8200H61P0410@010@400H61P051@D00`<300D51@061PH01`L700H6
1P0200D51@0600@410051@D020P800P820051@D01PH60`051@D200L71`@01PH600H01`L700H61P06
1PH02@T900H61P071`L200H61P0800L71`051@D01PH600@410051@D01`L700@410061PH200D51@0:
00H61P071`L01@D500@410061PH01@D500H61P0410@00`<300@410<01PH600l010@400820P051@D0
1PH600D51@0410@00`<300820P030`<010@400<30`020P800`<300410@030`<00P020P800`030`<0
0P8200D51@0200<30`0700@410020P8010@400820P030`<00@4100820P0200<30`<00P8200<00@41
00820P0410@00P020P8200@410@0dLfY00030=7=Z@800P8200H00@41000000010@401@D500@41002
0P8200<30`0400@410051@D00`<300<30`801@D500`010@400820P0410@00`<300820P0410@00P82
00<30`0410@01@D500820P051@D300<30`0400D51@061PH010@400<30`<010@400d01PH600@41006
1PH01`L700H61P071`L020P800D51@061PH01@D500@410092@T01@D500801PH60P071`L00`051@D0
20P800P8200200L71`0400H61P071`L01`L700H61P801`L700<01PH600/;2`061PH01@071`L200H6
1P0300T92@0820P01PH600<01PH600<01@D500P820061PH00P061PH01@0410@01@D500@410051@D0
1PH6008010@400@00`<300D51@0410@01PH60P0410@02P030`<01@D500<30`020P800`<300D51@02
0P801@D500<30`020P8200<30`0500P820030`<00P8200D51@020P800P030`<010020P800`<300@4
100410@300820P0600@4100000000P8200820P0410@01@D50`020P800`030`<00P820=7=Z@030=7=
Z@000`3AcJT01@0000000P8200410@010@401@D500D00P820P030`<01@020P800`<300@410010@40
0P82008010@400D00@4100<30`0410@00`<300@4100200<30`8010@40P051@D06@061PH010@400H6
1P030`<010@400H61P0410@01`L700D51@0410@01`L700H61P0410@01`L700D51@061PH020P800D5
1@061PH01@D500L71`0820P01PH600P820071`L00`0820P010071`L02`/;00L71`092@T200L71`08
00/;2`0820P02@T900X:2P061PH01`L700P8200:2PX200P8200700T92@071`L020P800L71`061PH0
1`L700D51@0200P8200;00H61P0820P01PH600L71`061PH01@D500<30`071`L01PH600D51@071`L0
0P051@D010030`<01@D500@410051@D200@4100500<30`0410@010@400<30`0410@00P020P8200<3
0`8010@400@00P8200<30`020P801@D50P030`<0300410@00`<300@410010@400`<300820P0410@0
0@4100820P010@4010@4000000800@410`020P800`000000dLfY0=7=Z@020=7=Z@000`3AcJT01P01
0@400P8200@4100410@00`<300410@800P8200L00@4100<30`020P800P8200410@020P800`<30080
10@400<01@D500@410030`<00P030`<00`0410@00`<300<30`0300<30`<010@400L01PH600@41004
10@01`L700H61P051@D01PH600801@D500X010@400<30`061PH010@400D51@0820P01`L700T92@04
10@020P80P061PH01@071`L01PH600L71`0820P01`L7008020P800D03@d=00T92@0<30`01PH600X:
2P0200P820801`L700/020P800X:2P061PH01`L700P820071`L020P800H61P0820P01`L700P82004
00L71`801PH60P071`L01@0410@01@D500D51@071`L01PH600@010@40P051@D02`030`<01`L700H6
1P020P8010@400<30`051@D00@4100<30`061PH00`<300D010@400<00`<300820P0410@00P0410@0
1`020P8010@400410@0410@00`<300410@0410@010020P80100410@00`<300820P0410@200820P03
00410@3AcJT0dLfY0080dLfY00030=7=Z@0300820P0410@00P8200D00@410`020P8200<30`0;0082
0P051@D010@400<30`020P800`<300410@020P801@D500820P061PH00`030`<200@4100300<30`04
10@01@D5008010@400h01@D500@410051@D02@T900D51@071`L020P800H61P071`L020P800H61P07
1`L02`/;00H61P802@T900D020P800X:2P0820P030`<00L71`0200P8200600L71`092@T02@T900P8
200:2PX02@T90`0820P02@092@T020P800P8200:2PX01PH600P820092@T01`L700X:2P0200T92@07
00P820071`L01`L700H61P0820P01`L700P8200400H61P801`L70P051@D010092@T01@D500@41005
1@D200@410800`<30P051@D200@4100800H61P0410@00`<300@410020P8010@400D51@030`<200@4
10800@4100<010@400820P020P800P030`<00`010@400`<300<30`0200410@0500820P071`L00P82
00<30`010@400P020P8010030`<00P8200<30`020P840=7=Z@000`3AcJT010030`<00P8200820P04
10@300820P0<00<30`020P801@D500@410030`<00P8200D51@0410@00P8200<30`010@400`<30P04
10@01`030`<010@400<30`071`L01PH600820P030`<00P051@D01@071`L01PH600@410092@T01`L7
00801PH600H020P800H61P0820P01`L700H61P0820P400H61P0@00L71`092@T02@T900P820071`L0
2PX:00T92@0:2PX02`/;00T92@071`L030`<00P8200:2PX02@T900`<30802@T900<02PX:00T92@0;
2`/00`092@T02@0820P02`/;00T92@092@T020P800T92@0:2PX02@T900X:2P0200L71`0300T92@0=
3@d020P800801`L700@02@T900L71`061PH01PH60P071`L500D51@801PH60P0410@200H61P800`<3
00@01@D500@4100410@010@40P020P801@030`<01@D500@410030`<010@400<00`<300L00P8200<3
0`051@D0000000@410030`<01PH600<00@410P020P801@0410@00P8200410@010@400`<300@0dLfY
00030=7=Z@0300@410010@400`<300<00`<300<00@4100D51@030`<00P0410@200820P0700<30`02
0P800`<300<30`020P8010@400820P0200@4100500<30`020P801@D500D51@030`<00P051@D01P04
10@00`<300H61P071`L020P800D51@801PH600@01@D500H61P0;2`/020P80P071`L00`0820P01`L7
00P8200200P8200400T92@0:2PX02PX:00X:2P8020P800P02PX:00/;2`0>3Ph02PX:00`<30092@T0
2`/;00X:2P<02`/;0P0:2PX01@0;2`/02PX:00/;2`0<30`02`/;008030`<00L02PX:00T92@0820P0
2PX:00P8200=3@d020P800<02@T90P061PH00`071`L020P800H61P0200L71`<01PH600P020P800L7
1`0410@01PH600T92@051@D010@400H61P800`<300D01@D500@410020P801@D500L71`0200<30`03
00820P051@D01@D500<00`<30`0410@300820P0500@410020P801@D500820P030`<00P010@401`03
0`<00P8200410@010@400`<300410@020P80103AcJT000<0dLfY00L00@4100<30`020P801@D50082
0P010@400P8200@00`<30P0410@020030`<01PH600@4100410@00`<300@410030`<00@410P0410@2
00H61P0300<30`0410@010@400801@D50P0410@02`0820P010@400H61P071`L01PH600D51@071`L0
20P800H61P071`L02@T9008020P800D02@T900P8200820P02PX:00/;2`0200T92@0300/;2`092@T0
2`/;00802PX:100<30`01P092@T030`<00d=3@0<30`03@d=00`<30802`/;00<03@d=00`<300=3@d0
0P0;2`/01@0:2PX02`/;00X:2P092@T02PX:00@02@T900L030`<00T92@061PH02PX:00P820071`L0
1@D500801PH60P0820P300H61P0400L71`061PH01`L700D51@801PH60P0410@200D51@0500@41002
0P8010@400<30`020P800P0410@300<30`0700D51@010@400`<300@410010@400P8200@410020082
0P0500<30`051@D010@400<30`010@400P030`<0100410@00`<300410@010@440=7=Z@000`3AcJT2
00820P0900@410030`<00@4100410@020P800`<300D51@00000010@400800P820P061PH00`020P80
0`<300@4100300<30`0500@410071`L01@D500D51@0410@00`051@D200H61P0:00L71`061PH01PH6
00D51@071`L020P800T92@061PH01`L700P820802`/;01<02PX:00T92@0;2`/030`<00/;2`0:2PX0
3Ph>00X:2P0;2`/030`<00X:2P0=3@d02`/;00l?3`0=3@d02`/;010@400<30`03@d=008030`<0P0=
3@d03@0>3Ph03@d=00d=3@0=3@d03Ph>00`<300@41003@d=00`<300;2`/02PX:00`<30092@T00P0;
2`/02@0=3@d01`L700P8200:2PX01PH600d=3@092@T01`L700P8200200L71`0700P820061PH01`L7
00L71`061PH01`L700D51@0200H61P0400D51@0410@01`L700H61P8010@400L01PH600<30`0410@0
10@400820P061PH00`<3008010@40P051@D01`0410@00`<300@410020P8010@400410@030`<00P02
0P8300<30`0500820P0410@010@4000000030`<00P0410@40=7=Z@000`3AcJT200820P8010@400/0
0`<300820P0410@010@400<30`010@400P8200410@051@D010@400<30`0200@410800P8200L00`<3
00@410051@D01`L700H61P0410@00`<300801PH600P020P800D51@0820P01PH600L71`0820P02@T9
00X:2P8020P800H02@T900/;2`071`L01`L700/;2`0:2PX200T92@802PX:01802`/;00d=3@0<30`0
30`<00/;2`0=3@d02`/;00h>3P0=3@d03Ph>00`<300=3@d0410@014A4@0=3@d03Ph>00d=3@0?3`l2
00h>3P0700l?3`0@4100410@00h>3P0=3@d030`<00d=3@0200/;2`0=00X:2P0<30`02`/;00X:2P0;
2`/02PX:00/;2`0820P02`/;00L71`0820P02@T900H61P0200P8200600L71`0820P01`L700P82007
1`L020P80P071`L200D51@801PH600P010@400D51@0410@010@400D51@030`<01PH600@410800`<3
0P020P801`0410@01@D500<30`030`<00P8200D51@020P800P0410@600<30`0600820P051@D00@41
00410@030`<01@D5103AcJT000<0dLfY00<00`<300820P030`<00P030`<00`020P800`<300@41003
00@4100300<30`0410@00@4100800`<300@00P8200<30`051@D01PH60P030`<200L71`0<00<30`05
1@D010@400T92@061PH01`L700T92@061PH01@D500L71`0;2`/020P80P071`L020092@T01`L700T9
2@0:2PX030`<00X:2P0<30`02`/;0P0<30`00`0;2`/03@d=00d=3@0300`<300300h>3P0=3@d03`l?
00803`l?00@0410@00d=3@0@4100410@0P0>3Ph02P0A4A40410@01@D500>3Ph03`l?010@400>3Ph0
51@D014A4@0>3Ph200d=3@0>00`<300=3@d030`<00/;2`0:2PX03@d=00/;2`0<30`02@T900d=3@0:
2PX02@T900P820071`L200T92@0300H61P0820P020P800801`L700<01PH600L71`071`L00`071`L0
2@030`<01`L700L71`061PH02@T900L71`0410@01@D500H61P0200<30`0600H61P030`<01PH600<3
0`071`L010@40`030`<00`0410@00`<300<30`0200820P800`<300H00P8200<30`030`<00P8200<3
0`071`L40=7=Z@000`3AcJT00`020P800`<300820P0200<30`8010@400`00`<300820P030`<010@4
00820P051@D010@400<30`0410@00`<300H61P051@D300@4100500L71`030`<010@400D51@061PH0
0P0820P200L71`0400P820071`L020P800L71`802@T900D020P800X:2P0;2`/02`/;00h>3P0200/;
2`0500`<300?3`l03Ph>00h>3P0<30`00`0>3Ph01P0=3@d0410@00h>3P0?3`l04Q8B014A4@803`l?
00<0410@018B4P0C4a<00P0B4Q802P0C4a<04Q8B018B4P0@41004Q8B010@400B4Q803`l?010@400?
3`l2010@40803@d=00P03`l?00d=3@0=3@d03@d=00/;2`0<30`03`l?00`<30802PX:0P092@T00`07
1`L020P800X:2P0200P8200D00L71`0820P01PH600P820071`L020P800L71`061PH01`L700D51@07
1`L01PH600D51@061PH01`L700D51@030`<01PH600L71`051@D200<30`0;00820P030`<00`<300<3
0`020P801PH600@410061PH010@400L71`010@400P030`<200820P0400410@051@D00`<300410@@0
dLfY00030=7=Z@0500820P030`<00P8200410@020P800`0410@01P061PH00`<300D51@0410@01@D5
00@410800`<300@010@400D51@061PH020P80P030`<020051@D01`L700H61P0410@020P800L71`08
20P01PH60P0820P200T92@0500X:2P0820P03Ph>00T92@0<30`00P0:2PX02@0<30`02PX:00l?3`0=
3@d03Ph>00`<300=3@d030`<00d=3@0400l?3`08014A4@0@41004Q8B01<C4`0?3`l0410@01<C4`0A
4A4201<C4`0:018B4P0C4a<04Q8B01<C4`0A4A4051@D014A4@0@41004A4A01@D50<03`l?00<03Ph>
00l?3`0>3Ph00`0=3@d300/;2`803@d=0P0:2PX01@092@T02`/;00`<30071`L02@T9008020P800T0
2PX:00D51@061PH01`L700H61P051@D020P800D51@071`L00P051@D01`061PH01@D500D51@0410@0
1@D500P820051@D00P020P8040061PH00`<300D51@0410@00`<300820P030`<01PH600@410061PH0
0P8200<30`020P800`<300D51@030`<300820P0300<30`3AcJT0dLfY0080dLfY00030=7=Z@0B00<3
0`051@D00`<300410@061PH00P8200<30`0410@00`<300@410020P801@D500@410030`<01@D500@4
10030`<01PH60P051@D01P061PH010@400H61P071`L010@400D51@801`L700L01PH600D51@071`L0
30`<00X:2P0820P02@T900<02PX:00D02`/;00d=3@0;2`/03@d=00`<300200d=3@<03Ph>00L04A4A
018B4P0?3`l04A4A010@400A4A4051@D00804Q8B00<04a<C018B4P0B4Q800P0C4a<02@0D51@04a<C
01HF5P0E5AD051@D01DE5@0F5QH04a<C01HF5P0201<C4`804A4A0`0C4a<0100B4Q803Ph>00h>3P0>
3Ph200d=3@0300h>3P0?3`l02`/;00<02PX:01402@T900X:2P0<30`02PX:00T92@0820P02`/;00P8
200:2PX02@T900L71`051@D02PX:00P820071`L020P800D51@0300H61P0300@410051@D010@40080
10@40P030`<02@0410@00`<300<30`061PH010@400<30`020P8010@400D51@0200<30`0700H61P03
0`<010@400820P030`<00P820000000200<30`@0dLfY00030=7=Z@<010@400H00P8200<30`051@D0
10@400<30`020P8200D51@0300@410020P801@D5008010@40P051@D010061PH01`L700D51@071`L2
00H61P0:00P820061PH01PH600X:2P092@T020P800L71`0:2PX020P800X:2P802@T900<03@d=00h>
3P0<30`00P0>3Ph01@0<30`03Ph>00h>3P0A4A403`l?0080410@0P0A4A403@0C4a<0410@014A4@0C
4a<04Q8B01<C4`0F5QH051@D01DE5@0D51@05QHF01@D500E5AD00P0F5QH00`0G5aL061PH01LG5`03
01LG5`0301PH600D51@051@D00<04a<C00H04A4A018B4P0@41004A4A00h>3P0?3`l200h>3P0400`<
300@410030`<00l?3`8030`<00@02@T900X:2P0;2`/020P80P0:2PX01@071`L020P800L71`071`L0
2`/;00<01`L700D01PH600L71`0820P01PH600T92@0200H61P0300D51@0410@010@400801@D50P04
10@01P051@D010@400410@030`<010@400D51@800`<300D01@D500@4100410@00`<300820P0200D5
1@0300@410020P801PH600@0dLfY00030=7=Z@0400820P0410@00`<300@410800@4100L00P8200<3
0`0410@00P8200D51@0410@00`<3008010@400H00`<300D51@030`<01PH600L71`051@D600H61P03
00T92@0;2`/02@T900802@T900H02`/;00d=3@0:2PX030`<00h>3P0=3@d200h>3P@0410@00X04a<C
01@D500@410051@D01<C4`0A4A404a<C01@D500G5aL05QHF0P0E5AD01P0D51@05QHF01LG5`0G5aL0
6QXJ01TI6@806QXJ00<061PH01/K6`0K6a/00P0K6a/201XJ6P0701TI6@0G5aL061PH01HF5P0G5aL0
4Q8B01@D500201<C4`804Q8B0100410@00h>3P0?3`l04Q8B00l?3`0<30`03Ph>018B4P0>3Ph02`/;
00X:2P092@T02PX:00/;2`092@T020P80P092@T0100:2PX020P800T92@0820P300L71`0400H61P08
20P01@D500L71`@01@D500<010@400D51@061PH00P0410@02`0820P01PH600@410051@D010@400<3
0`020P801PH600<30`0410@00@4100@00`<30P020P840=7=Z@000`3AcJT020010@4010@400@41001
0@401@D500820P030`<01@D50P020P801@051@D00`<300@4100410@01PH600801@D501400`<300D5
1@061PH01PH600L71`061PH01`L700P820092@T020P800L71`0:2PX02@T900`<300:2PX02`/;00d=
3@0300h>3P0500l?3`0@41003`l?014A4@0B4Q800P0A4A400`0D51@04a<C01LG5`0301DE5@0301HF
5P0E5AD05QHF00805aLG0`0H61P02P0L71`05aLG01XJ6P0K6a/06QXJ01hN7P0M7Ad071`L01hN7P0P
820201lO7`0<01/K6`0J6QX06ATI01XJ6P0I6AT061PH01LG5`0H61P05ADE01<C4`0B4Q8051@D0P0B
4Q80100?3`l04A4A00l?3`0C4a<200d=3@0300`<300=3@d03Ph>00802`/;00X030`<00/;2`0;2`/0
2`/;00P8200:2PX02@T900L71`0820P02@T90P0820P200L71`0800@410051@D01PH600T92@071`L0
10@400L71`051@D200@4100300H61P051@D010@400801@D500@00`<300D51@030`<010@40P051@D0
1`020P800`<300<30`0410@01@D500<30`0410@0103AcJT000<0dLfY00L010@400<30`051@D010@4
00<30`0410@00P82008010@400<01@D500@410030`<00`0410@040061PH01@D500@410061PH010@4
00D51@061PH01`L700P8200;2`/01`L700T92@0;2`/03@d=00/;2`0<30`200d=3@0400l?3`0=3@d0
3Ph>01<C4`804A4A00@0410@01@D500B4Q804a<C0P0E5AD401LG5`0301PH600J6QX06QXJ00@06a/K
00D06QXJ01TI6@0L71`07QhN01/K6`0401hN7P@08B4Q00P092@T01hN7P0L71`06a/K01TI6@0K6a/0
6QXJ01HF5P805aLG00X05ADE01HF5P0D51@051@D01<C4`0B4Q80410@01<C4`0@41004Q8B0`0?3`l0
1`0<30`03@d=00d=3@0>3Ph03@d=00/;2`0<30`00P0;2`/04P0>3Ph02PX:00X:2P0:2PX02@T900P8
20071`L020P800D51@061PH01`L700P8200410@01PH600D51@0410@01@D500H61PD010@400X01@D5
00@410051@D00P8200@410020P800@4100<30`0410@00P820`030`<40=7=Z@000`3AcJT00`010@40
0`<300<30`0200<30`0400D51@0410@01@D500820P@01@D500@01PH600D51@051@D01@D50P061PH0
1@0820P01`L700T92@071`L02@T9008020P800D02PX:00/;2`0:2PX0410@00X:2P0200`<3006010@
400?3`l0410@014A4@0@410051@D0P0C4a<0200D51@05ADE01PH600H61P05aLG01XJ6P0K6a/06ATI
0`0K6a/401`L700501hN7P0M7Ad07QhN01lO7`0P82000P0O7al4028R8P0502@T900S8b<08B4Q020P
800Q8B400P0N7Qh01P0K6a/071`L01XJ6P0J6QX061PH01TI6@805aLG00@05ADE01HF5P0D51@051@D
0`0A4A404@0C4a<04A4A010@400A4A40410@00d=3@0?3`l03@d=00`<300=3@d02`/;00`<300;2`/0
3@d=00X:2P092@T02PX:00<020P800H02PX:00H61P061PH01@D500H61P071`L200@4100600L71`05
1@D010@400<30`0410@00`<30P061PH01P051@D00`<300820P0410@00P8200@410<00`<30P051@D0
0`030`<0dLfY0=7=Z@020=7=Z@000`3AcJT200<30`@010@40P051@D01@030`<01PH600H61P020P80
10@400801@D500H010@400D51@0820P01`L700H61P0820P200H61P802@T900H02PX:00T92@0=3@d0
2@T900l?3`0=3@d200h>3P80410@00L04a<C01DE5@0G5aL051@D01PH600G5aL06QXJ00806ATI00<0
6a/K01`L700N7Qh00P0L71`06@0N7Qh07alO01lO7`0Q8B407alO02@T900Q8B408R8R024Q8@0R8R80
92@T028R8P0T92@09RHV02LW9`0U9BD09bLW02HV9P0X:2P0:RXZ02DU9@0V9RH092@T028R8P0P8200
0P0N7Qh01@0M7Ad06a/K01`L700I6AT07AdM008061PH00D05QHF01LG5`0E5AD051@D01<C4`0201@D
5006018B4P0?3`l04A4A010@400A4A403`l?0`0>3Ph0100?3`l03@d=00`<300>3Ph200d=3@802PX:
00L01`L700X:2P0:2PX01`L700H61P071`L020P800801`L70P061PH300@4100500H61P0410@00`<3
00<30`0410@00P030`<010051@D010@400@4100410@300<30`8010@4103AcJT000<0dLfY00D01@D5
00820P030`<01@D500@4100200<30`0800D51@020P801@D500D51@0820P01@D500@410051@D200H6
1P0400L71`061PH01`L700L71`8020P800H02@T900`<300<30`030`<00/;2`0<30`200h>3P07010@
400>3Ph0410@018B4P0A4A404a<C01LG5`0201HF5P0701LG5`0J6QX06QXJ01/K6`0M7Ad071`L01hN
7P0201lO7`0601hN7P0O7al08B4Q024Q8@0R8R808b<S0P0R8R801P0T92@09BDU02@T900U9BD0:BTY
02HV9P80:BTY0P0X:2P03`0W9bL0:2PX02TY:@0W9bL08b<S02DU9@0Q8B408b<S028R8P0M7Ad0820P
01`L700K6a/06ATI01PH600201LG5`0601TI6@0F5QH05ADE01@D500E5AD04a<C0P0D51@0100B4Q80
4A4A010@400?3`l200h>3P0300l?3`0>3Ph03@d=00<030`<00`02`/;00T92@0<30`02@T900L71`08
20P02@T900P820051@D01PH600T92@0820P200H61P801@D500X020P800L71`051@D010@400<30`04
10@00`<300@410030`<01@D50P0410@01@051@D010@400D51@020P800`<300@0dLfY00030=7=Z@03
00820P0410@010@400<00`<30P051@D300@410801PH600<01`L700P820061PH00`061PH300P82004
00T92@0<30`02PX:00/;2`@030`<00@03`l?010@400A4A404Q8B0P0C4a<01@0E5AD05aLG01DE5@0G
5aL06a/K00807AdM00D08R8R01dM7@0Q8B408R8R024Q8@0202<S8`809BDU0P0W9bL0200U9BD09RHV
02HV9P0W9bL09RHV02TY:@0Z:RX0:2PX0`0[:b/302d];@0602`/;00[:b/0:BTY02LW9`0V9RH09BDU
0P0S8b<0100Q8B407QhN01lO7`0K6a/201dM7@0701/K6`0J6QX061PH01TI6@0G5aL051@D01LG5`02
01DE5@04014A4@0D51@04A4A010@40804A4A00<03`l?010@400?3`l00P0>3Ph0100<30`03@d=00/;
2`0=3@d200T92@0@00/;2`0820P02PX:00T92@071`L01@D500T92@061PH020P800@410071`L02@T9
00L71`061PH01`L700D51@@010@400@01@D500<30`0410@00`<30P0410@00`051@D00`<300@41004
0=7=Z@000`3AcJT00`030`<010@400<30`0200D51@0600L71`030`<01PH600H61P030`<01`L70P05
1@D02`0:2PX010@400P820061PH02PX:00L71`0:2PX02@T900`<300:2PX030`<00802`/;0P0<30`0
1`0?3`l0410@00l?3`0A4A404Q8B01HF5P0D51@00P0G5aL01@0H61P06QXJ01dM7@0M7Ad07alO0080
8R8R00`09BDU02@T900X:2P09BDU02LW9`0Y:BT0:2PX02TY:@0Z:RX0:BTY02XZ:P0[:b/302d];@<0
;Rh^0140<30`02l_;`0`<300<S8b030`<00a<C40<S8b034a<@0/;2`0:b/[02TY:@0Z:RX0:BTY02LW
9`0T92@08R8R020P800202<S8`0401lO7`0L71`07AdM01dM7@806QXJ00@071`L01TI6@0G5aL05aLG
0P0F5QH301<C4`0>01@D500A4A404A4A014A4@0?3`l0410@00h>3P0<30`03Ph>00`<300=3@d02`/;
00`<300;2`/300T92@0800L71`092@T01PH600L71`061PH01@D500L71`061PH200D51@0>00@41003
0`<01@D500<30`0410@01@D500<30`061PH00P8200<30`0410@01@D500@410030`<40=7=Z@000`3A
cJT01@0410@00`<300<30`030`<01PH600800`<300P01PH600@410051@D010@400L71`092@T01@D5
00L71`801PH600H020P800L71`092@T020P800T92@0:2PX200`<300300h>3P0=3@d03@d=0080410@
00@04A4A01@D500E5AD05QHF0P0H61P02P0I6AT06a/K01`L700N7Qh0820P02<S8`0W9bL09RHV02LW
9`0X:2P202/[:`80;2`/00L0;bl_02h^;P0a<C40<C4a030`<00c<c<0<30`0080<C4a0P0d=3@00`0c
<c<0=3@d03@d=00203Hf=P80=CDe00<0=3@d03<c<`0b<S800P0_;bl01P0a<C40;Bd]02XZ:P0X:2P0
9bLW02@T90808b<S00D08B4Q020P800P82007QhN01lO7`0201XJ6P0501dM7@0L71`061PH01TI6@0F
5QH00P0G5aL0300E5AD04a<C018B4P0B4Q804A4A01<C4`0A4A404Q8B00h>3P0=3@d03`l?00`<3080
3@d=0P0;2`/200T92@8020P800P01`L700X:2P061PH01@D500L71`051@D00`<300T92@801PH60P05
1@D00`020P8010@400D51@0200D51@0500410@030`<02@T900820P061PH0103AcJT000<0dLfY0P05
1@D010030`<01@D500D51@0410@200D51@0700@410051@D020P800H61P071`L020P800D51@0200L7
1`0400P820092@T02`/;00X:2P802`/;00D03@d=00/;2`0@41003Ph>014A4@02018B4P0>01<C4`0D
51@05QHF01DE5@0H61P06a/K01`L700M7Ad0820P024Q8@0U9BD09bLW02PX:00[:b/202`/;080;bl_
00@0<c<c03@d=00d=3@0=CDe0P0d=3@02@0h>3P0=3@d03Hf=P0h>3P0=CDe03Ti>@0f=SH0=cLg03Ph
>00203Xj>P0?03Ti>@0k>c/0>SXj03/k>`0j>SX0>3Ph03De=@0f=SH0<c<c034a<@0^;Rh0;2`/02XZ
:P0X:2P09RHV00809BDU00l092@T024Q8@0Q8B40820P01lO7`0P82007QhN01`L700K6a/06QXJ01TI
6@0H61P05QHF01PH600J6QX00`0E5AD0100C4a<04Q8B018B4P0B4Q8200l?3`803@d=00D0410@00/;
2`0<30`02`/;00d=3@0300P8200700T92@061PH01PH600T92@0820P01PH600@4100300H61P801@D5
0P0410@00`051@D00`<300D51@0200<30`0300@410051@D0dLfY00<0dLfY00030=7=Z@800`<300D0
1@D500<30`0410@010@400L71`0200H61P8010@400D01@D500@4100820P020P800H61P0200T92@08
00P8200:2PX02PX:00`<300;2`/02PX:00d=3@0B4Q82010@4005018B4P0E5AD05QHF01DE5@0G5aL0
0P0K6a/03P0O7al0820P028R8P0S8b<09RHV02TY:@0Z:RX0;Rh^030`<00c<c<0=CDe03Ph>00f=SH0
=cLg0P0j>SX0100i>CT0>c/k03`l?00k>c/203Xj>P<0?3`l01X0@41003dm?@0n?Sh0@4100451@@12
@T80@D510492@P11@D40@41003`l?00k>c/0?Cdm03Ti>@0h>3P0=3@d034a<@0];Bd0:b/[02d];@0Y
:BT0:2PX02LW9`0U9BD08b<S02DU9@808B4Q00X0820P01hN7P0N7Qh06a/K01dM7@0K6a/071`L01TI
6@0J6QX06a/K0P0H61P201LG5`0401@D500B4Q804Q8B014A4@803`l?00d0410@00d=3@0>3Ph030`<
00T92@0;2`/02PX:00T92@061PH02@T900P820071`L020P800<01PH600P01`L700D51@0410@01PH6
00D51@0410@01PH600820P800`<300<00@4100<30`030`<0103AcJT000<0dLfY00@01@D500@41004
10@01PH60P0410@02P071`L010@400H61P0410@01@D500L71`0820P02@T900L71`092@T200P82007
00`<30092@T030`<00`<300=3@d03Ph>00d=3@02010@400@014A4@0C4a<05ADE01HF5P0G5aL06ATI
01`L700K6a/07alO028R8P0T92@09bLW02TY:@0/;2`0<C4a03@d=080=cLg0P0k>c/203hn?P0503lo
?`13@d<0@T920451@@12@T800P13@d<01@14A4@0AdM704=3@`15ADD0A4A40080ADE50P16ATH03@19
BDT0B4Q804Q8B019BDT0ATI604E5A@11@D40@41003lo?`0k>c/0>SXj03Lg=`0d=3@00P0b<S801`0^
;Rh0;2`/02/[:`0Z:RX09RHV02LW9`0U9BD00P0R8R82024Q8@08020P800O7al07QhN01lO7`0L71`0
6a/K01XJ6P0K6a/201TI6@0401HF5P0E5AD05ADE01@D50804A4A00P04Q8B014A4@0=3@d03`l?00`<
300:2PX02`/;00X:2P<02@T910071`L200H61P0500@410051@D01PH600H61P051@D00P030`<00`05
1@D01`L700<30`0300<30`@0dLfY00030=7=Z@0=00@410020P800P8200D51@061PH01`L700<30`04
10@01@D500L71`030`<01`L700H61P0200L71`0800P820071`L02`/;00X:2P0=3@d02`/;00d=3@0<
30`2010@40804A4A01D04Q8B01LG5`0G5aL05ADE01PH600J6QX071`L020P800Q8B409bLW02HV9P0Y
:BT0<30`02l_;`0d=3@0>CTi03dm?@10@400?clo04A4A015ADD00P17AdL01@19BDT0BTY:04Q8B01;
Bd/0B4Q80080BDU90100Bd];04Y:BP1<C4`0CDe=051@D01=CDd0CTi>04m?C`1=CDd0D51@04e=C@1@
D500Cdm?04Y:BP18B4P0AdM70P12@T801`0l?3`0>c/k03Ti>@0g=cL0<c<c038b<P0d=3@00P0_;bl0
1@0];Bd0:b/[02TY:@0W9bL09BDU008092@T00d08b<S028R8P0Q8B408R8R020P800M7Ad07alO01`L
700K6a/06QXJ01/K6`0J6QX05QHF00805ADE00L061PH018B4P0B4Q803`l?018B4P0?3`l03Ph>0080
30`<0P0;2`/00`092@T02PX:00L71`0200L71`0500H61P071`L01@D500@410071`L00P0410@02005
1@D00`<300D51@061PH010@400<30`0410@01@D5103AcJT000<0dLfY00@01@D500<30`051@D01PH6
0P0410@010030`<01PH600@4100410@300H61P0400P820061PH02PX:00X:2P802`/;00L03@d=00h>
3P0?3`l03`l?010@400A4A404Q8B00<05ADE0P0I6AT05P0J6QX07AdM01lO7`0S8b<092@T02PX:00Y
:BT0;Rh^034a<@0e=CD0>CTi03lo?`13@d<0A4A404M7A`1=CDd0C4a<051@D01=CDd0D51@059BDP1D
E5@205=CD`0705ADE01BDU80EEEE05ADE01CDe<0E5AD05EEE@0305IFEP0=05YJFP1FEUH0F5QH05MG
E`1EEED0DU9B055AD@1=CDd0C4a<04U9B@14A4@0@D510410@00203/k>`0303Ti>@0f=SH0=3@d0080
<C4a00d0;Rh^02l_;`0/;2`0:BTY02d];@0W9bL0:2PX02HV9P0U9BD092@T02<S8`0U9BD08B4Q0080
7alO00P071`L01dM7@0N7Qh06ATI01LG5`0J6QX05ADE01<C4`804Q8B00<04A4A00l?3`0<30`00P0<
30`200/;2`0600T92@0:2PX020P800P820092@T020P80P061PH200D51@0400H61P051@D00P8200L7
1`8010@400@01PH600@410030`<010@4103AcJT000<0dLfY0P0410@020030`<01@D500D51@0410@0
1PH600D51@0410@01@D50P061PH00`0820P01PH600P8200300T92@<03@d=00X03Ph>014A4@0A4A40
51@D01DE5@0F5QH05ADE01LG5`0H61P071`L0P0M7Ad05@0P820092@T02LW9`0[:b/0;2`/034a<@0e
=CD0>3Ph03`l?011@D40B4Q804Y:BP1=CDd0D51@059BDP1ADE40DU9B05ADE01FEUH0EEEE05IFEP02
05QHF00:05]KF`1IFET0F5QH05QHF01KFe/0FEUI05aLG01IFET0Fe]K05aLG080GUiN0180HF5Q05]K
F`1FEUH0EEEE059BDP1@D500BTY:04E5A@13@d<0@D5103dm?@0l?3`0>CTi03Xj>P0e=CD0=3@d038b
<P0_;bl202h^;P<0:b/[00D0:BTY02LW9`0W9bL0:BTY02@T900302<S8`0301lO7`0N7Qh07alO0080
7AdM0P0I6AT0100G5aL05ADE01DE5@0B4Q82010@4009014A4@0=3@d030`<00h>3P0:2PX02`/;00T9
2@0820P02PX:008020P800h01PH600D51@051@D01`L700H61P030`<010@400D51@061PH010@400H6
1P051@D010@400D51@@0dLfY00030=7=Z@0;00D51@0410@010@400820P051@D010@400D51@071`L0
10@400H61P071`L00P0820P02@071`L020P800T92@0820P02@T900`<300=3@d03`l?010@4002018B
4P0I01DE5@0F5QH05QHF01LG5`0H61P06ATI01dM7@0N7Qh07alO02@T900V9RH0;2`/02l_;`0b<S80
<c<c03Ph>00k>c/0@T9204];B`1@D500De=C05IFEP1HF5P0G5aL05]KF`0205mOG`0305iNGP1OGel0
GemO0080GemO00D0H61P065QH@1RHV80HV9R061PH00306=SH`0<06IVIP1WIfL0IfMW06UYJ@1WIfL0
Hf=S069RHP1NGUh0FUYJ05MGE`1CDe<0CTi>0P1;Bd/204=3@`0903lo?`0m?Cd0>SXj03Xj>P0g=cL0
=3@d038b<P0c<c<0<C4a0080;bl_00@0<C4a02d];@0^;Rh0;2`/0P0Z:RX0100Y:BT09BDU02DU9@0T
92@2024Q8@0<020P800M7Ad06QXJ01XJ6P0G5aL05QHF01DE5@0C4a<03`l?01<C4`0=3@d02`/;0`0<
30`00`092@T020P800T92@0200P820801`L700<01PH600D51@051@D00P061PH200D51@0500@41006
1PH01PH600<30`0410@0103AcJT000<0dLfY0P051@D030030`<01PH600L71`0410@01PH600@41007
1`L010@400H61P0820P01PH600h>3P<02@T902802PX:00d=3@0=3@d03`l?014A4@0D51@04a<C01@D
500I6AT05aLG01TI6@0K6a/07QhN020P800O7al08b<S02HV9P0Y:BT0;Bd]034a<@0d=3@0>CTi03hn
?P14A4@0BDU9059BDP1IFET0Fe]K05iNGP1RHV80IFEU06QXJ01ZJVX0JFUY0P1ZJVX00`1YJFT0JVYZ
06][J`0206YZJP80K6a/0P1[Jf/0301]KFd0L71`075aL@1bLW80M7Ad07MgM`1fMWH0LG5a06e]K@1Y
JFT0I6AT05mOG`80FEUI00P0DE5A04e=C@1:BTX0ATI604E5A@12@T80?clo03`l?080>SXj00L0>3Ph
03Lg=`0f=SH0=SHf03<c<`0b<S80=3@d0080<30`00/0;bl_02`/;00[:b/0:RXZ02TY:@0X:2P09bLW
02@T900R8R808B4Q01hN7P0201`L700401TI6@0F5QH05ADE014A4@80410@00D03`l?00h>3P0<30`0
2@T900`<300200X:2P0400H61P092@T01`L700L71`@01@D500<01PH600D51@030`<010030`<00`06
1PH0dLfY0=7=Z@020=7=Z@000`3AcJT0400410@00`<300<30`020P801@D500@410051@D01`L700D5
1@071`L020P800H61P0820P01`L700T92@0:2PX200`<30803@d=00H04A4A010@400C4a<04a<C01LG
5`0I6AT201XJ6P0D01hN7P0L71`07AdM024Q8@0U9BD09bLW02/[:`0];Bd0=CDe03Lg=`0k>c/0@D51
04U9B@1ADE40FUYJ061PH01RHV80JFUY06e]K@1_Kfl207=cL`0407EeM@1fMWH0MGEe07AdM080MWIf
00@0MGEe07IfMP1eMGD0Lg=c0P1eMGD06@1gMgL0Ng]k0820P01nOWh0Ogmo0861P@1oOgl0Ng]k07Qh
N01bLW80KFe]06MWI`1SHf<0GUiN05UIF@1EEED0CTi>04];B`1<C4`0AdM704A4A013@d<0?clo03hn
?P0k>c/00P0l?3`0100k>c/0>SXj03Ph>00h>3P203Hf=P80=CDe00X0<S8b030`<00^;Rh0:b/[02h^
;P0];Bd09BDU02@T900Q8B407AdM0P0K6a/00`0H61P06ATI018B4P02018B4P06010@400>3Ph03@d=
00d=3@0<30`02`/;0P092@T200P8200300H61P051@D01PH600H01@D500@00`<300L71`061PH01@D5
103AcJT000<0dLfY00D00`<300@410051@D01@D500@4100200H61P0:00@410061PH01`L700X:2P07
1`L02PX:00L71`092@T02PX:00/;2`<03@d=00D03`l?014A4@0D51@05QHF01TI6@0301dM7@807QhN
01L08B4Q028R8P0V9RH0:b/[02h^;P0e=CD0=SHf03Ti>@0n?Sh0B4Q8055AD@1HF5P0Hf=S06IVIP1Z
JVX0M7Ad07IfMP1jNWX0OWin08:2PP24Q8@0P82008B4Q00507moO`070861P@1oOgl0Ogmo07inOP24
Q8@0Ph>308J6QP0308Z:RP0>08N7Q`25QHD0Ph>307YjNP1hN7P0LG5a06YZJP1UIFD0GEeM05]KF`1G
EeL0De=C04m?C`1<C4`204Q8B00504M7A`14A4@0@D510492@P11@D400P10@40203lo?`0>03dm?@0o
?cl0>CTi03Ti>@0g=cL0>3Ph03<c<`0a<C40<S8b02l_;`0Z:RX09bLW02@T900R8R8201hN7P0B01`L
700I6AT061PH01@D500B4Q80410@00l?3`0>3Ph02`/;00X:2P0;2`/02PX:00P820092@T02PX:00P8
20061PH01@D50P0410@00`051@D01`L700@4100200D51@0300@410061PH01@D500@0dLfY00030=7=
Z@8010@400D01@D500@4100820P01`L700P8200200H61P0400D51@061PH02@T900P820802@T900<0
2`/;00T92@0:2PX00P0<30`01P0?3`l04Q8B01<C4`0D51@05aLG01/K6`807alO01`0820P02DU9@0S
8b<092@T02PX:00];Bd0<C4a03@d=00j>SX0>c/k04=3@`19BDT0DU9B061PH01VIVH0L71`079bLP1h
N7P0P82008F5Q@29RHT0Shn?092@T02ATI40SXj>08f=S@2;Rh/0SHf=0`2:RXX07@2>SXh0RXZ:08^;
R`2=SHd0SXj>096AT@2CTi<0V9RH09>CT`2@T900SHf=08^;R`23Ph<0P82007UiN@1cLg<0KFe]06IV
IP1QHF40FUYJ05QHF01DE5@0De=C059BDP1>CTh0C4a<04];B`18B4P0C4a<00<0AdM700D0ADE504A4
A014A4@0A4A40410@00203lo?`0C03dm?@0j>SX0=SHf03Lg=`0a<C40;Rh^02l_;`0Y:BT09BDU024Q
8@0O7al071`L01XJ6P0G5aL04a<C018B4P0C4a<03`l?018B4P0300/;2`0600X:2P092@T020P800T9
2@051@D020P80`071`L300D51@801PH60P0410@00`051@D0dLfY0=7=Z@020=7=Z@000`3AcJT01P03
0`<020P800@410030`<01PH600D51@8010@40P071`L030061PH02@T900H61P0:2PX020P800X:2P0=
3@d02`/;00h>3P0=3@d0410@014A4@805ADE02405aLG01/K6`0O7al0820P028R8P0T92@09BDU02HV
9P0Y:BT0;Bd]03@d=00f=SH0?Cdm03lo?`15ADD0C4a<05=CD`1MGEd0JVYZ07=cL`1fMWH0OWin08R8
R02>SXh0U9BD09ZJVP2LW9`0Vi^K09jNWP2MWId0VIVI09^KV`2HV9P00P2EUID01P2DU9@0UIFE09RH
V02EUID0VYZJ09^KV`80WYjN0P2KVi/0302EUID0TY:B08^;R`29RHT0P82007]kN`1bLW80K6a/06UY
J@1SHf<0HV9R05eMG@80FEUI00h0EUIF05=CD`1BDU80Cdm?051@D01ADE40CTi>051@D01>CTh0Cdm?
04];B`1<C4`0BTY:04I6AP80@d=301<0@T9203hn?P0l?3`0>SXj03De=@0_;bl0;Rh^02HV9P0T92@0
8B4Q01lO7`0K6a/05aLG01HF5P0D51@04a<C014A4@0@41004A4A00803@d=00D030`<00/;2`092@T0
2PX:00L71`0300P8200300H61P051@D01PH600<01PH600<00`<300H61P051@D0103AcJT000<0dLfY
0P051@D010061PH01@D500D51@051@D300H61P0500D51@061PH01PH600P820092@T00P0;2`/00`0=
3@d02`/;00d=3@0200l?3`07010@400C4a<05ADE01DE5@0H61P07AdM020P800302DU9@0G02PX:00Z
:RX0;Bd]034a<@0i>CT0?Shn03lo?`17AdL0CTi>05EEE@1RHV80JFUY07EeM@1kNg/0Ph>308j>SP2E
UID0X:2P0:BTY02XZ:P0YjNW0:VYZ@2ZZZX00P2VYZH02P2SXj<0Y:BT0::RXP2QXJ40X:2P0:6QX@2P
X:00XZ:R0:BTY02UYJD20:>SX`0@0:2PX02MWId0V9RH096AT@2?Shl0R8R80861P@1hN7P0LW9b071`
L01[Jf/0J6QX06IVIP1QHF40GEeM05]KF`80FUYJ00h0FEUI05QHF01FEUH0EeMG05EEE@1FEUH0E5AD
05=CD`1BDU80DE5A04i>CP1<C4`0Bd];04Q8B080@T9200T0@41003Ph>00c<c<0<C4a02`/;00W9bL0
8b<S020P800O7al00P0J6QX0300E5AD04A4A018B4P0?3`l03Ph>00d=3@0;2`/03@d=00X:2P092@T0
20P800T92@<01`L700D01PH600L71`061PH01@D500<30`0200D51@800`<3103AcJT000<0dLfY0P04
10@200H61P801@D501P020P800@410061PH020P800H61P092@T020P800T92@0820P02`/;00X:2P0<
30`03`l?00h>3P0B4Q8051@D01DE5@0D51@05QHF01/K6`0M7Ad08B4Q028R8P0V9RH202XZ:P0D02h^
;P0`<300=CDe03Xj>P0o?cl0@d=304U9B@1@D500F5QH065QH@1[Jf/0N7Qh07inOP2;Rh/0Ti>C09fM
W@2UYJD0[jn_0;2`/02b/[820;Jf]P050;>c/`2a/K40[jn_0:f][@2^[Zh00P2ZZZX20:^[Z`0N0:b/
[02][Jd0[jn_0:j^[P2/[:`0[Jf]0:NWY`2RXZ80W9bL09ZJVP2@T900R8R808B4Q01iNGT0MgMg075a
L@1`L700Jf][06QXJ01WIfL0IFEU06ATI01RHV80Hf=S069RHP1OGel0HF5Q05mOG`1NGUh0GEeM0P1L
G5`205YJFP0<05IFEP1CDe<0DE5A04e=C@1:BTX0ADE50492@P0j>SX0=3@d02d];@0Y:BT0:2PX0P0R
8R80100M7Ad061PH01PH600F5QH2018B4P0300l?3`0<30`030`<008030`<00T02@T900L71`0820P0
2@T900P8200:2PX01PH600P820051@D00P071`L010030`<02@T900H61P051@D40=7=Z@000`3AcJT0
0`0410@01@D500<30`0300D51@0:00H61P0820P020P800P820071`L01PH600P8200:2PX03@d=00T9
2@803Ph>00<03@d=00l?3`0A4A400P0C4a<07@0E5AD05aLG01`L700M7Ad092@T02<S8`0W9bL0:2PX
02XZ:P0`<300<C4a03De=@0i>CT0@T9204E5A@19BDT0D51@05MGE`1QHF40K6a/07QhN01oOgl0S8b<
09JFUP2PX:00ZZZZ0:j^[P2f][H0]KFe0080^KVi00P0_Kfm0;Ng]`2e]KD0/k>c0;6a/@2_[jl0/k>c
0:n_[`80/K6a0100/k>c0;Bd]02a/K40/[:b0:j^[P2ZZZX0ZJVY0:6QX@2LW9`0Ti>C08^;R`25QHD0
P82007alO01gMgL0LW9b0P1_Kfl01P1XJ6P0Jf][06IVIP1XJ6P0IFEU06MWI`80Hf=S0`1RHV82065Q
H@0?05mOG`1MGEd0FEUI05QHF01FEUH0DE5A05=CD`1:BTX0ADE503/k>`0f=SH0;Rh^02`/;00Y:BT0
9BDU0080820P00D06ATI01LG5`0C4a<05ADE014A4@0200l?3`0500`<30092@T02@T900T92@0:2PX0
0P071`L01P0820P01PH600H61P061PH01`L700H61P801@D500<010@400H61P051@D0103AcJT000<0
dLfY0`051@D010061PH010@400H61P0820P300H61P0500X:2P092@T01`L700P8200:2PX00`0;2`/0
100=3@d03Ph>00l?3`0C4a<201@D500501TI6@0K6a/06a/K01hN7P0Q8B400P0X:2P0700^;Rh0;bl_
03@d=00f=SH0>c/k04=3@`12@T80C4a<059BDP1IFET0HV9R06e]K@1jNWX0PH6108n?S`2LW9`0Y:BT
0:f][@2c/k<0^k^k0;fm_@2o_kl0`l?30<G5a@34a<@0_kno0;bl_02o_kl20;^k^`030;Vi^@2k^k/0
^k^k0080_;bl01<0^k^k0;bl_02h^;P0];Bd0:n_[`2VYZH0YJFU09bLW02DU9@0Shn?08R8R021PH40
OWin07alO01jNWX0MWIf07=cL`1aLG40L71`00D0KVi^0P1_Kfl05P1`L700KFe]06a/K01/K6`0IVIV
06ATI01PH600GUiN05aLG01KFe/0DU9B04Q8B012@T80>3Ph03@d=00_;bl0:BTY02DU9@0R8R8071`L
01XJ6P0G5aL201@D5006014A4@0>3Ph03@d=00`<300;2`/02PX:0P092@T00`071`L020P800T92@02
00H61P0800D51@071`L00`<300D51@061PH01@D500H61P0410@40=7=Z@000`3AcJT00`0410@00`<3
00D51@0200D51@0300H61P051@D010@400<01@D50`0820P00`092@T02PX:00/;2`0300l?3`804Q8B
01`051@D01<C4`0F5QH06QXJ01`L700N7Qh08R8R02@T900Z:RX0;2`/030`<00d=3@0>CTi03hn?P10
@400ADE504e=C@1DE5@0Fe]K06=SH`1]KFd0NWYj0861P@2=SHd0W9bL0:NWY`2`/;00]kNg0P2o_kl0
0`37alL0bl_;0<c<c0020<c<c080bLW900H0b<S80<C4a034a<@0`l?30<O7a`38b<P20<K6aP0A0<?3
``31`L40_Kfm0;Vi^@2`/;00[:b/0:JVYP2MWId0UYJF08n?S`2:RXX0QhN708>3P`22PX80Ogmo07al
O01mOGd0101iNGT06P1hN7P0MgMg07UiN@1iNGT0MgMg07alO01hN7P0MWIf07AdM01^KVh0JVYZ06QX
J01TI6@0Hf=S05]KF`1ADE40ATI603dm?@0e=CD0<30`02`/;00Y:BT08R8R020P800L71`05aLG0P0E
5AD01`0C4a<0410@00l?3`0<30`03Ph>00d=3@0:2PX00`092@T300L71`801PH600H020P800@41004
10@010@400<30`061PH40=7=Z@000`3AcJT020051@D01`L700H61P0410@01@D500P820051@D01PH6
0`051@D300P8200700X:2P092@T030`<00`<300?3`l04A4A010@400201<C4`0R01HF5P0I6AT06ATI
01dM7@0N7Qh08R8R02DU9@0V9RH0;Bd]034a<@0f=SH0>SXj03dm?@14A4@0ATI604e=C@1DE5@0Fe]K
06IVIP1_Kfl0NWYj07moO`2?Shl0WinO0:RXZ02c/k<0^k^k0<71`@33`l<0bLW90=7Ad@3Bd]80e=CD
0=GEe@80e=CD0P3>c/h04P3=cLd0c<c<0<g=c@3>c/h0dM7A0<k>cP3=cLd0bLW90<C4a030`<00_Kfm
0;Jf]P2^[Zh0YjNW09fMW@2IVIT0Ti>C08j>SP80RXZ:00<0QhN708F5Q@25QHD00P23Ph<08`22PX80
Ph>30861P@22PX80Q8B408J6QP24Q8@0Ph>308B4Q021PH40OWin07alO01bLW80LG5a06YZJP1WIfL0
H61P05ADE01=CDd0@d=303Xj>P0`<300;bl_02LW9`0U9BD08B4Q01hN7P0H61P05ADE01@D500A4A40
3`l?00h>3P0=3@d03Ph>00802PX:00P020P800T92@071`L01PH600T92@0820P01PH600L71`<01@D5
00<00`<300@410071`L0103AcJT000<0dLfY0`051@D020071`L010@400D51@051@D01PH600D51@07
1`L01@D50`0820P200T92@1800X:2P0<30`03`l?00h>3P0?3`l04A4A01DE5@0D51@05aLG01XJ6P0K
6a/07QhN020P800V9RH09BDU02d];@0b<S80=SHf03/k>`10@400ADE504Q8B01>CTh0E5AD05]KF`1T
I6@0KVi^07YjNP1lO7`0Rh^;09VIV@2WYjL0/k>c0;fm_@33`l<0bLW90<k>cP3Cdm<0emOG0=SHf03L
g=`0g]kN0=gMg@3IfMT0emOG0=GEe@3Fe]H0eMGE0=SHf03Fe]H0emOG0=GEe@3Bd]80c<c<0<W9b@31
`L40_kno0;Rh^02^[Zh0YjNW0:2PX02LW9`0VIVI09FEU@2DU9@0T92@08j>SP2=SHd0Shn?08b<S02?
Shl0SHf=0P2>SXh2096AT@0G09>CT`2>SXh0S8b<08V9R@27QhL0Ogmo07]kN`1dM7@0KVi^06UYJ@1P
H600F5QH04U9B@13@d<0>CTi038b<P0`<3009bLW02DU9@0O7al07QhN01TI6@0F5QH00P0D51@02@0@
41004A4A00d=3@0<30`03@d=00`<300:2PX02@T900/;2`0200L71`801PH600L01`L700H61P0410@0
10@400D51@030`<01@D500@0dLfY00030=7=Z@<01@D500D010@400H61P061PH01@D500H61P0400L7
1`0600P8200:2PX030`<00/;2`0:2PX02`/;0P0=3@d01`0C4a<04A4A01DE5@0C4a<06ATI01/K6`0J
6QX00P0P8200700S8b<09BDU02/[:`0^;Rh0=SHf03`l?012@T80ATI604Q8B01>CTh0E5AD05eMG@1S
Hf<0KFe]07QhN01nOWh0R8R809NGU`2RXZ80/[:b0;^k^`35aLD0b/[:0<k>cP3Fe]H0fm_K0=kNgP3Q
hN420>;RhP80hN7Q01@0gmoO0=gMg@3QhN40g=cL0=gMg@3Kfm/0f][J0=SHf03Bd]80clo?0<S8b035
aLD0_[jn0;Jf]P2d];@0Z:RX0:JVYP2QXJ40WYjN09bLW080Vi^K01l0W9bL09RHV02IVIT0WIfM09bL
W02NWYh0WIfM09ZJVP2MWId0VIVI09FEU@2CTi<0TI6A08V9R@23Ph<0Ng]k07EeM@1/K6`0IfMW05eM
G@1CDe<0BTY:0492@P0j>SX0<S8b02h^;P0X:2P09BDU02<S8`0L71`06QXJ00805QHF00<051@D014A
4@0>3Ph00P0>3Ph200`<300:00T92@0;2`/020P800H61P0820P01@D500H61P0820P01@D500@41080
1@D500<01PH600D51@3AcJT00`3AcJT000<0dLfY00D020P800H61P061PH01PH600@4100200L71`05
00H61P071`L01`L700H61P071`L00P0820P01@0:2PX02@T900X:2P0;2`/03@d=00803Ph>00D04a<C
01@D500D51@05QHF01PH600201hN7P0l028R8P0U9BD08b<S02XZ:P0_;bl0=3@d03Xj>P11@D40A4A4
04I6AP1<C4`0DU9B05]KF`1RHV80KVi^07MgM`1kNg/0RHV909>CT`2NWYh0[Jf]0;bl_034a<@0b<S8
0=;BdP3GemL0gMgM0>;RhP3Vi^H0inOW0>[ZjP3Xj>P0jNWY0>OWi`3Vi^H0hn?S0>CTi03UiND0i>CT
0>3Ph03Kfm/0fMWI0=GEe@3>c/h0bl_;0<G5a@30`<00^KVi0;>c/`2][Jd0ZZZZ0:JVYP2XZ:P0YZJV
0:BTY02RXZ80YjNW0:RXZ02UYJD0YjNW0P2XZ:P20:FUY@0O0::RXP2KVi/0UiNG09:BTP2<S8`0QHF5
07inOP1dM7@0KVi^06MWI`1MGEd0DE5A04];B`10@400>3Ph03<c<`0^;Rh0:RXZ02HV9P0O7al07AdM
01PH600E5AD05QHF01DE5@0A4A403`l?00h>3P0<30`02`/;00`<300200X:2P0500L71`092@T01PH6
00H61P071`L00P051@D200H61P0300D51@0410@01@D500@0dLfY00030=7=Z@0300D51@0410@01@D5
00<01PH600@01`L700D51@0820P020P80P071`L0100820P02PX:00T92@0:2PX200/;2`0;00l?3`0>
3Ph04A4A014A4@0C4a<051@D01LG5`0H61P06QXJ01dM7@0R8R800P0V9RH08P0W9bL0;2`/034a<@0i
>CT0@41004A4A017AdL0CDe=059BDP1HF5P0HF5Q06YZJP1dM7@0NWYj08:2PP2>SXh0VYZJ0:NWY`2h
^;P0`<300<W9b@3AdM40fMWI0=gMg@3Shn<0iNGU0>_[j`3]kNd0kno_0>k^kP3]kNd0k>c/0>SXj03[
jn/30>SXj080h>3P02h0fMWI0=?Cd`3AdM40bl_;0<S8b030`<00_;bl0;Jf]P2c/k<0[jn_0;>c/`2b
/[80[Zj^0;6a/@2c/k<0/K6a0;:b/P2c/k<0[jn_0;2`/02/[:`0YjNW0::RXP2LW9`0VIVI09>CT`2?
Shl0QXJ607inOP1eMGD0J6QX06=SH`1GEeL0CDe=04Q8B010@400>3Ph03<c<`0];Bd0:2PX02DU9@0P
82007alO01PH600F5QH05ADE0P0B4Q801`0?3`l030`<00d=3@0<30`02`/;00X:2P0820P00P0:2PX3
00L71`801@D500D010@400D51@051@D010@400L71`040=7=Z@000`3AcJT02`061PH010@400D51@07
1`L01PH600D51@061PH01@D500H61P051@D02@T900801`L704002@T900P8200<30`02PX:00d=3@0?
3`l03Ph>010@400C4a<04Q8B01@D500E5AD061PH01/K6`0L71`08B4Q02@T900S8b<0:RXZ02h^;P0`
<300>SXj03dm?@15ADD0AdM704e=C@1GEeL0FEUI065QH@1ZJVX0M7Ad07MgM`24Q8@0Rh^;09VIV@2R
XZ80[Jf]0;fm_@33`l<0cLg=0=KFeP3Lg=`0h^;R0>KViP3Zj^X0kNg]0?3`l03clo<0m?Cd0?;blP3_
knl0kNg]0>c/k03Zj^X0k>c/0>OWi`3Shn<0gmoO0=SHf03GemL0dM7A0<g=c@37alL0`/;20P2n_[h0
1P2k^k/0_;bl0;^k^`2o_kl0^[Zj0;no_`<0^[Zj01L0^KVi0;>c/`2`/;00ZZZZ0:BTY02MWId0Vi^K
09BDU02=SHd0QHF507]kN`1_Kfl0I6AT061PH01DE5@0Bd];04E5A@0o?cl0=cLg034a<@0^;Rh0:BTY
02PX:00201hN7P0401/K6`0E5AD05QHF01<C4`<0410@00X030`<00X:2P0;2`/03@d=00X:2P071`L0
2@T900D51@061PH01@D50P061PH01@051@D010@400@410051@D01`L700@0dLfY00030=7=Z@0300D5
1@0:2PX020P800801PH600<01@D500H61P061PH00P061PH00`071`L02@T900P8200200T92@0>00/;
2`092@T030`<00h>3P0<30`03`l?018B4P0E5AD04a<C01HF5P0J6QX06ATI01dM7@0P820202@T900J
02XZ:P0/;2`0<C4a03Hf=P0l?3`0@d=304A4A01>CTh0EUIF05UIF@1QHF40JFUY07=cL`1dM7@0P820
08Z:RP2BTY80WYjN0:b/[02l_;`0`/;20<[:bP3EeMD0gMgM0>7Qh@3Xj>P20>_[j`050??cl`3bl_80
m_Kf0?Gem@3dm?@00P3_knl0303^k^h0k>c/0>WYj@3WinL0i>CT0=oOg`3Kfm/0e=CD0=7Ad@3;bl/0
b<S80<?3``80`L7100@0`/;20<30`034a<@0`L710P30`<001`2m_Kd0_;bl0;^k^`2f][H0/K6a0:^[
Z`2TY:@00P2MWId0:P2EUID0S8b<08>3P`1kNg/0Kfm_06EUI@1OGel0EEEE04Y:BP13@d<0?Shn03Hf
=P0a<C40;bl_02TY:@0S8b<0820P01dM7@0J6QX061PH01DE5@0D51@0410@00d=3@0@410030`<00d=
3@092@T03@d=00T92@0820P02@T900L71`061PH01`L700H61P071`L01PH600@410061PH01`L700D5
1@@0dLfY00030=7=Z@0A00L71`051@D01PH600@410061PH01`L700@410071`L01PH600X:2P071`L0
20P800T92@0:2PX02@T900d=3@0:2PX00P0<30`00`0>3Ph0410@00l?3`0201<C4`0T01@D500I6AT0
6QXJ01dM7@0O7al092@T02HV9P0Z:RX0:b/[030`<00d=3@0>c/k0410@015ADD0Bd];059BDP1KFe/0
HV9R06IVIP1aLG40MGEe07alO027QhL0Shn?09bLW02XZ:P0/k>c0;Zj^P35aLD0dm?C0=_Kf`3Rh^80
inOW0>[ZjP3_knl0lo?c0P3fm_H0103moOd0moOg0?Gem@3fm_H20?7al@030>o_k`3]kNd0j>SX0080
i>CT0340gMgM0=WIf@3De=@0d=3@0<c<c03=cLd0c/k>0<_;b`3<c<`0b/[:0<W9b@37alL0a/K60<?3
``30`<00_[jn0;Vi^@2c/k<0Zj^[0:FUY@2NWYh0VIVI092@T029RHT0P82007=cL`1YJFT0HV9R05YJ
FP1ADE40BDU904A4A00m?Cd0=3@d02h^;P0];Bd09BDU02@T900P82006a/K01XJ6P0H61P04a<C014A
4@0@41003Ph>00l?3`0;2`/030`<00802PX:00<02@T900P8200820P00`071`L01`0820P01@D500/;
2`0410@01@D500<30`051@D0103AcJT000<0dLfY00L01@D500L71`061PH010@400D51@061PH010@4
00801`L703D01PH600T92@071`L01`L700X:2P092@T02`/;00d=3@0>3Ph03@d=010@400A4A40410@
014A4@0D51@05QHF01PH600M7Ad071`L01lO7`0S8b<09BDU02PX:00];Bd0<30`03De=@0i>CT0?clo
04=3@`1:BTX0DE5A05QHF01NGUh0J6QX06a/K01cLg<0O7al08>3P`2=SHd0VIVI0:>SX`2/[:`0/[:b
0;fm_@3=cLd0f=SH0=gMg@3WinL0jn_[0>k^kP3alO40m_Kf0?Win@020?[jnP0f0?Win@3gmoL0n?Sh
0?Cdm03emOD0lO7a0>g]k@3[jn/0inOW0>?Sh`3QhN40fm_K0=[JfP3IfMT0emOG0=GEe@3De=@0d];B
0<k>cP3=cLd0bl_;0<S8b035aLD0`L710;no_`2i^KT0/k>c0:f][@2RXZ80VIVI09FEU@2;Rh/0PX:2
07MgM`1]KFd0IFEU05aLG01EEED0Cdm?04I6AP11@D40>c/k03<c<`0];Bd0:b/[02LW9`0R8R807alO
01/K6`0I6AT05ADE01HF5P0A4A403`l?0P0>3Ph00`0=3@d02`/;00`<300400P8200:00H61P071`L0
20P800D51@071`L01@D500L71`061PH010@400D51@@0dLfY00030=7=Z@<01`L70P051@D01@071`L0
1@D500@410071`L01PH600801`L70P092@T0<@0<30`02`/;00`<300=3@d02`/;00l?3`0>3Ph0410@
01<C4`0B4Q805ADE01LG5`0K6a/071`L01hN7P0R8R8092@T02LW9`0];Bd0;bl_03@d=00i>CT0?Cdm
0451@@16ATH0Cdm?05MGE`1NGUh0I6AT06][J`1cLg<0NWYj08>3P`2:RXX0Ti>C09bLW02YZJT0[Zj^
0;Vi^@36a/H0clo?0=_Kf`3Rh^80j^[Z0>g]k@3clo<0m_Kf0?[jnP3kno/00P3moOd20?_kn`0[0?Og
m`3fm_H0lo?c0??cl`3_knl0kNg]0>[ZjP3UiND0i>CT0>;RhP3Shn<0gmoO0=cLg03IfMT0e]KF0=OG
e`3@d=00c<c<0<S8b036a/H0`L710;jn_P2g]kL0/;2`0:RXZ02MWId0UiNG08n?S`25QHD0Ng]k075a
L@1WIfL0GemO05EEE@1@D500Bd];04=3@`0n?Sh0>3Ph038b<P0/;2`0:RXZ02DU9@02020P800?01/K
6`0I6AT05ADE01DE5@0A4A405ADE00h>3P0=3@d0410@00`<300:2PX02@T900P820092@T020P80080
1`L700P01@D500H61P071`L01@D500H61P051@D01`L700D51@@0dLfY00030=7=Z@0300D51@071`L0
10@400801PH600<01@D500H61P071`L00P061PH00`092@T01`L700P8200200X:2P0500T92@0;2`/0
2`/;00d=3@0?3`l00P0@4100:`0B4Q8051@D01HF5P0G5aL06a/K01hN7P0P82008R8R02<S8`0W9bL0
;2`/030`<00c<c<0>3Ph03`l?010@400ADE504i>CP1DE5@0Fe]K06EUI@1/K6`0L71`07IfMP22PX80
QHF5096AT@2LW9`0Xj>S0:RXZ02a/K40`<300<g=c@3De=@0g]kN0>SXj03Zj^X0lO7a0?Gem@3hn?P0
o?cl0?knoP3moOd00P3lo?`0103jn_X0n?Sh0?KfmP3gmoL20?;blP030>o_k`3]kNd0jNWY0080inOW
00P0i^KV0>3Ph03Ogml0fm_K0=GEe@3Cdm<0clo?0<[:bP80`l?301/0^KVi0;>c/`2YZJT0XJ6Q09FE
U@2=SHd0R8R807inOP1fMWH0KVi^061PH01JFUX0De=C04m?C`19BDT0A4A403dm?@0g=cL0<S8b02`/
;00Z:RX09bLW02<S8`0P82006QXJ01LG5`0C4a<00P0B4Q8200l?3`803@d=00<02`/;00T92@0:2PX0
0P0820P01@092@T01`L700H61P061PH01@D500801`L700@020P800D51@0410@01`L7103AcJT000<0
dLfY00P00`<300D51@0410@01@D500H61P051@D010@400H61P8020P800H01`L700X:2P092@T02PX:
00P8200;2`/200`<300400d=3@0>3Ph03Ph>014A4@804a<C00<05ADE01TI6@0J6QX00P0N7Qh09`0Q
8B408b<S02HV9P0/;2`0;Rh^03<c<`0h>3P0?Shn0410@015ADD0CDe=05ADE01LG5`0Hf=S06a/K01^
KVh0MGEe07emO@24Q8@0Shn?09JFUP2RXZ80YJFU0:n_[`2g]kL0aLG50<o?c`3GemL0i>CT0>[ZjP3^
k^h0m_Kf0?Shn03kno/0oOgm0?clo03moOd0no_k0?clo0020?Win@050?Ogm`3fm_H0lo?c0?7al@3`
l?000P3^k^h07P3YjNT0j>SX0>CTi03QhN40g=cL0=OGe`3De=@0c<c<0<G5a@30`<00_[jn0;Fe]@2]
[Jd0Xj>S09JFUP2<S8`0QHF50820P01eMGD0KVi^06EUI@1NGUh0F5QH051@D01<C4`0ATI60410@00h
>3P0=3@d02h^;P80:2PX00D092@T01lO7`0L71`06ATI01LG5`0201@D500:018B4P0@4100410@00l?
3`0<30`02PX:00T92@0820P02PX:00T92@<01PH610051@D010061PH020P800D51@061PH40=7=Z@00
0`3AcJT01@092@T01`L700L71`051@D01PH600801`L700D020P800T92@092@T01PH600L71`0200T9
2@0400/;2`0:2PX030`<00d=3@8030`<02X03Ph>010@400E5AD04Q8B01DE5@0G5aL061PH01hN7P0P
82008B4Q02DU9@0W9bL0;2`/02d];@0d=3@0=cLg03dm?@10@400ADE504a<C01CDe<0G5aL069RHP1Z
JVX0Kfm_07EeM@1nOWh0R8R808f=S@2EUID0W9bL0:2PX02ZZZX0];Bd0;fm_@39bLT0dm?C0=oOg`3Q
hN40kNg]0?3`l03dm?@20?Win@030?_kn`3jn_X0n_[j0080nOWi00<0n?Sh0?Ogm`3gmoL00P3dm?@0
903emOD0k^k^0?3`l03[jn/0j>SX0>?Sh`3QhN40g=cL0=OGe`3@d=00b<S80<;2`P2l_;`0];Bd0:j^
[P2RXZ80V9RH096AT@25QHD0OGem07YjNP1aLG40K6a/061PH01JFUX0DU9B04i>CP1;Bd/0@D5103dm
?@0e=CD0<C4a02d];@0Y:BT09RHV028R8P807QhN00X05aLG01@D500E5AD04Q8B010@400A4A403`l?
00/;2`0?3`l02`/;0P0:2PX01`092@T020P800P8200820P01`L700P820092@T00P0820P010092@T0
1@D500H61P051@D40=7=Z@000`3AcJT01P051@D01PH600D51@051@D01`L700H61P801@D500@02@T9
00H61P0820P01`L70P0;2`/200T92@0600/;2`0<30`03`l?00h>3P0@41004A4A0P0B4Q8201HF5P1F
01/K6`0N7Qh0820P028R8P0U9BD09RHV02/[:`0_;bl0<S8b03Lg=`0o?cl0@D5104A4A01=CDd0D51@
05MGE`1QHF40Jf][06a/K01cLg<0OWin08:2PP2<S8`0Ti>C09jNWP2PX:00[:b/0;Jf]P2k^k/0`l?3
0<k>cP3Hf=P0fm_K0>KViP3[jn/0l?3`0?Ogm`3emOD0m_Kf0?Win@3kno/0m_Kf0?Shn03fm_H0n?Sh
0?Cdm03emOD0lo?c0?;blP3_knl0kNg]0>WYj@3Xj>P0hn?S0>;RhP3IfMT0e=CD0<_;b`34a<@0_;bl
0;>c/`2`/;00YZJV09bLW02CTi<0Rh^;07moO`1jNWX0MGEe06m_K`1TI6@0GEeM05MGE`1>CTh0BDU9
04E5A@0o?cl0>c/k03@d=00`<300;2`/02TY:@0T92@08b<S01dM7@0I6AT201HF5P0301<C4`0A4A40
410@00803Ph>00@030`<00/;2`0;2`/020P80P0:2PX01P092@T01`L700H61P061PH02@T900P82080
1PH60P071`L00`051@D00`<30=7=Z@030=7=Z@000`3AcJT01P051@D01PH600@4100410@01`L700@4
108020P800<01`L700D51@0820P00P092@T00`0820P02PX:00X:2P0200/;2`0]00d=3@0>3Ph03`l?
018B4P0C4a<06ATI01HF5P0G5aL06QXJ020P800N7Qh08b<S02@T900X:2P0:BTY02l_;`0c<c<0>SXj
03`l?014A4@0ATI604a<C01ADE40F5QH065QH@1VIVH0K6a/07=cL`1nOWh0QXJ608^;R`2DU9@0WYjN
0:2PX02[Zj/0[jn_0;Vi^@30`<00bLW90=;BdP3Kfm/0h^;R0>OWi`3_knl0l?3`00@0m?Cd00<0m_Kf
0?Ogm`3dm?@00P3emOD0<@3bl_80lo?c0?3`l03^k^h0k>c/0>[ZjP3Vi^H0h>3P0=kNgP3Fe]H0clo?
0<G5a@30`<00][Jf0:j^[P2XZ:P0XJ6Q09NGU`2;Rh/0PX:207alO01bLW80KVi^06YZJP1SHf<0F5QH
055AD@1;Bd/0A4A40451@@0j>SX0=SHf030`<00_;bl09bLW02DU9@0R8R807alO01`L700H61P05ADE
01HF5P0D51@04a<C00h>3P0?3`l030`<00d=3@0<30`00P0;2`/0100820P02@T900L71`0;2`/200H6
1P0300L71`061PH01PH600801`L70P0410@00`051@D0dLfY0=7=Z@020=7=Z@000`3AcJT03@0410@0
1`L700@410061PH020P800D51@0410@01`L700H61P071`L01PH600L71`0;2`/00P0820P02@0;2`/0
2PX:00/;2`0>3Ph03@d=00l?3`0C4a<05ADE01<C4`0201LG5`0Z01/K6`0L71`07alO02@T900S8b<0
9bLW02XZ:P0_;bl0<c<c03Ph>00o?cl0@D5104I6AP1=CDd0D51@05QHF01OGel0IVIV06i^KP1fMWH0
OWin08J6QP2=SHd0TY:B09^KV`2QXJ40ZZZZ0;6a/@2h^;P0_kno0<O7a`3AdM40e]KF0=kNgP3UiND0
k>c/0>g]k@3`l?00lO7a0?KfmP3clo<0m?Cd0P3clo<00`3dm?@0lo?c0?;blP020?7al@040>g]k@3[
jn/0jNWY0>3Ph080fm_K0200d];B0<c<c034a<@0_Kfm0;Bd]02ZZZX0YJFU09bLW02BTY80Rh^;08B4
Q01jNWX0LG5a06m_K`1VIVH0HV9R05MGE`1?Cdl0BTY:04=3@`10@400>c/k03Ph>00a<C40:b/[02LW
9`0U9BD08R8R024Q8@0P82006a/K01HF5P8051@D0P0A4A401P0?3`l03@d=00/;2`0;2`/02PX:00T9
2@8020P800T02PX:00T92@061PH01@D500H61P051@D010@400P820061PH00P051@D00`071`L0dLfY
0=7=Z@020=7=Z@000`3AcJT020051@D01PH600L71`0820P01PH600D51@0820P01@D50P061PH400T9
2@0300`<300:2PX030`<008030`<00H03Ph>018B4P0A4A405ADE01@D500G5aL201XJ6P0^020P800N
7Qh08B4Q02DU9@0Z:RX0:b/[03<c<`0f=SH0?3`l0410@011@D40B4Q804m?C`1CDe<0Fe]K061PH01X
J6P0JVYZ07MgM`1lO7`0QHF508f=S@2EUID0Vi^K0::RXP2YZJT0/;2`0;Zj^P32`/80alO70<o?c`3D
e=@0g=cL0>?Sh`3Xj>P0j^[Z0>c/k03`l?00kNg]0>o_k`3`l?00lO7a0?;blP3alO40kno_0?3`l080
kNg]02@0jNWY0>SXj03Rh^80g]kN0=SHf03Cdm<0c<c<0<G5a@2n_[h0^;Rh0:f][@2SXj<0X:2P09NG
U`2?Shl0QXJ60820P01fMWH0KVi^06YZJP1UIFD0GEeM05MGE`1<C4`0ATI603hn?P0l?3`0>3Ph03@d
=00_;bl0:BTY02PX:00R8R80820P01dM7@0J6QX201LG5`0?01HF5P0D51@0410@010@400>3Ph03@d=
00`<30092@T030`<00/;2`0820P02PX:00P820092@T01`L700801PH60P051@D01@061PH010@400D5
1@071`L01@D500@0dLfY00030=7=Z@0500@410061PH010@400@410061PH00P051@D010061PH020P8
00L71`061PH200P820802PX:00<02`/;00`<300;2`/00P0=3@d01@0>3Ph04A4A01<C4`0C4a<05ADE
00806a/K02807AdM01lO7`0U9BD09RHV02XZ:P0];Bd0<S8b03De=@0j>SX0@D5104=3@`18B4P0DE5A
05IFEP1MGEd0H61P06QXJ01]KFd0MWIf07moO`27QhL0Shn?09RHV02OWil0YJFU0:ZZZP2_[jl0][Jf
0;jn_P38b<P0clo?0=?Cd`3Jf]X0h>3P0`3Xj>P01P3[jn/0kNg]0>k^kP3`l?00kno_0>g]k@@0k>c/
02H0jn_[0>SXj03Xj>P0h>3P0=_Kf`3Cdm<0c<c<0<O7a`32`/80]kNg0;6a/@2WYjL0WIfM09ZJVP2F
UYH0RXZ:08>3P`1jNWX0M7Ad06][J`1UIFD0GUiN05IFEP1@D500C4a<04A4A00o?cl0?3`l03Lg=`0`
<300;Bd]02PX:00U9BD092@T020P800M7Ad06ATI01PH60805ADE00d0410@00l?3`0@41003Ph>00d=
3@0?3`l02`/;00X:2P092@T02PX:00T92@071`L02PX:00801PH600H020P800H61P061PH01PH600T9
2@071`L200H61P@0dLfY00030=7=Z@0600@410071`L01`L700D51@030`<01@D50`071`L02P0820P0
1`L700X:2P0:2PX02`/;00P8200;2`/03@d=00/;2`0>3Ph200l?3`0401DE5@0D51@05QHF01LG5`80
71`L02H0820P024Q8@0V9RH09bLW02PX:00];Bd0=CDe03Hf=P0l?3`0@D5104A4A01;Bd/0DE5A05QH
F01MGEd0IVIV06a/K01aLG40NGUi08:2PP29RHT0TY:B09ZJVP2OWil0Y:BT0:f][@2c/k<0^[Zj0;no
_`37alL0dM7A0=;BdP3Lg=`0h>3P0>;RhP3Shn<0i>CT0>OWi`80jNWY0240j^[Z0>_[j`3]kNd0j^[Z
0>WYj@3Zj^X0inOW0>SXj03YjNT0h^;R0=cLg03EeMD0cLg=0<W9b@33`l<0^k^k0;Ng]`2^[Zh0Y:BT
09jNWP2HV9P0TI6A08N7Q`20P800Ng]k06m_K`1UIFD0HV9R05eMG@1DE5@0CDe=04U9B@12@T800P0j
>SX03P0d=3@0<C4a02/[:`0W9bL08R8R01lO7`0Q8B406a/K01XJ6P0F5QH04a<C014A4@0C4a<04A4A
0`0=3@d200X:2P0400L71`0820P02@T900T92@801`L700@01PH600P820071`L01PH60P051@D01006
1PH01@D500D51@071`L40=7=Z@000`3AcJT03@0410@01`L700H61P051@D010@400H61P0820P010@4
00H61P0820P01PH600X:2P0820P00P0:2PX200`<300800h>3P0<30`04A4A00l?3`0C4a<05ADE01@D
500I6AT201/K6`0S01hN7P0R8R809BDU02PX:00/;2`0<30`03@d=00g=cL0@41004=3@`17AdL0CDe=
05=CD`1IFET0Hf=S06][J`1_Kfl0MGEe07alO022PX80SHf=09BDU02MWId0Y:BT0:JVYP2_[jl0]kNg
0;no_`35aLD0bl_;0<k>cP3Cdm<0emOG0=cLg03Ng]h00P3QhN400`3Shn<0hN7Q0>;RhP020>KViP03
0>SXj03UiND0i^KV0080iNGU01<0inOW0>GUi@3Ti>@0g=cL0=CDe03;bl/0a/K60;jn_P2i^KT0];Bd
0:b/[02SXj<0VIVI09NGU`2<S8`0QXJ607inOP1gMgL0Jf][0080HF5Q01<0F5QH05ADE01<C4`0ADE5
0410@00n?Sh0>3Ph03@d=00`<300:b/[02HV9P0S8b<07alO01dM7@0J6QX061PH01@D500C4a<0410@
00803`l?00P0410@00d=3@0;2`/03@d=00/;2`0:2PX02@T900P820801`L70P061PH02@051@D01PH6
00L71`0820P01PH600@410030`<01@D500H61P040=7=Z@000`3AcJT0100410@01`L700P820030`<2
00D51@8020P800L01PH600L71`071`L02@T900L71`0:2PX02@T900802`/;0P0=3@d2010@400W018B
4P0E5AD05QHF01PH600J6QX06a/K01lO7`0S8b<09RHV02XZ:P0/;2`0;bl_03@d=00l?3`0@41004I6
AP1;Bd/0D51@05QHF01MGEd0IFEU06a/K01bLW80NGUi07moO`27QhL0T92@09FEU@2OWil0Z:RX0:ZZ
ZP2b/[80^[Zj0<;2`P36a/H0c/k>0=;BdP3Cdm<0e]KF0080fMWI00H0gMgM0=cLg03Ng]h0g=cL0>;R
hP3Ph>020>;RhP040>3Ph03Shn<0hN7Q0>7Qh@80h^;R02<0h>3P0=WIf@3@d=00b<S80<C4a02n_[h0
^KVi0;2`/02WYjL0WIfM09RHV02CTi<0SHf=08:2PP1jNWX0LG5a06QXJ01RHV80G5aL05=CD`1?Cdl0
Bd];04=3@`0m?Cd0>CTi03Hf=P0a<C40<30`02LW9`0U9BD08B4Q01lO7`0N7Qh071`L01/K6`0201DE
5@0401<C4`0A4A403`l?00d=3@8030`<00T03@d=00/;2`092@T020P800H61P092@T01PH600T92@07
1`L00P061PH00`0820P010@400<30`0200D51@0300H61P051@D0dLfY00<0dLfY00030=7=Z@0C00D5
1@0:2PX01`L700H61P071`L02`/;00H61P092@T020P800T92@0:2PX02@T900P8200:2PX02@T900h>
3P0;2`/030`<00d=3@02010@400U01DE5@0D51@05ADE01LG5`0I6AT07QhN028R8P0U9BD0:2PX02XZ
:P0_;bl0<c<c03Ph>00m?Cd0@T9204a<C01;Bd/0De=C05YJFP1QHF40JFUY079bLP1iNGT0O7al08F5
Q@2:RXX0TY:B09bLW02SXj<0[:b/0:n_[`2f][H0_[jn0<?3``39bLT0c/k>0=7Ad@020=CDe0<0e]KF
02l0emOG0=GEe@3EeMD0f=SH0=_Kf`3Lg=`0g]kN0=oOg`3Ng]h0gMgM0>3Ph03Shn<0h>3P0=gMg@3H
f=P0dM7A0<S8b033`l<0_;bl0;Fe]@2_[jl0YJFU09jNWP2DU9@0TI6A08N7Q`1nOWh0MgMg06m_K`1Y
JFT0GemO05YJFP1BDU80CDe=04E5A@12@T80?Cdm03Lg=`0b<S80<30`02/[:`0V9RH08b<S024Q8@0L
71`06a/K01TI6@0201HF5P04018B4P0?3`l0410@00d=3@803Ph>00T02PX:00T92@0;2`/020P800T9
2@061PH02@T900P820071`L00P051@D01@0410@020P800<30`061PH010@400801@D500<01PH60=7=
Z@3AcJT00P3AcJT000<0dLfY00<01PH600L71`071`L00P0410@01@051@D01PH600L71`071`L01PH6
00<020P800<02PX:00/;2`0:2PX00P0=3@d0:@0>3Ph04A4A018B4P0C4a<05QHF01PH600I6AT06a/K
01dM7@0P82009bLW02/[:`0Z:RX0<30`03@d=00k>c/0@T9204E5A@1>CTh0Cdm?05EEE@1MGEd0J6QX
06a/K01cLg<0OWin07moO`29RHT0T92@09ZJVP2PX:00Z:RX0;6a/@2h^;P0^k^k0;jn_P34a<@0b/[:
0<_;b`3@d=00c/k>0080dM7A02h0d];B0=7Ad@3@d=00clo?0=;BdP3Cdm<0d];B0=GEe@3GemL0f=SH
0=_Kf`3MgMd0f][J0=kNgP3Ogml0g=cL0=WIf@3@d=00bLW90<C4a02l_;`0/[:b0:^[Z`2SXj<0VYZJ
09:BTP2=SHd0QHF507inOP1eMGD0K6a/06EUI@1KFe/0F5QH055AD@1=CDd0A4A403lo?`0h>3P0<c<c
038b<P0/;2`0:2PX02HV9P0R8R807alO0`0J6QX01P0H61P04a<C01<C4`0?3`l0410@00l?3`803@d=
0P0:2PX200P8200400`<30071`L020P800H61P<01`L700P01@D500H61P030`<01@D500L71`0410@0
1`L700P820@0dLfY00030=7=Z@0;00L71`0410@01PH600P820071`L01PH600L71`061PH020P800H6
1P071`L00P0820P01`0:2PX02@T900/;2`0<30`03Ph>00d=3@0B4Q800P0C4a<08@0F5QH05aLG01PH
600L71`0820P028R8P0V9RH0:2PX02`/;00`<300=SHf03/k>`10@400BTY:04i>CP1BDU80Fe]K065Q
H@1VIVH0L71`07IfMP1oOgl0Ph>308j>SP2EUID0WIfM0:JVYP2/[:`0];Bd0;Jf]P2l_;`0`l?30<C4
a0020<S8b00=0<[:bP3=cLd0c/k>0=3@d03?cll0c/k>0<g=c@3@d=00dM7A0=3@d03AdM40dm?C0=CD
e0020=OGe`0P0=[JfP3Kfm/0g=cL0=cLg03Kfm/0emOG0=7Ad@37alL0a<C40;bl_02b/[80ZJVY0:6Q
X@2HV9P0T92@08n?S`25QHD0O7al07AdM01_Kfl0Hf=S05eMG@1HF5P0DE5A04Y:BP14A4@0?Shn03Ti
>@0f=SH0<C4a030`<00/;2`202<S8`0501dM7@0K6a/06QXJ01XJ6P0F5QH00P0D51@00`0@41003`l?
00l?3`0200d=3@0600`<300:2PX02PX:00T92@0:2PX020P80P071`L02`092@T01@D500H61P0820P0
1@D500@410051@D01PH600<30`061PH01@D500@0dLfY00030=7=Z@0300@4100820P01@D500@01PH6
00l020P800H61P0820P02@T900`<300=3@d02`/;00T92@0<30`02PX:00h>3P0?3`l03Ph>018B4P0D
51@00P0F5QH201`L700L01hN7P0S8b<09bLW02d];@0^;Rh0=CDe03Ph>00n?Sh0ADE504a<C01BDU80
EUIF05eMG@1TI6@0Jf][07IfMP1lO7`0QhN708^;R`2DU9@0W9bL0::RXP2/[:`0/k>c0;Ng]`2j^[X0
_kno0<30`080aLG503/0alO70<S8b036a/H0alO70<K6aP37alL0a/K60<G5a@37alL0aLG50<K6aP38
b<P0b/[:0<c<c03@d=00dM7A0=CDe03Hf=P0fm_K0=SHf03IfMT0e]KF0=7Ad@3;bl/0aLG50;bl_02e
]KD0[:b/0:BTY02LW9`0TY:B08f=S@23Ph<0OGem07EeM@1ZJVX0I6AT05]KF`1GEeL0D51@04U9B@15
ADD0?Cdm03Lg=`0a<C40<30`02d];@0Y:BT092@T02<S8`0N7Qh06QXJ01TI6@0F5QH05ADE01<C4`0@
41003`l?00d=3@0200l?3`0700/;2`0820P02PX:00/;2`0820P02PX:00P8200200L71`801PH600@0
1@D500H61P061PH01PH60P071`L00`061PH010@400L71`040=7=Z@000`3AcJT200D51@0500H61P05
1@D01`L700D51@061PH00P071`L010092@T020P800H61P0820P200T92@0400`<300=3@d03@d=00l?
3`<04a<C02005ADE01XJ6P0L71`07AdM024Q8@0T92@0:RXZ02l_;`0`<300<c<c03/k>`11@D40AdM7
04i>CP1HF5P0FUYJ069RHP1WIfL0L71`07UiN@23Ph<0Shn?09>CT`2KVi/0XZ:R0:VYZ@2_[jl0]KFe
0;^k^`2n_[h0_kno0<;2`P80`L7100D0`<300;no_`31`L40_[jn0;no_`020;jn_P080;Zj^P2m_Kd0
_;bl0;jn_P30`<00`/;20<K6aP38b<P20<o?c`0U0=GEe@3Hf=P0f][J0=OGe`3Cdm<0clo?0<_;b`37
alL0`L710;Fe]@2[Zj/0XJ6Q09NGU`2@T900S8b<08:2PP1lO7`0M7Ad06YZJP1QHF40Fe]K05QHF01?
Cdl0AdM70451@@0k>c/0>CTi034a<@0];Bd0:BTY02HV9P0S8b<08R8R01hN7P0L71`06a/K01HF5P02
01DE5@06018B4P0@4100410@00l?3`0<30`02`/;0P0:2PX200T92@0900P820071`L01`L700L71`05
1@D01`L700@4100820P01`L700801@D500@010@400H61P051@D01@D5103AcJT000<0dLfY00@01@D5
00@410051@D01@D50P071`L0200410@01PH600L71`071`L01PH600X:2P0;2`/02@T90P0<30`0100;
2`/03@d=00h>3P0?3`l201DE5@0L01PH600G5aL06QXJ01dM7@0P82009BDU02TY:@0^;Rh0<S8b03Hf
=P0m?Cd0A4A404e=C@1BDU80FEUI05mOG`1VIVH0L71`07UiN@20P800RXZ:09>CT`2IVIT0X:2P0:JV
YP2^[Zh0/k>c0;Jf]P80^KVi0`2m_Kd0202k^k/0^;Rh0;Rh^02h^;P0]KFe0;Jf]P2a/K40[jn_0P2`
/;00;`2c/k<0/[:b0;Bd]02f][H0^KVi0<30`034a<@0bLW90<k>cP3AdM40d];B0=CDe03?cll0c/k>
0<c<c039bLT0_kno0;Rh^02/[:`0XZ:R09VIV@2BTY80RXZ:08B4Q01iNGT0LW9b06YZJP1QHF40FEUI
05EEE@1;Bd/0ATI60451@@0k>c/0=cLg02l_;`0^;Rh0:RXZ02DU9@0T92@0820P01`L700K6a/071`L
01HF5P0C4a<05ADE0080410@00@03`l?00h>3P0>3Ph030`<0P092@T00`0820P01`L700L71`0200H6
1P0400L71`061PH020P800D51@801PH60P051@D010071`L01@D500D51@0410@40=7=Z@000`3AcJT0
20030`<020P800L71`0410@01PH600L71`0410@020P80`061PH0:P0820P02PX:00T92@0;2`/02PX:
00`<300;2`/0410@01@D500A4A405ADE01LG5`0J6QX06a/K01dM7@0T92@09RHV02`/;00b<S80=3@d
03Xj>P11@D40AdM704e=C@1EEED0GUiN06=SH`1/K6`0MWIf07inOP2:RXX0TI6A09NGU`2MWId0XZ:R
0:VYZ@2/[:`0/;2`0;Bd]02e]KD0][Jf0;^k^`80]kNg00<0][Jf0;6a/@2a/K400P2/[:`01@2ZZZX0
YJFU0:NWY`2UYJD0Xj>S0080Z:RX02T0Zj^[0:j^[P2`/;00^;Rh0;bl_030`<00aLG50<_;b`3<c<`0
cLg=0<[:bP39bLT0bl_;0<O7a`32`/80_[jn0;2`/02TY:@0V9RH09BDU02=SHd0Q8B407UiN@1cLg<0
Jf][065QH@1JFUX0E5AD04e=C@18B4P0?clo03`l?00d=3@0;bl_02d];@0Z:RX0:2PX02HV9P0O7al0
6a/K01PH600201LG5`0<01DE5@0D51@04A4A00l?3`0>3Ph02`/;00`<30092@T030`<00/;2`0:2PX0
2@T90P071`L010061PH01`L700P8200410@200D51@0300@410051@D01@D500801PH60P030`<40=7=
Z@000`3AcJT00`071`L01PH600@4100200D51@0:00H61P071`L01PH600P820092@T01`L700H61P07
1`L02@T900X:2P802`/;01X030`<010@400A4A404Q8B01DE5@0I6AT05aLG01`L700N7Qh08b<S02TY
:@0[:b/0<c<c03De=@0j>SX0@D5104a<C01ADE40EeMG06=SH`1XJ6P0Lg=c07YjNP27QhL0T92@09>C
T`80WIfM00D0Y:BT0:JVYP2YZJT0Zj^[0:n_[`020;6a/@0e0;>c/`2b/[80/K6a0:f][@2[Zj/0Y:BT
0:FUY@2RXZ80X:2P09fMW@2NWYh0Vi^K09bLW02PX:00WIfM09nOW`2RXZ80YJFU0:ZZZP2b/[80][Jf
0;fm_@37alL0a/K60<G5a@34a<@0b<S80<G5a@32`/80`L710;fm_@2a/K40YjNW09jNWP2ATI40Rh^;
08B4Q01lO7`0Lg=c06][J`1RHV80EeMG05ADE01<C4`0ADE503hn?P0i>CT0=SHf02l_;`0];Bd0:BTY
02PX:00S8b<00P0M7Ad201PH600:01LG5`0D51@04Q8B014A4@0@41003`l?00d=3@0;2`/030`<00T9
2@802`/;00<020P800T92@051@D00`061PH00`051@D01PH600@4100200P8200300@410030`<01@D5
008010@4103AcJT000<0dLfY00<010@400<30`061PH00P061PH02`092@T01`L700P820071`L01PH6
00L71`0820P02PX:00P8200;2`/02@T9008030`<02L03`l?010@400C4a<05ADE01HF5P0H61P06a/K
020P800S8b<0:BTY02d];@0f=SH0=cLg03lo?`13@d<0BTY:05=CD`1KFe/0IfMW06a/K01fMWH0Q8B4
08V9R@2ATI40UYJF09bLW02MWId0Y:BT0:>SX`2VYZH0ZZZZ0:^[Z`2WYjL0[:b/0:NWY`2XZ:P0Y:BT
0:6QX@2PX:000P2IVIT01@2FUYH0U9BD09>CT`2BTY80TI6A0080Ti>C0280VIVI09FEU@2JVYX0Vi^K
0:6QX@2VYZH0[Jf]0;>c/`2j^[X0_Kfm0<71`@32`/80_kno0<;2`P30`<00_;bl0;Zj^P2d];@0ZZZZ
0:2PX02FUYH0TI6A08F5Q@1kNg/0LG5a06YZJP1QHF40Fe]K05EEE@1;Bd/0B4Q80410@00i>CT0=CDe
0P0^;Rh01`0X:2P09BDU02DU9@0M7Ad06QXJ01TI6@0G5aL00P0D51@02P0B4Q804A4A00h>3P0>3Ph0
2`/;00h>3P092@T02PX:00`<300:2PX400L71`801PH600<01`L700@410051@D00P071`L200P82003
00D51@0410@010@400@0dLfY00030=7=Z@0500D51@030`<01@D500@410061PH00P051@D200H61P80
20P802001PH600P8200:2PX02@T900d=3@0:2PX03@d=010@400?3`l04Q8B01LG5`0H61P06ATI01/K
6`0O7al09BDU02PX:00a<C40=CDe03Xj>P0o?cl0ATI604a<C01GEeL0H61P06YZJP1aLG40NWYj08:2
PP29RHT0Shn?09NGU`80Vi^K00l0WYjN0:>SX`2RXZ80XZ:R0:BTY02QXJ40XZ:R09nOW`2LW9`0V9RH
09FEU@2ATI40Shn?08j>SP2<S8`00`2:RXX03@2<S8`0RXZ:08V9R@2<S8`0Shn?09:BTP2CTi<0UiNG
09fMW@2OWil0Z:RX0;6a/@2d];@00P2m_Kd08`2n_[h0_Kfm0;fm_@2j^[X0^;Rh0;:b/P2/[:`0XZ:R
09NGU`2DU9@0QXJ607inOP1dM7@0JFUY06=SH`1IFET0E5AD04e=C@15ADD0?clo03Ph>00b<S80;bl_
02/[:`0V9RH08b<S02@T900M7Ad06QXJ01PH600G5aL04a<C018B4P0E5AD03`l?00<03Ph>00`02PX:
00`<300:2PX020P800L71`0820P02@T900H61P092@T020P800H61P0410@200D51@0700L71`0820P0
1@D500L71`030`<01`L700D51@040=7=Z@000`3AcJT300H61P0600@4100820P01`L700D51@061PH0
1`L70`092@T01@0820P01`L700/;2`0=3@d030`<00803`l?00@04A4A018B4P0H61P06ATI0P0L71`0
4`0Q8B4092@T02PX:00_;bl0=3@d03Ph>012@T80AdM704m?C`1IFET0Hf=S06a/K01bLW80NWYj0861
P@27QhL0SXj>092@T02FUYH00P2IVIT0102JVYX0Vi^K09ZJVP2IVIT209JFUP0809:BTP2>SXh0Rh^;
08N7Q`24Q8@0QhN708:2PP21PH4208>3P`<0PX:20P23Ph<01029RHT0RXZ:08f=S@2ATI4209JFUP0L
09^KV`2UYJD0[Jf]0;6a/@2f][H0^;Rh0;Jf]P2h^;P0]kNg0;Jf]P2c/k<0Zj^[0:JVYP2LW9`0UYJF
08Z:RP1oOgl0Lg=c06YZJP1QHF40FEUI05IFEP1@D500A4A40492@P0h>3P0<c<c02l_;`80:b/[0P0R
8R801`0P82006QXJ01TI6@0F5QH051@D018B4P0@41000P0>3Ph01P0<30`02`/;00l?3`0:2PX01`L7
00X:2P801`L700D02`/;00P820071`L01`L700D51@0200H61P0300D51@0410@01@D500801@D500<0
10@400D51@051@D0103AcJT000<0dLfY00P01PH600L71`061PH01@D500@4100820P01PH600D51@80
1`L700@020P800/;2`0820P020P80P0:2PX01`0;2`/03`l?00h>3P0@41004A4A01DE5@0F5QH00P0K
6a/05@0Q8B40:2PX02XZ:P0a<C40=SHf03Lg=`11@D40B4Q8055AD@1IFET0I6AT06i^KP1bLW80OGem
0820P026QXH0Rh^;092@T02BTY80U9BD09RHV00209NGU`0<09BDU02BTY80T92@08j>SP2;Rh/0RHV9
08J6QP24Q8@0PH6107inOP1mOGd0Ogmo0`1nOWh207emO@0Y07moO`22PX80P82008>3P`27QhL0S8b<
08j>SP2ATI40V9RH09nOW`2XZ:P0[Jf]0;Bd]02f][H0]KFe0;Rh^02e]KD0/k>c0:n_[`2][Jd0Y:BT
09jNWP2GUiL0Rh^;07moO`1eMGD0Jf][069RHP1IFET0E5AD04i>CP15ADD0@T9203Ph>00b<S80;Rh^
02`/;00X:2P09BDU01lO7`0M7Ad00P0I6AT00`0G5aL051@D01<C4`0200l?3`0700h>3P0<30`030`<
00`<300820P02@T900X:2P0400P8200500L71`061PH01`L700T92@071`L00P0410@01P071`L010@4
00D51@051@D02@T900D51@@0dLfY00030=7=Z@801@D500<00`<300D51@061PH00P051@D200T92@80
1PH602001`L700T92@0:2PX030`<00d=3@0;2`/03`l?010@400A4A4051@D01HF5P0G5aL06QXJ01dM
7@0O7al09RHV02TY:@0];Bd0=cLg03Ti>@0o?cl0C4a<059BDP1LG5`0IfMW071`L01aLG40MgMg07al
O023Ph<0QHF508R8R080S8b<04D0SXj>092@T02;Rh/0RHV908N7Q`24Q8@0Ph>30820P01nOWh0OGem
07UiN@1fMWH0MGEe07=cL`1fMWH0Lg=c07EeM@1fMWH0MGEe07IfMP1iNGT0MWIf07emO@1lO7`0Ogmo
08:2PP27QhL0RHV9096AT@2GUiL0VYZJ0:>SX`2[Zj/0[Jf]0;:b/P2a/K40[jn_0:f][@2[Zj/0ZZZZ
0:BTY02NWYh0VIVI08f=S@21PH40MgMg06i^KP1SHf<0FEUI05MGE`1=CDd0AdM704E5A@0h>3P0<S8b
02h^;P0[:b/09BDU02@T900N7Qh06QXJ01/K6`0H61P05ADE01<C4`0A4A404Q8B014A4@0>3Ph00P0;
2`/00`092@T03@d=00L71`0200L71`0700H61P0820P02@T900P8200:2PX01@D500P8200200D51@03
00H61P0410@01@D5008010@40P051@D40=7=Z@000`3AcJT010051@D01`L700H61P061PH300D51@03
00@410061PH01PH600801`L700<02PX:00T92@0<30`00P0:2PX06P0=3@d03`l?00l?3`0C4a<05aLG
01TI6@0J6QX071`L028R8P0W9bL09RHV030`<00e=CD0=cLg0410@01<C4`0E5AD061PH01WIfL0KVi^
075aL@1dM7@0NGUi07]kN`1mOGd0PH610P24Q8@02P25QHD0Q8B40861P@1mOGd0OWin07QhN01iNGT0
N7Qh079bLP1cLg<306e]K@<0Jf][02/0JVYZ06a/K01^KVh0K6a/075aL@1`L700Kfm_07AdM01hN7P0
NGUi07inOP20P800PX:208V9R@2@T900UiNG09nOW`2TY:@0ZJVY0:b/[02[Zj/0[:b/0:RXZ02WYjL0
XZ:R09jNWP2HV9P0SXj>08N7Q`1jNWX0Kfm_06ATI01HF5P0EEEE04a<C015ADD0?clo03Ti>@0c<c<0
;2`/02/[:`0V9RH08b<S00807QhN00@061PH01HF5P0F5QH04Q8B0P0@41001P0?3`l03@d=00/;2`0;
2`/02@T900/;2`<020P800<01PH600P820092@T00P061PH0100410@01@D500<30`061PH200D51@05
00@410061PH00`<300D51@030`<0103AcJT000<0dLfY00D010@400H61P051@D00`<300@4100200H6
1P0600D51@061PH01@D500L71`092@T01`L70P092@T0700<30`03@d=00h>3P0=3@d03`l?010@400F
5QH061PH01TI6@0J6QX07alO02@T900W9bL0;Rh^03<c<`0f=SH0@41004M7A`1CDe<0FUYJ06ATI01W
IfL0JFUY06m_K`1`L700Lg=c07QhN01fMWH207YjNP0507UiN@1eMGD0M7Ad075aL@1_Kfl00P1/K6`0
0`1[Jf/0JVYZ06QXJ00206IVIP0706ATI01SHf<0IFEU06=SH`1RHV80I6AT06EUI@0206MWI`0606YZ
JP1YJFT0K6a/071`L01eMGD0MgMg0P1lO7`06P21PH40QhN708j>SP2ATI40W9bL0:2PX02SXj<0YZJV
0:RXZ02UYJD0XJ6Q09fMW@2HV9P0UIFE08n?S`26QXH0Ng]k075aL@1TI6@0FEUI05IFEP1?Cdl0B4Q8
03lo?`0h>3P0<C4a0P0/;2`02@0U9BD0820P01hN7P0L71`05aLG01@D500C4a<04Q8B014A4@0200h>
3P0:00l?3`0;2`/02`/;00`<30071`L020P800X:2P061PH02PX:00H61P801@D500`020P800D51@06
1PH01@D500H61P051@D010@400D51@030`<01PH600<30`051@D40=7=Z@000`3AcJT02@071`L01PH6
00D51@0410@01PH600D51@092@T01`L700D51@0200H61P0K00X:2P0820P030`<00X:2P0;2`/02PX:
00/;2`0?3`l03Ph>010@400F5QH05aLG01PH600K6a/0820P028R8P0U9BD0:BTY038b<P0c<c<0?3`l
04Q8B01>CTh0E5AD05UIF@1PH600GemO0080IFEU00<0JFUY06YZJP1_Kfl00P1^KVh00`1[Jf/0JVYZ
06MWI`0206IVIP0706=SH`1TI6@0Hf=S069RHP1OGel0H61P05eMG@0305]KF`0F05UIF@1JFUX0Fe]K
05aLG01OGel0H61P065QH@1SHf<0IFEU06IVIP1[Jf/0Kfm_075aL@1eMGD0N7Qh07]kN`20P800R8R8
09:BTP2GUiL0VIVI09fMW@80WYjN01P0W9bL09ZJVP2DU9@0UIFE08^;R`26QXH0OGem07=cL`1XJ6P0
FUYJ05IFEP1;Bd/0ATI603hn?P0j>SX0<S8b02h^;P0Z:RX09bLW02<S8`0P820071`L01PH600F5QH2
01DE5@09010@400>3Ph03`l?00d=3@0:2PX02@T900d=3@0820P01`L7008020P800<01PH600L71`05
1@D00P061PH01`0410@01@D500D51@0410@01@D500<30`071`L00P051@D00`0410@01@D50=7=Z@03
0=7=Z@000`3AcJT01@0410@00`<300D51@071`L01PH600<01@D500P020P800H61P0820P02PX:00L7
1`092@T020P800X:2P8030`<00<03Ph>014A4@0@41000`0F5QH03@0J6QX07alO028R8P0V9RH0:BTY
030`<00a<C40>CTi0410@017AdL0Cdm?055AD@1EEED00P1HF5P00`1IFET0GEeM061PH003069RHP03
061PH01NGUh0GemO0080G5aL00<0GEeM05YJFP1JFUX00P1HF5P305MGE`80De=C00<0E5AD059BDP1D
E5@00P1FEUH01P1JFUX0Fe]K05aLG01MGEd0HF5Q069RHP80J6QX00X0KFe]079bLP1hN7P0MgMg0820
P025QHD0Rh^;08n?S`2BTY80UYJF0P2EUID07`2BTY80Shn?092@T02:RXX0QHF507UiN@1`L700IFEU
05aLG01DE5@0CDe=04A4A00m?Cd0>CTi03<c<`0/;2`0:RXZ02DU9@0Q8B406a/K01hN7P0G5aL05ADE
01HF5P0C4a<04A4A00h>3P0@410030`<00X:2P0;2`/00P092@T01@0820P01`L700H61P0:2PX01PH6
00801@D500X010@400D51@030`<01PH600D51@0410@00`<300L71`0820P01`L70P061PH40=7=Z@00
0`3AcJT01@061PH01@D500D51@030`<01PH600<010@40P061PH00`092@T020P800D51@0300T92@06
00/;2`0<30`03@d=00h>3P0@41004a<C0P0F5QH201/K6`0A01hN7P0V9RH09BDU02d];@0^;Rh0<c<c
03Ph>013@d<0ADE504Q8B01<C4`0CDe=04m?C`1@D500De=C05ADE01GEeL00P1FEUH0101GEeL0EEEE
05ADE01DE5@205EEE@0605IFEP1ADE40DE5A05=CD`1BDU80Cdm?1@1>CTh01`1=CDd0DE5A05=CD`1A
DE40E5AD05IFEP1IFET00P1KFe/0201RHV80HF5Q06QXJ01YJFT0KVi^075aL@1fMWH0NGUi0P21PH40
5`28R8P0S8b<08j>SP2?Shl0SHf=08^;R`29RHT0QhN70861P@1gMgL0Kfm_06ATI01IFET0EUIF04Y:
BP13@d<0?Shn03Hf=P0_;bl0;2`/02TY:@0T92@0820P00807AdM00T05QHF01LG5`0C4a<04a<C010@
400?3`l03@d=00X:2P0<30`00P0;2`/00`0820P02PX:00X:2P0300T92@0700P820051@D01PH600@4
10061PH01`L700@4100200D51@0500H61P051@D01PH600<30`020P80103AcJT000<0dLfY00L00`<3
00H61P030`<01@D500H61P051@D01`L700<01@D500P02@T900L71`0:2PX020P800`<300;2`/02@T9
00X:2P803Ph>01403`l?014A4@0C4a<051@D01TI6@0J6QX07QhN020P800U9BD0:RXZ02/[:`0^;Rh0
<C4a03Xj>P0n?Sh0@D510492@P0204M7A`80BTY:00@0CTi>04e=C@1ADE40CTi>101?Cdl01@1=CDd0
Bd];04Y:BP1:BTX0AdM70080BDU900<0B4Q804E5A@15ADD00P16ATH304Q8B080BTY:02X0CDe=051@
D01DE5@0DU9B05MGE`1LG5`0Fe]K05iNGP1OGel0IfMW06UYJ@1/K6`0LG5a07EeM@1gMgL0OGem0820
P027QhL0QXJ608R8R025QHD0Ph>30861P@1lO7`0MGEe071`L01SHf<0FEUI05EEE@19BDT0@D5103dm
?@0e=CD0<30`02`/;00Z:RX092@T020P800L71`06a/K01LG5`0E5AD201@D5005014A4@0?3`l030`<
00h>3P0;2`/00P0:2PX02`0;2`/02@T900L71`061PH020P800H61P051@D01`L700P820071`L010@4
00801@D50P0410@00`061PH010@400<30`0200D51@@0dLfY00030=7=Z@@00`<300H01@D500L71`05
1@D01@D500L71`0410@200P8200700T92@0820P02@T900T92@0:2PX02@T900`<300200h>3P05014A
4@0B4Q804Q8B01HF5P0H61P00P0O7al04`0S8b<09BDU02LW9`0/;2`0;Bd]03<c<`0f=SH0>CTi03lo
?`0m?Cd0@T920451@@14A4@0ATI604U9B@16ATH0BDU904M7A`16ATH00P18B4P02@17AdL0ADE504=3
@`13@d<0@D5103lo?`10@400@D510410@0020492@P0804E5A@14A4@0@D510492@P14A4@0AdM704E5
A@1;Bd/204e=C@0]055AD@1BDU80EEEE05IFEP1KFe/0GEeM065QH@1UIFD0J6QX06][J`1`L700LW9b
07IfMP1hN7P0O7al07moO`21PH40OGem07alO01hN7P0L71`06QXJ01NGUh0EUIF051@D01:BTX0?clo
03Xj>P0e=CD0<30`02/[:`0X:2P09BDU01lO7`0L71`061PH01HF5P0C4a<04Q8B014A4@0?3`l03@d=
00h>3P0;2`/02PX:008020P800<02@T900X:2P061PH00`071`L00`051@D01`L700D51@0200@410<0
1@D500<01PH600@410030`<00P061PH00`071`L0dLfY0=7=Z@020=7=Z@000`3AcJT0200410@01@D5
00H61P030`<010@400H61P0820P01@D50P092@T01@051@D01PH600L71`0820P02@T900<02PX:0P0=
3@d01P0?3`l0410@018B4P0B4Q805ADE01TI6@8071`L0180820P02DU9@0X:2P0:BTY02h^;P0_;bl0
=3@d03Lg=`0h>3P0>SXj03lo?`0n?Sh0@T920410@015ADD0@d=304A4A013@d<204A4A0070451@@13
@d<0@4100492@P10@400?Shn03lo?`0203dm?@0;03hn?P0l?3`0?Shn03hn?P0o?cl0@41003hn?P13
@d<0?clo0492@P14A4@00P1:BTX03`1<C4`0D51@059BDP1CDe<0EUIF05aLG01MGEd0I6AT06EUI@1X
J6P0K6a/06e]K@1aLG40M7Ad07MgM`0207UiN@0=07YjNP1hN7P0LW9b06m_K`1WIfL0GUiN05EEE@1A
DE40B4Q80410@00j>SX0<c<c02h^;P0202PX:00702<S8`0Q8B407QhN01TI6@0E5AD04Q8B014A4@04
00l?3`0500`<30092@T020P800T92@071`L00P0820P00`071`L01@D500H61P0200H61P0500D51@06
1PH010@400D51@030`<00P0410@200H61P0300D51@030`<01@D500@0dLfY00030=7=Z@800`<300L0
1@D500@410030`<00`<300H61P051@D010@400<01PH600X02@T900L71`092@T02PX:00P8200<30`0
3Ph>00l?3`0>3Ph04Q8B0P0@4100300D51@05ADE01PH600K6a/07alO020P800T92@09RHV02XZ:P0[
:b/0<30`03<c<`80=SHf00@0>c/k03Ph>00k>c/0?3`l0P0k>c/01`0m?Cd0>c/k03`l?00k>c/0?3`l
03Xj>P0l?3`00P0i>CT203Xj>P0503Ph>00j>SX0>CTi03Xj>P0k>c/00P0i>CT02P0j>SX0>c/k03/k
>`0o?cl0?3`l03hn?P12@T80A4A404I6AP1:BTX204m?C`0:055AD@1CDe<0EEEE05UIF@1LG5`0HV9R
065QH@1SHf<0IFEU06QXJ080KVi^01L0LG5a06m_K`1^KVh0JVYZ06IVIP1SHf<0FUYJ05ADE01@D500
ATI603lo?`0h>3P0<C4a02l_;`0Y:BT09RHV028R8P0N7Qh07AdM01LG5`0D51@05QHF018B4P02010@
400A00`<300A4A402`/;00X:2P0820P02@T900L71`061PH02PX:00H61P071`L01PH600@410051@D0
10@400H61P051@D01@0410@010071`L01@D500D51@051@D40=7=Z@000`3AcJT020051@D01`L700@4
10061PH010@400D51@030`<01@D50`061PH0100820P01`L700H61P0820P200T92@0300P820092@T0
2PX:00803Ph>00d0410@018B4P0D51@04a<C01PH600I6AT06QXJ01hN7P0Q8B40820P02HV9P0W9bL0
:RXZ00<0;Rh^00X0<30`038b<P0d=3@0=3@d03<c<`0e=CD0=cLg03Hf=P0e=CD0=3@d0P0e=CD00`0f
=SH0=3@d03De=@0303@d=00403<c<`0e=CD0=CDe038b<P80=CDe00<0=3@d03Xj>P0g=cL00`0i>CT0
4P0n?Sh0@4100410@016ATH0ADE504U9B@1;Bd/0CDe=051@D01ADE40EUIF05QHF01GEeL0FUYJ05eM
G@1SHf<0HV9R06=SH`80I6AT01/0Hf=S06ATI01SHf<0GEeM05MGE`1ADE40C4a<04E5A@0k>c/0=CDe
02l_;`0Z:RX09BDU02<S8`0O7al071`L01hN7P0I6AT051@D01<C4`0@41003`l?00h>3P0?3`l02PX:
00/;2`0820P00P092@T200P8200300H61P051@D01`L700<01PH600D010@400820P0410@00`<300D5
1@0200820P801@D50P030`<00`0410@0dLfY0=7=Z@020=7=Z@000`3AcJT300@410801PH60P051@D0
10030`<01`L700@410051@D300H61P0400T92@0820P02@T900T92@8030`<00l03Ph>00l?3`0?3`l0
410@014A4@0B4Q8051@D01HF5P0J6QX06a/K01dM7@0Q8B407alO028R8P0U9BD00`0Y:BT01@0/;2`0
;bl_02h^;P0];Bd0;Rh^0080<30`00<0;Rh^030`<00a<C400`0`<3000`0c<c<0;bl_030`<00202l_
;`05034a<@0^;Rh0;bl_034a<@0`<3000P0_;bl00`0b<S80<c<c03<c<`0203Lg=`0>03Hf=P0k>c/0
?clo03dm?@0o?cl0@D5104I6AP19BDT0B4Q804];B`1?Cdl0DE5A059BDP1CDe<205MGE`80FEUI00<0
G5aL05YJFP1LG5`00P1JFUX02@1IFET0EEEE04a<C01;Bd/0@41003Xj>P0c<c<0;Bd]02XZ:P02028R
8P0=020P800N7Qh061PH01DE5@0C4a<04Q8B00h>3P0?3`l03@d=00`<300;2`/02PX:00T92@0300P8
20<01`L700D01PH600@410061PH01PH600@4100200D51@8010@400@01@D500820P030`<00`<30`05
1@D40=7=Z@000`3AcJT010030`<01@D500<30`061PH200<30`0700D51@061PH01PH600D51@0410@0
1@D500P8200200H61P0400L71`0:2PX01`L700/;2`802PX:00<03@d=00l?3`0=3@d00P0@4100100C
4a<05aLG01@D500J6QX201/K6`807QhN00<08b<S028R8P0U9BD00P0W9bL01@0X:2P0:RXZ02XZ:P0/
;2`0;Bd]0080:RXZ00X0:BTY02XZ:P0/;2`0;2`/02XZ:P0[:b/0;2`/02TY:@0Z:RX0:BTY0P0Z:RX0
4P0Y:BT0:b/[02`/;00/;2`0;Rh^02d];@0_;bl0;Rh^02l_;`0b<S80=CDe03<c<`0f=SH0>CTi03Xj
>P0m?Cd0@D510492@P80@d=300D0BDU904Y:BP1;Bd/0C4a<04i>CP04055AD@0305=CD`1BDU80De=C
0080De=C00/0Cdm?04Q8B013@d<0?Cdm03Hf=P0^;Rh0:RXZ02TY:@0S8b<07alO01hN7P0201/K6`04
01LG5`0C4a<04A4A010@40<03@d=00P02PX:00T92@092@T020P800T92@071`L010@400P820801`L7
00<010@400H61P051@D00P0410@01`071`L01PH600820P030`<00P8200@410030`<00`0410@40=7=
Z@000`3AcJT200<30`0400D51@030`<00P8200<30`801@D50P061PH01`071`L00`<300H61P071`L0
2PX:00H61P071`L00P0820P0300;2`/02PX:00l?3`0?3`l03@d=014A4@0?3`l0410@018B4P0C4a<0
5ADE01TI6@806QXJ00L071`L01dM7@0O7al08R8R02@T900Q8B4092@T00809RHV00/09bLW02@T900V
9RH09BDU02@T900Y:BT09bLW02DU9@0Y:BT09BDU02LW9`0302DU9@0<02@T900U9BD0:b/[02PX:00U
9BD09RHV02XZ:P0X:2P0:BTY02XZ:P0];Bd0;2`/0P0^;Rh01P0`<300<c<c03<c<`0g=cL0?Cdm03`l
?080@41000@0@d=304E5A@16ATH0B4Q81@1:BTX05P1<C4`0BTY:04Y:BP1;Bd/0BDU904I6AP11@D40
?Shn03Ph>00b<S80:b/[02PX:00U9BD08R8R024Q8@0L71`06QXJ01DE5@0D51@04Q8B010@400>3Ph3
00`<30802`/;00L02@T900L71`0820P02@T900L71`061PH010@400801@D50P071`L00`0410@00`<3
00D51@0200@4100700<30`020P801@D500820P0410@01PH600@410040=7=Z@000`3AcJT01`0410@0
1@D500D51@030`<01@D500820P0410@00P051@D0100410@01PH600@410051@D200H61P0900P82006
1PH020P800P8200;2`/02PX:00/;2`0=3@d03Ph>00803`l?00@0410@014A4@0D51@04a<C0P0F5QH0
1`0J6QX05aLG01/K6`0L71`07QhN01dM7@0O7al00P0P82000`0R8R80820P028R8P0302<S8`05028R
8P0S8b<08b<S028R8P0T92@00`0S8b<00`0R8R808B4Q02<S8`0302@T900A02<S8`0W9bL09bLW02TY
:@0U9BD0:2PX02XZ:P0];Bd0:b/[02`/;00_;bl0<C4a038b<P0e=CD0>3Ph03/k>`0l?3`00`0m?Cd2
04=3@`0D04A4A013@d<0A4A404A4A012@T80@d=30492@P10@400A4A40410@00j>SX0=SHf038b<P0/
;2`0:2PX02HV9P0S8b<08B4Q01dM7@0L71`201LG5`0301<C4`0A4A403Ph>00803Ph>00`02`/;00`<
300:2PX02`/;00X:2P092@T01PH600T92@071`L01@D500H61P071`L300D51@0500<30`061PH00`<3
00L71`051@D00P030`<00`061PH010@400820P0200<30`@0dLfY00030=7=Z@0500D51@030`<010@4
00D51@0410@00P051@D01@0410@00`<300D51@0410@02PX:00801@D500@010@400P820071`L01PH6
0P092@T200X:2P0300/;2`0:2PX03@d=00803`l?00h04A4A01<C4`0D51@04a<C01HF5P0H61P05aLG
01PH600L71`06QXJ01`L700M7Ad06a/K01lO7`8071`L00D07alO01dM7@0P82007alO01hN7P02020P
800301dM7@0O7al08B4Q00<07alO0P0P82001@0O7al08B4Q028R8P0O7al092@T00808B4Q00D092@T
02<S8`0V9RH0:2PX02TY:@0202/[:`80;Rh^00@0<C4a038b<P0f=SH0=cLg0P0h>3P01P0i>CT0?3`l
03`l?00k>c/0?Shn0451@@80?Shn00`0>c/k03dm?@0k>c/0>CTi03Lg=`0c<c<0<C4a02h^;P0X:2P0
9BDU028R8P0P820201`L700301TI6@0H61P04a<C00804Q8B0P0?3`l04@0>3Ph030`<00/;2`092@T0
20P800L71`0820P01`L700H61P0410@01@D500H61P051@D010@400L71`061PH01@D5008010@40P05
1@D200@410800P820`0410@40=7=Z@000`3AcJT00`030`<020P800<30`0300@4100700D51@061PH0
1`L700L71`0410@01@D500<30`0200@410801`L700@01@D500X:2P071`L01`L70P092@T200/;2`80
3@d=00H03`l?014A4@0@41004A4A018B4P0C4a<201@D500401DE5@0H61P05QHF01XJ6P806ATI00L0
71`L01TI6@0J6QX07alO01/K6`0L71`06a/K008071`L00P06a/K01`L700K6a/06a/K01`L700J6QX0
820P01XJ6P807QhN0P0M7Ad0200P82008B4Q01hN7P0Q8B4092@T028R8P0V9RH09BDU0`0X:2P02@0Y
:BT0:RXZ02d];@0_;bl0<C4a03<c<`0g=cL0=3@d03De=@0203Lg=`0@03Hf=P0i>CT0>3Ph03Lg=`0f
=SH0=cLg03Hf=P0c<c<0<S8b02h^;P0[:b/0:RXZ02LW9`0S8b<07QhN01dM7@806QXJ00P05QHF01LG
5`0D51@03`l?00h>3P0?3`l03Ph>00`<30802PX:00L02`/;00X:2P0:2PX020P800L71`0820P01PH6
00801`L700T01PH600@4100410@01PH600@410020P800`<300H61P030`<00P051@D200410@800`<3
00<010@40=7=Z@3AcJT00P3AcJT000<0dLfY00H01@D500<30`030`<00P8200<30`0410@200<30`<0
1@D500<010@400<30`061PH00P061PH010051@D01PH600P8200;2`/300T92@0700X:2P0=3@d030`<
00`<300?3`l0410@01<C4`0200l?3`08014A4@0C4a<05QHF01@D500H61P05aLG01HF5P0G5aL201PH
60@06ATI00H06a/K01XJ6P0J6QX06QXJ01`L700J6QX201/K6`0901dM7@0J6QX06a/K01`L700K6a/0
71`L01/K6`0L71`07QhN00807AdM01`07alO024Q8@0Q8B408b<S028R8P0W9bL09BDU02LW9`0V9RH0
:BTY02/[:`0/;2`0;bl_03<c<`0e=CD0<c<c03@d=00c<c<0=CDe03<c<`0d=3@0=cLg03Hf=P0d=3@0
<c<c030`<00a<C40;Bd]0P0[:b/0300W9bL09RHV028R8P0P820071`L01PH600I6AT05QHF01@D500C
4a<04A4A00d=3@803Ph>00`03@d=00X:2P092@T02@T900/;2`0820P01`L700H61P071`L02@T900H6
1P051@D200@4100:00H61P0410@010@400<30`0410@00@4100<30`020P800`<300@410800P8200<0
10@400<30`3AcJT00`3AcJT000<0dLfY0P030`<00`051@D010@400<30`0200<30`0300820P0410@0
0`<300<010@400L01PH600L71`061PH020P800D51@071`L02@T900<020P80P0:2PX03@0;2`/03@d=
00d=3@0<30`03`l?00h>3P0@41004A4A010@400B4Q80410@018B4P0C4a<00P0F5QH01@0E5AD05QHF
01LG5`0G5aL05ADE00806ATI00T061PH01TI6@0H61P061PH01HF5P0G5aL06ATI01XJ6P0G5aL00P0H
61P0100K6a/05aLG01TI6@0I6AT201/K6`0301`L700K6a/071`L00807QhN00<0820P02DU9@0R8R80
0P0S8b<00`0T92@09RHV02TY:@0202`/;00302h^;P0_;bl0<30`0080<30`00H0;bl_034a<@0a<C40
<30`02l_;`0];Bd202`/;00802XZ:P0V9RH092@T02@T900Q8B407QhN01`L700J6QX201PH600501<C
4`0B4Q804A4A010@400<30`00P0;2`/02P0?3`l02`/;00X:2P0820P02@T900P820061PH01@D500L7
1`061PH200D51@800`<300@01PH600D51@0410@01PH60`030`<00`061PH010@400<30`0200<30`03
00820P0410@0dLfY00<0dLfY00030=7=Z@800`<300D010@400820P051@D00P8200<30`0200D51@03
00@410020P801PH6008010@400D01PH600@410051@D01PH600D51@0200L71`0700T92@0;2`/02@T9
00T92@0:2PX03@d=00`<300200h>3P<03`l?00P0410@014A4@0A4A404Q8B01<C4`0B4Q805ADE01@D
50804Q8B00D04a<C01@D500G5aL05QHF01@D500201DE5@0701@D500F5QH05ADE01HF5P0D51@05QHF
01PH600301HF5P0301TI6@0K6a/061PH00806QXJ0P0K6a/01@0L71`07QhN01lO7`0O7al07QhN0080
8R8R00H092@T02<S8`0S8b<0:2PX02TY:@0/;2`202/[:`0402h^;P0/;2`0;Bd]02/[:`80;2`/0P0Z
:RX202PX:00302DU9@0S8b<08R8R0080820P00L071`L01TI6@0H61P05ADE01@D500B4Q8051@D0080
3`l?00<0410@00/;2`0;2`/00P0;2`/010092@T02PX:00L71`0820P200H61P<01`L700l01PH600D5
1@030`<00`<300D51@030`<010@400<30`020P8020P800@410020P801@D500<30`020P800P051@D4
0=7=Z@000`3AcJT03`051@D00P8200820P020P8010@400H61P051@D010@400H61P030`<01@D500<3
0`051@D010@400D51@0200@4100B00L71`061PH02@T900P8200:2PX020P800X:2P092@T020P800X:
2P0;2`/02PX:00h>3P0=3@d0410@00l?3`0=3@d04A4A0P0@41001@0?3`l04A4A018B4P0?3`l04a<C
00804A4A00@04Q8B01<C4`0@410051@D0`0B4Q801P0C4a<051@D01<C4`0G5aL04a<C01HF5P8051@D
00@05aLG01DE5@0F5QH05QHF0`0G5aL01P0H61P06ATI01TI6@0J6QX07AdM01/K6`80820P00<07QhN
020P800Q8B400P0T92@00`0Y:BT09BDU02LW9`0202TY:@0702PX:00Y:BT09BDU02LW9`0V9RH092@T
02HV9P0202<S8`09024Q8@0O7al07AdM01TI6@0L71`05QHF01LG5`0D51@04Q8B0080410@00<03`l?
00h>3P0>3Ph00P0:2PX03P0;2`/02@T900T92@0820P02@T900H61P092@T01PH600D51@071`L010@4
00H61P0410@00`<30P0410@00`051@D010@400@4100200D51@0500@410061PH00`<300820P010@40
0P030`<40=7=Z@000`3AcJT00`010@400`<300L71`0400<30`8010@400<01@D500@410020P800P03
0`<00`051@D01PH600L71`0200D51@0300P820071`L01`L7008020P800D02`/;00T92@0<30`030`<
00T92@0200X:2P0300`<300;2`/02`/;00803Ph>00D03@d=00h>3P0=3@d03Ph>00l?3`0200h>3P03
00l?3`0A4A404a<C0080410@00D04a<C01@D500B4Q80410@01@D500401<C4`804Q8B00X051@D018B
4P0B4Q804a<C01DE5@0D51@061PH01DE5@0F5QH061PH0P0I6AT301/K6`0301dM7@0L71`0820P00<0
820P00D08R8R02HV9P0S8b<09RHV02DU9@0402@T900502<S8`0O7al0820P020P800O7al00P0K6a/0
0`0I6AT05QHF01@D500201@D50804A4A00l03Ph>00d=3@0<30`02`/;00d=3@0820P02PX:00T92@08
20P02@T900L71`051@D01PH600D51@0410@00`061PH300@4100;00D51@030`<00P8200820P061PH0
1@D500@410010@401PH600820P0410@00P020P840=7=Z@000`3AcJT010051@D00`<300<30`0410@3
00<30`801@D500`010@400H61P061PH010@400820P061PH01@D500<30`051@D01PH600D51@071`L2
00H61P0@00L71`051@D01`L700`<30092@T020P800/;2`092@T02PX:00T92@0;2`/030`<00/;2`0>
3Ph030`<00h>3P<03@d=0P0?3`l00`0>3Ph03`l?010@4002010@400=014A4@0>3Ph0410@01<C4`0?
3`l04Q8B014A4@0@41004A4A00l?3`0@41004A4A018B4P0201<C4`0>018B4P0F5QH04a<C01@D500F
5QH061PH01HF5P0H61P06QXJ01TI6@0J6QX07AdM01`L700M7Ad301hN7P0501dM7@0Q8B408b<S02<S
8`0Q8B400P0P8200100O7al0820P01hN7P0L71`201XJ6P8061PH0P0F5QH2018B4P05014A4@0?3`l0
3Ph>00h>3P0:2PX00P0<30`04P092@T02`/;00L71`071`L02`/;00P820061PH01@D500L71`0410@0
1PH600D51@0820P010@400D51@030`<010@400<30`801@D510030`<01P0410@00`<300<30`0410@0
0P8200<30`@0dLfY00030=7=Z@0400410@030`<010@400D51@800`<300@00P8200@410030`<010@4
0P030`<04@051@D00`<300<30`020P800`<300@410061PH01@D500@4100820P01PH600P820051@D0
1PH600X:2P092@T02PX:00802@T900L020P800T92@0820P02PX:00`<300=3@d030`<00803@d=0P0>
3Ph200d=3@<030`<00D03`l?00h>3P0?3`l03Ph>00d=3@0200h>3P0300l?3`0=3@d03`l?0080410@
00H04A4A018B4P0A4A403`l?010@400A4A42018B4P0301@D500C4a<051@D00805QHF00d05ADE01LG
5`0I6AT06ATI01XJ6P0I6AT06a/K01hN7P0L71`07QhN01`L700M7Ad07alO00807QhN00H07AdM01`L
700L71`06ATI01/K6`0G5aL201HF5P0701DE5@0C4a<04A4A01@D500A4A404Q8B014A4@0200h>3P05
00d=3@0<30`02`/;00/;2`0820P00P061PH00`051@D01`L700D51@0200H61P0400D51@061PH01@D5
00820P801PH600H00P8200H61P071`L010@400D51@061PH200<30`8010@400D00`<300410@0410@0
10@400<30`040=7=Z@000`3AcJT0100410@01PH600820P020P8200<30`<00P8200<010@400<30`01
0@400P030`<300@4100600D51@061PH01@D500H61P051@D02@T90`061PH00`0:2PX01PH600P82002
00T92@0600L71`092@T02@T900P8200:2PX030`<100;2`/01P0>3Ph030`<00h>3P0=3@d02`/;00`<
30803`l?00<02`/;00d=3@0<30`00P0>3Ph0100?3`l03@d=00l?3`0=3@d300h>3P803`l?00`04A4A
00h>3P0C4a<04Q8B010@400C4a<04Q8B01<C4`0B4Q8051@D01HF5P0D51@201HF5P0601PH600G5aL0
6ATI01PH600I6AT061PH100M7Ad201/K6`0801XJ6P0F5QH061PH01HF5P0D51@05ADE01@D500C4a<2
018B4P0B00d=3@0?3`l03Ph>00/;2`0<30`02`/;00P820092@T020P800T92@071`L02`/;00H61P08
20P01PH600@410092@T01@D50P0410@200H61P801@D500@00`<300@410020P800P820P010@401@05
1@D00@4100@410020P8010@400800P8200<010@40=7=Z@3AcJT00P3AcJT000<0dLfY0`020P801`05
1@D010@400<30`030`<010@400820P030`<00`0410@200<30`<010@400P00`<300@410051@D020P8
00H61P051@D01`L700P820801`L700/02@T900L71`0820P01@D500P820092@T020P800L71`0:2PX0
2`/;00T92@0300X:2P802@T900D030`<00/;2`0:2PX03Ph>00X:2P0200`<300300l?3`0=3@d030`<
00<030`<00D03Ph>00/;2`0?3`l03@d=00l?3`0300h>3P0>00d=3@0>3Ph04A4A018B4P0A4A40410@
01<C4`0B4Q804a<C01DE5@0F5QH051@D01HF5P0E5AD201HF5P0501LG5`0I6AT061PH01PH600K6a/0
0`0I6AT01`0E5AD061PH01DE5@0D51@04a<C01@D500B4Q800P0@41002@0?3`l03@d=00h>3P0<30`0
2PX:00/;2`0:2PX020P800H61P0200P820802PX:00`01PH600L71`061PH020P800D51@061PH00`<3
00H61P020P8010@400D51@030`<300@4100300820P0410@00P82008010@400@01PH600@410030`<0
0@410P030`<40=7=Z@000`3AcJT200<30`0800@410020P800P8200@410030`<00P8200@410051@D2
00820P0:00H61P030`<00`<300<30`0410@01PH600D51@0410@01@D500H61P801@D500H01`L700D5
1@061PH01@D500H61P071`L200H61P0700T92@0820P01`L700L71`092@T02`/;00P8200200T92@04
00P8200:2PX02`/;00/;2`803@d=014030`<00d=3@0:2PX030`<00d=3@0:2PX03@d=00X:2P0;2`/0
30`<00h>3P0<30`03Ph>00d=3@0A4A403Ph>00d=3@0200h>3P@03`l?00P04A4A018B4P0A4A404A4A
018B4P0D51@04a<C01@D50805aLG01H051@D01HF5P0D51@06QXJ01HF5P0I6AT061PH01LG5`0H61P0
6ATI01@D500B4Q804a<C01DE5@0C4a<0410@014A4@0=3@d0410@00d=3@0;2`/02PX:0P0;2`/00`0:
2PX020P800P8200300L71`0800H61P071`L01`L700H61P051@D01PH600D51@030`<200@410800`<3
0P051@D200820P8010@40`020P8200@4100400820P030`<00P8200<30`@0dLfY00030=7=Z@800`<3
00D010@400<30`020P8010@400820P0200<30`0800@410030`<00`<300<30`0410@01PH600820P03
0`<300D51@0500<30`0410@01@D500L71`0820P00P051@D01`061PH01@D500L71`071`L01PH600T9
2@061PH00`0820P010071`L02PX:00X:2P0820P300T92@0400`<300;2`/030`<00d=3@802PX:00<0
2@T900`<30092@T00P0;2`/01@0=3@d02PX:00`<300<30`02`/;00H03@d=00D04A4A00l?3`0=3@d0
3`l?00h>3P0200l?3`08010@400A4A403`l?014A4@0B4Q8051@D018B4P0C4a<201@D500501<C4`0D
51@05QHF01DE5@0F5QH00P0D51@201<C4`804A4A00T0410@00l?3`0=3@d03@d=00`<300;2`/030`<
00/;2`0?3`l0100820P00`061PH01@D500@4100200L71`0700H61P0820P010@400T92@030`<01PH6
00@4100400<30`0800D51@0410@00`<300@410020P800`<300820P051@D200<30`<00P8200<01@D5
0=7=Z@3AcJT00P3AcJT000<0dLfY0`010@4200820P0500<30`0410@010@400@410051@D00P0410@2
00<30`0:00@410061PH010@400<30`020P8010@400<30`071`L00`<300L71`801@D500L020P800L7
1`0410@01PH600@410071`L01PH600@01`L700`02@T900L71`0:2PX020P800X:2P092@T01`L700P8
20092@T030`<00/;2`0:2PX400T92@0500`<300:2PX02@T900T92@0;2`/00P0:2PX200/;2`0:00X:
2P0;2`/03`l?00`<300>3Ph030`<00h>3P0?3`l030`<00d=3@80410@00@03Ph>010@400C4a<04A4A
0P0@41001`0E5AD04a<C010@400C4a<051@D014A4@0C4a<0100B4Q801@0>3Ph0410@010@400>3Ph0
3`l?00803Ph>00<030`<00/;2`0;2`/00P0;2`/01@071`L02@T900P820051@D01PH600<020P80P06
1PH00`0820P010@400820P0200<30`0400D51@030`<00`<300<30`8010@400@00`<300H61P020P80
0`<30`020P801P030`<00P8200820P030`<01@D500H61P@0dLfY00030=7=Z@070000000410@00`<3
00D51@020P80000000<30`0200820P0600<30`020P8010@400<30`0410@00`<30P0410@200D51@05
00<30`0410@01PH600@410030`<00P071`L0200410@01@D500H61P0410@01@D500P8200410@01PH6
0P051@D200H61P0600L71`061PH02@T900L71`092@T020P80P071`L00`092@T02`/;00T92@0200X:
2P8020P800@02@T900/;2`0;2`/02PX:0P092@T00`0;2`/02@T900T92@0200/;2`0300T92@0;2`/0
2`/;008030`<00H02PX:00`<300:2PX030`<00d=3@0@410200l?3`08010@400=3@d04Q8B00h>3P0@
41003Ph>01<C4`0>3Ph2014A4@05010@400B4Q804A4A00h>3P0@41000`0=3@d01P0;2`/030`<00X:
2P0<30`02PX:00P820802@T900<020P800T92@061PH00`061PH01P071`L010@400<30`061PH01`L7
00H61P8010@400D01@D500<30`030`<010@400H61P0300<30`0<00D51@030`<01`L700410@020P80
1PH600410@030`<00P8200<30`0000000`<3103AcJT000<0dLfY00D00@4100<30`020P8010@400<3
0`0300820P0700410@020P800`<300D51@030`<010@400D51@0300<30`0300820P061PH01@D50080
1@D500L01PH600L71`0410@010@400D51@061PH010@400801@D500P01PH600L71`061PH02@T900H6
1P071`L01PH600L71`<020P800<02@T900L71`061PH00P0820P02P092@T01`L700T92@0:2PX02@T9
00L71`0:2PX02@T900/;2`092@T200L71`0700X:2P092@T02@T900X:2P0<30`03@d=00`<300200X:
2P0700/;2`0<30`03@d=00/;2`0=3@d03`l?00`<300300d=3@0500`<300>3Ph03`l?00h>3P0=3@d0
0`0>3Ph2010@40803Ph>0P0<30`0100=3@d030`<00`<300;2`/200T92@0400`<30092@T02PX:00P8
20801`L700<02@T900L71`061PH00P071`L00`051@D01PH600D51@0200@4100800H61P051@D010@4
00@410051@D00`<300@410030`<200@410800P8200D010@400820P051@D00`<300410@0200@41003
00410@020P800`<300@0dLfY00030=7=Z@0300820P030`<00`<300800@4100@00`<300410@030`<0
10@40P020P8200@4100400<30`010@400`<300<30`801@D500<010@400<30`061PH00P020P801@06
1PH010@400D51@0410@01PH600801@D500@00`<300H61P071`L01PH60P071`L200H61P801@D500P0
1PH600L71`071`L01`L700H61P0820P01`L700T92@8020P810071`L200T92@0300P820092@T01`L7
008020P80`092@T04@0820P02PX:00L71`0820P02PX:00/;2`092@T02PX:00`<300=3@d02`/;00`<
300=3@d0410@00`<300;2`/030`<00<03Ph>00D03@d=00h>3P0>3Ph03Ph>00`<300200/;2`0=00h>
3P0;2`/03@d=00/;2`092@T01`L700`<30071`L02@T900L71`061PH01`L700P8200200H61P0300L7
1`0410@00`<3008010@400<01PH600@410030`<00`030`<0200410@01@D500D51@010@400`<300@4
10020P8010@40`030`<0200410@00`<300410@030`<00@4100<30`010@4010@4103AcJT000<0dLfY
00<00P8200@410030`<00P020P8200@410800@41010010@400820P0410@01@D500820P010@400P82
00<30`051@D00`<300820P0410@01PH600@410030`<01@D5100410@00`071`L01@D500D51@0200@4
10801@D50P061PH200D51@0800L71`0410@020P800H61P051@D020P800D51@071`L200P8200300T9
2@071`L01`L7008020P800P02@T900L71`0820P01`L700X:2P092@T020P800X:2P8020P800D02`/;
00X:2P092@T02`/;00P8200200T92@0800X:2P0820P02@T900T92@0<30`03@d=00/;2`0?3`l200/;
2`0500h>3P0=3@d03@d=00h>3P0=3@d0100;2`/01`092@T02PX:00d=3@0<30`02`/;00L71`0820P0
10071`L01P061PH01@D500@410071`L010@400D51@8010@400D01PH600<30`0410@01@D500@41003
00<30`0500@410030`<00`<300<30`0410@00P030`<010020P800`<300<30`010@4200820P0300<3
0`010@400P8200800P8200<00@410=7=Z@3AcJT00P3AcJT000<0dLfY00<00@4100820P020P800P03
0`<00`010@400`<300<30`0200<30`801PH600H01@D500@410030`<00P8200<30`061PH200<30`80
10@400<00`<300@4100410@00P051@D200@4100;00<30`061PH00`<300D51@0410@01PH600L71`05
1@D01`L700H61P0820P00`051@D00`0410@01@D500L71`0200P8200800T92@071`L01PH600H61P07
1`L02@T900H61P0820P200L71`0300P820061PH02@T900801`L70P092@T300P8200700T92@061PH0
20P800X:2P071`L02PX:00/;2`0200P8200300T92@0:2PX030`<00<030`<00L02`/;00X:2P0;2`/0
2PX:00/;2`0<30`02PX:00<02`/;00H02@T900X:2P0:2PX020P800T92@0820P200L71`0>00P82007
1`L010@400L71`0410@01@D500@410061PH010@400H61P051@D010@400<30`0410@200820P0700<3
0`010@4010@400D51@020P800`<300820P0200@4100;00<30`010@400`<300H61P020P8010@40082
0P061PH00@4100820P010@40103AcJT000<0dLfY00@00@4100H61P020P800P820`030`<00`0410@0
0`<30000000200820P0900<30`020P8010@400820P0410@01`L700410@030`<00P82008010@400<0
0`<300410@0410@00P051@D200@4100@00<30`051@D01PH600D51@0410@01PH600D51@030`<01PH6
00D51@071`L020P800D51@0410@01`L700D51@<01PH600<010@400T92@0820P00P051@D01@061PH0
20P800H61P071`L020P800801`L70P0820P00`092@T02PX:00L71`0200L71`0:00P8200:2PX020P8
00P8200:2PX020P800/;2`0:2PX020P800X:2P802@T900@020P800X:2P092@T02@T90`0<30`200P8
200300`<30092@T02PX:00<020P800@01`L700X:2P071`L01PH60`071`L200H61P0400L71`051@D0
1PH600P820801@D50P0410@02@020P801@D500410@0410@00`<300@410061PH00@4100H61P0200@4
100400<30`020P800`<300820P<00`<31@020P800`0000000P820=7=Z@030=7=Z@000`3AcJT20082
0P0300<30`020P800P8200<00P820P0410@300<30`0500D51@030`<00`<300D51@0410@00P030`<0
1P061PH00`<300H61P0410@00P8200D51@800`<300H01@D500<30`020P8020P800D51@020P8200<3
0`8010@400d01PH600@410051@D01@D500@4100820P01@D500@410051@D010@400D51@071`L020P8
00801`L72@061PH0200820P01`L700L71`071`L020P800H61P0820P02@T90`071`L01@092@T030`<
00L71`092@T02PX:00802@T900@01`L700T92@092@T020P80`092@T00`0:2PX030`<00`<300200P8
200300T92@0:2PX01`L700801PH60P0820P03`061PH020P800L71`071`L01PH600D51@061PH01@D5
00L71`030`<01PH600@410030`<01@D500820P0200<30`0300820P061PH00`<300800`<300H00@41
00<30`030`<00`<300@410020P8200<30`800P820P010@4010020P801PH600410@020P840=7=Z@00
0`3AcJT400820P03000000010@400P8200800@410P020P8010030`<00P8200410@051@D200<30`0<
00820P030`<010@400<30`0410@00`<300D51@061PH010@400H61P0410@00`<30P061PH01P030`<0
0P8200H61P030`<010@400H61P801@D501<01PH600820P0410@00`<300P8200410@01`L700D51@06
1PH02PX:00L71`0410@01PH600D51@071`L020P800L71`092@T01PH600801`L700<020P800L71`05
1@D00P071`L300P8200300H61P092@T020P8008020P80`092@T200L71`0800P820071`L020P800T9
2@0820P01`L700T92@071`L200T92@8020P800L01`L700X:2P061PH02@T900L71`0:2PX01PH60080
1@D500<01PH600<30`0820P00P061PH300D51@800`<30P051@D01P0410@00`<300@410030`<010@4
00D51@800P8200D00`<300820P0410@00P8200410@0200<30`0800410@020P801PH600820P030`<0
000000410@0410@200820P0300410@3AcJT0dLfY0080dLfY00030=7=Z@0800820P030`<010@400<3
0`020P800`<300820P00000200820P8010@400H00`<300820P030`<01@D500820P0410@300820P0@
00410@0410@00`<300820P051@D010@400<30`051@D010@400<30`061PH01@D500@410051@D01`L7
00<30`8010@400X01@D500<30`061PH01@D500H61P0410@01`L700H61P0410@01PH60P071`L02@05
1@D01`L700D51@030`<01PH600D51@0410@01PH600D51@0300H61P801`L700<020P800H61P0820P0
0`071`L0100:2PX01`L700T92@061PH200L71`0;00P820061PH020P800L71`0<30`02@T900P82009
2@T02PX:00L71`0820P00`071`L200H61P0<00T92@061PH02PX:00L71`051@D01`L700P8200410@0
20P800<30`0410@01`L70P030`<300D51@0400@410010@4010@400@410801PH600D00P8200410@05
1@D01`L700820P0400<30`<010@400@00`<300410@010@400P820P010@400`020P800`<300000004
0=7=Z@000`3AcJT010010@400`<300820P010@4200820P0500410@020P800@4100820P0410@00P02
0P8010010@400`<300820P030`<200820P0700410@0410@01@D500D51@030`<010@400820P0300<3
0`0600@410051@D00`<300D51@0410@01PH60`0410@01@030`<01`L700@410051@D01`L700801PH6
0`0410@300H61P0300D51@071`L020P8008010@40P051@D010071`L01@D500H61P061PH200L71`05
00P820071`L01@D500L71`051@D00`071`L00`092@T01PH600H61P0300L71`0300H61P0820P01@D5
00801`L700D020P800T92@071`L01`L700P8200200H61P0700L71`051@D01@D500P820071`L01@D5
00P8200200H61P0?00@410030`<010@400L71`051@D01PH600@410061PH00`<300@410030`<01`L7
00@410061PH00`<300<010@400<01@D500820P010@400`010@4300820P0300@410020P800P820080
0P8200H0000000820P0410@00P8200<30`020P840=7=Z@000`3AcJT200@4100700410@020P800000
00<30`010@400P8200<30`0200820P0700@410030`<010@400<30`0410@0000000<30`0200820P80
10@40P020P8010030`<010@400<30`051@D400@4100900<30`0410@010@400@410061PH01`L70082
0P0410@00`<3008010@400<01`L700820P051@D00P0410@01P071`L010@400H61P0410@01@D500@4
10801PH600<01`L700D51@051@D00P061PH02P071`L010@400P8200820P01PH600D51@0820P01@D5
00@410071`L200H61P0500D51@061PH020P800L71`0820P00P061PH01@071`L02@T900L71`061PH0
1@D500801`L700<020P800L71`051@D00P0820P03P061PH01`L700H61P0410@01@D500<30`061PH0
10@400H61P030`<010@400<30`0410@01@D50P0410@200820P0800L71`030`<00`<300<30`0410@0
0P8200410@051@D200820P0500@410030`<010@400@410020P800P010@401@020P801@D500820P02
0P8010@400800@410P020P800`000000dLfY0=7=Z@020=7=Z@000`3AcJT01@0410@00P8200000005
1@D010@400800P8200<00`<300820P0410@010020P8010010@400`<300@410010@4300<30`050082
0P030`<00P8200820P0410@00P030`<01@051@D00`<300<30`020P801@D5008010@400T01PH600<3
0`051@D010@400<30`071`L010@400D51@020P800P0410@030071`L020P800P820051@D010@400L7
1`030`<01`L700H61P0410@01PH600@410<01PH600D01`L700@410061PH01PH600L71`0200@41007
00L71`051@D01`L700P820071`L01@D500L71`0200D51@801PH600<01`L700T92@092@T00P061PH0
1@071`L01PH600T92@071`L01@D500801PH600<01@D500H61P0410@00P051@D01`030`<01PH600H6
1P071`L01@D500@410020P800P051@D040030`<010@400D51@020P8010@400820P0410@00P820041
0@020P8010@400820P0000000@4100820P010@4200<30`0400D51@010@400`<3000000D00P8200D0
000000410@020P8010@400820P040=7=Z@000`3AcJT200410@0:00<30`010@400@4100820P051@D0
0P82000000020P8010@400820P800@4100D00`<300820P030`<00`<300410@0300<30`800P8200<0
10@400820P030`<00P030`<03@0410@00@4100@410030`<00P8200@410020P8010@400D51@020P80
0`<300@410020P800P051@D010061PH01@D500D51@030`<200D51@0400@410061PH01@D500@41080
1@D500<01PH600D51@051@D00P0410@01P051@D01`L700@410051@D010@400P820801@D500T01PH6
00L71`0410@020P800L71`051@D020P800D51@061PH00P071`L0100820P01`L700D51@071`L200D5
1@@01PH600@010@400H61P051@D01@D50P061PH01@030`<01@D500H61P061PH00`<3008010@400<0
0`<300@410051@D00`020P801`061PH00`<300410@0410@01@D500410@030`<00P051@D010010@40
0`<300@410010@4200<30`0500820P061PH00`<300@410010@401@020P800`010@401@D500410@04
0=7=Z@000`3AcJT02`020P800@4100<30`0000001PH600<30`010@400P8200<30`020P800`<30080
10@40`020P802@030`<00@4100H61P0000000`<300410@020P800`<300H61P0200@410800P8200H0
0@4100<30`030`<00`<300D51@030`<200@4100300<30`051@D010@400<010@400@00`<300D51@04
10@01PH60P0410@200D51@0500P820051@D010@400@410061PH00P030`<010020P8010@400D51@06
1PH200<30`8010@400@01@D500<30`051@D01`L710051@D300H61P0300@410071`L01@D500801@D5
00<01PH600L71`071`L00P071`L00`0410@01@D500D51@0200D51@0;00@410061PH00P8200D51@03
0`<01@D500<30`051@D010@400H61P030`<00P0410@01P030`<00P8200<30`0410@00`<300410@80
0P8200X010@400<30`0000001@D500820P030`<00P8200410@030`<010@40P020P801@010@400`<3
00820P0000000`<300800@4100D00`<300D51@010@400P8200410@040=7=Z@000`3AcJT020010@40
10@400820P020P800@4100<30`020P8000000P030`<010020P800@4100D51@0410@400410@070082
0P030`<00P8200<30`020P800`<300820P0200<30`800P8200T010@400<30`030`<010@400410@05
1@D010@400<30`020P800P0410@300<30`0800D51@020P800`<300L71`0410@00`<300820P061PH2
00D51@0>00@410051@D00`<300D51@0410@01`L700<30`051@D01`L700D51@0820P00P8200D51@04
10@200<30`0500D51@061PH01@D500D51@071`L010051@D01@0820P01PH600@4100410@01PH600H0
1@D500@010@400H61P0410@010@40`051@D200@410801PH600T01@D500@4100410@010@400<30`04
10@01@D500<30`051@D00`030`<200@4100500820P030`<00@4100820P030`<00P020P802P000000
0P8200@4100410@00@4100L71`030`<00@4100@410030`<200410@0400D51@010@400`<300820P@0
dLfY00030=7=Z@800@4100@00P8200410@030`<00P820P010@401000000010@400410@030`<20082
0P0C000000020P800`<300<30`010@400`<300@410030`<0000000<30`051@D0000000820P051@D0
10@400410@020P800`<300@4100300<30`801@D500P00`<300@4100410@010@400<30`0410@00`<3
00820P801@D500H010@400D51@030`<00`<300820P051@D200@4100:00H61P051@D01@D500D51@06
1PH00`<300L71`030`<010@400D51@8010@400<00`<300@410051@D00P051@D0200410@00`<300@4
100:2PX01PH600<30`061PH02@T90P061PH02`030`<010@400P820061PH01@D500820P051@D010@4
00D51@0410@01@D500<010@400T00`<300@410030`<01@D500@410071`L00`<300@410051@D00P04
10@200820P0C00H61P0410@00`<300410@020P800@4100D51@030`<00@4100D51@010@401@D500<3
0`020P80000000@410051@D00`<300820P020000000600H61P010@400`<300410@030`<00@41103A
cJT000<0dLfY00D00@4100D51@030`<00@4100<30`0200820P0400@410030`<010@400D51@800P82
00<00@4100820P010@400P030`<300820P@00`<30P020P801P0410@00P8200@410020P8010@400D5
1@800`<300H01@D500<30`030`<00`<300D51@030`<200@4100300410@030`<01@D5008010@400@0
1@D500820P051@D010@40P061PH300<30`0300D51@0410@00`<300<00`<300H010@400L71`030`<0
1@D500P8200410@300H61P0300@410051@D01`L700<01@D500<01`L700H61P061PH00P061PH01007
1`L00`<300D51@0410@200H61PD010@400P01@D500820P051@D00P8200H61P051@D010@400H61P80
10@401000`<300410@010@400@4100@410020P8010@400<30`061PH010@400<30`020P800`<30041
0@020P800@410`020P8200D51@0<000000010@400P8200820P030`<0000000820P0000000@410082
0P030`<00P82103AcJT000<0dLfY00<0000000410@020P801@030`<400820P0400<30`020P800P82
00410@800P8200X00`<300820P010@4010@400820P010@401PH600820P030`<010@40`020P8400@4
100600820P030`<00`<300@410020P801PH6100410@010051@D00P8200410@051@D200@410800`<3
0P0410@020061PH00`<300@4100410@01@D500@410061PH00`<30P051@D02`0410@00`<300D51@04
10@01@D500820P071`L01@D500@410051@D00`<3008010@400<01@D500@410051@D00`071`L200P8
20<01PH60P0410@00`061PH00`<300@4100200@4100400<30`051@D00`<300@410<00`<300<010@4
00<30`030`<00`020P801`0410@00`<300<30`0410@00@4100820P030`<00P0410@010020P800`<3
00D51@0410@200820P0900H61P020P801@D500410@030`<00@4100820P0410@00`<3008010@400<0
0@4100@4103AcJT00`3AcJT000<0dLfY00<00P8200@410030`<00P010@4200820P0800410@030`<0
0`<300<30`020P801@D500<30`00000200@410800@4100X00P8200410@030`<010@400410@030`<0
0@4100<30`020P8010@40P020P800`061PH010@400@4100200D51@0300H61P030`<00P8200801@D5
00<00P8200@4100410@00P0410@01`051@D010@400H61P051@D00`<300D51@020P800P051@D200<3
0`0700D51@020P800`<300@410030`<010@400P8200300D51@0900H61P0410@01@D500D51@0410@0
1`L700H61P051@D010@400801@D500@00`<300H61P071`L01@D50P030`<00`061PH010@400@41003
00@4100700H61P0410@00P8200<30`051@D01PH600@4100200820P8010@400<00`<300820P030`<0
0P030`<010020P800@4100<30`030`<200820P8010@40P010@40200000000P8200<30`020P800`<3
00820P051@D00@410P020P802`030`<00@4100410@010@400`<300820P010@400`<300@410020P80
0`<300@0dLfY00030=7=Z@0300820P061PH00P8200800`<30P00000010030`<00@41000000020P82
0000000800820P0000001@D500@410051@D00`<300@410051@D200<30`0:00H61P030`<01@D50000
00051@D00@4100820P030`<010@400<30`8010@400<00P8200<30`030`<010030`<200820P0300<3
0`061PH010@400800`<30P051@D02P030`<01@D500820P0410@01`L700@410051@D01`L700@41006
1PH200<30`0500@410061PH010@400D51@061PH00P051@D200H61P801@D500@010@400D51@030`<0
1@D50P0410@200D51@0;00L71`061PH00`<300D51@0410@00`<300@410030`<010@400D51@030`<0
0P051@D02@0410@01@D500@410020P800`<300@410020P801PH600<30`0300820P8010@400D01@D5
00820P0410@01@D500410@0200820P800@410P0410@01@0000000@4100<30`020P8010@400800`<3
00P00@4100<30`010@400`<300410@0410@00@4100<30`800@41103AcJT000<0dLfY00h01@D500@4
10030`<00@4100@410030`<00@4100820P010@4010@4000000030`<00P8200<30`800P8200X00@41
00820P020P800@4100D51@010@400`<300820P030`<020P80P030`<02@020P800`<300820P0410@0
0@4100D51@061PH00`<300410@0200@4100600D51@020P8010@400@410061PH00P820`030`<01@08
20P00`<300H61P0410@01@D5008010@400T01@D500@4100410@01`L700H61P0410@01PH600@41006
1PH00P030`<03`0410@01PH600D51@0410@01PH600D51@030`<01@D500@410030`<010@400<30`06
1PH01@D500L71`0200@4100L00D51@020P8010@400<30`0410@01PH600<30`051@D00`<300H61P03
0`<00P8200H61P030`<01@D500820P0410@01PH600<30`020P8010@400H61P051@D00`<300@41003
0`<00P8200<30`<00@4100D00`<300@41000000010@400410@0200820P0:00410@020P800`<30082
0P030`<00P8200T92@020P8010@400410@800`<30P020P800`010@4000000=7=Z@030=7=Z@000`3A
cJT02P0000000@4100410@010@400`<3000000010@40000000410@00000200410@0600<30`000000
0P8200410@020P800`<30`020P801`010@400P8200@410020P801@D500820P030`<010020P800`06
1PH010@400@4100200<30`0400820P030`<01@D500D51@8010@400H01`L700D51@030`<00P8200@4
10051@D300820P800`<300d01@D500@410061PH010@400H61P051@D010@400<30`0410@00P8200P8
20061PH01@D500<00`<300d01@D500@4100410@00`<300@410061PH010@400H61P051@D010@400D5
1@061PH010@400800`<300<01@D500@410030`<00P061PH010020P800`<300D51@030`<200D51@80
10@400X01@D500<30`030`<00@4100H61P0820P010@400820P0410@01@D50P020P8300<30`050041
0@0410@00P8200410@020P800P0410@02P051@D00`<300820P0000001PH600<30`0410@00`<30041
0@00000200410@0300820P010@400`<300800@41103AcJT000<0dLfY00<010@400820P030`<00P02
0P8020010@401@D500@4100410@00`<300H61P020P800@410P020P8200410@8010@400@01@D50041
0@0000000`<30`020P803@0000000`<300@410010@400P8200@410020P8010@400820P010@400`<3
00@410030`<00P0410@03@051@D010@400@410051@D00`<300410@020P801PH600D51@0410@01@D5
00@410030`<00P0410@00`071`L010@400@4100200@4100800D51@061PH00`<300H61P051@D00`<3
00@410051@D200@4100800H61P051@D01@D500L71`051@D01PH600D51@071`L200<30`0400@41006
1PH00P8200820P801PH600l01@D500<30`061PH010@400H61P030`<010@400<30`020P800`<30082
0P030`<00P8200@410020P800`0410@200820P0500<30`051@D00`<300<30`010@400P030`<30041
0@0700820P030`<00P8200410@020P800`<300410@0200820P0400410@020P800`<300410@800P82
0P010@400`030`<00@4100<30`040=7=Z@000`3AcJT01`010@400P8200820P030`<010@400000002
0P800P010@400`0000000@4100<30`0200820P0300@410020P800`<300800`<300H00@4100820P04
10@00@4100<30`020P8200410@0800820P0410@010@400820P0410@01@D500<30`010@4200<30`04
00@410051@D010@400@410801@D50P0410@01@061PH00`<300D51@030`<010@400800`<300L00P82
00@410030`<010@400D51@030`<01PH600<00`<30`051@D01`030`<01@D500H61P061PH00`<300H6
1P071`L00P030`<04P0820P01@D500@410061PH00`<300H61P030`<010@400L71`0410@00P8200D5
1@061PH00`<300820P051@D00`<300@410800`<30P061PH02P030`<01@D500@4100820P00`<30082
0P010@401PH600<30`0410@300820P800`<300H01@D500<30`020P800P8200410@020P8200<30`@0
0P8200<00@4100<30`030`<010010@4200<30`<00@4100<00P8200410@3AcJT00`3AcJT000<0dLfY
00<010@4000000020P8010030`<010010@400P8200410@00000400820P0A000000020P800@4100@4
10020P800`<300@410030`<00P8200<30`0410@01@D500820P051@D00P8200@410020P800`030`<0
1`0410@00P8200820P030`<00P8200410@030`<00P0410@00`020P800`<300@4100300D51@800P82
00h010@400820P071`L010@400<30`061PH01@D500<30`061PH010@400<30`0410@01@D500@41080
1@D501<010@400<30`0410@010@400L71`0410@01@D500<30`0410@01@D500820P0820P010@400D5
1@030`<010@400H61P030`<01@D5008010@400D00`<300820P030`<00P8200H61P0200<30`0I00H6
1P0410@01@D500<30`020P8010@400<30`0410@00P8200<30`020P8010@400820P010@4010@40041
0@020P800@4100820P010@400P8200<30`051@D00P8200410@0400820P03000000010@400`<30080
0P8200L00`<300820P020P800@4100@410010@400`<300@0dLfY002@0=7=Z@00T03AcJT00900dLfY
002@0=7=Z@00\
\>"],
  ImageRangeCache->{{{180, 323}, {252.5, 109.5}} -> {-343.407, 198.651, \
1.87239, 1.87239}}],

Cell[BoxData[
    InterpretationBox[\("SNR: "\[InvisibleSpace]25.329174828269476`\
\[InvisibleSpace]" dB"\),
      SequenceForm[ "SNR: ", 25.329174828269476, " dB"],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
In an analogous way, the convolution is performed between the guide \
star and the PSF images; Poissonian scaled noise is added to obtain the \
observed blurred and noisy guide star. 
The parameters involved in the noise calibration may differ from those used \
in the noise affecting the satellite image, but the resulting values of the \
SNR are similar.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g\_star\  = \ 
        Re[InverseFourier[
              Fourier[f\&^\_star]\ *\ 
                Fourier[
                  RotateLeft[
                    Map[RotateLeft[#, \ m\_\(x, \ star\)] &, \ h\&^\_star], \ 
                    m\_\(y, \ star\)]]]]\ *\ \@\(len\_\(y, \ sat\)\ *\ \
len\_\(x, \ sat\)\);\)\), "\[IndentingNewLine]", 
    \(\({\[Beta]\_star, \ \[Gamma]\_star}\  = \ {5, \ 
          5\ *\ 10^6};\)\), "\[IndentingNewLine]", 
    \(\(noise\_star\  = \ 
        Table[Random[
              PoissonDistribution[\[Beta]\_star]], \ {len\_\(y, \ sat\)}, \ \
{len\_\(x, \ sat\)}]\ /\ \[Gamma]\_star;\)\), "\n", 
    \(\(\[Rho]\_star\  = \ 
        Apply[Plus, \ g\_star, \ {0, \ 1}]\ /\ 
          Apply[Plus, \ g\_star\  + \ noise\_star, \ {0, \ 1}];\)\), "\n", 
    \(\(g\&~\_star\  = \ \((g\_star\  + \ 
              noise\_star)\)\ *\ \[Rho]\_star;\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]\_star\  = \ 
        g\&~\_star\  - \ g\_star;\)\), "\[IndentingNewLine]", 
    \(\(showImage[g\&~\_star];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<SNR: \>", \ 
        computeSNR[g\_star, \ \[Delta]\_star], \ "\< dB\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000001000000000000010000000000000000000000
000001010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
000100000100000001000100000000000000000000000000010001010100000000000000
010100000000000000000000000000000000000000000000000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000000000000010000
000000000000010000000100000000000001000000000001000100010000000000000001
000100000000010000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000000000000000000000000010000000000000000000100000000
010000000100010000000000000100010000000000010100000101000000010100000100
000000000101000001010001000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000100000000000001010100
000000010101000000000100010001010000000100000000010000000100000101010000
000000000000010001000000000000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000100000000010000
000101010001000001000001000001000001010001010001000100010100010100010101
000001000001000000000000000001000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010000010000000000000000000100000000010000010000
000000000101000001000101010100000101000101010101010101010100010101010000
000001000100000000000000000000000000000000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010001000101000000000000000100010100
010001010100010101010101010001010101010100010101010101010001010001010101
010000000101010001000000000000010000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010100000000000101000000010100000001
000001010001010101010101010101010101010101010101010101000101010101010000
000001010001010000010000000001000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010001010000000100000101000101010001
000101010101010101010101010101010101010101010101000000000101010101010101
010101010101010100010000000101000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000000100000101010100010100000101
010101010101010001010101010101010101010101010101010101010101010101010101
010100010101010101010100010000000000000100010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000000000000100000000000000010000010101000100010001010101
010101010101010101010101010101010101010101010101010101010101010101010001
010101010101010101010100000101000000010000010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000000000000100000000000001000101010101010101000101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010001010101000000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000100010001000100010101010101000101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010000010000000100010000000100000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000001000000000000010001000101010001010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010001000100010000000000000000000000000000010000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010001000001010000010101000101010001010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010001010000010000000101000000010001000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010100010100010001000100010000000101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010001010000000000010000000001000000000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000000001010101000001010101010101010101010101010101010101010101
010101010101010101010101010101010101010101020101010101010101010101010101
010101010101010101010101010101010100010101010001000101000000000001010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000101000000010101000101010101010001010101010101010101010101010101
010101010101010101010101010101010101020101010101010101010101010101010101
010101010101010101010101010101010101010001000101010100000000000001000000
000100000000010000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
000101010000010000000001010100010101010101010101010101010101010101010101
010101010101010101010101010101010102010102020201010101010101010101010101
010101010101010101010101010101010101010101010101000101000100000101010000
000000000001000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000001
010101000100010100010001010101010101010101010101010101010101010101010101
010101010101010101010102010202010101010102010102020101010101010101010101
010101010101010101010101010101010101010101010101010101010100010101000100
000100000100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000001010101000101010101010101010101010101010101010101010101
010101010101010101010102010102010202010102020102020201010201010101010101
010101010101010101010101010101010101010101010101010101010101000001000000
010001000101000000010000000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100010000
000001010101010101010101010101010101010101010101010101010101010101010101
010101010101020102010102020102020202010201020201020202010101010201010101
010101010101010101010101010101010101010101010101010101010100000100010001
010000010001000100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000100000101
000100000101010101010101010101010101010101010101010101010101010101020102
010201020101020202020202020202020202020202020202020202020202020201010101
010101010101010101010101010101010101010101010101010101010101010100000101
010100010000010000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010000000001000000000100010000
010001000101010100010101010101010101010101010101010101010101010101020101
020202020202020202020202020202020202020202020202020202020202020202020202
020201020102010202010101010101010101010101010101010101010101010101010101
000000000100000000000100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000000000000000000000000000000000000000010000010001000100
010001010101010101010101010101010101010101010101010101010101010101010202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020101020201020201010101010101010101010101010101010101010101010101
010101000000000101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000001000001000100
000001010101010101010101010101010201010101010101010101010101010102020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020201020101010201010101010101010101010101010101010101010100010001
010101010000000100000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000010101010101
010101010101010101010101010101020101010101010101010102020202020202020202
020202020302020202020202020202020202020202020202020202020203020202020202
020202020202020202020202020101010101010101010101010101010101010101010101
010101010000000001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001010000010101
000101010101010101010101010101010101010101010102010202020202020202020202
020202020202020202020202020202020202020202020203030302020302020202020202
020202020202020202020202010101010101010101010101010101010101010101010101
010101000000010000010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000001000000000000010101010101
010101010101010101010101010101010201010101010102010102020202020202020202
020202020202030202020202020202020202020202030303030203020302020202030202
020202020202020202020202020202020101010101010101010101010101010101010101
010101010100010001010000000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000100000001010101
010101010101010101010101010101010102010102010101010202020202020202020202
020202020303030203020203030303030203020303030303030303020303020303020303
020202020202020202020202020202010101010101010101010101010101010101010101
010101000101000100000000000000000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000100010101010001
010101010101010101010101010101020101020102010202020202020202020202020202
020302030303030303030303030303030303030303030303030303030303030303030303
020202020202020202020202020201010202020101020102010101010101010101010101
010101000101000001010000000100000001010000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001010001000001010101010101
010101010101010101010101010101010101020102020202020202020202020202020202
020303030303030303030303030303030303030303030303030303030303030303030303
030202020202020202020202020202020202020201020101010101010101010101010101
010101010101000101000000000100000000010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010000000001000000000001010101010101
010101010101010101010201010101020102020202020202020202020202020202020202
020303030303030303030303030303030303030303030303030303030303030303030303
030302020203020202020202020202020202010102020101010101010101010101010101
010101010101010001000001000001000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000000000100010101010101010101
010101010101010101010101010202020102020202020202020202020202020302020203
030303030303030303030403030403030303030303030404040404040303030303030303
030303030302030302020202020202020202010202010102010201010101010101010101
010101010100010100010000010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001010100010101010101010101
010101010101010101010101010102020202020202020202020202030303030302030303
030303030404040404040304040404040304030404040404040404040304040404040403
030303030303030303020202020202020202020202020201010102010101010101010101
010101010101010000000100010000010000000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010000010001010101010101010101010101
010101010101010101010202020202020202020202020302020203030303030303030303
030304040404040404040404040404040404040404040404040404040404040404040404
030303030303030303030203020202020202020202020202010101010101010101010101
010101010101010101010000000001000000000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001010001010101000100010101010101
010101010101010101020102020202020202020202030303030303030303030303030303
040304040404040404040404040404040404040404040404040404040405050404040404
030303030303030303030303020202020202020202020202020102020101010101010101
010101010101010001010100010100010000000000000000000100000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000001000001010101000101010101010101010101
010101010101010202010102020202020202020203020303030303030303030303030303
040304040404040404040404040404040404040404050505050505050505050505040404
040303030303030403030303030302020202020202020202020202020102010101010101
010101010101010101010100010000010100000000000000000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010001000100000001010001010001010101010101010101
010101010101010101010102020202020202020202030303030303030303030304030304
040404040405050504040404040405040405050505050505050505050505050505050404
040404040403030303030303030302020202020202020202020202020201010101010101
010101010101010101010100010101010000000100000000000000000000000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000000000000010100010101010101010101010101010101
010101010101010101020201020202020202030303030303030303040303040404040404
040404050505050505050505050505050505050505050505050505050506050505050404
040404040404040403040303030303020202020202020202020202020201010101010101
010101010101010101010001000101010000010100010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000101010101010101010101010101010101
010101010101010101020202020202020202030203030303030403040404040404040404
040505050505050505050505050505050505060606060606050605050605050505050505
040404040404040404040403030303030202020202020203020202020201010101010101
010101010101010101010101010100010000010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000100000001000101010101010101010101
010101010101010201020202020202020203030303030303030404040404040404040404
050505050506050505060605060606060606060606060606060606060606050605050505
050505050404040404040403030303030303030302030202020202020202020201010101
010101010101010101010101010101000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000100010000000101010101010101010101010101010201
010101010102010102020202020202020303030303030303040404040404040404050405
050506050606060606060606060607060607070707070707060606060606060605050505
050505050504040404040404030303030303030303030302020202020202020102020201
010101010101010101010101010101010101010101000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000001010101010101010101010101
010101020202020202020202020203030303030303040404040404040404040404050505
050606060606060606070707070707070707070707070707070707070706060606050605
060505050505050504040404040403030303030303030302020202020202020202010202
010101010101010101010101010101010001010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000000000000001000000000101010101010101010101010102
010101010102020202020202020203030303030303040404040405040404050505050505
050606060607070707070707070707070708080808080808080707070706060606060606
050505050505050505040404040403030303030303030303030202020202020202020202
010101020101010101010101010101010101010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010101010101010101010101010101010101
010201020202020202020203020303030303030304040404040405050505050505050606
060606070707070707080808080808080808080808080808090808070707070606060606
060606050505050505050504040404030403030303030303030202020202020202020202
010101010101010101010101010101010101010100010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000000000000000000000100000001010101010101010101010101010101
020202020202020202020302020303030303030304040404040505050505050505060606
060607070707080808080808080909080909080909090909090908080807070707070606
060606060606050505050505050404040403030303030303030202020202020202020202
020101010101010101010101010101010101010000010000000000000000000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000100000101010001010101010101010101010101010101
020202020202020202030303030303030403040404040504050505050505060606060606
0707070707080809090909090909090909090909090A0909090909090908080707070707
070706060606060606060505050504040404030303030303030303020202020202020202
010102010101010101010101010101010101000101010100000000010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000101010101010101010101010101010101020202
020202020202020202020303030303030404040404040505050505060606060607060707
0707080808090909090909090A09090A0A090A0A0A0A0A0A0A0A0A090909080807070707
070707070606060606060505050504040404040404030303030303030302020202020202
020201010101010101010101010101010101010100010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001010001010101010101010101010101010102
020202020202020203030303030303030404040405050505050506060606070707070707
0808080809090A0A0A0A0A0A0A0A0A0A0A0A0B0A0B0B0B0A0A0A0A0A0909090808080707
070707070707070707060606050505050404040404040303030303030302020203020202
020202010101010101010101010101010101010100010001000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001010100010101010101010101010101010101010102
020202020202020303030303030303040404040405050505050606070707070707080808
08080909090A0A0B0B0B0B0B0B0A0B0B0B0B0B0B0B0B0B0B0B0B0B0A0A0A090909080808
080807070707070707070606060505050504040404040303030303030302030202030202
020201010101020101010101010101010101010101000100000000000001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000001010101010101010101010101010102020202
020202020203020303030303030304040404050505050506060607070708070808090809
0909090A0A0B0B0C0B0B0B0B0B0B0B0B0C0C0C0C0C0C0C0C0C0B0B0B0B0A0A0A09090909
090808080807070707070706060605050505050404040404040303030303030202030202
020202020101010201010101010101010101010101010101000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000001000000000000
000000000001000000000001000001000001010101010101010101010101010101020202
020202020202020303030304040404040404050505060606070707080808080808090909
0A0A0B0B0B0C0C0C0C0C0C0C0C0C0C0C0D0D0D0D0D0D0D0C0C0C0C0C0B0B0B0A0A0A0A09
090909080808080808070707070606050505050404040404040403030303030303020202
020202020202010101010101010101010101010101010101010001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010001000101010101010101010101010102020202
02020202020203030303030304040404040505050506060707080808080909090909090A
0A0B0B0B0C0C0C0D0D0D0D0D0D0D0D0D0E0E0E0E0E0E0E0E0D0D0D0C0C0C0B0B0B0B0A0A
0A0A09090908080808080707070706060505050404040404030303030303030303020202
020202020202020101010101010101010101010101000101000100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000000010000010100010000010101010101010101010101010201020202
020202030302030303030404040404050505050506060607070808090909090A0A0A0B0B
0B0B0C0C0D0D0D0E0E0E0E0E0E0E0F0F0F0F0F0F0F0F0F0F0E0E0D0E0D0D0C0C0C0C0B0B
0B0A0A0A0909080908080808070706060606050504040404040403030303030303030202
020202020202010101010101010101010101010101010100010001010000010000000000
000001000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000101000000000000000101010101010101010101010101020102020202
02020202030303030304040404040405050505060606070708080809090A0A0A0A0B0B0B
0B0B0C0C0D0E0E0E0F0F0F0F0F101010101111101010100F0F0E0E0E0E0E0D0D0D0D0C0C
0C0B0B0A0A09090909080807070707060606050505040404040403030303030303030202
020202020202020101010101010101010101010101010001010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010101010101010101010101010101010202020202
020202030303030303040404040405050505050606070707080809090A0A0A0B0B0B0B0C
0C0C0D0D0E0F0F0F101010101111111112121212111110100F0F0F0F0F0F0F0E0E0E0E0D
0D0C0C0B0B0A0A0909080808070707070706060605050404040404040303030303030202
020202020202020102010101010101010101010101010101010000000001000101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001010001010100000000010101010101010101010101010101010202020202
0202020303030303040404040505050505050606070707070808090A0A0A0B0B0C0C0C0C
0D0D0E0F0F1010111111111112121313131313131212111110101010101010100F0F0F0E
0E0E0D0C0B0B0A0A09090808070707070707060605050504040404040403030303030302
020202020202020202010101010101010101010101010000010000000100000000000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000001000000000000000000
000000000000000000000001010101010101010101010101010101010102010202020202
0202020203030303040404050405050506060606070707080808090A0A0B0B0C0C0D0D0D
0E0E0F0F101112121213131313131414141414141312121212121212121211111110100F
0F0F0E0D0D0C0B0A0A090909080808070707070606050505050404040404030303030302
020202020202020101010101010101010101010101010101010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000100010101010101010101010101010101010101020202020202
0202020303030304040404040505050506060607070708080909090A0B0B0C0D0D0E0E0E
0F0F10111212131415141415151515161615151514141313131313131313131312111111
10100F0E0E0D0C0B0B0A0A09090808080808070706060505050404040404030303030303
020202020202020201020101010101010101010101010101010001000000010000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101010101010101010101010201010101020202020202
02020303030303030404040505050506060607070708080809090A0B0B0C0D0D0E0F0F0F
0F1011121314151616161616171717171717171616151515151515151515151413121211
111110100E0E0D0C0C0B0A0A090909080808070706060605050504040404040403030303
020202020202020202020101010101010101010101010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100010100010001010101010101010101010101010101010202020202020202
0203030303030404040405050505060606070707080809090A0A0B0B0C0D0D0E0F0F1010
111112131415161717181818191919191919191818171717171717171716161514141313
121211100F0F0E0D0C0B0B0A0A0A09090808080707070606050505040404040303030303
030202020202020202020201010101010101010101010101010000010100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000000000000010001000101010101010101010101010202020202020202020203
0303030303030404040405050506060607070808080909090A0B0B0C0D0D0E0F0F101011
1112131415161718191A1A1A1B1B1B1B1B1B1A1A1A1A1A19191919181818171716151413
1312111110100F0E0D0C0C0B0B0A0A090908080707070706060505050404040303030303
030303020202020202020201010101010101010101010101010100000000010001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000101000001000000010101010101010101010101010101020202020202020202
030303030304040404050505050606060707080809090A0A0B0B0C0C0D0E0F1010111111
12131415171718191A1B1C1C1D1D1D1D1D1D1D1D1C1C1B1B1B1A1A1A1A19191817161514
141313121111100F0E0D0C0C0B0B0A0A0909080807070606060605050404040404040303
030302030202020202020201010101010101010101010101010101000100000000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000101000001010101010101010101010101010202020202020202030303
030303030404040405050505060606070708080809090A0B0B0C0D0D0E0F0F1011111213
1314151617181A1B1C1D1D1E1E1F1F1F1F1F1F1F1F1E1E1D1D1C1C1C1B1B1A1A19181616
15141413131211100F0E0D0C0B0B0B0A0A09090808070707070606050504040404040403
030303030302030202020201010101010101010101010101010101010101010101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000100010101010101010101010101020101020202020202020202030303
03030303040404040505050506060607070808090A0A0B0B0C0D0D0E0F0F101011121214
15151718191A1B1C1D1E1F2020202121212222222221201F1F1E1E1E1D1D1C1B1A191817
1616151414131211100F0E0D0C0C0B0B0A09090808070707070606050505040404040404
030303030303020202020202020201020101010101010101010100010001000100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010001010101010101010101010101010202020202020303030303
03030303040404050505050606060707080809090A0B0B0C0C0D0E0F0F10101112131315
1617191A1B1C1D1E1F20212222222323242425252423232221212020201F1E1D1C1B1A19
181716151514131211100F0E0D0C0C0B0A0A0A0808080807070706060505040404040403
030303030303020202020202010101010101010101010101010101010100000000000100
000000000001010000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000101010101010101010101010101020202020202020203030303
030303040404040505050506060607070808090A0A0B0C0C0D0E0E0F1010111213131516
18191B1C1D1E1F2021222323242525262627282828272625242323232221201F1E1D1C1B
1A191817161514131211100F0E0D0C0B0B0A090908080808070706060505050504040404
030303030303020202020202010201010101010101010101010101000101010100000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000010001010101010101010101010202020202020202020203030303
030304040404040505060506060707080808090A0A0B0C0D0E0E0F101011121214151618
191B1D1E1F21222223242526272727282A2B2C2C2C2B2A282727262625242322201F1E1D
1C1B1A19171615141311110F0E0D0D0C0B0A0A0908080808070707060505050404040404
040303030302030202020202020101010101010101010101000101010100010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001010101010101010101010101020102020202020202020303030303
030304040405050505060606060607080809090A0B0B0C0D0E0F10101111121314161819
1C1D1F212223242425272728292A2A2B2D2F3031302F2E2C2B2A2929282725242221201F
1D1C1B1A19171615131211100F0E0D0D0C0B0A0909090808070707060505050404040404
040303030303020202020202020201010101010101010101010101000101000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000101000001010101010101010101020202020202020202020203030303
0304040405050505050606060707070809090A0A0B0C0D0E0F0F1011121213141517191B
1D1F21222425262728292A2A2B2C2E2F31333535353433312F2E2D2C2B2A282624232220
1F1E1D1B1A18171615131211100F0E0D0C0B0B0A09090908080807060606050504050404
040303030303030302020202020202010101010101010101010100000101010000000000
000100000000000000000100000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010100010001010101010101010101010102020202020203030203030303
0304040404050505050606060707080809090A0B0B0C0D0E0F1011111213141516181A1C
1F202324252728292A2B2C2D2E2F30323437393A3A3937363332302F2E2C2B2927252322
21201E1C1B1918161514131211100E0E0D0C0B0A0A090908080807060605050504040404
040303030303020202020202020101010101010101010101010101010101010101000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000000010101010101010101010101010202020202020202020303030303
03040404040505050506060707080809090A0A0B0C0D0E0F101112121314151617191B1E
2022242628292A2B2C2D2F3031323436393B3D3E3F3E3C3A37353332312F2D2B29272524
22211F1D1B1A19171615141211100F0E0D0C0B0B0A0A0909080807060605050504040404
040303030303030202020202020201010101010101010101010101010100000101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000100000000000000
000000000000000001010101010101010101010101010202020202020202020203030303
040404040405050506060607070809090A0A0B0B0C0D0F101111121314141517191B1D1F
222426282A2B2C2D2F3032333436373A3C3F41434342403E3B3937353432302E2C292826
2422201E1D1B19181716151312110F0F0E0D0C0B0B0A0A09090807070606050505040404
040403030303030202020202020202010102010101010101010101010101010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000010000000101010101010101010101010101010202020202020202020203030303
0303040405050505060607070808090A0A0A0B0C0D0E0F1011121213141517181A1C1E20
2325282A2C2D2F3032343537383A3C3E40434547474645423F3D3B39373633312E2C2927
2623221F1E1C1A19181715141311100F0E0D0D0C0B0A0A09090807070606050505050404
040404030303030302020202020201010202010101010101010101010101010001010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000100000001000101010101010101010101010101020202020202020303030303
0304040404050505060607080808090A0A0B0B0C0D0E0F1011121314151618191B1D1F22
2427292C2E30323335383A3C3D3F41434547494A4B4A494644413F3C3B393634312E2C29
272523211F1D1C1A191816151312110F0E0E0D0C0C0B0A0A090808070606060505050405
040304030303030302020202020202010102010101010101010101010101010101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000001000000
000000000000010000010101010101010101010101010201020202020202020203030303
0404040405050506060707080809090A0A0B0B0C0D0E0F10121314151617191A1D1F2123
25282B2E303235373A3D3F41434547484A4C4D4E4E4E4C4A484643403F3C3A3834312E2C
29272523211F1D1B1A181716141211100F0E0E0D0C0B0A0A090908080706060505050404
040403030303030302020202020202020101010101010101010101010101010100000101
000000010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000000100000101010101010101010101010102010202020202020303030303
04040404050505060607070808090A0A0B0B0B0C0D0E10111213141517181A1C1E202224
27292C2F3235383B3E414547494B4D4E4F5051525252504F4C4A474542403D3A3733302E
2C29282623211F1D1B19181614131110100F0E0D0C0B0B0A090908080706060605050504
040404030303030303020202020202010102010101010101010101010101000101000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001010001000101010101010101010101010101020202020202030303030304
0404040405050606060707080809090A0A0B0C0C0D0F10111213141617191B1D1F212325
282A2E3134373B3F43474A4D4F5152535454555555545452504E4C494744403D3A363330
2E2C2A282523211E1C1A181715131211100F0E0E0D0C0B0A0A0908070706060605050504
040404040303030302020202020202020201010101010101010101010101010100000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000101000101000001010101010101010101010101010202020202020303030303
0404040405050606060707080809090A0B0B0C0D0D0F101112141516181A1C1E20222426
282B2E3235393E42474B4F525557575858585858585757555452504D4B4744403C393633
312E2C2A282522201E1B19171513121110100E0E0D0C0B0A0A0908080707060606060504
040404040303030303030202020202020201010101010101010100010001000100010000
000100000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000001000101010101010101010101010101010202020202020202020203030303
0404040505050606060707070809090A0B0B0C0D0E0F111213141517191B1D2022242527
2A2C2F33373C40464B505357595A5B5D5C5C5C5B5B5A5A59585654514E4B47423F3B3835
33312F2C2A2724211F1C1A181614131210100F0E0D0C0B0B0A0909080707070606050505
040404040403030303020202020202020201010101010101010101010101010001010001
010000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101010101010101010101010101010101010102020202020203030203030304
0404040505050606060707080808090A0B0C0C0D0F101112131416181A1C1F2123242628
2B2D3034393E43484E52565A5C5E5F60616161605F5E5E5C5B595754514E4945413E3A37
3533302E2B2825221F1D1B181615131211100F0E0D0C0C0B0A0909080807070606050505
050404030304030303020202020202020101010101010101010101010100000000010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010000010100010101010101010101010102010102020202020202030303030303
0404040505060606060707080809090A0B0C0D0E0F101113141516191B1D202124262729
2B2E32363B40464B5054585C5E61636667696969686664615F5D5A5754504D4844403D39
3734322F2C292623201D1B191716141211100F0E0D0C0C0B0A0A09090807070606050505
050404040303030303020202020202010101010101010101010101010101000100000100
000100000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101010001010101010101010101010101010102020202020202030303030303
0304040505050606060707080809090A0B0C0D0E0F111113141617191B1E20222426282B
2D3034383E43484D52565A5D6164696D7174767674716D6965605D5956534F4C48433F3C
383533302C292623201E1C1A1816141311100F0E0D0C0B0B0B0A09090807070606060505
040404040403030303020202020202010201010101010101010101010100010001010100
000000000001000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001010000000001010001010101010101010101020102020202020202030303030304
04040405050606060707070808090A0A0B0C0E0F101012131416171A1C1F212325272A2C
2F32363B40454B4F54575B5F646A70787F85888986817B736C66605C5855524F4B46423E
3A3633302D292623201E1C1A1816141311100E0D0D0C0B0B0A0A09090808070606060505
050404040303030302030202020202020101010101010101010101010101010101000000
000101000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000100
000001000101000101010101010101010101010101010102020202020303030303030303
04040405050606060707080809090A0B0C0D0E0F101112131416181A1D1F222426292B2D
3134393E42484D5155595D6168707A8590999FA09D968C80766B635E5A5654514E494440
3B3734302D2A2623211F1C1A1817151311100E0D0D0C0B0B0A0A09090807070606050505
050404040303030303020202020202020101010101010101010101010101010101000101
000000000100010000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000101010001000001010101010101010101010101010102020202020203030303030403
04040404050506060707080809090A0B0C0D0D0F101111131416181A1D20222527292C2F
32363B3F45494E53565A5E646D788594A3B0B8BBB7ADA090817368605B585653504C4741
3D3834302D2A2724211F1C1A1917151312100E0D0C0C0B0B0A0A09080807060606050505
040404030303030303020302020202020102010101010101010101010101010100010101
010100000001000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101000101010101010101010101010101010102020202020203030303030303
04040405050506060707080809090A0B0C0D0E0E0F1011131416181A1D202325282B2D31
34383D42464B4F53575B6067728091A3B6C6D1D5D1C5B4A08C7A6C625C595754524D4842
3D3834302D2A2724211F1D1B1917151311100F0D0D0C0B0B0A0A09090807060606050505
040404030303030303020202020202020201010101010101010101010101000101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000000000100010101010101010101010101010102020202020203030303030404
04040404050506060707080808090A0A0C0C0E0E0F1011121416181A1D202326282B2E32
363A3E43474C5053575C616A76869AB0C6D9E6EBE7DAC6AE968070645D595755524E4943
3D3833302D2A2725221F1D1B1917151311100F0E0D0C0C0B0A0A09080807070605050505
040404030303030303020202020202020201010201010101010101010100010000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000100
000000000000000000010101010101010101010101010102020202020202030303030304
04040405050506060707080809090A0A0B0C0D0E0F1011121415181A1D202327292C2F33
363B3F43484C5053575B616B77899FB8D1E6F4FAF6E8D2B89E8573655D595755534E4943
3D37332F2C29272422201D1B1917151312110F0E0D0C0C0B0A0A09080807060605050505
050404030303030303020202020202020202010101010101010101010101010100000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000010001000001010101010101010101010101010102020202020203030303030304
04040405050606070707080809090A0B0B0C0D0E101011131416181B1E202327292C2F32
363B3F44484C5053575A60697789A0B9D3E9F9FFFCEDD7BCA18874665D585654524E4842
3C37322E2B29262422201D1B1917151312110F0E0D0C0B0B0A0A09080807070605050504
050404040403030303030302020202020101010101010101010101010100010000000000
010000010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000000010001010101010101010101010101010101020202020202030303030304
04040405050606060708080809090A0A0B0C0D0E0F1112131416181B1E212326292C2F32
363B3F44484C5053565A5F6775869CB5CEE4F4FAF7EAD4BB9F8774655C585553514D4842
3B36322E2B29262421201D1B191715141211100E0D0C0C0B0A0909080807060605050505
040404040303030303030202020202020101010101010101010101010101010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000100000000
000000000001000001000101010101010101010101010102020202020202030303030303
04040404050506070707070808090A0A0B0C0D0E0F1012131416181B1E212426282B2E31
353A3E43484C505356585D64708094AAC2D6E5ECE9DDCAB39A8371635B575453504C4741
3B36312E2B282623211F1D1B191715141211100F0D0C0B0A0A0909080807060606050504
040404040303030303020202020202020101010101010101010101010101010100010000
000000010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001010000010101010101010101010101010202020202020203030303030304
04040404050506070707070808090A0A0B0C0D0E0F1012131416191B1E202326282B2D31
35393D42474C505355585B616B79899DB1C3D1D7D5CBBAA6907C6C61595553514F4A4641
3B36312E2A282523201E1C1A181715141211100F0D0C0B0A0A0909080807070606050505
040404040303030303020202020202020201020101010101010101010101010101000000
000000000001000000010000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000010000000000000000
000000010100000001000101010101010101010101020202020202020202020303030303
0404040405050606060707080809090A0B0C0D0E0F1011131416181B1D202325272A2D30
33373C41464B4F5255585B5F66707E8E9EADB8BDBCB5A7968474675D575452504D4A4540
3A36322E2A282522201E1C1A181615141211100E0D0C0B0A0A0909090807070606050504
040404040303030303030202020202010102010101010101010101010101010101010001
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000010000
000000000000010101010101010101010101010102010202020202020203020303030303
0404040405050606070707080809090A0B0C0D0E0F1011131416181A1D202325272A2C2F
32363A3F44494E5255575A5D6269737F8C97A0A4A49D9386786B615A5552504F4C48443F
3A35312E2A2724221F1D1B191816151312110F0E0D0C0B0A0A0909090808070606050504
040404030303030303030202020202010101010101010101010101010101010101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000101010101010101010101010101010202020202020203030303030304
0404040405050606070707080809090A0B0C0C0E0F1011121416181A1D1F222426292B2D
3134373C42474D515457595B5F646A737C83898D8C8881776D645C5653514F4D4A46423D
3934312D2A2724211F1D1A191716141311100F0E0D0C0B0A0A0A09090807070606050504
040404040303030303020202020202010202020102010101010101010101010101000000
010001000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000101010001010101010101010101010101010202020202020202030303030304
0404040405050606070707080809090A0B0C0D0D0E0F11121415171A1C1F212326282A2C
2F32363A3F454A4F5356585A5D6063696E7377797976716B635D585452504F4C4945403B
3733302D292724211F1C1A181615131211100F0E0D0C0B0A0A0909080807070606050404
040404040303030303020202020202010102020101010101010101010101010100010001
000001010000010000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000100
000001010001000101010101010101010101010101010102020202020303030303030303
0404040405050606070708080809090A0B0B0C0D0E0F1012131517191C1E20232427292B
2E3033373C42484D515457595A5C5F616467696B6A6965615C59555351504D4B47433E39
35312E2B282623211E1C1A181614131211100F0E0D0C0B0A0A0909080807070605050404
040404040303030303030202020202020102010101010101010101010101010100010000
000001010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010101010001010001010100010101010101010202020202020202020303030303
0404040404050506060707080809090A0B0B0C0D0E0F1011131417191B1E1F222325272A
2C2E31353A3F444A4E51545658595B5C5D5F6060605F5D5B58565452514F4C4945403B37
332F2C2A272523201E1C19181614131211100F0D0D0C0B0A090908080707060605050404
040404030403030302030202020202020201010101010101010101010101010100010000
000001000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000001
000000000001000100010101010101010101010101010102020202020203030303030304
0404040404050606060708080809090A0B0B0C0D0E0F1011131416181A1D1E2022242628
2B2D3033373C41464A4E51535557585959595A595958575655535251504E4B47423D3834
302D2B28262422201D1B19171514131210100F0D0C0C0B0A090908080707060605050404
040404040303030302020202020202020101010101010101010101010101010100000000
000100000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000001000001010101010101010101010101020102020202020202030303030303
0404040405050506060707080809090A0B0B0C0D0E0E0F1112141617191B1D1F21232527
292B2E3135393D4246494D50525456565656565554545453525251504E4C48443E3A3531
2E2B29272523211F1D1B191715141312100F0E0D0C0B0A0A090808070706060605050404
040404030303030302020202020202010201010101010101010101010101010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001010001000101010001010101010101010101010101020202020202030303030304
0404040405050506060707070809090A0A0B0C0D0E0F0F1112131517191A1C1E1F212426
282A2D2F32363A3E4145484B4E515354545453535151515050504E4D4B4844403B36322E
2B2927252321201E1C1A181715141212100F0E0D0C0B0A09090808070606060505050404
040403030303030302020202020202020201010101010101010101010100000001010101
010000010001000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000101010101010101010101010101010101010102020202020202020303030304
040404050505050606070707080809090A0B0C0D0D0E0F1011131516181A1B1D1F202224
26282B2D3033373A3D4043474A4D4F51515151504F4E4E4D4D4C4B494744403B36322F2C
2927252322201F1D1B19181614131211100F0E0D0B0B0A09090807070706060505050404
040303030303030203020202020202020102010101010101010101010101010101010000
000100000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000100
000000010101000101010001010101010101010101010102020202020202020203030304
040404040505050506060707080809090A0B0C0C0D0E0F101113141618191B1C1E1F2123
2527292B2E313437393C3F4246494B4D4E4F4E4D4C4B4A4A49484644423E3A37322F2C2A
28262422211F1D1C1A18171513131210100F0E0D0C0A0A09080808070606050505050404
040303030303030302020202020202010201010101010101010101010100010100000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010001010001010101010101010101010101020101010202020202020203030303
040404040404050505060607070808090A0A0B0C0D0E0F101112141517181A1B1D1E2022
232527292C2F313436393B3E414446494A4A4A49484847464543413F3C3935322F2C2A28
262423211F1E1C1B19181615131211100F0E0E0C0B0A0A09090807070606050505050404
040303030303020202020202020201020102020101010101010101010101010000010000
000001000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001010000000101010101010101010101010101010201010202020202020202030303
03040404040505050506060707070808090A0B0C0D0E0F0F101213141617181A1C1D1F20
222425272A2C2F313436383A3C3F41434445464545444341403E3C3A3734312F2C2A2927
252321201E1C1B1918171513131211100F0E0D0C0B0A0A09080807070606050505040404
040403030303020202020202020101010101010101010101010101010101010100000000
000100010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001010100010001010101010101010101010101020202020202020203030303
04040404040505050506060607070808090A0B0B0C0D0F0F10111214151618191B1C1D1E
20212325282A2C2F3133343637393B3D3F40414141403F3D3B39373532302E2C2A292826
2423211F1D1B1A18171614131211100F0F0E0D0C0B0A0909080807070606050505040404
040403030303030202020202020201020102010101010101010101010101000101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000000000000000101010101010101010101010101020202020202020203030303
0303040404040505050606060707080808090A0B0C0D0E0E0F10111314151617191A1B1C
1E1F212325282B2D2F303132333536383A3B3D3D3D3C3B39373533312E2D2B2929272625
2321201E1C1A1918161514121111100F0E0D0C0B0B0A0909080807070606050505050404
040303030303020202020202020201020201010101010101010101010101010000000100
000000000000000000000000000001000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100010101000101010101010101010201010202020202020202030303
0303040404040505050506060707070808090A0B0C0D0D0E0F101112131414161718191A
1C1D1F212326282B2D2E2F3030313234353739393939373533312F2D2C2A292827262523
22201E1C1B1918171614131211100F0E0D0D0C0B0A0A0908080807070606050505040404
040303030303020202020202020202010101010101010101000101010000000001010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000101
000100010000000001010101010101010101010101010102020202020202020203030303
0303040304040405050506060607070808090A0A0B0C0C0D0E0F0F111112131415171819
1A1B1D1F212426282A2B2C2D2D2E2F303234353536353432302E2C2A2928272625242321
201E1D1B1A18171615141211100F0F0D0D0C0B0B0A090908080707060606050505040404
030303030302020202020202020201010101010101010101010101010101010000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000000000100000101010101010101010101010201020202020202020202030303
030303040404040505050606060707080809090A0B0B0C0D0D0E0F101011121314151617
18191B1D1F21232527292A2B2B2B2C2D2F3031323231302E2D2B2928272624242321201F
1D1C1B1A19171615141311100F0E0E0D0C0B0B0A09090808070707060605050505040404
030303030302020202020202010201010101010101010101010101010101010000000000
000100010000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010101000101010101010101010102020202020202020202020203
030303030404040405050506060707080809090A0A0B0B0C0D0D0E0F1010111213141516
17181A1B1D1F2123252627282829292B2C2D2E2E2E2E2D2B2928262524242322201F1E1C
1B1A191817161514131211100F0E0D0C0B0A0A0909080808070706060605050505040404
030303030303020202020202010201010101010101010101010101010100010000000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001010101010001010101010101010102010202020202020202020203
03030303040404040505050606070707080809090A0A0B0C0C0D0E0E0F0F101012131415
1617181A1B1D1E202223242526272728292A2A2B2B2A2927262523232221211F1E1D1B1A
19181716161514131211100F0E0D0C0B0A0A0A0908080807070606060605050504040404
030303020202020202020202010101010101010101010101010101010101000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000001000101010101000101010101010101010102020102020202020202020202
0303030303040404050505060607070707080809090A0B0B0C0D0D0D0E0E0F1011121314
15161718191B1C1E1F2121222323242526262727272625242322212020201E1D1C1A1918
171615151414131211100F0E0D0C0B0B0A09090808080707070606060505050404040403
030303020302020202020202010101010101010101010101010101010100000101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
010000000001000000010101010101010101010101010101010102020202020202020203
0303030303030404040505050606070707080808090A0A0B0B0C0D0D0D0E0E0F10111213
1415161718191A1C1D1E1F1F202121222223242424232221201F1E1E1E1E1C1C1A191817
1615151413121211100F0E0D0C0C0B0A0A09090808080707070606050505050404040303
030303020202020202020202020101010101010101010101010101010000010100000100
000000000000000001000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000101010101010101010101010101010201020202020202020202
030303030303030404040505050606060607070809090A0B0B0C0C0C0C0D0E0E0F101212
131415161717191A1B1B1C1D1E1E1F1F2020212121201F1E1E1D1C1C1C1C1B1A19181716
15141313121211100F0E0D0C0C0B0A0A0909080808080707060605050504040404040303
030302020202020202020201010101010101010101010101010100010000010001000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000100
000000000000000000000101010101010101010101010101010101020202020202020202
03030303030303040404050505060606060707070809090A0B0B0C0C0C0D0D0E0F101111
1213141415161718191A1A1B1B1C1C1D1D1E1E1E1E1E1D1C1C1B1B1B1A1A191818171615
141312121111100F0E0D0C0C0B0A0A090909080807080706060605050504040404040303
030302020202020202020101010101010101010101010101010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000010000000000000000000000
000000000001000100000001010101010101010101010101010101020202020202020203
02030303030303040404050505050506060607070808090A0A0B0B0B0C0C0C0D0E101011
121213141415161717181819191A1A1A1B1B1C1C1C1C1B1A1A1919191818181716151514
1313121110100F0E0D0C0C0B0A0A09090808080707070606060605050504040403030303
030202020202020202020201010101010101010101010101010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000001000000
000000000000000000000001010101010101010101010101010101010202020202020202
0203030303030303040404040505050506060607070809090A0A0B0B0B0B0C0D0E0F1010
1111121314141515161617171718181918191A1A1A1A1919181817171716161615141413
12121110100F0E0E0D0C0B0A0A0908090808080707060606060505050505040404030303
020202020202020202010101010101010101010101010101010100010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010100010101010101010101010101010101010202020202020202
0203020303030303040404040505050506060607070708090A0A0A0A0A0B0C0C0D0E0F10
101111121313141415151516161717171717181818181817171616151515141413131212
111110100F0E0D0C0C0B0A0A090908080807070706060606050505050404040403030303
030202020202020201020101010101010101010101010101010101000001000000000000
000100000100000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010100010001010101010101010101010101020101020202020202
02020303030303030404040404040505050506060607080809090A090A0A0B0C0D0D0E0F
101011111213131313131414151515151616161616171616151514141313131212121111
11100F0E0E0D0C0B0B0A0A09090808080707070606060505050505040404040403030303
030203020202020202020201010101010101010101010101010101000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000100000000000000010100010101010101010101010101020202020202020202
02020203030303030304040404040505050506060607080808090909090A0A0B0C0D0E0E
0F0F10111112121212121213131314141515151515151414141313121212111111101010
100F0E0E0D0C0B0B0A0A0909080808070707060606050505050504040404030303030303
030202020202020202020101010101010101010101010101010100010000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000101010101010101010101010101010202010202020202
0202020203030303040404040404050505050505060707070808080909090A0A0B0C0D0D
0E0E0F101011111111111111121213131313131313131313121211111111101010100F0F
0F0E0D0D0C0B0A0A0A090908080807070706060605050505040404040404030303030303
030202020202020202020101010101010101010101010101010001000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010001010101000101000101010101010101010101020101010202020202
020203030303030303030404040404040505050506070707080808080809090A0B0B0C0C
0D0D0E0E0F0F101010101010101111121212121212121111111010100F0F0F0F0F0E0E0E
0E0D0D0C0B0B0A0909090808080807070606060505050504040404040403030303030303
020202020202020201010101010101010101010101010001010101000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001010100010001010101010101010101010101020201020202
02020202020303030303030404040404050505050606060707080808080809090A0A0B0B
0C0C0D0D0E0E0F0F0F0F0F0F0F0F10101011101010101010100F0F0F0F0F0E0E0E0E0D0D
0D0C0C0B0B0A090908080808070707060606060505040404040404030303030303030302
020202020202020101010101010101010101010101010100000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000001000000000100010101010101010101010101010101010102020202
0202020203030303030303030404040404040505050606060707080808080809090A0A0A
0B0B0C0C0C0D0E0D0E0D0E0E0E0E0E0F0F0F0F0F0F0F0F0F0E0E0E0E0E0E0E0E0D0D0D0C
0C0B0B0A0A09090808080807070706060605050505040404040404030303030303030303
020202020202020201010101010101010101010101010101010000000000000001000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000000001010100010101010101010101010101010101020202
02020202020202030303030303040404040405050505060606070707080808080909090A
0A0A0B0B0C0C0C0D0C0D0D0D0D0D0D0E0E0E0E0E0E0E0E0D0D0E0D0D0D0D0D0C0C0C0B0B
0B0B0A0A0909080808070707070606050605050504040404040303030303030303020202
020202020202010202010101010101010101010101010001000000010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000000000001010100010101010101010101010101010201010202
020202020202030303030303030404040404040505050506060607070707080808090909
090A0A0A0A0B0B0B0C0C0C0C0C0C0C0D0D0D0D0D0D0D0C0C0D0D0D0C0C0C0C0C0B0B0B0B
0A0A09090908080807070706060606050505050504040404030303030303030302020202
020202020101020102010101010101010101010101010100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000010000010000010101010101010101010101010101010101010202
020202020202020303030303030304040404040505050506060606060707070808080909
090909090A0A0A0A0A0B0B0B0B0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0C0B0B0B0B0A0A0A
090909080808070707070606060505050505040404040303040303030303030202020202
020202020101010101010101010101010101010101010000010001010001010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010001000001000101010101010101010101010101020202
020202020202020202030303030303040404040404050505050606060607070708080808
09090909090909090A0A0A0A0A0A0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0B0A0A0A0909
090808080707070706060605050505050504040404040303030303030303030202020202
020202020101010101010101010101010101010101010100010100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000001000001010101010101010101010101010101010102
020202020202020302020303030303030303040404050505050506060606060707070808
080808090808080909090909090A0A0A0A0A0A0A0A0A0A0A0A0A0A0A0A0A0A0909090908
080808070707070706060505050504050404040403030303030303030303020202020202
020101010101010101010101010101010101010101010100000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000001000101010101010101010101010101010101010101
010102020202020202020203030303030303040404040405050505060606060607070707
070808080808080808090909090909090A0A0A0A090A0A0A090A09090909090909080808
070707070707060606050505040404040404040403030303030303030302020302020202
020202010101010101010101010101010101010101010100000000000100000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000001000000010101010101010101010101010101010101
010101010102020202020202020303030303030304040404050505050605050606060607
070707070707080808080909080909090909090909090909090909090909090808080807
070707070607060605050504040404040404040303030303030303030303020202020202
020202010101010101010101010101010101010101010101000001010001000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000101010101010101010101010101010102
010101020202020202020202020203030303030404040404050405050505050505050606
060607070707070708080808080808080808090808080808080808080808080808070707
070606060606060605050404040404040404040303030303030302030202020202020202
020201010101010101010101010101010101010001000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100010101010101010101010101010101
010102020202020202020202020202030303030303040404040404050505050505050505
060606060607070707070808080807080808080808080808080807080707070707070707
060606060606050505050404040403040303030303030303030302020202020202020202
020101010101010101010101010101010101010100010101000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000010001000100010101010101010101010101010101
010101020202020202020202020202020303030303030304040404040405050404050505
050506060606060707070707070707070707070707070707070707070707070706060606
060606050506050505040404040404040303030303030303030202020202020202020202
020101010101010101010101010101000101010101010100010100000000010000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000101000101010101010101010101
010101020202020202020202020202020203030303030303040404040404040404050505
050505050606060606060707070707070707070707060707060606060606060606060606
050505050505050504040404040404040303030303030203030302020202020202020101
010101010101010101010101010101010000010101010100010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000101010001000000010101010101010101010101
010102020201020202010202020202020203030303030303030403040304040404040405
050505050506050606060606060606070706060606060606060606060606060606060606
050505050505050504040404040404040303030303030302020202020202020202010101
010101010101010101010101010101000100000100000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000000000000101000000000101010101010101010101
010101010102020202020202020202020202020303030303030303030304040404040404
050405050505050505050606060606060606060606060606060606060605060506060505
050504050405040404040404040403030303030303020202020202020202020201020101
010101010101010101010101010101010101000100010000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000010001010101010101010101010101
010101010102020201010202020202020202020203030303030303030303030404040404
040405050505050505050505050606060605060505050505050505050505050505050505
050504040404040404040404030403030303030302020202020202020202020201010101
010101010101010101010101010101010101000101010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000100000001010101010101010101010101
010101010102010101010202020202020202020202020303030303030303030303040404
040404050404050505050505050505050505050505050505050505050505050505050504
040404040404040404040303030303030303030202020202020202020202020101010101
010101010101010101010101010100010100010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000000010101010101010101
010101010102010101010202010102020202020202030203020203030303030303030404
040404040404040505040505050505050505050505050505050505040405050404050404
040404040403040303030303030303030303030203020202020202020202010201010101
010101010101010101010101010101010101000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000001000001000001010101010101
010101010101010101020201010202020202020203020202030202020303030303030303
030304040404040404040404040405050505040505050505040505040404040404040404
040403030303030303030303030303030203020202020202020202020202010201010101
010101010101010101010101010101010001010100000000010100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000000000000000000000100000000000001000101010101010101
010101010101010101010101010201020202020202020202020202030203030303030303
030304030404040404040404040404040404040404040404040404040404040404040404
040303030303030303030303030303020202020202020202020202020101010101010101
010101010101010101010101010101000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010001010001010101
010101010101010101010101020102020202020202020202020202030203020302030303
030303030303040404040404040404040404040404040404040404040404040404040404
040303030303030303030302020202020202020202020202020201010201010101010101
010101010101010100010101010000000101000000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000000000000101010000000101010101
010101010101010101010101010101020202020202020202020202020202020302030303
030303030303030303030304030303030304040404040404040404030303040304040303
030303030303030202020202020202020202020202020202020101010102010101010101
010101010101010001000100000100000001000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000001000001000101010101
010101010101010101010101010201020202020202020202020202020202020203020303
030303030303030303030303030303030303030304040303030303040303030303030303
030303030303020202020202020202020202020202020101010201010101010101010101
010101010101010100000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000101010101
010101010101010101010101010202020202020102020202020202020202020202030303
030303030303030303030303030303030303030303030303030303030303040303030303
030303030302020202020202020202020202020201010102010101010101010101010101
010101010101010100010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000001010101
010101010101010101010101010101020202020202020202020202020202020202020203
030203020303030303030303030303030303030303030303030303030303030303030303
030203020202020202020202020202020202020201020101010101010101010101010101
010101010100010100000001000000010000000000010000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000100000001010001
010101010101010101010101010101010201020202020202020202020202020202020202
020202020203030303020303020203020303030303030303030303030303030303030302
030302020202020202020202020202020202020101010101010101010101010101010101
010101010100010000000001000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010000000101010101
010101010101010101010101010201020101020102020102020202020202020202020202
020202020203020202030202030202020303030302030303030302030203030203030303
020202020202020202020202020202020202010101010101010101010101010101010101
010001010101010001000000010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000000000000000000000
000100010101010101010101010101010101010101020201010202010202020201020202
020202020202020202020202020202020302020303030202020303020202020203020202
020202020202020202020202020101010201010101010101010101010101010101010101
010101010001010100010101010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000000000001
010100010101010101010101010101010101010101010101010101020202020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202020202020101010101010101010101010101010101010101010101010101
010101010101010001010000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
010101010100010101010101010101010101010101010101010101010101020202020202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202020202020101020101010102010101010101010101010101010101010101
000100010101010001010100010000000000000000000000010000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000000000000010101
010101000100010001010101010101010101010101010101010101010201020101010202
020202020202020202020202020202020202020202020202020202020202020202020202
020202020202010201010101020101010101010101010101010101010101010101010001
010101010100010100010000000100000000000000000001000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010100
010101010100010101010101010101010101010101010101010101010101010202010201
020202020202020202020102020202020202020202020202020202020102020202020202
020202020202020201010101010101010101010101010101010101010101010101000101
000101000100010001000000000100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000001000101
010001010100010100010101010101010101010101010101010101010101010101020202
020102010202010202010201020202020202020202020202020201020102010101020202
020202010101010101010101010101010101010101010101010101010101010100000001
000101010000000101000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000001
010001010100010100010101010101010101010101010101010101010101010102020101
010201010102010202010201020102010202020202020202020201010202020201010101
010101010201010101010101010101010101010101010101010101000101010000000000
000000000001010001000001000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000100
000101000000010101000101010101010101010101010101010101010101010101010101
010101010101010202020101020202020202020201020102010102010101010101020101
010201010201010101020101010101010101010101010101010101010101000000010101
010100010000000000010000000001000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000010001010001010101010101010101010101010101010101010101010101010101
010101010101010101020101010202010202020102020201010101010101010101010201
010101010101010101010101010101010101010101010101010101010101010101000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000100000000
010000000100000100010101010101010101010101010101010101010101010101010101
010101010101010101010101020102020102010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010100010101010100000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000000000001000101
000000000100000000000001010101010100010101010101010101010101010101010101
010101010101010101010101010101010102010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010001010101000100000000
010100000000000001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010001010000000101010000000001010101010101010101010101010101010101010101
010101010101010101010101010101010201010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010100010000000000
000001000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000100000000000000000000000000
000000000001000001000000010001010000010101010001010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101000001000000000000010000
000000000000000001000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100000000000000
000001000001000101000001010001000101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101000101000100000101000001000001000100
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000001000000000000
010000000000000100000000000000000100010100010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010000000001000001000000000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000100000000000000010100010101000000010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010000010101010101010100010000010000000001000100010001
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000100000000000000000000
000000000101000000010000000000000000000001000000010101010100010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010100000001000101010001010000000000000000000000000100
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000000000001010000000000000000000000000100010001000101010001010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010100000001000101000000000000000100000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000010000000000000000000000000000000001000000010100000101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101000101010001000000010001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000001000000000000000000000100000000000101000101010101
010001010101010101010101010101010101010101010101010101010101010101010101
010101010001010101000101010001000100010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000000000010001000000000101010001010101
000000010101010001010101010101010101010101010101010101010101010101010101
010101010001000000000101000000000101000100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010000010000010101010101
010101000101000000010101010101010101010101010101010101000100010101010101
010101010001010100010001000100000001010100000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000100000000000000000000010100000100000000
010001000101000000000101010101010101010101010101010100010101000101000101
000101010101000100000000000000000000010000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010000010000000000000001010000010101010000
000101010001010101000001010100010001010101010101010000010100010100000000
010100010101000000000000000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000010000
000001000000010100010001010001000100010100000101000101000100000001000100
010000010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010001000000000000
010000000000000101000100000100000100000100010100000000000100010001000000
010000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000100000000000000000000000000000000000100010000000100000000
010000000001000001000001010001010001000000010100000000000000010000000001
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000000000100010001000100000001000001000001000100000000000000010000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000100010000000000
000000000000000000010100000000000000000000000100000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000001000001000000010000000000000001000000000000000000000000000001000100
000000000100000000000000000000000001000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000010000000000000100000000000000000000
000000000000000000000000010000000000000000000100000000000000000000000000
000001000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000001000000000000000000000000000000000000
000000000000000000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000001000000
000000000000000000000000000000000000000000000001000000000000000000000000
000000010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100010000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000001
000000000000000000000000000000000100000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000001000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000100000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZCX0000000<00@41
000000000000C00000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfY
?`0000001@010@4000000000000000000@4100X0000000<00@41000000000000>00000040=7=Z@00
0`3AcJTY0000000300410@000000000005d00000103AcJT000<0dLfY<P0000000`010@4000000000
00030000000300410@00000000000080000000<00@41000000010@400`0000000`010@4000000000
000200410@d0000000<00@41000000000000<@0000040=7=Z@000`3AcJTc000000800@410`000000
1@010@4000000000000000000@41008000000P010@40100000000@41000000010@44000000030041
0@0000000@4100/0000000<00@41000000000000;`0000040=7=Z@000`3AcJT]0000000300410@00
0000000000@0000000D00@41000000000000000000410@030000000300410@0000000@4100<00@41
00<0000000410@010@401`010@42000000800@412@0000000`010@4000000000000]000000@0dLfY
00030=7=ZC00000000D00@41000000000000000000410@020000000600410@0000000@4100000001
0@4000003`010@420000000500410@0000000@41000000010@40=P0000040=7=Z@000`3AcJTb0000
000700410@0000000@4100410@0000000@410000000E00410@03000000010@400@4100800@411`00
00000`010@4000000000000/000000@0dLfY00030=7=ZBl0000000@00@4100000000000000001@01
0@400`0000000@4100410@0N00410C000000103AcJT000<0dLfY:00000000`010@40000000000006
0000000300410@0000000@4102000@410`0000000`010@400000000000050000000400410@000000
000000410BH00000103AcJT000<0dLfY;@0000001P010@40000000410@0000000@41000002D00@41
0`0000000`010@40000000410@0[000000@0dLfY00030=7=ZBP0000000<00@410000000000000P01
0@400`0000000@4100410@0E00410@0300820P010@400@4100h00@4100<0000000410@010@400P00
00001@010@4000000000000000000@4102T00000103AcJT000<0dLfY9P00000300410@@0000000<0
0@41000000010@404`010@400`020P800@4100820P0D00410@04000000010@400@41000000800@41
0`0000000`010@4000000000000S000000@0dLfY00030=7=ZB/000000P010@400`0000000@410041
0@0C00410@0300820P010@400P8200800P8200<00@4100820P010@404P010@460000000300410@00
0000000002<00000103AcJT000<0dLfY9P00000200410@03000000010@400@4100d00@410P020P83
00410@h00P8250010@40100000000@4100410@010@4V000000@0dLfY00030=7=ZB<000000P010@43
000001400@415P020P8200410@800P823`010@42000000800@418`0000040=7=Z@000`3AcJTS0000
01800@411`020P800`030`<00P8200820P0E00820Pl00@410P0000000`010@4000000000000J0000
000300410@000000000000@00000103AcJT000<0dLfY7P0000000`010@40000000000002000000`0
0@4100H00P8200410@010@400@4100820P010@4800820P0300<30`020P800P8200D00P820P030`<0
0`020P800`<300<30`0<00820Pd00@410P0000000`010@4000000000000Q000000@0dLfY00030=7=
ZB4000003`010@4<00820Q400`<320020P800`010@400P8200820P0:00410@04000000010@400000
00410@@0000000<00@41000000000000700000040=7=Z@000`3AcJTP000000800@4100<000000041
0@010@402`010@4;00820Q<00`<32P020P8>00410@@0000000<00@41000000000000700000040=7=
Z@000`3AcJTN0000000400410@0000000000000000`00@4100<00P8200410@020P801P020P800`03
0`<00P8200<30`0500<30`0300@410030`<010@400@00`<30`0410@700<30`0300820P030`<00P82
00@00P8200<00@4100820P010@402@010@401@0000000@410000000000000@4102400000103AcJT0
00<0dLfY7000000010010@40000000000000000<00410@H00P8200<00`<300820P020P801P030`<B
00@410L00`<31P020P8<00410@80000000@00@410000000000000@417@0000040=7=Z@000`3AcJTH
0000000600410@0000000000000000010@4000000P010@400`0000000@4100410@0700410@030082
0P010@400@4100@00P822@030`<;00@410L01@D50P0410@300<30`0400@410030`<00`<300<30`L0
0P8230010@400`0000000@41000000030000000300410@000000000001P00000103AcJT000<0dLfY
600000000`010@400000000000020000000300410@0000000@4100/00@411@020P8500<30`0300@4
10030`<010@400@010@440051@D700@410800`<320020P8900410@80000000D00@41000000010@40
000000410@0L000000@0dLfY00030=7=ZA`000000P010@43000000T00@411P020P8400<30`H010@4
1@051@D;00H61PD01@D5100410@500<30`L00P822P010@4P000000@0dLfY00030=7=ZAd0000000<0
0@4100000000000020010@4600820P@00`<31P0410@300D51@@01PH62`071`L400H61P@01@D50`04
10@500<30`D00P8200<00@4100820P010@401`010@400`0000000@4100410@0M000000@0dLfY0003
0=7=ZAd000002P010@4700820P<00`<3100410@400D51@<01PH60`071`L:00P820801`L710061PH4
00D51@8010@41P030`<600820PX00@4100<0000000410@0000006`0000040=7=Z@000`3AcJTJ0000
000400410@0000000@41000000T00@4110020P8400<30`<010@400<01@D500@410051@D00P051@D3
00H61P<01`L700<020P800T92@092@T01@092@T00`0:2PX02@T900T92@0200T92@0400P820071`L0
1`L700L71`D01PH60P051@D200@410D00`<31@020P8900410@03000000010@400@410080000000<0
0@410000000000005`0000040=7=Z@000`3AcJTL000000T00@411`020P8300<30`<010@40`051@D4
00H61P801`L70P0820P300T92@0400X:2P092@T02PX:00T92@D02PX:00<02@T900P820071`L00`07
1`L400H61P801@D5100410@400<30`D00P822@010@400`0000000@410000000K000000@0dLfY0003
0=7=ZA/0000000<00@41000000010@4020010@4400820PD00`<30P0410@300D51@0400H61P071`L0
1`L700L71`<020P80P092@T01@0:2PX02`/;00/;2`0;2`/02PX:00L02`/;00<02PX:00T92@092@T0
0P0820P500L71`0300H61P051@D01@D500<010@41@030`<010020P800`<300820P020P8:00410@@0
000000<00@410000000000005P0000040=7=Z@000`3AcJT?0000000300410@000000000000L00000
00<00@410000000000002@010@4500820P<00`<30`0410@200D51@801PH600@01`L700P8200820P0
20P80P092@T00`0:2PX02`/;00/;2`0600`<30<03@d=0`0<30`200/;2`802PX:0P092@T300P82080
1`L700@01PH600D51@051@D01@D50`0410@400<30`D00P822P010@4K000000@0dLfY00030=7=ZAP0
000000D00@41000000010@400@410000000800410@<00P8200@00`<300820P030`<00`<30`0410@2
00D51@801PH600@01`L700P820092@T02@T90P0:2PX200/;2`0300`<300=3@d03@d=00@03Ph>1@0?
3`l00`0>3Ph03@d=00d=3@0200`<30802`/;00@02PX:00T92@092@T02@T90P0820P010071`L01PH6
00H61P051@D300@410D00`<310020P8900410@80000000<00@410000000000000`0000000`010@40
00000000000A000000@0dLfY00030=7=ZA/000002@010@4400820P<00`<30`0410@300D51@0600H6
1P071`L01`L700P820092@T02PX:0P0;2`/200`<300300d=3@0>3Ph03`l?0080410@0`0A4A42018B
4P03014A4@0@41003`l?00<03`l?0P0>3Ph01@0=3@d030`<00/;2`0:2PX02@T9008020P80P071`L2
00H61P0400D51@0410@010@400@410@00`<310020P800`010@400P8200410@0700410@8000000P01
0@4G000000@0dLfY00030=7=ZAT000002`010@4500820P800`<30`0410@00`051@D01PH600H61P02
00L71`8020P800<02PX:00/;2`0<30`00P0=3@d00`0>3Ph03`l?010@4002018B4P<04a<C0`0D51@5
018B4P804A4A00H0410@00l?3`0>3Ph03@d=00`<300:2PX200T92@0500P820071`L01`L700L71`06
1PH00P051@D200@410<00`<310020P8:00410A/00000103AcJT000<0dLfY6P00000900410@D00P82
0`030`<200@410801@D500<01PH600L71`071`L00P0820P010092@T02`/;00`<300=3@d300l?3`03
014A4@0C4a<05ADE00805QHF100G5aL00`0F5QH05ADE01DE5@0401DE5@0401<C4`0B4Q804A4A010@
40803Ph>00@030`<00/;2`0:2PX02@T90P0820P010071`L01PH600H61P051@D400@410800`<31@02
0P8800410A/00000103AcJT000<0dLfY6000000900410@D00P8210030`<200@410801@D500@01PH6
00L71`0820P020P80P092@T01@0;2`/030`<00d=3@0?3`l0410@00804A4A00D04a<C01DE5@0G5aL0
6ATI01XJ6P0401/K6`806QXJ0`0I6AT01P0H61P05aLG01HF5P0D51@04a<C014A4@80410@00D03Ph>
00`<300;2`/02PX:00T92@0200P820801`L700@01PH600D51@0410@010@410030`<500820PP00@41
6P0000040=7=Z@000`3AcJTG0000000300410@0000000@4100L00@4110020P8400<30`8010@40P05
1@D200H61P0:00L71`0820P02@T900X:2P0;2`/030`<00d=3@0?3`l0410@014A4@804a<C00H05ADE
01LG5`0J6QX071`L01dM7@0N7Qh401lO7`0A01hN7P0M7Ad071`L01`L700K6a/06QXJ01TI6@0F5QH0
5ADE01@D500C4a<04Q8B010@400>3Ph030`<00/;2`0:2PX00P092@T01@0820P01`L700L71`061PH0
1@D500<010@40`030`<400820P/00@415`0000040=7=Z@000`3AcJTG000000T00@411@020P8400<3
0`8010@40P051@D200H61P0300L71`0820P02PX:00802`/;00`03@d=00h>3P0?3`l0410@018B4P0D
51@05ADE01LG5`0I6AT06a/K01dM7@0O7al2020P8005024Q8@0R8R808R8R024Q8@0O7al00P0N7Qh0
3@0M7Ad071`L01XJ6P0H61P05QHF01DE5@0D51@04a<C014A4@0?3`l03@d=00`<300;2`/00P092@T0
1@0820P01`L700L71`061PH01@D500@010@40`030`<400820PX00@415`0000040=7=Z@000`3AcJTI
000000L00@4110020P8400<30`8010@40`051@D01@061PH01`L700P820092@T02PX:008030`<01<0
3Ph>00l?3`0@41004Q8B01<C4`0F5QH061PH01/K6`0M7Ad07alO024Q8@0S8b<092@T02DU9@0V9RH0
9bLW02PX:00W9bL09BDU00808b<S00l08R8R020P800N7Qh071`L01XJ6P0H61P05QHF01DE5@0C4a<0
4A4A00l?3`0=3@d02`/;00X:2P092@T00P0820P00`071`L01PH600D51@0200D51@8010@40`030`<3
00820PP00@4100<0000000410@010@405`0000040=7=Z@000`3AcJTH000000P00@4110020P8400<3
0`0300@410051@D01@D500<01PH602`01`L700P820092@T02`/;00`<300=3@d03`l?010@400A4A40
4a<C01HF5P0I6AT071`L01lO7`0R8R8092@T02DU9@0W9bL0:BTY02XZ:P0[:b/0;bl_034a<@0_;bl0
;2`/02XZ:P0Y:BT0:2PX02DU9@0R8R80820P01dM7@0K6a/06ATI01LG5`0E5AD04Q8B010@400>3Ph0
3@d=00/;2`0:2PX02@T900P820801`L70P051@D300@410<00`<310020P8700410@03000000010@40
000001L00000103AcJT000<0dLfY5P00000:00410@<00P8210030`<200@410801@D50P061PH0<007
1`L020P800T92@0:2PX02`/;00d=3@0>3Ph0410@014A4@0C4a<05ADE01PH600L71`07alO02<S8`0U
9BD0:2PX02XZ:P0/;2`0;Rh^02l_;`0b<S80=cLg03Xj>P0i>CT0=SHf038b<P0`<300;Rh^02/[:`0W
9bL08b<S024Q8@0N7Qh06a/K01TI6@0F5QH051@D018B4P0@41003Ph>00`<300;2`/02PX:00T92@08
20P01`L700H61P801@D50P0410@300<30`@00P822P010@400`0000000@410000000D000000@0dLfY
00030=7=ZAP000001`010@4500820P<00`<30P0410@200D51@801PH603001`L700T92@0:2PX02`/;
00`<300?3`l0410@014A4@0C4a<051@D01LG5`0K6a/07alO028R8P0V9RH0:RXZ02`/;00_;bl0<S8b
03@d=00f=SH0>SXj03lo?`13@d<0@T9203hn?P0i>CT0=cLg03@d=00`<300;2`/02PX:00T92@0820P
01dM7@0K6a/061PH01HF5P0C4a<04A4A00l?3`0=3@d030`<00/;2`0:2PX02@T900L71`061PH200D5
1@<010@40P030`<500820PP00@41600000040=7=Z@000`3AcJTE0000000400410@00000000000000
00L00@4110020P8300<30`8010@40P051@D06@061PH01`L700P820092@T02PX:00/;2`0=3@d03`l?
010@400B4Q8051@D01HF5P0I6AT07AdM028R8P0T92@0:BTY02h^;P0b<S80=CDe03Xj>P0m?Cd0?clo
04=3@`17AdL00P1:BTX05P16ATH0@D5103lo?`0k>c/0=SHf034a<@0/;2`09bLW02<S8`0O7al07AdM
01XJ6P0H61P05ADE018B4P0?3`l03Ph>00d=3@0<30`02PX:00T92@0820P200H61P<01@D510030`<4
00820PX00@415P0000040=7=Z@000`3AcJTG0000000300410@0000000@4100L00@410`020P8300<3
0`8010@400H01@D500H61P071`L01`L700P8200:2PX200/;2`0C00d=3@0@41004A4A01<C4`0E5AD0
61PH01`L700P820092@T02LW9`0/;2`0<S8b03Ph>00n?Sh0ADE504U9B@1;Bd/0CTi>051@D002059B
DP0G04m?C`1:BTX0AdM70492@P0m?Cd0=cLg030`<00/;2`0:2PX02<S8`0Q8B407AdM01TI6@0F5QH0
4a<C010@400?3`l03Ph>00`<300;2`/02@T900P820071`L00P061PH00`051@D010@400@4100400<3
0`<00P822@010@400`0000000@410000000D000000@0dLfY00030=7=ZAD0000000@00@4100000001
0@40000020010@4300820P<00`<30P0410@06@051@D01PH600L71`071`L020P800T92@0;2`/030`<
00d=3@0@41004A4A01@D500F5QH06QXJ01hN7P0R8R809RHV02PX:00^;Rh0=CDe03hn?P17AdL0Cdm?
05EEE@1GEeL00`1HF5P0601GEeL0EEEE059BDP1@D500Bd];04A4A00l?3`0=SHf034a<@0/;2`0:2PX
02DU9@0P82006a/K01LG5`0C4a<04A4A010@400>3Ph03@d=00/;2`0:2PX020P800L71`<01PH60`04
10@300<30`@00P822@010@4F000000@0dLfY00030=7=ZAD000002`010@4300820P<00`<30P0410@2
00D51@0e00H61P071`L01`L700P820092@T02`/;00`<300?3`l04A4A018B4P0D51@061PH01`L700Q
8B4092@T02PX:00[:b/0<30`03Ti>@13@d<0CTi>05IFEP1LG5`0GUiN061PH01QHF40H61P05iNGP1L
G5`0FEUI05MGE`1ADE40BDU90451@@0j>SX0=CDe030`<00[:b/0:2PX028R8P0M7Ad061PH01DE5@0B
4Q80410@00l?3`0=3@d030`<00X:2P092@T020P800L71`061PH00P051@D00`0410@00`<300@41002
00<30`<00P821`010@420000000300410@000000000001@00000103AcJT000<0dLfY5P0000080041
0@0300820P010@400P8200800P8210030`<0100410@01@D500H61P061PH200L71`0F00P820092@T0
2`/;00d=3@0?3`l04A4A01<C4`0E5AD06ATI01dM7@0Q8B409RHV02TY:@0[:b/0<S8b03/k>`16ATH0
D51@05QHF01NGUh0HF5Q06IVIP80JFUY01X0IVIV065QH@1MGEd0FUYJ05ADE01=CDd0A4A403dm?@0g
=cL0<S8b02`/;00Y:BT08b<S01dM7@0I6AT05QHF018B4P0@41003`l?00d=3@0<30`02PX:00T92@08
20P01`L700H61P801@D50P0410@300<30`<00P822@010@400`0000000@410000000D000000@0dLfY
00030=7=ZA@0000000@00@41000000000000000020010@4300820P<00`<30P0410@00`051@D01PH6
00H61P0200L71`0a00P8200:2PX02`/;00h>3P0@41004Q8B01<C4`0F5QH06QXJ01lO7`0S8b<09bLW
02`/;00_;bl0=SHf0410@01;Bd/0E5AD05]KF`1TI6@0JVYZ07QhN025QHD0RHV90861P@1cLg<0IVIV
061PH01HF5P0DU9B04];B`12@T80>SXj03<c<`0];Bd0:BTY02<S8`0N7Qh06QXJ01HF5P0C4a<0410@
00h>3P0=3@d02`/;00X:2P092@T020P800L71`0200H61P0300D51@0410@010@400800`<310020P89
00410@<0000000<00@410000000000004@0000040=7=Z@000`3AcJTD0000000400410@0000000000
000000P00@410`020P8400<30`8010@403@01@D500H61P071`L020P800T92@0:2PX030`<00d=3@0@
41004A4A01<C4`0F5QH06QXJ020P800U9BD0:BTY02l_;`0b<S80>c/k04E5A@1>CTh0EUIF05iNGP1]
KFd0N7Qh09BDU02`/;00^k^k0:f][@2@T900Lg=c06QXJ01KFe/0EUIF051@D017AdL0?Cdm03@d=00]
;Bd0:RXZ02@T900O7al06QXJ01LG5`0C4a<0410@00h>3P0<30`02`/;00X:2P092@T020P80P061PH2
00D51@0300@410030`<00`<300<00`<30P020P8<00410A@00000103AcJT000<0dLfY4`0000001001
0@40000000000000000900410@<00P820`030`<300@4100300D51@061PH01`L7008020P803402PX:
00`<300>3Ph03`l?014A4@0B4Q805QHF01XJ6P0P82009RHV02/[:`0b<S80=SHf03hn?P17AdL0D51@
05MGE`1QHF40MWIf08J6QP2`/;00fMWI0>_[j`3Jf]X0[Zj^0820P01`L700GEeM05MGE`1BDU80BDU9
03dm?@0c<c<0;Bd]02XZ:P0U9BD07alO01/K6`0G5aL04a<C010@400?3`l03@d=00`<300:2PX02@T9
00P820071`L01PH600801@D500<010@400<30`030`<00P030`<400820PH00@410`0000000`010@40
00000000000C000000@0dLfY00030=7=Z@h0000000<00@410000000000001`00000800410@<00P82
0`030`<200@4100h00D51@061PH01`L700L71`0820P02@T900X:2P0;2`/03@d=010@400A4A404a<C
01HF5P0K6a/0820P02LW9`0/;2`0<S8b03Hf=P0o?cl0B4Q8051@D01GEeL0H61P07MgM`29RHT0^KVi
0>WYj@3oool0kNg]0;bl_028R8P0M7Ad05eMG@1FEUH0DU9B04Q8B00l?3`0<S8b02/[:`0Y:BT092@T
020P800K6a/05aLG01<C4`0A4A403`l?00d=3@0;2`/02PX:00T92@0820P01`L700H61P051@D300@4
10@00`<30P020P8700410@@0000000<00@410000000000004P0000040=7=Z@000`3AcJTI000000L0
0@410`020P8400<30`8010@403@01@D500L71`071`L01`L700P8200:2PX02`/;00d=3@0?3`l04Q8B
01<C4`0F5QH06a/K024Q8@0V9RH0:b/[034a<@0e=CD0?Shn04Q8B01@D500EUIF05eMG@1`L700P820
0:ZZZP3Fe]H0k>c/0=gMg@2c/k<0Ph>3075aL@1KFe/0E5AD051@D017AdL0>c/k034a<@0[:b/0:2PX
02<S8`0O7al06a/K01LG5`0D51@04A4A010@400=3@d02`/;00X:2P092@T020P80P061PH010051@D0
10@400@4100410@300<30`<00P822P010@4F000000@0dLfY00030=7=Z@h0000000<00@4100000000
00001000000010010@40000000000000000600410@D00P820`030`<200@4100g00D51@061PH01`L7
00L71`0820P02@T900/;2`0=3@d03`l?014A4@0C4a<05QHF01/K6`0P82009BDU02XZ:P0`<300<c<c
03`l?016ATH0Cdm?05EEE@1KFe/0IVIV071`L02>SXh0[Jf]0;fm_@2e]KD0UYJF07AdM01WIfL0EeMG
059BDP1=CDd0ADE503Xj>P0b<S80:RXZ02PX:00R8R807QhN01XJ6P0F5QH051@D014A4@0@41003@d=
00/;2`0:2PX02@T900P820071`L01PH600D51@0300@410<00`<30`020P8:00410AH00000103AcJT0
00<0dLfY5`00000800410@@00P820`030`<300@4100g00D51@061PH01`L700L71`0820P02@T900/;
2`0<30`03`l?014A4@0B4Q805QHF01XJ6P0O7al092@T02TY:@0];Bd0<C4a03Lg=`12@T80CDe=05AD
E01IFET0GemO06ATI01cLg<0Ph>308f=S@28R8P0MgMg06ATI01LG5`0De=C04m?C`1:BTX0@T9203Ti
>@0a<C40:RXZ02LW9`0Q8B407AdM01TI6@0F5QH04a<C010@400?3`l03@d=00/;2`0:2PX02@T900P8
20071`L01PH600D51@0300@410<00`<31P020P8600410@8000000P010@4C000000@0dLfY00030=7=
ZA@000000`010@400`0000000@4100410@0500410@@00P820`030`<300@4100g00D51@061PH01`L7
00L71`0820P02@T900/;2`0=3@d03Ph>014A4@0B4Q805ADE01XJ6P0O7al08b<S02PX:00/;2`0;bl_
03Hf=P0o?cl0BTY:05=CD`1HF5P0GEeM061PH01YJFT0Lg=c07UiN@1fMWH0Jf][05eMG@1HF5P0DU9B
04m?C`19BDT0@41003Lg=`0`<300:BTY02LW9`0Q8B4071`L01PH600E5AD04Q8B010@400?3`l03@d=
00/;2`0:2PX02@T900P820071`L01PH600D51@0300@410<00`<30`020P800`010@400P8200410@07
00410@80000000<00@41000000010@404@0000040=7=Z@000`3AcJTE000000800@4100<000000041
0@010@401@010@4500820P<00`<30P0410@0=0051@D01PH600L71`071`L020P800T92@0;2`/030`<
00h>3P0@41004A4A01@D500I6AT07QhN028R8P0U9BD0:RXZ02`/;00a<C40>SXj04A4A01>CTh0E5AD
05QHF01IFET0G5aL05mOG`1PH600GemO05]KF`1FEUH0E5AD055AD@1<C4`0ADE503/k>`0c<c<0;2`/
02LW9`0U9BD0820P01`L700H61P051@D018B4P0@41003`l?00d=3@0;2`/02@T900P820071`L200H6
1P0300D51@0410@010@400<00`<31@020P8900410@80000000<00@410000000000004@0000040=7=
Z@000`3AcJTD0000000400410@0000000000000000P00@410`020P8400<30`8010@401T01@D500H6
1P071`L01`L700P820092@T02`/;00`<300>3Ph03`l?014A4@0D51@05aLG01/K6`0O7al08b<S02LW
9`0Y:BT0;Rh^03De=@0m?Cd0ATI604e=C@1BDU80E5AD0080EUIF01T0EEEE05ADE01CDe<0DU9B055A
D@1>CTh0B4Q803hn?P0e=CD0;Rh^02TY:@0U9BD08b<S01lO7`0K6a/05aLG01@D500B4Q803`l?00h>
3P0<30`02PX:00T92@0820P01`L700801PH600<01@D500@4100410@00`030`<500820PL00@416000
00040=7=Z@000`3AcJTE000000/00@4110020P8200<30`8010@40P051@D060061PH01`L700L71`08
20P02@T900X:2P0<30`03@d=00l?3`0@41004a<C01HF5P0J6QX07AdM020P800T92@09RHV02/[:`0`
<300=cLg03dm?@13@d<0BTY:04e=C@80DE5A01L0D51@04i>CP1=CDd0C4a<04];B`17AdL0@41003Hf
=P0_;bl0:BTY02DU9@0R8R80820P01dM7@0I6AT05QHF01<C4`0A4A403`l?00h>3P0;2`/02PX:00T9
2@0200L71`0400H61P051@D01@D500@410<00`<300<00P8200<30`020P800P020P8:00410AH00000
103AcJT000<0dLfY5P0000000`010@40000000410@0800410@<00P820`030`<300@4100/00D51@06
1PH01PH600L71`0820P02PX:00/;2`0=3@d03`l?010@400B4Q805ADE01PH600K6a/07QhN028R8P0S
8b<09bLW02`/;00a<C40=SHf03/k>`11@D40A4A404U9B@1:BTX0BDU904Q8B016ATH0@d=30451@@0l
?3`0=CDe02l_;`0Z:RX09RHV02<S8`0O7al07QhN01/K6`0H61P05ADE018B4P0@410200h>3P0500/;
2`0:2PX02@T900L71`061PH00`051@D0100410@00`<300<30`030`<400820P800@4100<00P820041
0@010@4010010@401@0000000@410000000000000@4101<00000103AcJT000<0dLfY5P00000:0041
0@@00P820`030`<200@410801@D50P061PH01@071`L020P800T92@0;2`/030`<00803`l?02T04A4A
01@D500F5QH06ATI01`L700N7Qh0820P02<S8`0X:2P0;2`/034a<@0d=3@0=cLg03Ti>@0m?Cd0@410
0451@@10@400?Cdm03Ti>@0g=cL0<S8b02h^;P0Z:RX0:2PX02@T900Q8B407AdM01/K6`0H61P05QHF
01<C4`0A4A403`l?00h>3P0=3@d02`/;00T92@0820P01`L700H61P0200D51@<010@40P030`<40082
0PX00@415`0000040=7=Z@000`3AcJTG000000P00@4100<00P8200410@020P800`020P8300<30`80
10@40P051@D060061PH01`L700L71`0820P02PX:00`<300=3@d03Ph>010@400B4Q8051@D01HF5P0H
61P06QXJ01`L700O7al08b<S02PX:00];Bd0;bl_030`<00a<C40=3@d03Lg=`80>CTi01L0=CDe034a
<@0_;bl0;2`/02TY:@0W9bL09BDU028R8P0N7Qh06a/K01TI6@0G5aL051@D018B4P0@41003Ph>00d=
3@0<30`02PX:00T92@0820P01`L700H61P0200D51@8010@40`030`<500820PL00@410P0000000`01
0@4000000000000D000000@0dLfY00030=7=ZAL0000000<00@41000000010@401@010@4600820P<0
0`<30P0410@200D51@801PH601801`L700P820092@T02`/;00`<300=3@d03Ph>010@400A4A404a<C
01DE5@0G5aL061PH01/K6`0O7al08b<S02LW9`0Z:RX202/[:`0D02d];@0`<300<S8b034a<@0^;Rh0
:b/[02TY:@0W9bL092@T02<S8`0P82007AdM01/K6`0I6AT05aLG01DE5@0C4a<0410@00h>3P0=3@d2
00/;2`0500T92@0820P01`L700L71`061PH00P051@D200@410800`<310020P8:00410AP00000103A
cJT000<0dLfY6000000200410@03000000010@400@4100@00@411@020P8300<30`8010@40P051@D0
:@061PH01`L700P820092@T02PX:00/;2`0<30`03@d=00h>3P0?3`l0410@01<C4`0E5AD05QHF01PH
600K6a/07QhN028R8P0T92@09RHV02LW9`0X:2P0:RXZ02/[:`0Z:RX09bLW02DU9@0S8b<08R8R024Q
8@0N7Qh06a/K01TI6@0G5aL05QHF01DE5@0C4a<04A4A00l?3`0=3@d02`/;00802PX:0P0820P00`07
1`L01PH600H61P0200D51@8010@400<00`<300820P020P800`020P8:00410AP00000103AcJT000<0
dLfY5`00000900410@L00P820P030`<200@410801@D500D01PH600L71`071`L020P800T92@0200/;
2`803@d=00X03Ph>010@400B4Q8051@D01DE5@0G5aL06ATI01`L700O7al08B4Q0P0S8b<03@0U9BD0
9RHV02LW9`0V9RH092@T028R8P0Q8B40820P01hN7P0L71`06ATI01LG5`0E5AD00P0D51@01@0B4Q80
410@00h>3P0<30`02`/;00802@T900@020P800L71`071`L01PH60P051@D200@410800`<31@020P89
00410@03000000010@40000001H00000103AcJT000<0dLfY5`0000000`010@40000000410@080041
0@D00P820`030`<200@410801@D50P061PH010071`L02@T900X:2P0;2`/200`<300:00d=3@0>3Ph0
410@018B4P0C4a<05ADE01LG5`0I6AT06a/K01`L70807QhN00H07alO020P800Q8B40820P01hN7P0M
7Ad201`L700501/K6`0I6AT05aLG01DE5@0C4a<00P0B4Q801P0@41003Ph>00`<300;2`/02PX:00T9
2@8020P800@01`L700H61P051@D01@D50`0410@200<30`D00P822@010@430000000300410@000000
000001<00000103AcJT000<0dLfY5`0000000`010@40000000410@0800410@@00P8210030`<200@4
10<01@D500D01PH600L71`0820P02@T900X:2P0200/;2`0;00`<300=3@d0410@014A4@0B4Q804a<C
01@D500F5QH05aLG01PH600I6AT00P0J6QX0100K6a/071`L01`L700J6QX201TI6@8061PH00@05QHF
01DE5@0C4a<04Q8B0P0@41001@0>3Ph030`<00/;2`0:2PX02@T9008020P800<01`L700H61P061PH0
0P051@D200@410800`<31P020P8800410AX00000103AcJT000<0dLfY600000000`010@4000000041
0@0700410@D00P8210030`<200@410801@D50P061PH00`071`L020P800T92@0200X:2P0300/;2`0<
30`03Ph>0080410@00<04A4A01<C4`0D51@00P0E5AD0100F5QH05aLG01LG5`0G5aL201PH600@01LG
5`0F5QH05QHF01DE5@0D51@04a<C018B4P0A4A40410@00l?3`0>3Ph030`<00/;2`0:2PX02@T900P8
20801`L70P061PH200D51@<010@40P030`<400820PX00@4100<0000000410@000000100000000`01
0@4000000000000@000000@0dLfY00030=7=ZAD0000000<00@410000000000000P00000800410@H0
0P820`030`<300@410801@D50P061PH200P820802@T900L02PX:00/;2`0=3@d03Ph>00l?3`0@4100
4A4A00<04Q8B0P0C4a<01@0D51@05ADE01DE5@0E5AD051@D00804a<C00<04Q8B014A4@0A4A400P0@
41001`0>3Ph03@d=00`<300;2`/02PX:00T92@0820P00P071`L200H61P801@D50P0410@400<30`D0
0P822P010@4I000000@0dLfY00030=7=ZAH0000000<00@41000000010@400P010@400`0000000@41
00410@0600410@@00P8210030`<300@410801@D500<01PH600L71`071`L00P0820P01`092@T02PX:
00/;2`0<30`03@d=00h>3P0?3`l0100@41000`0A4A404Q8B018B4P02018B4P03014A4@0@4100410@
00<03`l?0P0>3Ph00`0=3@d02`/;00/;2`0200T92@8020P800<01`L700H61P061PH00P051@D300@4
10@00`<310020P8:00410AX00000103AcJT000<0dLfY6P00000:00410@D00P8210030`<300@41080
1@D50P061PH010071`L020P800P820092@T200X:2P0300/;2`0<30`030`<00D03Ph>1@0?3`l400h>
3P803@d=00@030`<00/;2`0:2PX02@T90P0820P200L71`0400H61P051@D01@D500D51@<010@41@03
0`<400820PT00@416`0000040=7=Z@000`3AcJTG0000000600410@0000000000000000010@400000
2@010@4400820P@00`<30`0410@200D51@801PH60P071`L0100820P02@T900T92@092@T200X:2P03
00/;2`0<30`030`<008030`<100=3@d00`0<30`03@d=00d=3@0200`<30802`/;00<02PX:00T92@09
2@T00P0820P00`071`L01PH600H61P0300D51@8010@41@030`<400820P800@4100<00P8200410@01
0@401@010@4L000000@0dLfY00030=7=ZA`000002@010@4600820P@00`<30`0410@200D51@801PH6
0P071`L200P820@02@T9100:2PX900/;2`0400X:2P092@T02@T900P820<01`L700@01PH600D51@05
1@D01@D50`0410@500<30`D00P822P010@400`0000000@410000000I000000@0dLfY00030=7=ZAT0
000000<00@410000000000002P010@4400820P0300<30`020P800`<300<00`<30P0410@300D51@80
1PH60P071`L500P820<02@T92P0:2PX200T92@8020P80`071`L010061PH01@D500D51@051@D200@4
10D00`<310020P8<00410@03000000010@40000001T00000103AcJT000<0dLfY7@00000<00410@D0
0P820`030`<300@410<01@D50P061PH400L71`8020P800<02@T900P820092@T02@092@T200P82080
1`L700@01PH600L71`061PH01@D51@0410@500<30`D00P8230010@400`0000000@4100410@0H0000
00@0dLfY00030=7=ZAd0000000<00@41000000010@4020010@4700820P<00`<30`0410@500D51@<0
1PH60P071`L900P820D01`L710061PH200D51@<010@41@030`<600820PX00@4100<0000000410@01
0@406`0000040=7=Z@000`3AcJTO0000000300410@0000000@4100H00@4120020P8400<30`@010@4
10051@D300H61PH01`L700<01PH600L71`061PH01@061PH500D51@@010@40`030`<00`020P800`<3
00820P0400820PT00@4100@0000000410@010@400@41700000040=7=Z@000`3AcJTI000000040041
0@0000000000000000800@410P00000800410@P00P821@030`<400@410D01@D53@061PH200D51@80
10@400<01@D500@4100410@00P0410@400<30`L00P822P010@420000000300410@000000000001X0
0000103AcJT000<0dLfY7@0000000`010@4000000000000900410@0300820P010@400@4100H00P82
1P030`<500@411001@D51P0410@500<30`H00P822P010@400`0000000@4100410@0N000000@0dLfY
00030=7=ZB40000000<00@41000000010@401`010@4200820P0500410@020P800P8200820P030`<0
10020P8500<30`L010@41`051@D500@410T00`<31P020P800`010@400P8200410@0900410@030000
00010@4000000080000000<00@41000000000000600000040=7=Z@000`3AcJTS000000X00@412002
0P8800<30a4010@41@030`<800820P0300410@020P800@4100L00@4100D0000000410@010@400000
00410@0O000000@0dLfY00030=7=ZB40000000<00@410000000000002`010@4:00820P`00`<300<0
10@400<30`030`<02@030`<800820P`00@410P0000000`010@4000000000000O000000@0dLfY0003
0=7=ZB@000002P010@4:00820Q800`<300<010@400<30`030`<00`030`<800820Pd00@4190000004
0=7=Z@000`3AcJTR0000000300410@0000000@4100X00@413P020P8300<30`<00P822`030`<:0082
0P/00@419P0000040=7=Z@000`3AcJTP0000000300410@000000000000@000002`010@4010020P80
0@4100820P010@4>00820P800`<300<00P8200<30`030`<00P020P800`030`<00P8200820P060082
0Q400@4100<0000000410@010@408@0000040=7=Z@000`3AcJTV000000<00@4100<0000000410@01
0@402`010@4L00820P<00@4100<00P8200410@010@402`010@40100000000@4100410@010@4Q0000
00@0dLfY00030=7=ZBD0000000D00@41000000010@400@410000000=00410@0300820P010@400@41
00D00P8200<00@4100820P020P801`020P800`010@400P8200820P0600820Pd00@4100<000000041
0@010@400`0000000`010@4000000000000Q000000@0dLfY00030=7=ZB@0000000H00@4100000001
0@40000000410@00000>00410@0300820P010@400@4100<00@410`020P8200410@D00P8200<00@41
00820P020P8010010@400`020P800@4100410@0<00410@D0000000<00@41000000010@408`000004
0=7=Z@000`3AcJTX000000800@4100<0000000410@010@4050010@401@020P800@4100820P010@40
0P8200H00@4100<00P8200410@010@4040010@4Z000000@0dLfY00030=7=ZB@0000000<00@410000
00010@401P00000F00410@0300820P010@400@4101L00@4100D0000000410@000000000000410@03
0000000300410@000000000002400000103AcJT000<0dLfY7`0000000`010@400000000000070000
000400410@0000000000000000800@4100@0000000410@010@4000009`010@400`0000000@410000
00020000000300410@000000000000<0000000<00@410000000000008@0000040=7=Z@000`3AcJTR
0000000300410@000000000000@000000P010@42000002X00@4100D0000000410@010@4000000041
0@060000000300410@000000000002@00000103AcJT000<0dLfY;00000001P010@40000000000000
00000@41000000800@4100<0000000410@010@4070010@400`0000000@4100410@0200410@800000
00@00@4100000000000000000`010@4X000000@0dLfY00030=7=ZB/0000000<00@41000000000000
100000001P010@4000000000000000000@41000001/00@410`0000000`010@4000000000000`0000
00@0dLfY00030=7=ZC80000000@00@4100000000000000006@010@401@0000000@4100410@000000
0@4100<0000000<00@41000000000000;`0000040=7=Z@000`3AcJTe0000000300410@0000000@41
00D00@410P00000@00410@03000000010@400@4100<00@4100<0000000410@010@40<@0000040=7=
Z@000`3AcJT`0000000300410@00000000000080000000@00@41000000010@400@410P0000001@01
0@40000000410@010@40000000L00@410P00000200410@80000000@00@41000000010@400@411@00
00000`010@4000000000000`000000@0dLfY00030=7=ZCD000000P010@430000000400410@000000
0000000000800@4100@0000000410@00000000000P010@43000000<00@4100<0000000410@000000
>P0000040=7=Z@000`3AcJTk0000000300410@000000000000<0000000<00@41000000010@400P00
000200410D400000103AcJT000<0dLfY?`0000000`010@40000000000017000000@0dLfY00030=7=
ZC00000000D00@41000000000000000000410@0;0000000300410@000000000000/0000000<00@41
000000000000>00000040=7=Z@000`3AcJU60000000300410@000000000004000000103AcJT000<0
dLfY>@0000000`010@4000000000001=000000@0dLfY00030=7=ZEP0000000<00@41000000000000
;P0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@00T03AcJT00900dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {643.562, 500.562}} -> {-343.407, 930.874, \
1.87239, 1.87239}}],

Cell[BoxData[
    InterpretationBox[\("SNR: "\[InvisibleSpace]24.56499016282168`\
\[InvisibleSpace]" dB"\),
      SequenceForm[ "SNR: ", 24.56499016282168, " dB"],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
The observed blurred and noisy guide star can now be considered as \
an approximation to an unknown PSF (see the Guide Star section) and used to \
obtain and estimate of the inverse filter. The parameter \[CurlyPhi] is a \
truncation value chosen arbitrarily to take into account the necessity of \
minimizing perturbation. 
The estimated inverse filter is then used to start the NSH\[Dash]RIF routine; \
it will be improved during the iterations.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CurlyPhi]\  = \ 1\ /\ 100;\)\), "\[IndentingNewLine]", 
    \(\(s\_sat = \ 
        getFilterEstimation[
          g\&~\_star, \ \[CurlyPhi]];\)\), "\[IndentingNewLine]", 
    \(\({n\_\(y, \ sat\), \ n\_\(x, \ sat\)}\  = \ {111, \ 137};\)\  (*\ 
      estimated\ support\ *) \), "\[IndentingNewLine]", 
    \(\(\[Micro]\_sat\  = \ {3\ /\ 2, 120, 1\ /\ 20, 
          0};\)\), "\[IndentingNewLine]", 
    \(\(Timing[\({res\_sat, \ val\_sat, \ variation\_sat}\  = \ 
            NSHRIF[g\&~\_sat, s\_sat, \[Micro]\_sat, n\_\(y, \ sat\), \ 
              n\_\(x, \ sat\), \ 
              NSHRIFMaxIterations\  \[Rule] \ 5];\)]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \(250.3900000000001`\ Second\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The last element of the list ",
  Cell[BoxData[
      StyleBox[\(res\_sat\),
        FontWeight->"Bold"]]],
  ", returned by the algorithm, is taken as the restored image:"
}], "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(showImage[res\_sat];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 144 144 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0238095 0.00373483 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
255 string
255 255 8 [255 0 0 255 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000003070B0C0B0804000000
000000020C17232E3840454645403A322A211810090300000000000000000002070C0F11
100D08020000000000000009192A3B4C59646A6D6B665E54493E32271E150E0804020102
04080D12181C202121201C17120D09050302010202030303020100000000000000000000
00000000010406090B0D0E0F0E0C0A080000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000070D1012100C06000000
00000009172534424C545757534D453C332B231D17110B05000000000000000001080D11
110F0A020000000000000011253B516576818889867F74685B4E41362B2219120C070504
05070C11171C2022211F1A140D0702000000000002050708080705030000000000000000
0102040507090B0C0E0F1010100F0E0C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000109101516140F08000000
000003102133445460676A68625A50463E36302B27221C160E050000000000000002090E
11100B040000000000000519314B657C8F9CA3A39E95887A6B5D5043382E241C140E0906
05070A0F14191D1F1E1B150E070000000000000003070B0D0E0C0A070401000000000103
0507090B0C0D0E0E0F10101010100F0E0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000010A121819171109010000
00000616293D516370787A7770665C524A443F3C3A36312A21160A00000000000000040B
0F0F0C060000000000000C223D59768FA3B1B7B7B1A79989796A5C4F43392E251C140D08
0605070B0F14171817140E070000000000000000040A0F1213120F0C0805020101020407
090B0D0E0F0F0F0E0E0E0D0D0E0E0E0E0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000912181A18120A020000
000008192E455A6D7B8486837C72685E5752504F4F4D4942372A1B0D0000000000000007
0C0F0D09020000000003142B4764819BB0BEC5C4BEB2A494837465584C41372C2219110A
060404060A0D10110F0C06000000000000000000060D1316171613100B08050303040609
0B0E0F10100F0D0C0A09080809090A0B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000060F151716110A020000
0000091B30475E72828B8F8C867D736B656261636465625C5142311F0E00000000000003
0A0D0E0C07020000020C1D344F6B88A1B5C3C9C9C2B7A99989796B5E53473C32271D130B
0502010203060808070400000000000000000000081015191A1815110D09060504050709
0C0D0E0E0D0C090705030201020305070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000002090F12120E08010000
0000091A2F465D71828D91918C857D76727173777A7D7C766C5D4A362210020000000001
070C0E0E0C0907080D17273C546E889FB2BFC5C5BFB4A7998A7B6E61564A3F34291E140B
05000000000001010000000000000000000000040C121719191815110D09060504050608
090A0B0A0806030000000000000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000002080B0C0A06000000
000008172B40576B7C888F918F8B86828081858A90939490877865503925130600000001
060B0E101010101218212F42576E8498A8B3B9B9B4ACA194877A6D61564B3F34281D130A
03000000000000000000000000000000000003090F1316171714110E0A07050403030405
050505030100000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000003050503000000
0000071324384C60717E888D8F8F8D8D8E91969DA4A9AAA8A092806B543D29180C050203
060A0D101315171B212A3746576A7C8C99A2A7A8A59F968C81766B5F54483D31251A1108
0200000000000000000000000000000001060A0E12131413110E0B080503020101010000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000050F1C2C3E5061707D868C9094979BA0A7AEB6BBBEBCB6AA99856F58422E1F130C08
08090C1013171C2129323C495664727E888F939593908A837B72675C5145382C20160D05
000000000000000000000000000104080B0F11131312100D090603010000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002000000000000000000000000
0000040A14202F3F50606F7C879199A1A8AFB7BFC6CBCECDC7BEB09E89735C4735251911
0C0A0B0E12171D252D36404A545E676F767B7F8182817E7A756D64594D4033261A100802
000000000000000101020305070A0E1215171716130F0904000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000B010000000000000000000001
010203060C141F2D3D4E5F7181909EAAB4BEC6CDD3D8D9D9D4CDC1B2A08C77614D3A2A1D
130D0A0B0E141C252F39424B53595F64686B6E7173757574706B62574A3C2D1F13090200
000000020406070808090A0D1013171A1C1D1B1611090200000000000000000000000000
000000000000000001040504010000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000014090000000000000000000203
040303030409101B2A3C50657B8FA2B2C0CBD4DADFE1E2E0DCD6CEC2B4A3907B66513D2B
1C110B080A0F18222E39434C52575A5C5E606366696D70716F6A62574939291A0D040000
000003080B0E101011111214161A1D1F201F1B140C030000000000000000000000000000
000000000000050D14191A19140E06000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000001E130800000000000000000406
070503000000030C1A2C425A748EA5BACBD8E0E6E8E8E6E3E0DBD5CDC3B6A6947F69523C
28180D07060A121E2A37434C53585A5B5B5C5E62666B6F72716D65594938261609000000
0001070D13161818181717181A1C1F20201D181006000000000000000000030708060200
00000000020C18242D3436342D24180B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000271E1309000000000000010508
08060200000000000C1E36516E8CA8C0D4E2EBEFEFECE8E3DFDBD7D2CCC4B8A99680684F
3722120703050C182635434E575C5E5F5F606165696F747777736A5D4C39261506000000
00030B13191D1F1F1D1B1A19191A1C1C1B171109000000000000000000070F1315130E09
0503040A142231404C5457544B3D2D1C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000030291F150B0300000000030609
090602000000000002142C49698AA9C5DBEAF3F6F4EEE8E1DBD7D5D3D1CDC6BBAB967E63
482F1A0B02020813223243515C636769696A6B6E73787D80807B7264523E291607000000
00050E161D2123221F1B181614141414120E080100000000000000000A161F2426241F1A
1514171F2C3C4F606E787A766A59442F0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000036322B21180E07030102040708
0806010000000000000D25436487A9C6DEEFF8FAF6EFE6DDD6D1D0D0D2D2D0C9BCAA9377
5A3E2512060205101F314455636D7477797A7B7D8185898B8A857B6C59442F1B0B000000
000610181F2323211D18130F0C0A090807040000000000000000010E1C2933393B39342F
2B2A2E38475A6E81919A9C9688745B410000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003A39342D231A110B0705050607
06040000000000000008203E6083A6C5DEEFF9FBF7EEE3D9D0CBCACCCFD3D5D2CABBA68C
6F51351E0E06070F1E3145596A7881878B8C8D8F91949697948E8475624C372211050000
010810181E21201D17110A050100000000000000000000000005132232404B5153514C47
4343485364788DA1B1BABBB3A28B6F520000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003B3D3B362E241B130D09060605
040100000000000000071D395A7D9FBFD9EBF6F9F5ECE0D5CBC6C4C6CCD2D7D8D4C9B8A0
8365472E1A0F0D132033485E72828F979C9FA0A0A1A2A2A19E978C7D6B56402C1A0D0502
04090F151A1B1A150F0700000000000000000000000000000A18283A4B59646A6C6A6560
5D5E646F8094A9BDCBD3D2C8B59C7E5E0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000383D3E3B352D231A120C080503
010000000000000000061B35537496B4CEE2EEF2F0E8DED2C9C2C0C2C8D0D7DBDBD4C6B2
977A5C412B1D171A25364B62788B9AA5ACAFB0B0AFAEACA9A59E9385735F4A3624160D08
07090D111313110C050000000000000000000000000006111F2F405364727D8385837E7A
77787E8999ACC0D1DEE4E1D4C0A585650000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000323A3D3D39322920170F090501
0000000000000000000719304B6988A6BFD4E2E8E9E4DBD1C8C2BFC0C6CDD6DCDFDCD2C1
AA8F72573F2E25252D3C4F667C91A2AEB6BBBCBAB8B5B2AEA8A1978A7A6754412F20150E
0A090A0B0C0A0702000000000000000000000000050E19263647596B7C8A949A9C9A9692
909196A0AEBFD0DEE7EAE4D6C1A585650000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000002933393B39352D251C130C0601
00000000000000000008162A415B7793ACC1D1DBDFDED9D2CAC4C1C1C6CCD4DCE0E0DACD
BAA3896E56433733374354687E93A4B2BBC0C1BFBCB8B3AEA8A1988C7E6E5D4B392A1D13
0D0906050301000000000000000000000000020C16222F3E4E5F7183929FA8AEAFAEABA7
A5A6ABB3BECBD8E2E7E6DDCEB79C7D5F0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000001F29313536342F282018100903
000000000000000000081323364C647C94AABCCAD3D6D6D3CEC9C6C6C8CDD3DADFE1DED6
C7B49D856D594B44444B58697D90A2AFB9BEBFBDBAB4AFA9A39D958B8072635242322418
0F080300000000000000000000000000000A15202D3A485767778797A4B0B8BDBEBDBBB9
B7B8BBC1C8D1D8DDDDD8CDBBA58A6E530000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000141E262C30312F2A241D150E08
03000000000000000207101B293A4E647B91A5B7C4CED3D4D3D1CECDCDCFD3D8DDE0DFDA
D0C2AF9A8470605551545C6A7A8A9AA7B1B6B7B6B2ACA7A19C9690887F7366574838291B
1006000000000000000000000000010A15212D3A475462707E8D9AA7B2BCC3C7C9C9C7C6
C5C5C7C9CDD0D2D0CBC2B4A18B735A420000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000009121A22282C2D2B28231C1610
0A0603010000000103060B121C29384B60768CA1B4C3CED5D9D9D8D5D4D3D4D7DADCDDDB
D5CBBDAB98857467605D616975828F9BA3A8AAA9A5A19B96918D88827B7267594A3B2B1D
100500000000000000000000070F1924303C495663707C89949FAAB4BCC3C9CCCECFCFCF
CECECECDCCCAC5BEB4A695826D57422F0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000070F171F252A2C2B29241F19
130E0A07050403030304060A10182433465C738BA2B7C8D5DDE1E1DFDBD8D6D5D6D7D9D9
D6D0C6B9A99888796E6866697079828C93989A9A97938F8B87837F7B756E64584A3B2B1C
0F0400000000000000050D151F2935414E5B6874808B969FA8AFB6BCC2C7CBCED0D2D3D4
D3D2D0CDC7BFB5A8998874614D3A2A1B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000040D161E262B2E2F2D2924
1E18130E0B080605030202020509121E2E435B7590A9BFD1DEE6E8E7E3DDD8D4D2D2D2D3
D3D1CBC2B6A8998A7C726C6A6B70767D83878A8A8886837F7C7A77736E685F534638291A
0D030000000000050D17222D394653606D7A86929CA5ADB3B8BCC0C2C5C7CACCCFD1D3D5
D5D3CFC8BFB2A3917D6954402E1F12090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000040D18212A303434322E
29221C16110C0906030100000000030C1A2D45607C99B4CBDCE8EDEDE8E2DAD3CECCCBCC
CECECDC8C0B5A7988A7D736C69696C7074787B7C7C7B797774726F6C6760584D41332518
0C03000000020A14202C3A475563707E8B97A2ACB5BCC1C5C6C7C7C6C6C6C7C9CBCED1D2
D2D0CAC1B4A4907A634C3623130700000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000006111D2730373A3A37
322B241D16100B0703000000000000000B1C324C6988A5C0D5E4EDEFEBE4DBD2CBC6C4C5
C7CACBCAC6BEB3A697897C726B6766676A6D7072737373716F6D6A66605950463A2D2116
0C06030308101A2735435261707E8C99A5B0BBC3CACFD2D3D2D0CCC9C6C4C3C4C6C9CBCD
CDCAC3B7A8947E654C341E0C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010C18242F373D3F3E
39332B231B140E090400000000000000010F223A577594B1C9DBE7ECEAE4DBD1C8C1BEBE
C0C4C8CAC9C5BCB1A395877A7069656465676A6D6F7171706E6B67625B53493F33281E15
0E0B0B0E16202D3B4A5A6A798896A3AFBBC5CED6DBDFE0DFDCD7D1CBC6C2C0BFC0C2C4C5
C4C0B8AB9A856C5239210C00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000007131F2B343C4040
3D3730271F17110B06020000000000000006162B4562809DB8CDDCE4E5E1D9D0C6BFBAB9
BBBFC4C8CAC9C4BBAFA19385796F696666676A6E71737473716D6861594F443A2F251C16
1313161D2733415060707F8E9BA8B5C0CBD4DCE3E8EAEAE8E3DDD6CEC7C1BDBAB9BABABA
B8B3AA9C8A755C432A130000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000030D18242E373C3E
3D39322A221A140E0A0603000000000000010D1E344D6A87A2B9CBD7DCDBD6CEC5BDB8B6
B8BCC1C7CBCCCAC4BAAEA092857A726E6C6D7074777A7B7B78736C63594E42372D251F1B
1B1F252E3A4856667583919EAAB6C1CBD5DEE6ECF0F2F1EEE9E2D9D0C8C0BAB5B2B0AFAD
A9A3998B79654E361F0B0000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000008111B252E3538
3936322B241D17120E0C090704020000000007132439526D88A1B6C5CED2D0CBC4BDB8B6
B7BAC0C6CCCFCFCCC5BAADA093887F7A78787B7E82858685817B72685C50443930292625
282F3843505E6C7A8894A0ABB5BFC8D2DAE3EAF0F4F6F5F2EDE5DCD2C8BFB7B0AAA5A19D
978F85786755402C18060000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000401000000000209111A232A2F
32322F2B25201B17151311100E0B08040100030A15263B536D869DB0BDC5C8C7C3BFBAB8
B9BCC1C7CDD2D4D3CEC5BBAEA2978F898686888B8F9192908C847A6F6255493F37323134
3A434E5A6875828E99A2ABB4BCC4CCD4DCE4EBF1F5F7F7F3EEE6DDD2C7BCB2A9A099928B
837A6F625444332213050000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000906020000000001060E161D24
282B2B292623201D1C1B1A1A1815110C0702000208142439516A8298AAB7BFC2C2C0BEBC
BCBFC4C9D0D5D8D9D5CFC6BCB1A69E98959496999C9E9E9C978E84776A5D524943404247
4F5A6673808C97A0A7AEB4BABFC6CCD4DCE3EAF0F4F6F5F2ECE4DACFC4B8ACA0958A8076
6D62574C4033261A0F060000000000020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000D0A0702000000000002081017
1E2326272726252423232323211F1A140C05000000041021364E677F95A6B3BBBFC1C0C0
C1C3C7CDD3D8DCDDDCD7D0C7BDB4ACA6A2A2A3A5A8A9A9A6A0988D8174685E565353575E
6974818E99A3AAB0B4B8BABDC1C6CCD3DAE1E8EDF0F2F0ECE6DED4C9BCAFA294877A6D61
554A3F352B221A120C080503030406090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000F0E0A0500000000000000040C
141B2126282A2A2B2B2B2B2B2926211A110700000000000C1E354E677F94A5B2BABFC2C3
C5C8CCD1D6DBDFE1E0DDD7CFC6BEB6B0ADACADAFB0B2B1AEA8A0958A7E746B6665686E78
84909DA8B1B8BCBFBFBFBFC0C2C6CBD1D8DFE4E9EBEBE8E4DCD3C9BDB0A2948577685A4C
3F33281F18120E0B0909090A0B0C0E0F0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000100F0C07010000000000000003
0C151D24292D2F31313232312F2C261E14090000000000000B1F37516A8195A5B2BAC0C4
C7CBCFD4D9DEE2E4E3E0DBD3CBC3BCB7B3B2B2B4B5B6B5B2ADA59B9188807A78797F8792
9FABB7C1C7CBCCCBC8C5C3C2C3C5CAD0D6DCE1E3E4E2DDD7CEC4B8AC9E91827464554637
291E140C0704030407090C0F111213120000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000F0F0D09030000000000000000
06111B232A2F333536373635332F2820160A000000000000000E243D566E8496A5B1B9C0
C6CBD0D6DBE0E3E5E4E1DBD4CCC5BEB8B5B3B4B5B6B6B6B3AEA79F97908B88898D959FAC
B9C5CFD7DBDCDAD5D0CAC6C3C3C5C9CED4D9DCDDDBD6CFC6BBAFA295887B6D5F50423324
170C03000000000004090E12151615140000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000D0E0D0A050000000000000000
030E19232B31353839393837342F2921170C0000000000000003162C445B718495A2AEB7
BFC7CED5DBE0E3E5E3DFDAD2CAC2BBB5B2B0B0B1B2B3B2B0ACA7A19B979494989FA9B5C2
CFDAE3E9EAE8E4DDD5CEC8C4C3C5C8CCD1D4D6D4CFC8BEB1A496887B6E6155493C2F2215
090000000000000001080E13161716130000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000A0C0C0B070100000000000000
030D18222A31353839393836332E2821180D02000000000000000C1F33485C6F808F9DA9
B4BEC8D1D9DFE2E3E1DDD6CDC4BCB4AFABA9A9AAABACACAAA7A4A09C9B9B9EA4AEB9C6D4
E0EAF2F5F5F1EAE1D8CFC8C4C2C3C6C9CCCECDC9C1B7A99A8A7A6B5E51463C32281E1409
000000000000000000070D12151614110000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000006090A0A080500000000000000
050D1720282E333536363533302C27201910070000000000000006142435475768778695
A3B1BECAD4DCE0E1DED9D0C7BDB3ABA5A1A0A0A1A2A3A3A3A19F9D9B9C9FA5ADB8C5D2DF
EBF4FAFCFAF4ECE2D8CFC7C2C0C0C1C3C5C5C1BBB0A393816F5E4E40342B231C16100902
000000000000000000050B101313110E0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000205080A0A0806020000000002
070E151D24292D303131302F2D2A26211B140D05000000000000040D1824313E4C5C6B7C
8E9FB0C0CDD6DCDDDAD4CAC0B4AAA19B97959697989A9A9A999898999BA0A8B2BECBD8E5
EFF7FCFCF9F3EAE0D5CCC4BEBBBABABABAB7B2A99D8D7B685442312419110C0906040200
00000000000000000003090D0F0F0E0B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000206090B0B0B090705040506
0A0E13181D2225282A2A2B2A292826231F1A150F0A050200000104080D131B25303E4E61
758A9FB3C3D0D7D9D6CFC4B8ACA097908D8B8C8D8F91929292929295999FA8B3BFCCD9E4
EDF4F7F6F3ECE3D9CFC6BEB8B3B1AFADABA69F948776634F3B29180B0200000000000000
0000000000000000000206090B0B0A080000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000003070B0D0E0E0E0C0B0A0A
0B0D0F1215191C1E212325262728272624211E1A16120F0C090706050405070C14203044
5B748DA4B8C7D1D4D1C9BEB1A4978E878483848688898A8B8B8B8D90959CA5B0BCC8D4DE
E5EAECEBE7E0D8CFC6BDB5AEA9A4A09C9791887D6F5F4C39261405000000000000000002
050707060402010000020305060707060000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000002060A0E11121211100E0C
0B0A0A0B0C0E1114171B1F2326292A2B2B292725221E1B17130E08030000000000051529
425E7A95ACBECACECCC4B8AA9C9086807D7D7E81838485858585878A9097A1ACB7C2CCD4
D9DCDDDBD7D1CAC2BAB2AAA29C958F8881796F6457483827160600000000000000000006
0C1012110F0C080502010101030405050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000001050A0E1113141412100D
0A0705030304070A0F141B21262B2F313232312F2C2925201B140B020000000000000012
2C4A6987A1B5C2C7C5BDB1A3958A817B797A7C7F81828281818182858B929CA6B0B9C1C7
CACBCAC7C3BEB8B2ABA49C948C847B72695F564B403427190C000000000000000000010B
13181B1B19140F0905010000000103040000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000104080C10121313120F0B
0703000000000002080F1820282F34373939383634312D2721180E020000000000000000
1B3A5B7B96ACBAC0BEB6AA9C8F847C7878797C7F8182817F7D7C7D80858D96A0A9B1B6B9
BAB9B6B2ADA9A49F9A948D857C72675C51463D332B221A1108000000000000000000040E
171E2222201B140D07010000000002050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000104070A0D0F11110F0D09
0400000000000000030C16202A32383D3F3F3E3B3835302B241B10030000000000000000
103051718EA3B2B7B5AEA295887F7977787B7F828484827E7B79797B8088919AA3A9ACAD
ABA7A29C97928F8B88837D756B6053473A2F261F1915110D090400000000000000000710
19202526241F181008020000000001050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000020303040608090B0C0D0C0A07
0200000000000000010B16212C353C4042413F3C3935312C251D12050000000000000000
0D2C4C6C879CA9AEACA4988C81797676797E83878887837E797574767B838D969EA3A5A3
9E978F87817C797674726D665C504335281D140F0C0C0D0E0F0E0C080400000000020810
181F242625201A120A030000000002060000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000007060505050506070708080705
0200000000000000010B16222D363C4041403D3A36322E2A241D14090000000000000000
112E4D6B8497A2A5A1998D82797372757B82888C8D8A847D76716F71767F89939B9FA09C
948A7F746C66636161605D584F4436281A0F080404070D13181B1C1A16100B070505090E
151B202323201A130B040000000003080000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000B0A0806040302020304050505
0300000000000000040D17222C34393C3D3B37332F2C2825221D170E0400000000000006
1D37536E84939B9C978D8277706D6E747D868D91918D857C736C696B717B86919A9E9E98
8D80726459524E4D4E4F4E4B443A2E201309020001070F1922282B2B272018110C09080B
10151A1E1F1D19130C060100000004090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000F0D0A07040100000001030506
0706040100000002070E1720282F333534322E2A26242221201E1A150F07000000000919
2E465E75879297948C81766C66666A737E899196958F867A6F6763656C7784919A9F9E97
8A7A6857493F3A393B3E40403C352B1F13080200030A14202B343939352E241A120B0808
0A0E13171A1A17130E0905020203060A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000011100C0804000000000004070A
0C0D0C0B090707080B0F151C2227292A2926231F1D1B1C1D1E20201E1B17141112172130
43586D7F8C94948E84776B625D5F66717E8B9499989085776A615C5E667281909CA2A199
8B77624E3C3029272A2F333737332C22170E080609101B27333C42433F382D21160D0705
05080D1115171614110D09060506080B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000013110D09040000000001060B10
1315161513100E0D0D0F1215191C1D1D1C1A17151414171B1F2427292A2929292C323C4A
5B6D7E8C9598948A7D6F62595659626F7E8C979B99918374655A5557606E7F909EA6A69D
8D785F4732231A171A20282F33332F29201813101218212C37414648443D3226190F0703
0204080D1114161514110E0B0A090A0B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000012100D08040000000004090F15
1A1D1F1E1B1814100E0C0C0D0E0F10100F0D0C0C0D10151C232A31363A3C3E41454C5764
7382909A9F9E968A7A6A5C5351555F6E7E8D989C9A90827161544F515A6A7D90A0A9AAA2
927A60442C1A0E0A0C141D272F3435322C25201D1D20273039414647443D33271B100803
0102060B10141617171513100E0D0C0C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000100E0B080401000002070D141A
20232524211C16110C08050403030303030405070B1118212B343D444A4F53575D656F7C
8997A2A9ABA69C8D7B695B514F535E6E7F8E999D9A90806E5D504A4C56677B90A2ADAFA8
977F62452A140600010914212C353A3A38332E2A28282C31373D40413E3930261B120A05
0304070B1014181A1A19171512100E0C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000C0B090604020103060A10171D
23262726221C160E0802000000000000000002070E16202B36414B545B61666B727A8590
9DA9B2B7B6B0A3927F6C5D535055606F808F999D9A8F7F6D5B4E484A54657A90A3B0B3AD
9D8467482B13020000010C1B29353D41423F3B36323030313336373735312A221A130D09
07080A0E1216191C1C1C1A1815120F0C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000706050403030405090D13191E
222525231F19110902000000000000000000050D16212C3945515B646C72777D838C96A1
ADB8C0C3C1B9AC9A8673635955596371818F999D998F7F6D5C4F494B55667B91A5B2B7B2
A38B6E4F301704000000071524323D45484845403B3632302E2E2D2C2A26221D1814100E
0D0D0F1215181B1D1E1D1C1A17130F0B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002020202030406080B0F13181B
1E1F1F1C17110A02000000000000000000050E1924313E4B58636D757C81868B9199A2AD
B8C2CACDCAC2B5A3907D6D625D6068758390999C988E806F5F534D4F596A7E94A7B5BAB6
A8927658391F0A00000003101F2D3A44494B4A46413A342F2A2623201E1B191716141313
13141517181A1C1D1D1D1B1917130F0B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000010305080A0D10121416
161614110C070100000000000000000008121E2A374553606C7780868B8F92969BA2ABB5
BFC9D0D3D1C9BDAC9987776C67686F798590989B978F8273655A565862718499ABB8BDBA
AE9A8063462B16070000030D1927333E45494A48433D352E27201B161312111112141617
191A1A1B1B1B1B1B1A1A191715120E0A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000104070A0C0E0F0F0F0E
0C0A070400000000000000000000040D182532404F5D6B77838C93979A9C9EA0A3A8AFB8
C2CBD2D5D4CDC2B3A29182767070757D868F9698958E84786C6562656E7C8EA0B0BBC0BE
B3A28B71563C26160B06060C141E29343C424545433D362E261D16100C0A0A0C0F13171A
1C1E1E1D1C1A18171615141312100D090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000002060A0C0E0E0D0B0804
010000000000000000000000040C16222E3C4A596876838F99A1A6A8A9A9A8A8A9ACB2B9
C1C9D0D3D2CDC3B6A7978A7F7877797F868D9294928D857C757070747D8A9AA9B7C0C4C1
B8AA967F67503B291C130E0E11161E262E353B3E3E3C3730271E160E090606080C11161B
1E201F1E1B1714110F0E0E0E0D0D0B090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000005090C0E0F0D0A060000
00000000000000000000050E17222E3A48566573828F9CA6AFB5B8B9B7B5B2B0AFAFB3B8
BEC4CACDCCC8C0B5A89A8E837D7A7B7E83888C8D8C8985807D7C7F858F9BA8B5BFC6C8C6
BEB1A18F7B66534131241A13100F12171D252D33373937332C231A110B060406090E1419
1D1E1E1B18130E0B08070708090A0A090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000004090D0F11100D08010000
0000000000000000030D18232F3C485563717E8C9AA7B2BCC3C7C9C8C5C1BCB7B4B2B3B5
B9BDC1C3C2BEB7AEA3978C837D79797A7D8083848483828283878D96A1ADB8C2CACECECA
C3B8AC9D8E7D6C5B4A3A2B1D120B07080C131C252D343736322B2219100A0605070B1015
191A1A17130D080401000002040708090000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000205090D101212100C05000000
000000000000000714212F3D4A5764707D8A96A3AFBBC5CED4D8D9D7D3CDC6BFB9B5B3B2
B3B4B5B5B4B0A9A1988E857D7774737374757778797A7C80868F99A5B2BEC8D0D5D6D4CF
C7BFB5AA9F93857665523E2B190B000000010A15222D353939342D2319100A0606080B0F
131414110D080200000000000105080A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000080B0F12141413100B04000000
0000000000000B1A2939495865727E8A95A0ABB6C1CBD4DCE2E6E6E4DFD8D0C7BFB8B2AE
ABAAA8A5A29D978F877F78716D6A6868686869696B6E737B8592A1B0BFCCD7DDDFDED9D3
CBC3BCB5AEA69C8F7F6B553D250F0000000000061524323B3F3E382F2419100905050609
0B0D0D0B07020000000000000004080B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000F1113151615130F0A04000000
000000000411213143546473808C96A0A8B1BAC4CDD7DFE7EDF1F1EFEAE3D9CFC4BBB2AA
A49E99948E88817A726B65615E5C5A5A595959595B5F67717F90A3B6C8D7E2E8E9E6DFD7
CEC7C1BCB9B5AFA597846C513419010000000000081B2C3A4345423A2F23170D06020102
0405060502000000000000000004090D0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000151616161513110D0904000000
0000040E1A2A3A4C5E6F7F8C98A2AAB1B7BEC5CDD5DEE6EEF4F8FAF8F3EBE0D5C8BCB0A5
9B928A827A7169625B55504D4B4B4A4A494848484A4E576374889FB5CADCE9EFF0ECE4DA
D0C8C3C0BFBFBDB7AC9B836747280B00000000000011253643494943392C1E1107010000
00000000000000000000000000050B0E0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000018181614120F0C0A0705040507
0B121B2735455668798997A3ACB3B9BDC1C6CBD1D8E1E9F1F8FDFEFDF8F0E5D8CABBAD9F
92867B70655B524A433E3A383838393939383737383D4553657B94AEC7DBEAF2F4F0E7DC
D1C8C3C0C1C3C5C3BCAE997D5D3B1B000000000000061C2F3F494C483F3224160A010000
00000000000000000000000003080C100000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000001916130F0B08060506080B1016
1F2935435262738392A0ABB5BBC0C3C5C7C9CDD2D8E0E9F1F8FDFFFEF9F0E5D7C7B7A696
87796C5F53473D342D2825242527292A2A2A2827282B3340526A85A1BCD4E6F0F4F1E9DD
D1C7C1BEBFC3C7C9C6BCAB9274523010000000000000112537434948413628190C020000
000000000000000000000003060A0E110000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000017120C0702000000040B131D28
354251606F7F8E9BA8B3BCC2C6C8C9C9C9CACCD0D6DDE5EEF5FAFCFBF5ECE0D0C0AE9C8B
7B6C5D5043362C221B16131315171A1D1E1D1C1A191B212D3E55708EABC6DBEAF0EFE8DD
D1C5BDBABABFC4C9CAC6BAA68B6B49280B000000000007192B3840423E35291C0F040000
0000000000030405050607080A0D10120000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000110A030000000000040F1C2B3B
4C5C6C7C8B98A5B0BAC1C7CBCDCDCCCAC9C9CACDD2D8E0E8EEF3F5F2ECE2D5C5B3A18F7D
6D5E5042362A1F160E090606080C1013141412100E0E111B2A3F5A7896B3CCDEE8EBE6DC
D0C4BAB5B4B8BEC5CACAC4B6A0846443240A00000000000C1C2A33383731281D11070000
0000000004070A0B0C0C0C0D0E0F10110000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000A010000000000000515273B4F
62758695A2AEB8C0C6CBCED0D0CFCDCAC8C7C7C9CDD2D9DFE4E8E8E5DDD2C4B3A18F7D6D
5D5043382C22180F080200000105090C0F0F0D090604050B172A425F7F9DB9CEDDE3E2DA
CFC3B8B0AEB0B6BEC6CBCAC2B39D816142250D00000000000C1923292C29241C130A0300
00000003080C0F1111121111101010100000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000100000000000000091D344B62
788C9CAAB6BFC6CBCED1D2D2D2D0CDCAC7C5C4C5C7CBCFD4D7D9D7D2C9BDAD9C8A796859
4C41382F271E160E070200000003060A0C0D0B070200000007162C476685A3BCCED9DCD7
CEC2B7AEA9A9AEB6C0C8CDCBC3B39C806142260F00000000000711181D1F1D19130D0703
020204070B0F12141515141311100E0D0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000001129435D76
8C9FAFBBC4CACED1D3D3D4D3D2D0CDCAC7C4C2C1C1C3C4C6C7C6C2BBB1A39381705F5144
3B332D28241E19130D0804020305080B0D0D0B0701000000000618314D6C8BA7BDCDD4D4
CDC3B8AEA7A5A8AFB9C4CCD1CEC5B49D8061432710000000000000070E131515130F0C09
0707080B0E11141616161513100E0C0A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000071E39546F88
9EB0BEC7CED1D3D3D3D3D3D3D2D0CECBC7C3C0BDBAB9B8B6B4B0AAA1958676655445392F
2926242323211E1B16110D0B0A0A0C0E10100E0A040000000000091D37557492ABBECACF
CCC5BBB0A8A4A5AAB4BFCAD3D6D3C8B69D7F6040240C00000000000000070D101111100E
0C0C0C0D0F111314151413110E0C09070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000318314C68839A
AEBDC8CFD3D4D3D3D2D2D2D2D2D1CFCCC8C3BDB7B2ADA8A49E978F8477685848382B211B
19191C1F23252625221D1915131212131414120E080000000000000E25405E7C97AEBFC8
CAC7BFB6ADA7A6A9B1BCC8D3DADCD7CAB59A7B5B3A1E0600000000000000040B0F111212
100F0E0E0F0F10111111100E0B0906040000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000005182F49647E97AB
BCC8CFD3D4D3D1D0CFCFD0D1D2D2D0CCC7C0B8B0A79F978F867D73675A4B3B2D1F140D0A
0A0E141C23292D2F2D2A26211D1B1919191816120D05000000000004162E4A67839DB1BF
C6C8C4BDB5AFABACB1BAC6D1DBE1E0D8C8B194745232160000000000000000060C111314
1311100E0D0C0C0C0C0C0B09080503010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000010E1F344C657E96AABB
C7CED2D2D1CFCDCBCBCCCED0D1D1CFCBC4BCB1A69A8E83786D62574B3E3023150A020000
00050E19232C33373735312C2723201E1D1B1916110B0300000000000C2038536F8AA1B3
C0C6C7C4BEB9B4B3B5BBC5CFD9E1E3DFD4C1A88A69482A0F00000000000000010A101315
1412100D0B09070706060605040301000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000040C192A3E546C849AADBDC8
CFD2D1CFCCC9C6C6C6C8CBCECFCFCCC7BEB3A698897A6D6054483D32261A0F0400000000
00000A16222D363C3E3D3A35302A26221F1D1B19150F090300000000061528405A758EA4
B6C2C8CAC8C4BFBDBCBFC5CDD6DDE1E0D9CBB79D7F5F40230C00000000000000070E1214
14120F0C0805030101010101010100000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000B152334495F778EA3B5C3CDD2
D3D1CDC8C3C0BEBEC0C3C7C9CAC9C5BEB3A69686756555473B30261C130A010000000000
000006131F2B363D41423F3B352F2A25211E1C1917130E0903000000030D1C2F46607A92
A8B9C5CCCFCECBC8C6C5C7CBD1D7DBDCD8CFC0AB9174573A210C000000000000050B1013
13120E0A0602000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000018283A50688199AEC0CDD5D8D7
D3CCC5BEB9B5B4B5B8BCC0C2C2BFB9AFA39382705E4D3E30251B130C0500000000000000
0000040F1B27323A3F41413D38322C26211E1B191714120E0A05020102071120334A637C
95ABBDCAD2D6D6D3CFCCCACACCCFD2D4D2CDC3B4A0886D53392311040000000003080D10
11100D0A0501000000000000000002020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000002539516A859FB6C9D7DEE1DED7
CDC3B9B0ABA8A8AAAEB2B5B6B5B0A89C8D7C6A584635271B110A05010000000000000000
0000030C16212A33393D3E3C38332D26211C1917161513110F0B08050304091321344B64
7F98AFC2D1D9DDDCD8D3CECAC7C7C7C8C9C7C2B8AA98826A523B27160A02000002060A0D
0F0F0D0A0601000000000000000204050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003048637F9CB6CCDCE6E8E5DCD0
C2B4A89F9A989A9DA1A5A7A7A39C91847462503E2E1F1309030000000000000000000000
00000309101821293035383836322D26201B17151413131312100D0905030307111F324A
65819DB5C9D7DFE1DFD9D1C9C3BFBDBDBDBEBDB9B1A494806A543E2A1A0E060201030609
0C0D0C0A0704000000000000000306070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000037516F8DABC4D8E6EBE9E0D3C2
B1A1948B8786898D929596948E84776857463525170B0200000000000000020405050504
030304060A10171E252C303333302C26201A1613111112141413110D07020000020C1B31
4A6785A2BACEDBE1E1DCD3C9C0B8B3B2B2B4B6B7B4AEA393806A543E2A190D0501000205
090B0C0C0A070400000000000205080A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000039557392AFC8DAE4E6E0D3C2AE
9A897C747172757A7F82817D75695B4B3A2A1B0E030000000000000001060A0E10100F0D
0B08060405080D131A21272C2E2E2B27211B1512100F1113151513100A03000000000718
304C6B8AA7BFD0DBDEDBD3C9BDB4ACA9A9ACB0B4B6B4AEA3927E68503925140801000001
05090C0E0D0B0805020000010306090B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003652708EAAC0D0D7D6CDBDAA94
806F625B595C61666B6C6A645A4D3E2E1E1004000000000000000002070D121619191816
110C0804010104090F171F252A2C2B28231D17120F0E0F12141615120C05000000000003
17314F6F8EAAC0CFD6D6D0C7BBB1A8A3A3A5ABB1B6B8B6AEA18E785F462F1A0B00000000
02070C0F100F0D0A060402030407090C0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000304965819BAFBCC1BEB3A28D77
6353484242454B515556534B403223130600000000000000000002080E13181C1E1F1E1B
16100A0400000001070E171F262A2B2925201914100E0F11141616140F07000000000000
021834537391AABDC8CCCAC3B9AFA6A1A0A2A8AFB6BBBBB6AB9A846B5137200D00000000
00040B101213110E0A0704030406090B0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000263C556E8496A1A49F93826D58
46372E2A2B30363C40403C33271A0B0000000000000000000004090E13171B1E2021211E
19130C05000000000108111A22282B2B28231D171310101114161716110A000000000000
00041C39587691A7B6BEC0BDB6AEA7A2A1A3A9B0B7BDBFBCB2A28D74583D240F00000000
0001090F131513100C0805040405070A0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000001A2C4156697780827C71604E3B
2A1E1614171C23292C2C271E130600000000000000000001070C101315171A1C1E1F1F1D
1A150E070100000000050D171F272B2D2B27221C1713121214161817140E050000000000
000008213D5A758DA0ACB3B4B2ADA9A5A4A7ACB2B9BFC1BEB6A792795E42271100000000
0000060E131515120E090503020305080000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000E1C2C3C4B575E5F5A4F413121
13090303060C13181B1A160E03000000000000000000030B101415161515151618191A1A
1815100A0400000000040B141D252A2D2D2A26201B1715141617191917120A0000000000
0000000E253F5A728797A2A8ABABAAA9AAACB0B6BCC0C2BFB7A8957C61452B1301000000
0000030B111414120E090502000103060000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000030C17232F383D3E3A3126180B
010000000000060B0E0D0902000000000000000000050E15191A191613100E0E0F111315
1514120E0904010001050B121A22282C2D2C2924201C191818191B1B1A16100700000000
0000000012283F576C7F8E9AA2A7AAACAEB2B6BABEC1C2BEB6A8957E64492E1704000000
000000070D1112100C080300000001030000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000060E161D21221F19100600
00000000000000030505010000000000000000000610181D1F1D1A140E09060405070B0E
111313110E0B080605070B11181F25292C2C2A2723201D1B1B1C1C1D1C1A150E06000000
000000000314283D52677988959FA7ACB1B5BABDC0C2C1BDB4A79580674D331B08000000
00000003090D0F0D0A060200000000020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000003080B0C0B07020000
000000000000000000000000000000000000000811191F22221E18100902000000000308
0D12141514110F0C0B0B0D10151B2024282929282623211F1E1E1E1F1E1D1A150F070000
00000000000515263A4E627586949FA9B0B6BABEC0C0BEBAB2A696826B5239220E000000
0000000005090B0A08050100000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000020A121A202425221C150C0300000000000004
0B11151819171513100F0E1012161A1E222426272625242221212020201F1D1A16110A03
000000000000061424384C60738594A0AAB1B7BABCBCBAB6AFA496857059422C17070000
000000000105070706030100000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000003070D131A202325231F1810070000000000000001
0910161A1C1C1B181512100F0F1113171B1E2123252525242322222121201F1E1C18130D
06000000000000051223364B5F7284929EA7ADB2B4B5B4B1ABA3988977634D3723110300
000000000001040504030100000000010000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000102030304040506090C10151A1E2123221F1A130B030000000000000001
0910171C1F1F1E1C1815110E0C0C0D0F13171A1E2123242524242322212120201F1D1A15
0F08010000000000041223364A5E70808D979EA3A7A9AAAAA7A29A8F806E5A44301D0D01
000000000000010304030201000001020000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000030507
0708070706060606060607080A0D1013161A1D1F201F1D19130D07000000000000000004
0B11171C1F20201E1B16120E0B0808090B0F13181C202224242423212020202020201E1B
160F080000000000000412233548596976818990969A9EA1A2A19D95897A67533E2A1809
000000000000000203040403030303040000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000004000000000000000206090C0E
0F0F0F0E0C0B090908090A0B0E101316191B1C1C1B1915110D0803000000000000000308
0D12171B1E1F1F1E1B17130E0A06040405080C11161B1F2122222221201F1F1F2020201E
1A140D050000000000000513223242505C67707980888F969C9F9F9C938675614C362211
050000000000000204050606050505050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000906030100000204080B0F1214
15151412100E0C0A0A0A0B0C0F1114161818181714110D0A070402010001020406080B0E
101316191B1C1D1C1A17130E0A0502010103060B10151A1D2020201F1E1E1E1E1F20201E
1B1710080000000000000006121E2B37414B555E68737E89949CA1A19C92826F58412C19
0A0000000000000205060808080707070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000C0A0806060607090C0F121416
17171513110F0C0A09090A0C0E101213141412100D0906040201020406090B0E10111213
13141516171819191816130F0B070300000002060B1015191C1D1E1E1D1D1D1D1E1E1F1E
1B17120B0300000000000000050E161F273039434E5C6B7B8A97A1A5A39B8D79624A331E
0D010000000000020508090A090908070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000D0C0B0A09090A0C0E10121415
16151412100D0B09080708090A0C0D0E0E0D0B0906030100000104080C11141719191917
1513121112121314151513110D09050200000002060B1014171A1B1C1C1C1C1C1D1D1D1D
1B17120C05000000000000000001060B10161E283545586B7F919EA6A7A1938069503822
100200000000000206090A0B0A0A08070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000C0C0C0B0B0B0B0C0D0E101112
1211100F0D0B0907060505050607080808060502000000000003070D12171C1F201F1D19
16120F0D0C0D0E1012131312100C09050200000103070B0F1316191A1B1C1C1D1D1D1D1C
1916120C070100000000000000000000000107111F30455C738899A3A6A295836B523922
100200000000000307090B0B0B0A08070000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000090A0A0A0A0A090A0A0A0B0C0C
0C0C0B0A090806040302020202020202020100000000000002060B11171C202223211E19
140F0B080707090B0E11121312100D09060302010204070B0F1215181A1C1D1E1E1E1D1C
1915110C070300000000000000000000000000000B1D334C657D909DA19E928069503720
0D00000000000003070A0B0B0A0908060000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000006070707070706060606060606
060606060504040201000000000000000000000000000002060A0F151A1E212322201C17
110C0704030305070B0E11131413110E0A070503030305080B0F1216191C1E2020201F1D
1915110C07040100000000000000000000000000000E243E5870849298958A786249311B
0A0000000000000307090B0A090807050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000002030404030302020101010101
0101020202020201010000000000000000000000000003060A0F13171B1D1F1F1D1B1712
0D08040100000205080C1012141413110E0B080604030405080B0F13171B1E212223211F
1B16110C08050302030303020000000000000000000318304A61758389877D6C57402915
050000000000000307090A0A090706050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000010202020100000000000000000000000205080C0F121517191A191816130F0B
0704010000000003060A0D1013141413110F0C090705040405080B1014191E2124252421
1D18130D0906040405070808060200000000000000000F253C52657177756C5C49341F0D
000000000000000407090A09080605040000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000102030303020000000000000000000206090D1013151616161412100D0A0704
020000000000000205080B0D1012131312110F0C090705040405080C10161B2024262624
201B150F0A07050507090B0C0B080300000000000000081B2F42525E6360584A39261405
000000000000000508090908070605050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000002030405050504030100000000000003060A0E111416161513110D0A0603010000
00000000000102030406080A0C0E0F111211100F0C090704030304070C11171D22252726
231E19120D090706080B0D0F100E0A040000000000000513233340494D4A433728180A00
000000000000020608090908070605050000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
01020304060708080807060403010000010306090D101315161513100B07020000000000
00000001030405050404040506080A0D0F1011100F0C090503010102060B11181E232627
25211C16100B0807080B0E1112120F0B050000000000030D19242E3537352E24180C0000
000000000000040709090908060605060000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{144, 144},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002@0000T2000`400?l00000o`00003oT03AcJT0
0900dLfY002@0=7=Z@00T03AcJT00900dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=
Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9
000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY
00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT0
0000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT0
00<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJTQ0000000400<30`0;2`/02`/;00@410<0000000@00P8201LG5`0^
;Rh0@4100P15ADD0100j>SX0:RXZ01PH60092@T50000000500820P0<30`04A4A010@400820P01000
00006`0I6AT0:RXZ04a<C01TI6@0KFe]06IVIP1DE5@0?Shn038b<P0N7Qh03Ph>00@410010@4010@4
00d=3@0H61P071`L024Q8@0P82005aLG00d=3@051@D00P8200410@020P800`<300820P0800000003
00@410092@T02`/;00803Ph>00<02PX:0000000000007P0000040=7=Z@000`3AcJTQ0000000400T9
2@0E5AD051@D00P820<0000000d0410@03<c<`1DE5@0IfMW06YZJP1RHV80D51@03hn?P0`<3009bLW
01`L700F5QH01@D500<0000000@00P8200h>3P0A4A402`/;0`0000005@051@D0<C4a04];B`1lO7`0
W9bL0:>SX`2EUID0NWYj05eMG@1@D500>3Ph02@T900D51@02@T900D51@0:2PX051@D01TI6@0O7al0
6a/K00h>3P040000000500<30`0;2`/03Ph>00X:2P0410@00`0000001P030`<01`L700/;2`0=3@d0
3Ph>00l?3`80410@00<03`l?0000000000007P0000040=7=Z@000`3AcJTQ0000000500T92@0H61P0
61PH00X:2P020P800P0000003P0I6AT0ADE506e]K@24Q8@0QXJ607alO01XJ6P0EeMG051@D01?Cdl0
BDU90492@P0Z:RX03@d=0`00000010071`L030`<00d=3@020P820000000D01@D5017AdL0I6AT09^K
V`2n_[h0a<C40;:b/P2DU9@0M7Ad06EUI@1<C4`0=cLg028R8P0A4A401PH600@4100:2PX03@d=014A
4@0<30`50000000A00H61P0C4a<05aLG01<C4`0;2`/01@D500<30`0410@02@T900h>3P0@41003`l?
00`<300:2PX020P800T92@0:2PX0800000040=7=Z@000`3AcJTQ0000000500820P0?3`l04Q8B00P8
20010@400P0000003`0J6QX0ATI6075aL@2=SHd0TI6A08b<S01mOGd0LW9b07=cL`1jNWX0O7al07If
MP1MGEd0=SHf010@40020000000E00410@071`L03Ph>00`<30071`L03@d=02LW9`1DE5@0KVi^09nO
W`2o_kl0aLG50;Bd]02IVIT0Ng]k06i^KP1FEUH0?clo02TY:@0D51@01@D500<0000000<00@410000
00000000100000001P0<30`05aLG01TI6@0E5AD03@d=00H61P801@D500@020P800X:2P0:2PX01PH6
9@0000040=7=Z@000`3AcJTS0000000300D51@030`<000000080000002H04a<C03Ph>01PH600OWin
08R8R02?Shl0SHf=08j>SP2FUYH0Y:BT0:ZZZP2XZ:P0TY:B06][J`0m?Cd061PH00D51@030`<01PH6
00d=3@0C4a<05aLG024Q8@0g=cL0EeMG06YZJP2<S8`0XZ:R0:RXZ02OWil0S8b<07IfMP1[Jf/0E5AD
03dm?@0U9BD04A4A00820PP0000000P01PH600X:2P0B4Q8051@D014A4@0;2`/01@D500820P800@41
:@0000040=7=Z@000`3AcJTX0000000L00X:2P0P8200?clo061PH01_Kfl0QhN709VIV@2XZ:P0]kNg
0<K6aP3>c/h0cLg=0;jn_P2NWYh0Lg=c04M7A`0U9BD04A4A00`<300;2`/04Q8B01dM7@0];Bd0@410
05ADE01NGUh0Kfm_07]kN`80PH6100L0NWYj06e]K@1TI6@0CDe=03<c<`0J6QX020P800@0000000D0
0@4100820P051@D02PX:018B4P0201LG5`0301<C4`092@T0000002h00000103AcJT000<0dLfY8000
00000`092@T0000000000003000000<00`<302<02@T901/K6`0l?3`0D51@07]kN`2RXZ80`<300=CD
e03Ogml0h^;R0>3Ph03Fe]H0`/;20:>SX`1kNg/0DE5A02/[:`0L71`02`/;00X:2P0H61P0;Rh^04=3
@`1BDU80EeMG05aLG01PH600IVIV06e]K@1aLG40JVYZ069RHP19BDT0:BTY00d=3@020000000700<3
0`0;2`/03Ph>010@400A4A4051@D01XJ6P0201lO7`0301/K6`0<30`0000000X0000000D03@d=01@D
500J6QX051@D00H61P0P000000@0dLfY00030=7=ZB00000000<04a<C0000000000000`0000009P06
1PH01@D500000000000030`<02`/;012@T80M7Ad0:FUY@3;bl/0h>3P0>SXj03Vi^H0hn?S0=_Kf`3=
cLd0][Jf09BDU01YJFT0?3`l02PX:00=3@d01PH6018B4P0Z:RX0@d=305=CD`1HF5P0Fe]K05aLG01R
HV80Jf][079bLP1]KFd0IFEU04U9B@0V9RH02@T90P0000002`071`L04a<C01HF5P0H61P05aLG01PH
600L71`0820P01dM7@0H61P01PH600@0000000<00`<300L71`061PH00`0000001P0<30`092@T02d]
;@0f=SH0;Bd]01PH62000000103AcJT000<0dLfY800000000`0Y:BT05ADE00<30`020000000300<3
0`092@T01PH600<00000024051@D02`/;01YJFT0ZJVY0=_Kf`3clo<0m?Cd0>SXj03QhN40emOG0=?C
d`3=cLd0^k^k09JFUP1SHf<0B4Q801XJ6P020P8020P8028R8P13@d<0G5aL06=SH`1YJFT0JVYZ06i^
KP1hN7P0P82007]kN`1bLW80DU9B02TY:@071`L00P0000001P0>3Ph07AdM024Q8@0R8R806a/K01HF
5P8051@D00<03Ph>00P8200000000`0000003@0:2PX07alO02@T900T92@06QXJ01@D500O7al0?3`l
061PH01^KVh0NWYj06YZJP14A4@0800000040=7=Z@000`3AcJTP0000000403Ti>@0];Bd06QXJ00/;
2`801@D500<01`L700@4100000000P000000:@0820P0820P061PH02VYZH0g]kN0?Win@3gmoL0hn?S
0=WIf@3;bl/0c<c<0=?Cd`3Bd]80^k^k08b<S01_Kfl0=CDe00h>3P071`L07QhN04E5A@1ZJVX0N7Qh
08N7Q`2<S8`0Shn?09BDU02GUiL0SXj>08B4Q01RHV80=cLg014A4@0000000@41010@400N7Qh08B4Q
01dM7@0A4A401@D500L0000000<04a<C038b<P1;Bd/00P1ADE402@17AdL0@d=305=CD`1hN7P0XJ6Q
0;6a/@2k^k/0XZ:R06m_K`0P000000@0dLfY00030=7=ZB00000000L0?Cdm03/k>`0];Bd06QXJ00`<
300820P00`<300@0000000T01PH601/K6`1CDe<0UYJF0<k>cP3^k^h0l?3`0=kNgP3Bd]800P32`/80
6@3@d=00fm_K0=CDe02b/[80UiNG05aLG00[:b/05aLG02DU9@1;Bd/0N7Qh08^;R`2UYJD0[jn_0;2`
/02^[Zh0ZJVY09jNWP2CTi<0Lg=c04Y:BP0T92@03@d=00L71`0=3@d00P0C4a<00`0<30`000000000
00050000000500H61P0O7al0@41006ATI01mOGd00P23Ph<02@1jNWX0N7Qh08V9R@2/[:`0dM7A0=kN
gP3QhN40`<3008F5Q@0P000000@0dLfY00030=7=ZB00000000L0<c<c03/k>`0e=CD09BDU01<C4`0<
30`00@4100@00000018020P801HF5P11@D40MgMg0:b/[03AdM40gmoO0=WIf@3Bd]80a<C40<71`@3<
c<`0g=cL0>3Ph03=cLd0^[Zj08V9R@1FEUH203Lg=`0B05ADE01nOWh0Ti>C0;:b/P30`<00_kno0;Rh
^02^[Zh0XJ6Q09RHV01nOWh0GEeM03Ti>@0M7Ad03@d=00H61P030`<00@411P0000001`020P805QHF
02l_;`1>CTh0LG5a09:BTP2XZ:P00P2^[Zh02@2WYjL0YZJV0;>c/`3;bl/0h^;R0>OWi`3MgMd0]kNg
07emO@0P000000@0dLfY00030=7=ZB00000000L07QhN02`/;00a<C40:RXZ01dM7@0E5AD020P800@0
000001P01`L7010@400Y:BT0CTi>07]kN`2UYJD0a<C40=?Cd`3De=@0dM7A0<g=c@3?cll0f=SH0>3P
h03Jf]X0d=3@0:n_[`24Q8@0H61P055AD@1LG5`0NWYj08Z:RP2WYjL20;Jf]P090:b/[02QXJ40UYJF
092@T01oOgl0IVIV04Q8B00Y:BT0410@00L0000000h02PX:024Q8@0];Bd0AdM7069RHP1nOWh0VYZJ
0;:b/P33`l<0alO70<W9b@36a/H0aLG50<W9b@80d=3@00@0bl_;0;Bd]02;Rh/0FUYJ800000040=7=
Z@000`3AcJTP0000000^00L71`0G5aL09BDU02`/;00Y:BT092@T01TI6@0>3Ph01`L700@410030`<0
10@400H61P0@410092@T04I6AP1cLg<0XZ:R0<S8b03EeMD0hN7Q0=oOg`3Hf=P0eMGE0=OGe`3IfMT0
e]KF0<K6aP2YZJT0R8R806i^KP1VIVH0L71`07UiN@2<S8`0V9RH09ZJVP2CTi<0Rh^;08>3P`1oOgl0
MGEe06ATI01:BTX0:b/[00l?3`@0000001L01@D501DE5@0Y:BT0@D5105]KF`1XJ6P0P82009JFUP2X
Z:P0][Jf0<;2`P3;bl/0c/k>0=;BdP3De=@0d];B0<g=c@2o_kl0Z:RX09VIV@1dM7@0CDe=02XZ:P0P
000000@0dLfY00030=7=ZB40000000<010@401PH600Z:RX00P0d=3@01P0^;Rh08R8R01HF5P0<30`0
1PH600410@80000000X00`<301XJ6P15ADD0O7al0;Bd]03;bl/0j>SX0>g]k@3Rh^80dm?C0P3<c<`0
1P3>c/h0cLg=0<30`02WYjL0RXZ:07=cL`80JFUY00`0L71`07QhN01lO7`0Ng]k07MgM`1bLW80Kfm_
06MWI`1HF5P0@D5102DU9@0<30`20000000H00820P0D51@0;2`/04M7A`1SHf<0OWin09NGU`2RXZ80
]KFe0<71`@36a/H0alO70<K6aP37alL0bLW90<k>cP3Bd]80d=3@0<71`@2TY:@0NWYj06=SH`0f=SH0
4a<C8@0000040=7=Z@000`3AcJTR0000000900`<300T92@0=cLg03dm?@0n?Sh0<c<c02<S8`0D51@0
2@T900@0000003P00@41028R8P1GEeL0U9BD0;6a/@3Kfm/0k>c/0>CTi03AdM40`L710;jn_P30`<00
b<S80<W9b@2l_;`0Xj>S08N7Q`1`L700JFUY06ATI01WIfL0KFe]075aL@1`L700Jf][06MWI`1KFe/0
BDU903<c<`0N7Qh03Ph>00/;2`0F5QH0820P03/k>`1JFUX0NGUi09JFUP2_[jl0aLG50<k>cP3Kfm/0
h>3P0=cLg03AdM40a/K60<30`02o_kl0`/;20<G5a@30`<00Zj^[08F5Q@1BDU80>CTi00`<32800000
103AcJT000<0dLfY8P0000002P071`L07alO03@d=00l?3`0@41003Lg=`0W9bL05aLG00/;2`020P84
0000000E01HF5P15ADD0P82009fMW@3=cLd0i>CT0>7Qh@3@d=00_kno0;Vi^@2k^k/0a<C40<[:bP34
a<@0[jn_09>CT`1iNGT0Kfm_06IVIP1WIfL0KVi^0080Lg=c01L0KFe]06QXJ01IFET0A4A402l_;`0L
71`04a<C01HF5P0W9bL0<c<c051@D01`L700SXj>0:RXZ030`<00e=CD0=cLg03Xj>P0j^[Z0>?Sh`3F
e]H0alO70;fm_@030;Zj^P050;>c/`2LW9`0MGEe04=3@`0Z:RX08`0000040=7=Z@000`3AcJTS0000
000;014A4@0U9BD0;Rh^03Ph>00f=SH0:b/[01dM7@0B4Q8030`<00T92@0410@00P0000005@071`L0
92@T059BDP1]KFd0XJ6Q0<G5a@3Bd]80bl_;0;fm_@2f][H0]kNg0<30`03<c<`0clo?0<G5a@2][Jd0
Ti>C08R8R01jNWX0N7Qh07inOP0208F5Q@0O07]kN`1bLW80G5aL04A4A00`<3009RHV02PX:00h>3P0
D51@05iNGP1jNWX0U9BD0:^[Z`2o_kl0d];B0>?Sh`3Zj^X0m?Cd0?Gem@3]kNd0g=cL0<S8b02g]kL0
/;2`0:FUY@2MWId0Shn?07QhN01EEED0;2`/01PH600S000000@0dLfY00030=7=ZB00000001T01PH6
0000000000000@4100h>3P0F5QH092@T02/[:`0Y:BT08b<S01dM7@0K6a/06QXJ01PH600A4A401`L7
0000000820P092@T03Ti>@1ZJVX0V9RH0;Ng]`32`/80`<300080_;bl02/0a<C40=3@d03Hf=P0eMGE
0<K6aP2a/K40YZJV09RHV02DU9@0VIVI09jNWP2LW9`0SXj>08B4Q01ZJVX0DU9B04=3@`12@T80Cdm?
06IVIP20P800S8b<0:2PX02^[Zh0^[Zj0<K6aP3De=@0hn?S0>[ZjP3dm?@0mOGe0>c/k03Jf]X0a<C4
0:b/[02PX:00RXZ:07IfMP1RHV80C4a<03<c<`0J6QX03`l?02<00000103AcJT000<0dLfY80000000
0`0>3Ph01@D5000000030000000400`<300K6a/09RHV02XZ:P<0:b/[00<0:BTY024Q8@0A4A400`00
00007P0<30`0=CDe06MWI`2DU9@0/[:b0;no_`33`l<0aLG50<c<c03Fe]H0gmoO0>3Ph03GemL0a/K6
0;jn_P2`/;00[:b/0:n_[`2b/[80[Zj^0:2PX02EUID0OWin06][J`1UIFD0KVi^08B4Q02MWId0/K6a
0;Rh^080_kno0180`<300<K6aP3AdM40gmoO0>CTi03[jn/0j>SX0=cLg039bLT0/;2`09BDU025QHD0
J6QX04a<C00c<c<07alO018B4P0;2`/200T92@0300/;2`0>3Ph0000001l00000103AcJT000<0dLfY
800000000`0?3`l02@T90000000400000009014A4@0S8b<0;bl_03De=@0g=cL0=SHf03<c<`0X:2P0
5QHF00@0000002h03Ph>03dm?@1^KVh0UYJF0;6a/@30`<00a/K60=3@d03Kfm/0hn?S0>CTi03Kfm/0
c<c<0<G5a@2h^;P0/k>c0;Fe]@2f][H0/k>c0:NWY`2OWil0T92@08R8R02=SHd0WinO0;Vi^@3?cll0
fm_K0=cLg03EeMD0b/[:0<?3``35aLD0c/k>0=WIf@3Lg=`0fm_K0<o?c`2k^k/0XZ:R08R8R01]KFd0
GemO0492@P0T92@030`<0`000000100410@03Ph>01DE5@0E5ADP000000@0dLfY00030=7=ZB000000
00<030`<00/;2`010@40100000002P0=3@d08R8R034a<@0h>3P0>CTi03Ph>00c<c<0:2PX01PH6002
0P840000000/01lO7`18B4P0Kfm_08n?S`2YZJT0];Bd0<S8b03IfMT0h^;R0>7Qh@3Fe]H0a<C40;bl
_02_[jl0ZJVY0:ZZZP2/[:`0ZZZZ0:BTY02PX:00Vi^K09jNWP2^[Zh0a/K60>3Ph03bl_80mOGe0?7a
l@3QhN40clo?0<C4a033`l<0bLW90<k>cP3=cLd0`L710:VYZ@2:RXX0Jf][055AD@0l?3`0<S8b01hN
7P092@T50000000300d=3@0E5AD051@D02000000103AcJT000<0dLfY8000000010051@D02PX:00P8
20020P820000000;00820P0>3Ph07AdM02TY:@0`<300<C4a030`<00];Bd09RHV01/K6`0=3@d01000
0000400=3@d092@T03hn?P1LG5`0O7al08j>SP2`/;00cLg=0=cLg03Jf]X0b/[:0;Bd]02ZZZX0Vi^K
09FEU@2GUiL209ZJVP80V9RH00/0Vi^K0:RXZ02n_[h0f=SH0>o_k`3lo?`0nOWi0??cl`3Ph>00c<c<
0;jn_P020;Zj^P0:0;Ng]`2b/[80WIfM07]kN`1DE5@0<C4a01TI6@0<30`02@T900@410H0000000<0
2@T900l?3`0>3Ph0800000040=7=Z@000`3AcJTQ0000000<00L71`0=3@d03Ph>00`<300;2`/02PX:
00d=3@0B4Q806ATI01hN7P0S8b<09BDU0P0W9bL01P0T92@07QhN01HF5P0?3`l030`<00L71`801@D5
00H030`<020P8014A4@0Fe]K08f=S@2h^;P20=7Ad@070;jn_P2TY:@0UiNG08N7Q`23Ph<0QXJ608V9
R@0208^;R`0D08f=S@2EUID0YJFU0;bl_03De=@0iNGU0>c/k03WinL0h>3P0<o?c`2m_Kd0[Zj^0:BT
Y02LW9`0TI6A08R8R01_Kfl0C4a<02HV9P051@D40000000400820P071`L01PH600820P80000000<0
0`<300H61P071`L0800000040=7=Z@000`3AcJTQ0000000E00D51@0>3Ph04a<C01@D500B4Q803@d=
00L71`030`<010@400X:2P0D51@06a/K02HV9P0_;bl0<S8b034a<@0/;2`09BDU020P800D51@00P82
00<0000000d04Q8B02`/;01YJFT0XJ6Q0<;2`P35aLD0/K6a09FEU@2:RXX0Ng]k07YjNP1oOgl0PX:2
0080PH6100D0PX:208^;R`2LW9`0/;2`0<71`@020<[:bP0<0<?3``2n_[h0/[:b0:BTY02DU9@0Q8B4
079bLP1OGel0EUIF0410@00W9bL030`<1@0000001P0;2`/061PH01/K6`0D51@02@T900D51@800000
00<00`<30000000000007P0000040=7=Z@000`3AcJTQ0000000700@4100<30`04Q8B01<C4`0B4Q80
2`/;00<30`020000000<00820P0?3`l061PH02PX:00d=3@0>CTi03Ph>00d=3@0;Bd]02LW9`0H61P0
0P82100000008@0K6a/0Fe]K09JFUP2j^[X0_[jn0:ZZZP2?Shl0Q8B407QhN01iNGT0Ogmo08:2PP1o
Ogl0O7al07emO@25QHD0UYJF0:VYZ@2f][H0^[Zj0;Jf]P2][Jd0ZJVY09nOW`2DU9@0QHF5079bLP1L
G5`0ATI603dm?@0[:b/06QXJ00P820050000000600h>3P0N7Qh08R8R01/K6`0=3@d01`L70P000000
0`020P8000000000000N000000@0dLfY00030=7=ZB00000000L00`<300@4100820P02`/;00d=3@0<
30`01`L700@0000000/02`/;01HF5P0/;2`0?3`l0492@P0o?cl0>CTi034a<@0/;2`07AdM00D51@04
0000000:00d=3@1<C4`0QhN70:VYZ@2/[:`0V9RH0861P@1iNGT0MWIf07inOP80QhN701L0OWin07Ee
M@1dM7@0Ng]k08f=S@2NWYh0YJFU09jNWP2?Shl0PH6107alO01fMWH0LW9b06IVIP1@D500=CDe01dM
7@0D51@030`<00d=3@0?3`l030`<00@410020000000700820P0@41007alO02HV9P0P82004Q8B00X:
2P020000000300820P000000000001h00000103AcJT000<0dLfY800000001@0:2PX01PH600<30`02
0P8010@400801@D5100000002`0=3@d05aLG02`/;00i>CT0?Cdm03Lg=`0_;bl0:2PX02DU9@0M7Ad0
3Ph>00<0000003001PH601dM7@1CDe<0Q8B409^KV`2GUiL0PX:2071`L01]KFd0M7Ad08J6QP2ATI40
SHf=07alO01/K6`0JFUY075aL@26QXH0VYZJ09jNWP2=SHd0LW9b05UIF@1BDU80CDe=04m?C`1;Bd/0
>SXj020P80092@T00P8200410@0?3`l08R8R02/[:`0W9bL061PH014A4@092@T02`/;01DE5@0N7Qh0
7AdM01<C4`0<30`00@410000000410@P000000@0dLfY00030=7=ZB00000000<0410@00P820000000
0P0000002@0410@02PX:00d=3@0;2`/01`L700P8200?3`l05ADE028R8P0202TY:@0i02<S8`0M7Ad0
71`L01dM7@0P82007QhN01LG5`0A4A405aLG030`<013@d<0KFe]08b<S02DU9@0Q8B406][J`1MGEd0
GemO075aL@2;Rh/0VIVI092@T01gMgL0HF5Q05aLG01VIVH0PH6109bLW02QXJ40Rh^;069RHP0l?3`0
<30`02LW9`0_;bl0=cLg03<c<`0R8R803Ph>00P820092@T06a/K03<c<`12@T80?clo02d];@0Q8B40
3@d=00D51@0820P04A4A01LG5`0D51@04A4A00T92@051@D020P802000000103AcJT000<0dLfY8000
00002`0@410020P800000000000010@400T92@0E5AD07AdM01hN7P0H61P0410@008030`<03L03Ph>
010@400?3`l030`<00d=3@0E5AD071`L02XZ:P0f=SH0?3`l0451@@1<C4`0I6AT07=cL`2@T900WinO
09JFUP1jNWX0G5aL055AD@1EEED0KVi^08f=S@2LW9`0T92@075aL@1DE5@0Cdm?05YJFP1mOGd0X:2P
0:ZZZP2BTY80H61P02`/;00J6QX02PX:01@D500W9bL0=3@d038b<P0U9BD0820P01dM7@0W9bL0>CTi
04I6AP14A4@0<c<c02LW9`0@41000`<300820P0;2`/051@D00805aLG00<04a<C00h>3P0<30`08000
00040=7=Z@000`3AcJTP0000000700/;2`061PH00P8200<30`0:2PX0410@01dM7@0202HV9P0301`L
700>3Ph00P8200@0000003@00P8200h>3P0P8200:b/[0451@@1DE5@0HF5Q06][J`1jNWX0T92@09fM
W@2b/[80][Jf0:>SX`1oOgl0GEeM051@D01EEED0Kfm_08n?S`2MWId0Shn?06e]K@1>CTh0B4Q805AD
E01jNWX0Xj>S0;>c/`2MWId0IfMW02/[:`0C4a<0000000410@0K6a/0=CDe0451@@0o?cl0>c/k038b
<P0`<300<c<c03Lg=`0e=CD0:RXZ028R8P0C4a<02@T900P8200>3Ph05QHF0P0L71`00`0J6QX05ADE
00l?3`0P000000@0dLfY00030=7=ZB0000000P020P802@0410@020P800l?3`0C4a<06a/K01lO7`0L
71`04A4A00820P050000000;00h>3P0T92@0?Shn04];B`1SHf<0MGEe0861P@2;Rh/0VIVI0:f][@2h
^;P00P3:b/X0502e]KD0T92@06e]K@1MGEd0H61P07EeM@2@T900W9bL08j>SP1_Kfl0De=C04e=C@1I
FET0OWin0:NWY`2j^[X0Z:RX07IfMP0i>CT07alO0P0000004@0@4100;Bd]04A4A01;Bd/0BTY:0451
@@0d=3@0:RXZ02<S8`0N7Qh06ATI01LG5`0D51@04a<C01@D500G5aL06QXJ00807AdM00<06a/K01LG
5`0?3`l0800000040=7=Z@000`3AcJTQ0000000300410@071`L030`<00803`l?00<03Ph>00X:2P04
10@01@0000004P0410@061PH038b<P1?Cdl0Jf][07MgM`2<S8`0UiNG09bLW02PX:00Z:RX0;Rh^032
`/80d];B0=CDe032`/80XZ:R08:2PP80L71`02L0OGem08n?S`2HV9P0SXj>07QhN01UIFD0HV9R06i^
KP2>SXh0/;2`0<30`02c/k<0Rh^;05IFEP0l?3`05QHF00H61P0<30`07QhN03@d=012@T80ADE504=3
@`0f=SH09RHV01HF5P0<30`02PX:00`<300C4a<06QXJ01hN7P0M7Ad06QXJ01LG5`0F5QH051@D018B
4P0=3@d0800000040=7=Z@000`3AcJTQ0000000600820P0:2PX03Ph>00d=3@0;2`/010@41P000000
6P0410@05QHF02h^;P1:BTX0J6QX08>3P`2?Shl0XJ6Q0:RXZ02YZJT0Z:RX0:b/[02i^KT0`L710=3@
d03Bd]80`l?30:NWY`2:RXX0N7Qh07MgM`1oOgl0SHf=09BDU02=SHd0O7al0P1`L700801mOGd0VYZJ
0;Ng]`34a<@0^;Rh09JFUP1WIfL0D51@02TY:@0C4a<03Ph>01HF5P0V9RH0=CDe03/k>`0n?Sh0=cLg
02LW9`0F5QH02@T900H61P0820P04A4A01/K6`0P82007QhN01LG5`0A4A403`l?00h>3P0=3@d02`/;
800000040=7=Z@000`3AcJTQ0000000500T92@0?3`l0410@00P820010@401@000000?P0=3@d061PH
02l_;`18B4P0Hf=S07inOP2JVYX0/[:b0;bl_037alL0b<S80<71`@2g]kL0/[:b0;Fe]@2i^KT0`L71
0<;2`P2g]kL0Xj>S08b<S01mOGd0NGUi07YjNP20P800Q8B408>3P`22PX80QhN708f=S@2QXJ40^;Rh
0<[:bP3>c/h0`l?30:b/[02>SXh0OGem05]KF`0j>SX07AdM00/;2`0820P04a<C01`L700];Bd0=cLg
038b<P0R8R80410@00H61P051@D02`/;01DE5@0J6QX05aLG00d=3@0410@00@410000000410@020P8
800000040=7=Z@000`3AcJTP0000000500/;2`0B4Q8051@D010@400410@01@000000600J6QX0>CTi
04U9B@1UIFD0OWin09FEU@2[Zj/0`L710=CDe03Lg=`0i^KV0>CTi03Hf=P0alO70;Rh^02^[Zh0Zj^[
0:RXZ02RXZ80UiNG08N7Q`1hN7P0KFe]06YZJP80J6QX0140JFUY06i^KP1kNg/0TY:B0:6QX@2o_kl0
emOG0=oOg`3IfMT0bl_;0;bl_02^[Zh0YZJV08n?S`1[Jf/0?Cdm00l?3`030000000<01DE5@0b<S80
?clo03Ph>00T92@0410@00T92@051@D02@T900d=3@0;2`/00P82100000000`0820P000000000000N
000000@0dLfY00030=7=ZB0000000P0F5QH00`0C4a<03@d=00@410030000000<00h>3P0Z:RX0C4a<
06m_K`1oOgl0V9RH0:ZZZP2g]kL0aLG50=GEe@3Vi^H0k^k^0P3hn?P02P3[jn/0eMGE0;bl_02UYJD0
Vi^K08Z:RP1jNWX0JFUY05]KF`1@D50204];B`0=04Y:BP18B4P0B4Q804i>CP1SHf<0R8R809nOW`3:
b/X0jNWY0?3`l03Ti>@0d=3@0<?3``020;no_`040;Ng]`2KVi/0IfMW02PX:0@0000000L09BDU04=3
@`19BDT0>CTi01hN7P0A4A400@4100P0000000<02`/;0000000000007P0000040=7=Z@000`3AcJTP
0000000O01HF5P0?3`l020P800D51@0820P02`/;01HF5P0Y:BT0@d=3069RHP23Ph<0X:2P0:^[Z`2k
^k/0`l?30<O7a`3=cLd0f=SH0>WYj@3alO40oOgm0?knoP3`l?00emOG0;Ng]`2FUYH0QhN706a/K01C
De<0?Cdm02d];@0202DU9@0E02LW9`0Z:RX0:RXZ02LW9`0[:b/0@41006YZJP25QHD0_;bl0>KViP3d
m?@0jNWY0=7Ad@31`L40_kno0<?3``39bLT0_;bl09:BTP1BDU80410@00<0000000L04A4A03Lg=`19
BDT0@D5102PX:00I6AT00P8200L0000000<01PH600h>3P0000007`0000040=7=Z@000`3AcJTP0000
000g00X:2P00000000000000000?3`l071`L03/k>`1LG5`0O7al09RHV02`/;00`L710<O7a`3=cLd0
c<c<0<W9b@3:b/X0d];B0>3Ph03Xj>P0lo?c0?;blP3Rh^80aLG50:6QX@1mOGd0KFe]051@D00f=SH0
7alO00h>3P061PH020P800`<300C4a<051@D010@400>3Ph06a/K03lo?`1JFUX0UYJF0<c<c03Xj>P0
i^KV0=3@d02j^[X0];Bd0;Rh^035aLD0b/[:0;Jf]P24Q8@0@d=300X:2P030000000601`L700c<c<0
=cLg02PX:00M7Ad01`L70`0000001P071`L02`/;00`<300<30`03Ph>010@42000000103AcJT000<0
dLfY90000000200M7Ad0=3@d069RHP2<S8`0ZZZZ0;no_`3;bl/0dM7A0P3Bd]804@3=cLd0alO70<C4
a037alL0clo?0=CDe03IfMT0d];B0;fm_@2LW9`0NGUi05UIF@1<C4`0>3Ph02LW9`0F5QH01`L70080
000000@00`<300X:2P0=3@d01`L70P000000200F5QH0;2`/06IVIP2SXj<0c/k>0=cLg03>c/h0]kNg
0P2YZJT01`2f][H0b<S80<_;b`2c/k<0P8200492@P0V9RH00`0000003P0A4A407AdM01dM7@0I6AT0
3@d=00<30`020P801`L700l?3`0D51@05ADE01@D500A4A403Ph>800000040=7=Z@000`3AcJTS0000
000700L71`0i>CT0E5AD08R8R02`/;00alO70=7Ad@030=?Cd`0C0=;BdP3>c/h0alO70<30`02j^[X0
^;Rh0;Jf]P2`/;00XJ6Q08J6QP1UIFD0ADE502l_;`0Y:BT092@T02<S8`0N7Qh05QHF00d=3@0200X:
2P0300h>3P0@41002PX:00<0000000/02@T903Lg=`1dM7@0Zj^[0<[:bP3<c<`0^k^k0:RXZ02TY:@0
ZZZZ0;no_`020=?Cd`040;Jf]P1oOgl0H61P02@T90@0000000`03@d=010@400A4A403Ph>00`<300=
3@d04A4A01@D500E5AD04a<C00h>3P092@TP000000@0dLfY00030=7=ZB80000000H01@D502l_;`1T
I6@0OWin0:^[Z`38b<P20=?Cd`0?0=3@d03?cll0d=3@0=;BdP3@d=00alO70;Rh^02WYjL0UiNG08n?
S`1mOGd0IfMW04];B`0];Bd051@D00802PX:00/051@D02<S8`0];Bd0;Bd]02HV9P0M7Ad06a/K01TI
6@0H61P04Q8B00D51@030000000A01HF5P1:BTX0Ph>30;6a/@36a/H0a<C40;Fe]@2_[jl0[:b/0;Zj
^P3AdM40hN7Q0=SHf02a/K40U9BD059BDP0F5QH0100000001@061PH04A4A01@D500A4A403Ph>00<0
30`<00<02`/;00P820030`<0800000040=7=Z@000`3AcJTQ0000000H00410@0O7al0C4a<07inOP2F
UYH0^k^k0<k>cP3Bd]80clo?0<_;b`3<c<`0c/k>0=7Ad@3?cll0a<C40;6a/@2JVYX0Ph>307QhN01R
HV80Bd];030`<00E5AD00P820P0000002`0>3Ph08b<S03<c<`0g=cL0<C4a02LW9`0S8b<07QhN01/K
6`0F5QH02`/;00<00000014030`<03Ph>01_Kfl0XJ6Q0<30`037alL0_[jn0;Vi^@2c/k<0^k^k0<o?
c`3QhN40gmoO0<71`@2XZ:P0JFUY02XZ:P040000000700410@0@41005ADE018B4P0=3@d02@T900L7
1`0200H61P0300@410010@40000001l00000103AcJT000<0dLfY800000005`0E5AD0=3@d05mOG`2>
SXh0]KFe0<?3``3Bd]80dM7A0<S8b030`<00_[jn0<?3``37alL0b/[:0<G5a@2c/k<0UYJF07EeM@1E
EED0AdM7030`<00L71`02PX:00@0000000`01PH601lO7`0f=SH0@D5103lo?`0e=CD0;bl_02DU9@0N
7Qh06ATI01<C4`092@T20000000B00<30`0L71`0ATI607YjNP2XZ:P0aLG50<o?c`3>c/h0b<S80<G5
a@3;bl/0emOG0=cLg03?cll0`<30096AT@1GEeL08B4Q100000001@0;2`/04a<C018B4P0:2PX00P82
02D00000103AcJT000<0dLfY80000000300i>CT0JVYZ09nOW`39bLT0g]kN0>7Qh@3GemL0`l?30;2`
/02XZ:P0ZZZZ0;:b/P80]KFe00P0Z:RX08f=S@1ZJVX0ATI602LW9`0K6a/02PX:00410@D000000280
0`<301HF5P0Z:RX0>CTi03hn?P0h>3P0<c<c02HV9P0L71`05aLG01DE5@0A4A402`/;00P820030`<0
2@T9024Q8@1;Bd/0Ogmo0:n_[`3AdM40fMWI0=cLg03Cdm<0b/[:0<O7a`38b<P0alO70<;2`P2ZZZX0
PX:2059BDP0W9bL02PX:0P0000001@061PH03@d=00l?3`0:2PX00@4100@0000000<010@400000000
00007P0000040=7=Z@000`3AcJTP0000000C055AD@2=SHd0a<C40>KViP3YjNT0h>3P0<;2`P2QXJ40
Rh^;08J6QP2=SHd0UIFE09JFUP2>SXh0MgMg05MGE`0e=CD05aLG00820P040000000]00@410051@D0
10@400<30`0410@02PX:01LG5`0U9BD0<30`03<c<`0`<3009RHV01XJ6P0C4a<04A4A01@D500C4a<0
4A4A00L71`0000000P8201/K6`1:BTX0QHF50;Zj^P3>c/h0hN7Q0=cLg039bLT0^;Rh0;:b/P2d];@0
][Jf0;Bd]02SXj<0P82005ADE00Z:RX03@d=00D51@0000001@D500/;2`0<30`01`L700<0000000<0
0P8200P8200000007`0000040=7=Z@000`3AcJTP0000000A059BDP2>SXh0`<300=OGe`3=cLd0_Kfm
09BDU01_Kfl0Fe]K05aLG01VIVH0K6a/06YZJP1JFUX0?Shn01hN7P0410@0100000005@020P803@d=
01HF5P0I6AT05QHF014A4@0820P00@4100@4100?3`l07alO02XZ:P0/;2`0:2PX01dM7@0B4Q803Ph>
018B4P0F5QH05ADE00`<30030000000;01LG5`1?Cdl0SXj>0:ZZZP3?cll0e]KF0<O7a`2a/K40Xj>S
0:FUY@2[Zj/00P2f][H01@2QXJ40N7Qh04I6AP0J6QX02`/;0080000000P01`L700l?3`0?3`l02PX:
00H61P020P8010@400T92B000000103AcJT000<0dLfY800000003`0l?3`0KVi^09JFUP2TY:@0Ti>C
08:2PP1HF5P0=cLg02XZ:P0`<300?3`l0410@00l?3`09bLW00/;2`050000000800@4100>3Ph05aLG
01hN7P0Q8B407QhN01TI6@0<30`20000000<00410@0A4A408R8R02PX:00[:b/08b<S01LG5`0@4100
4A4A01HF5P0G5aL04A4A100000004@0L71`0F5QH07IfMP2WYjL0_[jn0;fm_@2^[Zh0XZ:R0:>SX`2Y
ZJT0]kNg0;no_`2b/[80SHf=05QHF00T92@03`l?0080000000P00@4100l?3`0E5AD0410@00`<3005
1@D010@400L71b000000103AcJT000<0dLfY800000003P0L71`0?3`l05MGE`1OGel0Cdm?0451@@0Q
8B402@T900<30`0<30`061PH01XJ6P0F5QH00`<3100000002`030`<02`/;01@D500F5QH05ADE01HF
5P0I6AT06QXJ01PH600@410010@40080000000`02`/;01dM7@0U9BD0;Bd]02XZ:P0P82005aLG01@D
500G5aL06ATI01LG5`0:2PX40000000@02DU9@0o?cl0LW9b09NGU`2XZ:P0Zj^[0:VYZ@2/[:`0/;2`
0;bl_032`/80]kNg09FEU@1QHF40:b/[01<C4`<0000000L02`/;01@D500B4Q803Ph>00D51@000000
0`<302000000103AcJT000<0dLfY8@0000001@0>3Ph07AdM028R8P0I6AT0410@00@0000000<00`<3
00D51@010@40100000005P061PH061PH01dM7@0M7Ad051@D00T92@0410@01`L700h>3P0A4A404a<C
00h>3P0820P01@D500/;2`0H61P07alO02TY:@0/;2`09bLW020P800K6a/301`L700301DE5@061PH0
00000080000001000`<301@D500m?Cd0IfMW08R8R02OWil0[:b/0;Fe]@2j^[X0`<300<71`@2d];@0
UIFE06MWI`0c<c<06a/K0`0000001@030`<03@d=00d=3@0:2PX00P8202800000103AcJT000<0dLfY
<00000001P0:2PX06QXJ02@T900U9BD071`L00`<30<0000000l010@400/;2`0E5AD06ATI01DE5@0@
41003Ph>018B4P0F5QH07QhN02@T900W9bL09BDU028R8P0Q8B400P0P82000`0M7Ad05QHF00X:2P04
0000000?01@D500h>3P0H61P08F5Q@2PX:00/K6a0;Ng]`2l_;`0^[Zj0:n_[`2FUYH0L71`0492@P0/
;2`01`L700<0000000@01@D500L71`061PH00@418P0000040=7=Z@000`3AcJT_0000000700L71`0C
4a<0820P02DU9@0S8b<061PH00L71`030000000>00410@092@T05QHF01`L700K6a/05ADE010@400?
3`l04A4A01LG5`0N7Qh08b<S02DU9@0T92@2028R8P05024Q8@0O7al071`L01<C4`061PH00`000000
1`051@D08b<S04];B`1bLW80TY:B0:NWY`2][Jd00P2d];@01P2[Zj/0V9RH07MgM`1=CDd0=cLg014A
4@<0000000@00@4100D51@0410@00@418P0000040=7=Z@000`3AcJTU0000000400<30`071`L020P8
00L71`<01PH600T01`L700X:2P0@41005QHF01dM7@0P82007AdM01TI6@0=3@d0100000003@0410@0
2`/;01LG5`0O7al0820P01/K6`0B4Q802`/;00P820092@T03`l?01PH600P82000P0T92@01`0S8b<0
820P020P800P82007QhN01HF5P0820P00`0000003`0410@08b<S04Q8B01YJFT0PH6108V9R@2FUYH0
WYjN0::RXP2MWId0RHV906MWI`1CDe<0:RXZ00T92@030000000300820P030`<010@400800`<38000
00040=7=Z@000`3AcJTP0000000:00H61P010@40000000@4100;2`/03`l?01@D500E5AD04Q8B00h>
3P802PX:00<02`/;00l?3`0D51@00P0H61P0100D51@03@d=00X:2P0410@200410@0@00@4100820P0
3Ph>010@400F5QH06a/K01dM7@0J6QX04a<C00X:2P051@D00@4100<30`0;2`/05ADE01dM7@80820P
0P0N7Qh0100O7al0820P01/K6`0@41040000000>00H61P0N7Qh0=cLg04];B`1EEED0J6QX07inOP2D
U9@0XJ6Q09bLW022PX80Kfm_0451@@0I6AT30000000500820P051@D020P800P820071`L080000004
0=7=Z@000`3AcJTP0000000600`<300:2PX02@T900`<300@41004Q8B0P0E5AD04`0B4Q803@d=00T9
2@071`L020P800X:2P0=3@d03Ph>00/;2`061PH00@41000000010@4020P8014A4@0G5aL06ATI01LG
5`0E5AD00P0B4Q80300C4a<05ADE01<C4`0=3@d02@T900820P0000000P8200/;2`0D51@06QXJ01/K
6`8071`L0P0M7Ad00`0K6a/04Q8B00D51@040000000>00410@0;2`/05QHF01hN7P0e=CD0F5QH07mo
O`2NWYh0YjNW09>CT`20P800D51@028R8P020P820000000500820P061PH02PX:00X:2P0820P08000
00040=7=Z@000`3AcJTP000000D02PX:00H02`/;00`<300<30`02PX:00P8200410@500820P@00000
00/01PH6014A4@0L71`08R8R024Q8@0I6AT051@D00/;2`071`L02@T900h>3P02018B4P0@010@4009
2@T00`<300410@0410@02`/;018B4P0E5AD06QXJ01dM7@0N7Qh07AdM01TI6@0A4A401`L700<30`L0
000000T02`/;03<c<`1UIFD0T92@0:6QX@2BTY80P820051@D00P82000`0000001@030`<01`L700/;
2`0:2PX020P802000000103AcJT000<0dLfY8000000010030`<010@400<30`020P8400410@800P82
00<00@410000000000001@0000003P030`<01PH600l?3`0G5aL07AdM01lO7`0K6a/04Q8B00d=3@04
10@0000000820P0820P0410@0P0D51@04P0A4A402`/;00H61P030`<01@D500/;2`0?3`l05aLG01hN
7P0R8R808B4Q01/K6`0A4A4020P800D51@020P800`<300820PD0000000P061PH04Y:BP1eMGD0RHV9
07emO@1/K6`0@41001DE5@<0000000D00`<300L71`0:2PX02@T900H61P0P000000@0dLfY00030=7=
ZBT0000000<00P8200<30`020P801@0000002P061PH03@d=010@400E5AD05QHF01@D500@41002PX:
00@410020P830000000G00D51@0;2`/0410@018B4P0C4a<04A4A00`<30071`L010@400D51@0820P0
410@01/K6`0T92@09RHV020P800E5AD02PX:00L71`051@D02@T900`<300820P010000000200820P0
;bl_059BDP1SHf<0F5QH04Y:BP0V9RH01@D50`0000001@051@D020P800T92@071`L01@D502000000
103AcJT000<0dLfY9`00000030020P8010@400L71`0820P01`L700H61P030`<0000000410@061PH0
3@d=01<C4`805ADE00<0410@00L71`000000100000001`030`<01@D500@4100410@01PH600P8200=
3@d00P0@41004@0<30`01@D500410@010@401PH6014A4@0N7Qh09RHV02DU9@0L71`0410@00/;2`07
1`L02`/;014A4@0B4Q802`/;00<0000000L00`<301TI6@0^;Rh0=cLg02h^;P0T92@030`<00@00000
00D01`L700T92@092@T01PH600D51@0P000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@00
00040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@00
0`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV90000
00@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY0003
0=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000
103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0
dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@000004
0=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3A
cJV9000000@0dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0
dLfY00030=7=ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=
ZHT00000103AcJT000<0dLfYR@0000040=7=Z@000`3AcJV9000000@0dLfY00030=7=ZHT00000103A
cJT000<0dLfYR@0000040=7=Z@00T03AcJT00900dLfY002@0=7=Z@00T03AcJT00001\
\>"],
  ImageRangeCache->{{{180, 323}, {368.938, 225.938}} -> {-343.407, 416.668, \
1.87239, 1.87239}}]
}, Open  ]],

Cell["\<\
By employing the guide star, an almost optimal inverse filter has \
been obtained that resulted in a restoration of good quality.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  "Conclusions"
}], "Section"],

Cell[TextData[{
  "The NSH\[Dash]RIF iterative blind deconvolution algorithm has been \
outlined. A prototype for the restoration of astronomical images has been \
implemented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", by means of which it is possible to construct simulated data for \
numerical testing as well as processing real data images. \nThe tests carried \
out have shown the effectiveness of the algorithm in returning good quality \
images. The images can have high dimension leading to a large number of \
unknowns. The computing time required by the NSH\[Dash]RIF procedure \
obviously depends on the dimensions of the target image, but are always \
acceptable, being of the order of a few minutes in the case of real ",
  Cell[BoxData[
      \(TraditionalForm\`512\ \[Times]\ 512\)]],
  " images.\nIn this paper some experiments extracted from a wider set, are \
reported; more details of the numerical testing can be found in [5]; a \
comparison with other methods, such as the NAS\[Dash]RIF and the \
NSR\[Dash]RIF methods, that are well known in the field of blind \
deconvolution, is also described in [5].\nThe ",
  StyleBox["FITS", "MR"],
  " package, which can be employed to load and save images in the commonly \
used file format for astronomical images [9], has also been coded as part of \
this work."
}], "Text",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Section"],
  ". Acknowledgements"
}], "Section"],

Cell["\<\
The authors wish to thank Elena Piccolomini, Yaroslav Sergeyev, \
Mark Sofroniou and Vania Sordoni for helpful discussions. This work has been \
partially supported by the GNCS Research Project 2002 \
\[OpenCurlyDoubleQuote]Analysis and Development of Parallel Computational \
Kernels for Problem Solution\[CloseCurlyDoubleQuote].\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][1]\[ThickSpace]\[MediumSpace]Rafael C. \
Gonzalez and Paul Wintz, ",
  StyleBox["Digital Image Processing,",
    FontSlant->"Italic"],
  " Applied Mathematics and Computation Series, Addison\[Dash]Wesley \
Publishing Company, Reading, MA, USA, 1977"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][2]\[ThickSpace]\[MediumSpace]Mario Bertero and \
Patrizia Boccacci, ",
  StyleBox["Introduction to Inverse Problems in Imaging,",
    FontSlant->"Italic"],
  " Institute of Physics Publishing, Philadelphia, PA, USA, April 1998"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][3]\[ThickSpace]\[MediumSpace]Deepa Kundur, ",
  StyleBox["Blind Deconvolution of Still Images using Recursive Inverse \
Filtering,",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " ",
  StyleBox["Master's Thesis",
    FontVariations->{"CompatibilityType"->0}],
  ", Department of Electrical Engineering, University of Toronto, Toronto, \
Ontario, Canada, May 1995. Available electronically from: ",
  ButtonBox["http://www.comm.toronto.edu/~deepa/pdf/masc95.pdf",
    ButtonData:>{
      URL[ "http://www.comm.toronto.edu/~deepa/pdf/masc95.pdf"], None},
    ButtonStyle->"Hyperlink"]
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][4]\[ThickSpace]\[MediumSpace]Michael Kwok-Po \
Ng, Robert J. Plemmons and Sanzheng Qiao, ",
  StyleBox["Regularization of RIF Blind Image Deconvolution,",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  " IEEE Transactions on Image Processing, volume 9, issue 6, pages 1130\
\[Dash]1134, June 2000"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][5]\[ThickSpace]\[MediumSpace]Luca Caucci, ",
  StyleBox["Studio e Realizzazione di un Algoritmo per il Filtraggio Inverso \
di Immagini Astronomiche,",
    FontSlant->"Italic"],
  StyleBox[" Bachelor Thesis, Department of Computer Science, University of \
Bologna, Bologna, Italy, July 2002. In Italian. Available ",
    FontVariations->{"CompatibilityType"->0}],
  "electronically",
  StyleBox[" from: ",
    FontVariations->{"CompatibilityType"->0}],
  ButtonBox["ftp://ftp.cs.unibo.it/pub/spaletta/thesis.ps.gz",
    ButtonData:>{
      URL[ "ftp://ftp.cs.unibo.it/pub/spaletta/thesis.ps.gz"], None},
    ButtonStyle->"Hyperlink"]
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][6]\[ThickSpace]\[MediumSpace]Luca Caucci and \
Giulia Spaletta, ",
  StyleBox["Blind Restoration of Astronomical Images with Mathematica",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[".",
    FontVariations->{"CompatibilityType"->0}],
  " Technical Report, Department of Mathematics, University of Bologna, \
Bologna, Italy, November 2002. Available electronically from: ",
  ButtonBox["ftp://ftp.dm.unibo.it/library/preprints/2002/spaletta/\
preprint0502.ps.gz",
    ButtonData:>{
      URL[ 
      "ftp://ftp.dm.unibo.it/library/preprints/2002/spaletta/preprint0502.ps.\
gz"], None},
    ButtonStyle->"Hyperlink"]
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][7]\[ThickSpace]\[MediumSpace]Jean Baptiste \
Hiriart\[Dash]Urruty and Claude Lemar\[EGrave]chal, ",
  StyleBox["Convex Analysis and Minimization Algorithms 1: Fundamentals, ",
    FontSlant->"Italic"],
  "Grundlehren der mathematischen Wissenschaften 305",
  StyleBox[", ",
    FontSlant->"Italic"],
  "Springer Verlag, 1993"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][",
  
  CounterBox["Reference"],
  "]\[ThickSpace]\[MediumSpace]Jorge Nocedal and Stephen J. Wright, ",
  StyleBox["Numerical Optimization,",
    FontSlant->"Italic"],
  " Springer Series in Operations Research, Springer Verlag, 1999"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][9]\[ThickSpace]\[MediumSpace]NASA (National \
Aeronautics and Space Administration) Science Office of Standards and \
Technology (NOST), ",
  StyleBox["Definition of the Flexible Image Transport System (FITS), \
standard number NOST 100-2.0, ",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  "NASA Goddard Space Flight Center, Greenbelt, MD, USA, March 1999. \
Available electronically from: ",
  ButtonBox["http://archive.stsci.edu/fits/fits_standard/",
    ButtonData:>{
      URL[ "http://archive.stsci.edu/fits/fits_standard/"], None},
    ButtonStyle->"Hyperlink"]
}], "Reference",
  TextAlignment->Left,
  TextJustification->1],

Cell[TextData[{
  "\[ThickSpace]\[MediumSpace][10]\[ThickSpace]Space Telescope Science \
Institute. Available electronically \
from:ftp://ftp.stsci.edu/pub/software/stsdas/testdata/restore/data/jupiter/   \
",
  ButtonBox["http://www.stsci.edu/resources/",
    ButtonData:>{
      URL[ "http://archive.stsci.edu/fits/fits_standard/"], None},
    ButtonStyle->"Hyperlink"],
  "\[MediumSpace]"
}], "Reference",
  TextAlignment->Left,
  TextJustification->1]
}, Open  ]],

Cell["List of Additional Electronic Material", "Section"],

Cell[TextData[StyleBox["BDRestoration.m",
  FontFamily->"Courier"]], "BulletedList",
  FontWeight->"Bold"],

Cell[TextData[StyleBox["FITS.m",
  FontFamily->"Courier"]], "BulletedList",
  FontWeight->"Bold"],

Cell[TextData[StyleBox["PSF.fits",
  FontFamily->"Courier"]], "BulletedList",
  FontWeight->"Bold"],

Cell[TextData[StyleBox["j889.fits",
  FontFamily->"Courier"]], "BulletedList",
  FontWeight->"Bold"],

Cell[TextData[StyleBox["satellite.fits",
  FontFamily->"Courier"]], "BulletedList",
  FontWeight->"Bold"],

Cell["About the Authors", "SectionAboutAuthor"],

Cell["\<\
Luca Caucci received the Bachelor Degree in Computer Science from \
the University of Bologna, Italy, in 2002. From September 2002 and for one \
year he has been a part time collaborator at the Department of Mathematics \
and Biological Chemistry of the same university. His main research interest \
is in image restoration, signal processing and compression.

Giulia Spaletta received her M.Phil. in Computer Science in 1992 from \
Loughborough University, UK. Since 1991 she is a researcher at the \
Mathematics Department of Bologna University, Italy, and a lecturer in both \
the Computer Studies Degree and Medical Studies Degree, at the same \
university. Her research interests are mainly in numerical parallel linear \
algebra and ordinary differential equations.\
\>", "TextAboutAuthor",
  TextAlignment->Left,
  TextJustification->1]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{734, 700},
WindowMargins->{{57, Automatic}, {-8, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
  Inherited, Inherited, Cell[ "Luca Caucci and Giulia Spaletta", "Header"]}, {
    Cell[ "Blind Restoration of Astronomical Images", "Header"], Inherited, 
      Inherited}},
PageFooters->{{None, Inherited, Cell[ 
        TextData[ 
          ValueBox[ "Date"]], "Footer"]}, {Cell[ 
        TextData[ 
          ValueBox[ "Date"]], "Footer"], Inherited, None}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"PostScriptOutputFile":>"paper.ps",
"Magnification"->1},
Magnification->1,
StyleDefinitions -> "TMJv4Style.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 104, 2, 134, "Title"],
Cell[1861, 55, 378, 10, 176, "Author"],
Cell[2242, 67, 973, 18, 186, "Abstract"],

Cell[CellGroupData[{
Cell[3240, 89, 36, 0, 67, "SectionFirst"],
Cell[3279, 91, 980, 29, 62, "Text"],
Cell[4262, 122, 1214, 38, 46, "NumberedEquation"],
Cell[5479, 162, 2749, 104, 98, "Text"],
Cell[8231, 268, 1499, 39, 65, "DisplayFormula"],
Cell[9733, 309, 660, 29, 26, "Text"],
Cell[10396, 340, 986, 36, 44, "Text"],
Cell[11385, 378, 736, 22, 52, "NumberedEquation"],
Cell[12124, 402, 363, 13, 44, "Text"],
Cell[12490, 417, 651, 24, 44, "Text"],
Cell[13144, 443, 3325, 89, 149, "DisplayFormula"],
Cell[16472, 534, 1478, 47, 118, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17987, 586, 38, 0, 65, "Section"],
Cell[18028, 588, 1710, 59, 116, "Text"],
Cell[19741, 649, 125, 4, 24, "BulletedList"],
Cell[19869, 655, 91, 2, 24, "BulletedList"],
Cell[19963, 659, 104, 2, 24, "BulletedList"],
Cell[20070, 663, 90, 2, 24, "BulletedList"],
Cell[20163, 667, 1500, 52, 44, "Text"],
Cell[21666, 721, 1282, 34, 72, "NumberedEquation"],
Cell[22951, 757, 442, 18, 26, "Text"],
Cell[23396, 777, 648, 23, 44, "Text"],
Cell[24047, 802, 725, 23, 48, "NumberedEquation"],
Cell[24775, 827, 280, 12, 26, "Text"],
Cell[25058, 841, 757, 30, 45, "Text"],
Cell[25818, 873, 1065, 29, 34, "NumberedEquation"],
Cell[26886, 904, 395, 9, 62, "Text"],
Cell[27284, 915, 499, 9, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27820, 929, 32, 0, 65, "Section"],
Cell[27855, 931, 1202, 40, 81, "Text"],
Cell[29060, 973, 1347, 33, 59, "NumberedEquation"],
Cell[30410, 1008, 69, 2, 54, "Subsection"],
Cell[30482, 1012, 1247, 43, 63, "Text"],
Cell[31732, 1057, 594, 15, 51, "DisplayFormula"],
Cell[32329, 1074, 178, 7, 26, "Text"],
Cell[32510, 1083, 302, 10, 33, "DisplayFormula"],
Cell[32815, 1095, 298, 8, 44, "Text"],
Cell[33116, 1105, 42, 0, 54, "Subsection"],
Cell[33161, 1107, 455, 15, 44, "Text"],
Cell[33619, 1124, 929, 21, 45, "DisplayFormula"],
Cell[34551, 1147, 89, 2, 26, "Text"],
Cell[34643, 1151, 331, 11, 30, "DisplayFormula"],
Cell[34977, 1164, 589, 20, 44, "Text"],
Cell[35569, 1186, 42, 0, 54, "Subsection"],
Cell[35614, 1188, 828, 24, 80, "Text"],
Cell[36445, 1214, 34, 0, 54, "Subsection"],
Cell[36482, 1216, 366, 15, 26, "Text"],
Cell[36851, 1233, 540, 14, 45, "DisplayFormula"],
Cell[37394, 1249, 19, 0, 26, "Text"],
Cell[37416, 1251, 291, 9, 28, "DisplayFormula"],
Cell[37710, 1262, 500, 14, 62, "Text"],
Cell[38213, 1278, 56, 0, 54, "Subsection"],
Cell[38272, 1280, 513, 14, 44, "Text"],
Cell[38788, 1296, 1143, 23, 152, "Text"],
Cell[39934, 1321, 52, 0, 54, "Subsection"],
Cell[39989, 1323, 367, 8, 62, "Text"],
Cell[40359, 1333, 59, 0, 54, "Subsection"],
Cell[40421, 1335, 992, 26, 98, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41450, 1366, 29, 0, 65, "Section"],
Cell[41482, 1368, 3158, 90, 206, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44677, 1463, 33, 0, 65, "Section"],
Cell[44713, 1465, 1924, 50, 224, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46674, 1520, 37, 0, 65, "Section"],
Cell[46714, 1522, 36, 0, 54, "Subsection"],
Cell[46753, 1524, 472, 10, 80, "Text"],
Cell[47228, 1536, 299, 6, 88, "Input"],
Cell[47530, 1544, 346, 12, 26, "Text"],

Cell[CellGroupData[{
Cell[47901, 1560, 367, 6, 88, "Input"],
Cell[48271, 1568, 15006, 239, 160, 1248, 66, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[63292, 1810, 758, 27, 62, "Text"],
Cell[64053, 1839, 1530, 26, 300, "Input"],
Cell[65586, 1867, 1711, 55, 80, "Text"],

Cell[CellGroupData[{
Cell[67322, 1926, 107, 2, 40, "Input"],
Cell[67432, 1930, 198, 4, 35, "Print"]
}, Open  ]],
Cell[67645, 1937, 449, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[68119, 1954, 109, 2, 61, "Input"],
Cell[68231, 1958, 8196, 161, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[76430, 2121, 29665, 426, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[106110, 2550, 683, 18, 80, "Text"],

Cell[CellGroupData[{
Cell[106818, 2572, 720, 12, 120, "Input"],
Cell[107541, 2586, 48, 1, 41, "Output"]
}, Open  ]],
Cell[107604, 2590, 1905, 54, 152, "Text"],

Cell[CellGroupData[{
Cell[109534, 2648, 963, 16, 168, "Input"],
Cell[110500, 2666, 15773, 254, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[126276, 2922, 44054, 1365, 194, 14828, 1001, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[170345, 4290, 407, 10, 62, "Text"],

Cell[CellGroupData[{
Cell[170777, 4304, 90, 1, 40, "Input"],
Cell[170870, 4307, 15663, 253, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[186536, 4562, 15453, 250, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[201992, 4814, 15819, 255, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[217814, 5071, 15647, 253, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"],
Cell[233464, 5326, 15768, 254, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[249247, 5583, 392, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[249664, 5597, 498, 11, 88, "Input"],
Cell[250165, 5610, 60, 1, 41, "Output"],
Cell[250228, 5613, 16255, 260, 87, 4285, 109, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[266498, 5876, 31, 0, 54, "Subsection"],
Cell[266532, 5878, 381, 11, 45, "Text"],

Cell[CellGroupData[{
Cell[266938, 5893, 209, 4, 79, "Input"],
Cell[267150, 5899, 612440, 8718, 160, 532758, 7731, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[879605, 14620, 1815, 59, 119, "Text"],

Cell[CellGroupData[{
Cell[881445, 14683, 644, 14, 79, "Input"],
Cell[882092, 14699, 613721, 8741, 160, 532881, 7740, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1495828, 23443, 654, 21, 62, "Text"],

Cell[CellGroupData[{
Cell[1496507, 23468, 664, 11, 108, "Input"],
Cell[1497174, 23481, 49, 1, 41, "Output"]
}, Open  ]],
Cell[1497238, 23485, 122, 2, 26, "Text"],

Cell[CellGroupData[{
Cell[1497385, 23491, 58, 1, 40, "Input"],
Cell[1497446, 23494, 600389, 8569, 160, 532758, 7731, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2097850, 32066, 138, 5, 26, "Text"],
Cell[2097991, 32073, 116, 2, 40, "Input"],
Cell[2098110, 32077, 458, 11, 62, "Text"],
Cell[2098571, 32090, 47, 0, 54, "Subsection"],
Cell[2098621, 32092, 315, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[2098961, 32103, 524, 10, 119, "Input"],
Cell[2099488, 32115, 136349, 2137, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2235852, 34255, 186, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[2236063, 34264, 276, 5, 84, "Input"],
Cell[2236342, 34271, 149014, 2294, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2385371, 36568, 511, 10, 80, "Text"],

Cell[CellGroupData[{
Cell[2385907, 36582, 259, 5, 86, "Input"],
Cell[2386169, 36589, 159179, 2419, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2545363, 39011, 228, 6, 44, "Text"],
Cell[2545594, 39019, 965, 20, 173, "Input"],
Cell[2546562, 39041, 208, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[2546795, 39054, 178, 3, 60, "Input"],
Cell[2546976, 39059, 229937, 3293, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2776916, 42354, 199, 4, 35, "Print"]
}, Open  ]],
Cell[2777130, 42361, 427, 9, 80, "Text"],

Cell[CellGroupData[{
Cell[2777582, 42374, 1178, 24, 208, "Input"],
Cell[2778763, 42400, 158725, 2413, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2937491, 44815, 197, 4, 35, "Print"]
}, Open  ]],
Cell[2937703, 44822, 518, 10, 80, "Text"],

Cell[CellGroupData[{
Cell[2938246, 44836, 674, 12, 128, "Input"],
Cell[2938923, 44850, 60, 1, 41, "Output"]
}, Open  ]],
Cell[2938998, 44854, 250, 8, 26, "Text"],

Cell[CellGroupData[{
Cell[2939273, 44866, 57, 1, 40, "Input"],
Cell[2939333, 44869, 157988, 2404, 160, 132880, 2091, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3097336, 47276, 200, 5, 44, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3097573, 47286, 82, 5, 65, "Section"],
Cell[3097658, 47293, 1405, 26, 224, "Text"]
}, Open  ]],
Cell[3099078, 47322, 81, 4, 65, "Section"],
Cell[3099162, 47328, 401, 8, 62, "Text"],

Cell[CellGroupData[{
Cell[3099588, 47340, 29, 0, 65, "Section"],
Cell[3099620, 47342, 360, 9, 36, "Reference"],
Cell[3099983, 47353, 338, 8, 36, "Reference"],
Cell[3100324, 47363, 722, 17, 50, "Reference"],
Cell[3101049, 47382, 435, 10, 36, "Reference"],
Cell[3101487, 47394, 744, 17, 50, "Reference"],
Cell[3102234, 47413, 765, 19, 50, "Reference"],
Cell[3103002, 47434, 436, 11, 36, "Reference"],
Cell[3103441, 47447, 345, 10, 22, "Reference"],
Cell[3103789, 47459, 707, 16, 50, "Reference"],
Cell[3104499, 47477, 455, 12, 36, "Reference"]
}, Open  ]],
Cell[3104969, 47492, 57, 0, 65, "Section"],
Cell[3105029, 47494, 106, 2, 23, "BulletedList"],
Cell[3105138, 47498, 97, 2, 23, "BulletedList"],
Cell[3105238, 47502, 99, 2, 23, "BulletedList"],
Cell[3105340, 47506, 100, 2, 23, "BulletedList"],
Cell[3105443, 47510, 105, 2, 23, "BulletedList"],
Cell[3105551, 47514, 47, 0, 53, "SectionAboutAuthor"],
Cell[3105601, 47516, 853, 15, 146, "TextAboutAuthor"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

